import { ElementRef, OnInit, Renderer2 } from '@angular/core';
import { DynamicPageBackgroundType, DynamicPageResponsiveSize } from '../constants';
import * as i0 from "@angular/core";
/**
 * Dynamic Page Content Host Component.
 *
 * Adds some styles to host element.
 * For internal usage only.
 *
 */
export declare class DynamicPageContentHostComponent implements OnInit {
    readonly elementRef: ElementRef<HTMLElement>;
    protected _renderer: Renderer2;
    /**
     * a unique identifier for this content
     */
    id: string;
    /**
     * sets background for content to `list`, `transparent`, or `solid` background color.
     * Default is `solid`.
     */
    set background(backgroundType: DynamicPageBackgroundType);
    get background(): DynamicPageBackgroundType;
    /**
     * sets size which in turn adds corresponding padding for the size type.
     * size can be `small`, `medium`, `large`, or `extra-large`.
     */
    set size(sizeType: DynamicPageResponsiveSize);
    get size(): DynamicPageResponsiveSize;
    /**
     * @hidden
     * tracking the background value
     */
    private _background;
    /**
     * @hidden
     * tracks the size for responsive padding
     */
    private _size;
    /** @hidden */
    constructor(elementRef: ElementRef<HTMLElement>, _renderer: Renderer2);
    /** @hidden */
    ngOnInit(): void;
    /**
     * @hidden
     * sets the style classes for background property
     * @param background
     */
    private _setBackgroundStyles;
    /**
     * @hidden
     * sets the padding classes
     * @param sizeType
     */
    private _setSize;
    /** @hidden */
    private _removeClassNameToHostElement;
    /** @hidden */
    private _addClassNameToHostElement;
    static ɵfac: i0.ɵɵFactoryDeclaration<DynamicPageContentHostComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DynamicPageContentHostComponent, "fdp-dynamic-page-content-host", never, { "id": { "alias": "id"; "required": false; }; "background": { "alias": "background"; "required": false; }; "size": { "alias": "size"; "required": false; }; }, {}, never, ["*"], true, never>;
}
