import { EventEmitter, TemplateRef } from '@angular/core';
import { Nullable } from '@fundamental-ngx/cdk/utils';
import { DynamicPageBackgroundType, DynamicPageResponsiveSize } from '../../constants';
import * as i0 from "@angular/core";
/** Dynamic Page collapse change event */
export declare class DynamicPageCollapseChangeEvent {
    source: DynamicPageHeaderComponent;
    payload: boolean;
    /**
     * Dynamic Page collapse change event
     * @param source Dynamic Page component
     * @param payload Collapse state
     */
    constructor(source: DynamicPageHeaderComponent, payload: boolean);
}
/**
 * Dynamic Page Header Component.
 *
 * This component is part of Public API
 * used by supplier to declare inputs and template
 *
 */
export declare class DynamicPageHeaderComponent {
    /**
     * whether the header can be collapsed. True by default. If set to false, both pin/collapse buttons disappear
     * and the header stays visible
     */
    collapsible: boolean;
    /**
     * whether the header should be allowed to be pinned or unpinned. When set, the pin button shows up.
     * Pinning the header will make the header stay visible and the collapse button(if present) will disappear until unpinned.
     */
    pinnable: boolean;
    /**
     * the initial state of the header. Set to true if header should be collapsed.
     */
    collapsed: boolean;
    /**
     * ARIA label for button when the header is collapsed
     */
    expandLabel: string;
    /**
     * ARIA label for button when the header is expanded
     */
    collapseLabel: string;
    /** Header role  */
    role: string;
    /**
     * id for header
     */
    id: string;
    /**
     * aria label for header
     */
    headerAriaLabel: Nullable<string>;
    /**
     * aria label for pin state of pin button
     */
    pinAriaLabel: string;
    /**
     * aria label for unpin state of pin button
     */
    unpinAriaLabel: string;
    /**
     * sets background for content to `list`, `transparent`, or `solid` background color.
     * Default is `solid`.
     */
    background: DynamicPageBackgroundType;
    /**
     * sets size which in turn adds corresponding padding for the size type.
     * size can be `small`, `medium`, `large`, or `extra-large`.
     */
    size: DynamicPageResponsiveSize;
    /** Collapse/Expand change event raised */
    collapsedChange: EventEmitter<DynamicPageCollapseChangeEvent>;
    /**
     * @hidden
     * The component view is wrapped in ng-template so
     * component's consumer have to use this templateRef to render it
     * in its view.
     *
     * The template reference to the component view.
     */
    contentTemplateRef: TemplateRef<any>;
    /**
     * @hidden
     * Delegate collapse change event
     */
    _onCollapseChange(collapsed: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DynamicPageHeaderComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DynamicPageHeaderComponent, "fdp-dynamic-page-header", never, { "collapsible": { "alias": "collapsible"; "required": false; }; "pinnable": { "alias": "pinnable"; "required": false; }; "collapsed": { "alias": "collapsed"; "required": false; }; "expandLabel": { "alias": "expandLabel"; "required": false; }; "collapseLabel": { "alias": "collapseLabel"; "required": false; }; "role": { "alias": "role"; "required": false; }; "id": { "alias": "id"; "required": false; }; "headerAriaLabel": { "alias": "headerAriaLabel"; "required": false; }; "pinAriaLabel": { "alias": "pinAriaLabel"; "required": false; }; "unpinAriaLabel": { "alias": "unpinAriaLabel"; "required": false; }; "background": { "alias": "background"; "required": false; }; "size": { "alias": "size"; "required": false; }; }, { "collapsedChange": "collapsedChange"; }, never, ["*"], true, never>;
}
