import { TemplateRef } from '@angular/core';
import { DynamicPageHeader } from '@fundamental-ngx/core/shared';
import { DynamicPageBackgroundType, DynamicPageResponsiveSize } from '../../constants';
import { DynamicPageHeaderSubtitleDirective } from '../../directives/dynamic-page-header-subtitle.directive';
import { DynamicPageHeaderTitleDirective } from '../../directives/dynamic-page-header-title.directive';
import { DynamicPageGlobalActionsComponent } from '../actions/global-actions/dynamic-page-global-actions.component';
import { DynamicPageLayoutActionsComponent } from '../actions/layout-actions/dynamic-page-layout-actions.component';
import { DynamicPageBreadcrumbComponent } from '../breadcrumb/dynamic-page-breadcrumb.component';
import { DynamicPageKeyInfoComponent } from '../key-info/dynamic-page-key-info.component';
import { DynamicPageTitleImageComponent } from './dynamic-page-title-image.component';
import * as i0 from "@angular/core";
/**
 * Dynamic Page Title Component.
 *
 */
export declare class DynamicPageTitleComponent implements DynamicPageHeader {
    /**
     * Page Title
     */
    title: string;
    /** Whether title should wrap instead of truncation. */
    titleWrap: boolean;
    /**
     * Page Subtitle
     */
    subtitle: string;
    /** Whether subtitle should wrap instead of truncation. */
    subtitleWrap: boolean;
    /**
     * sets background for content to `list`, `transparent`, or `solid` background color.
     * Default is `solid`.
     */
    background: DynamicPageBackgroundType;
    /**
     * sets size which in turn adds corresponding padding for the size type.
     * size can be `small`, `medium`, `large`, or `extra-large`.
     */
    size: DynamicPageResponsiveSize;
    /** reference to breadcrumb component */
    breadcrumbComponent: DynamicPageBreadcrumbComponent;
    /** reference to global actions component */
    globalActionsComponent: DynamicPageGlobalActionsComponent;
    /** reference to layout actions component */
    layoutActionsComponent: DynamicPageLayoutActionsComponent;
    /** reference to key-info component */
    keyInfoComponent: DynamicPageKeyInfoComponent;
    /** reference to image component */
    imageComponent: DynamicPageTitleImageComponent;
    /** @hidden */
    _titleDirective: DynamicPageHeaderTitleDirective;
    /** @hidden */
    _subtitleDirective: DynamicPageHeaderSubtitleDirective;
    /**
     * @hidden
     * The component view is wrapped in ng-template so
     * component's consumer have to use this templateRef to render it
     * in its view.
     *
     * The template reference to the component view.
     */
    contentTemplateRef: TemplateRef<any>;
    static ɵfac: i0.ɵɵFactoryDeclaration<DynamicPageTitleComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DynamicPageTitleComponent, "fdp-dynamic-page-title", never, { "title": { "alias": "title"; "required": false; }; "titleWrap": { "alias": "titleWrap"; "required": false; }; "subtitle": { "alias": "subtitle"; "required": false; }; "subtitleWrap": { "alias": "subtitleWrap"; "required": false; }; "background": { "alias": "background"; "required": false; }; "size": { "alias": "size"; "required": false; }; }, {}, ["breadcrumbComponent", "globalActionsComponent", "layoutActionsComponent", "keyInfoComponent", "imageComponent", "_titleDirective", "_subtitleDirective"], ["*"], true, never>;
}
