import { AfterContentInit, AfterViewInit, DestroyRef, DoCheck, ElementRef, EventEmitter, OnDestroy, QueryList, Signal } from '@angular/core';
import { HasElementRef } from '@fundamental-ngx/cdk/utils';
import { DynamicPage } from '@fundamental-ngx/core/dynamic-page';
import { HeadingLevel, TabList } from '@fundamental-ngx/core/shared';
import { IconTabBarItem, IconTabBarTabComponent } from '@fundamental-ngx/platform/icon-tab-bar';
import { BaseComponent } from '@fundamental-ngx/platform/shared';
import { DynamicPageBackgroundType, DynamicPageResponsiveSize } from './constants';
import { DynamicPageContentHostComponent } from './dynamic-page-content/dynamic-page-content-host.component';
import { DynamicPageContentComponent } from './dynamic-page-content/dynamic-page-content.component';
import { DynamicPageFooterComponent } from './dynamic-page-footer/dynamic-page-footer.component';
import { DynamicPageHeaderComponent } from './dynamic-page-header/header/dynamic-page-header.component';
import { DynamicPageTitleComponent } from './dynamic-page-header/title/dynamic-page-title.component';
import { PlatformDynamicPage } from './platform-dynamic-page.interface';
import * as i0 from "@angular/core";
/** Dynamic Page tab change event */
export declare class DynamicPageTabChangeEvent {
    source: DynamicPageContentComponent;
    payload: IconTabBarItem;
    /**
     * Dynamic Page tab change event
     * @param source Dynamic Page component
     * @param payload Tab component
     */
    constructor(source: DynamicPageContentComponent, payload: IconTabBarItem);
}
export declare class DynamicPageComponent extends BaseComponent implements AfterContentInit, AfterViewInit, DoCheck, OnDestroy, PlatformDynamicPage, HasElementRef {
    /** Whether DynamicPage should snap on scroll */
    disableSnapOnScroll: boolean;
    /** Page role  */
    role: string;
    /** Whether or not tabs should be stacked. */
    stackContent: boolean;
    /**
     * sets background for content to `list`, `transparent`, or `solid` background color.
     * Default is `solid`.
     */
    background: DynamicPageBackgroundType;
    /**
     * sets size which in turn adds corresponding padding for the size type.
     * size can be `small`, `medium`, `large`, or `extra-large`.
     */
    size: DynamicPageResponsiveSize;
    /**
     * provided offset in px
     * Should be added, when there is something else at the bottom and dynamic page is not expanded to bottom's corners
     */
    offset: number;
    /** Whether DynamicPage should have responsive sides spacing changing with Page window width.
     * max-width: 599px                         - small
     * min-width: 600px and max-width: 1023px   - medium
     * min-width: 1024px and max-width: 1439px  - large
     * min-width: 1440px                        - extra large
     */
    autoResponsive: boolean;
    /**
     * Whether dynamic page should be expanded in whole page.
     */
    expandContent: boolean;
    /**
     * Tab Change event
     */
    tabChange: EventEmitter<DynamicPageTabChangeEvent>;
    /** reference to title component  */
    titleComponent: DynamicPageTitleComponent;
    /** reference to header component  */
    headerComponent: DynamicPageHeaderComponent;
    /** reference to footer component  */
    footerComponent: DynamicPageFooterComponent;
    /** reference to content component  */
    contentComponent: DynamicPageContentComponent;
    /** reference to content components list */
    contentComponents: QueryList<DynamicPageContentComponent>;
    /** @hidden */
    _dynamicPageComponent: DynamicPage;
    /** @hidden */
    _tabListComponent: TabList;
    /** Reference to tab items components */
    dynamicPageTabs: QueryList<IconTabBarTabComponent>;
    /** @hidden */
    _contentHostComponents: QueryList<DynamicPageContentHostComponent>;
    /** Whether Dynamic page is collapsed */
    collapsed: Signal<boolean>;
    /**
     * @hidden
     * whether tabbed content is present in this page
     */
    _isTabbed: boolean;
    /**
     * @hidden
     * holds the tab content
     */
    _tabs: DynamicPageContentComponent[];
    /**
     * Heading level of the dynamic page header title.
     */
    headingLevel: import("@angular/core").InputSignal<HeadingLevel>;
    /** @hidden */
    _headingLevel: Signal<number>;
    /** @hidden */
    readonly elementRef: ElementRef<HTMLElement>;
    /** @hidden */
    protected _destroyRef: DestroyRef;
    /** toggle the visibility of the header on click of title area. */
    toggleCollapse(): void;
    /** Triggers recheck for spacing and sizing of elements inside DynamicPage. */
    refreshSize(): void;
    /** @hidden */
    ngAfterContentInit(): void;
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden */
    ngDoCheck(): void;
    /**
     * marks the dynamic page tab as selected when the id of the tab is passed
     */
    setSelectedTab(id: string): void;
    /** @hidden */
    _onSelectedTabChange(event: IconTabBarItem): void;
    /** @hidden */
    private _listenToContentComponentsListChanges;
    /** @hidden */
    private _createContentTabs;
    /** @hidden */
    private _isTabContentPresent;
    static ɵfac: i0.ɵɵFactoryDeclaration<DynamicPageComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DynamicPageComponent, "fdp-dynamic-page", never, { "disableSnapOnScroll": { "alias": "disableSnapOnScroll"; "required": false; }; "role": { "alias": "role"; "required": false; }; "stackContent": { "alias": "stackContent"; "required": false; }; "background": { "alias": "background"; "required": false; }; "size": { "alias": "size"; "required": false; }; "offset": { "alias": "offset"; "required": false; }; "autoResponsive": { "alias": "autoResponsive"; "required": false; }; "expandContent": { "alias": "expandContent"; "required": false; }; "headingLevel": { "alias": "headingLevel"; "required": false; "isSignal": true; }; }, { "tabChange": "tabChange"; }, ["titleComponent", "headerComponent", "footerComponent", "contentComponent", "contentComponents"], never, true, never>;
}
