import * as i0 from '@angular/core';
import { Input, HostBinding, ChangeDetectionStrategy, Component, ViewChild, ViewEncapsulation, EventEmitter, Output, inject, TemplateRef, Directive, ContentChild, Injectable, InjectionToken, signal, input, computed, ElementRef, DestroyRef, Optional, ViewChildren, ContentChildren, NgModule } from '@angular/core';
import { startWith } from 'rxjs/operators';
import { NgTemplateOutlet } from '@angular/common';
import { BreadcrumbComponent } from '@fundamental-ngx/core/breadcrumb';
import { DynamicPageComponent as DynamicPageComponent$1, DynamicPageHeaderComponent as DynamicPageHeaderComponent$1, DynamicPageHeaderSubtitleDirective as DynamicPageHeaderSubtitleDirective$1, DynamicPageHeaderTitleDirective as DynamicPageHeaderTitleDirective$1, DynamicPageTitleContentComponent, DynamicPageGlobalActionsComponent as DynamicPageGlobalActionsComponent$1, DynamicPageLayoutActionsComponent as DynamicPageLayoutActionsComponent$1, DynamicPageSubheaderComponent, DynamicPageFooterComponent as DynamicPageFooterComponent$1, DynamicPageContentComponent as DynamicPageContentComponent$1, DynamicPageBreadcrumbComponent as DynamicPageBreadcrumbComponent$1, FD_DYNAMIC_PAGE, patchHeaderI18nTexts } from '@fundamental-ngx/core/dynamic-page';
import { FacetComponent } from '@fundamental-ngx/core/facets';
import { DYNAMIC_PAGE_HEADER_TOKEN, FD_TABLIST } from '@fundamental-ngx/core/shared';
import { FD_LANGUAGE } from '@fundamental-ngx/i18n';
import { IconTabBarComponent, IconTabBarTabComponent } from '@fundamental-ngx/platform/icon-tab-bar';
import * as i1 from '@fundamental-ngx/platform/shared';
import { PlatformConfig, BaseComponent } from '@fundamental-ngx/platform/shared';

const CLASS_NAME = {
    dynamicPage: 'fd-dynamic-page',
    dynamicPageTitleArea: 'fd-dynamic-page__title-area',
    dynamicPageMainContainer: 'fd-dynamic-page__main-container',
    dynamicPageBreadcrumbTitleContainer: 'fd-dynamic-page__breadcrumb-title-container',
    dynamicPageTitleAreaTransparentBg: 'fd-dynamic-page__title-area--transparent-bg',
    dynamicPageTitleAreaCollapsed: 'fd-dynamic-page__title-area--collapsed', // need to use thiis TODO
    dynamicPageTitleContainer: 'fd-dynamic-page__title-container',
    dynamicPageTitle: 'fd-dynamic-page__title',
    dynamicPageTitleMedium: 'fd-dynamic-page__title--md',
    dynamicPageBreadcrumb: 'fd-dynamic-page__breadcrumb',
    dynamicPageKeyInfo: 'fd-dynamic-page__title-content',
    dynamicPageGlobalActions: 'fd-dynamic-page__toolbar',
    dynamicPageLayoutActions: 'fd-dynamic-page__toolbar-actions',
    dynamicPageActionsContainer: 'fd-dynamic-page__actions-container',
    dynamicPageHeader: 'fd-dynamic-page__header',
    dynamicPageCollapsibleHeader: 'fd-dynamic-page__collapsible-header',
    dynamicPageCollapsibleHeaderTransparentBg: 'fd-dynamic-page__collapsible-header--transparent-bg',
    dynamicPageCollapsibleHeaderSmall: 'fd-dynamic-page__collapsible-header--sm',
    dynamicPageCollapsibleHeaderMedium: 'fd-dynamic-page__collapsible-header--md',
    dynamicPageCollapsibleHeaderLarge: 'fd-dynamic-page__collapsible-header--lg',
    dynamicPageCollapsibleHeaderExtraLarge: 'fd-dynamic-page__collapsible-header--xl',
    dynamicPageCollapsibleHeaderPinCollapseNoShadow: 'fd-dynamic-page__collapsible-header-visibility-container--no-shadow',
    dynamicPageTabs: 'fd-dynamic-page__tabs',
    dynamicPageTabsAddShadow: 'fd-dynamic-page__tabs--add-shadow',
    dynamicPageTabsSmall: 'fd-dynamic-page__tabs--sm',
    dynamicPageTabsMedium: 'fd-dynamic-page__tabs--md',
    dynamicPageTabsLarge: 'fd-dynamic-page__tabs--lg',
    dynamicPageTabsExtraLarge: 'fd-dynamic-page__tabs--xl',
    dynamicPageContent: 'fd-dynamic-page__content',
    dynamicPageContentAreaSmall: 'fd-dynamic-page__content--sm',
    dynamicPageContentAreaMedium: 'fd-dynamic-page__content--md',
    dynamicPageContentAreaLarge: 'fd-dynamic-page__content--lg',
    dynamicPageContentAreaExtraLarge: 'fd-dynamic-page__content--xl',
    dynamicPageContentListBg: 'fd-dynamic-page__content--list-bg',
    dynamicPageContentTransparentBg: 'fd-dynamic-page__content--transparent-bg',
    dynamicPageSummarizedTitleArea: 'fd-dynamic-page__summarized-title-area',
    dynamicPageSummarizedTitleAreaSmall: 'fd-dynamic-page__summarized-title-area--sm',
    dynamicPageSummarizedTitleAreaMedium: 'fd-dynamic-page__summarized-title-area--md',
    dynamicPageSummarizedTitleAreaLarge: 'fd-dynamic-page__summarized-title-area--lg',
    dynamicPageSummarizedTitleAreaExtraLarge: 'fd-dynamic-page__summarized-title-area',
    dynamicPageSummarizedTitleAreaNoShadow: 'fd-dynamic-page__summarized-title-area--no-shadow',
    dynamicPageSummarizedTitle: 'fd-dynamic-page__summarized-title',
    dynamicPageSummarizedTitleCollapsed: 'fd-dynamic-page__summarized-title-area--collapsed'
};

const addClassNameToElement = (renderer, element, className) => {
    renderer.addClass(element, className);
};
const removeClassNameFromElement = (renderer, element, className) => {
    renderer.removeClass(element, className);
};

/**
 * Dynamic Page Content Host Component.
 *
 * Adds some styles to host element.
 * For internal usage only.
 *
 */
class DynamicPageContentHostComponent {
    /**
     * sets background for content to `list`, `transparent`, or `solid` background color.
     * Default is `solid`.
     */
    set background(backgroundType) {
        if (backgroundType) {
            this._background = backgroundType;
            this._setBackgroundStyles(backgroundType);
        }
    }
    get background() {
        return this._background;
    }
    /**
     * sets size which in turn adds corresponding padding for the size type.
     * size can be `small`, `medium`, `large`, or `extra-large`.
     */
    set size(sizeType) {
        if (sizeType) {
            this._size = sizeType;
            this._setSize(sizeType);
        }
    }
    get size() {
        return this._size;
    }
    /** @hidden */
    constructor(elementRef, _renderer) {
        this.elementRef = elementRef;
        this._renderer = _renderer;
    }
    /** @hidden */
    ngOnInit() {
        this._addClassNameToHostElement(CLASS_NAME.dynamicPageContent);
        this._addClassNameToHostElement('content-sticker');
        if (this.background) {
            this._setBackgroundStyles(this.background);
        }
        if (this.size) {
            this._setSize(this.size);
        }
    }
    /**
     * @hidden
     * sets the style classes for background property
     * @param background
     */
    _setBackgroundStyles(background) {
        switch (background) {
            case 'transparent':
                this._addClassNameToHostElement(CLASS_NAME.dynamicPageContentTransparentBg);
                break;
            case 'list':
                this._addClassNameToHostElement(CLASS_NAME.dynamicPageContentListBg);
                break;
            case 'solid':
            default:
                this._removeClassNameToHostElement(CLASS_NAME.dynamicPageContentTransparentBg);
                this._removeClassNameToHostElement(CLASS_NAME.dynamicPageContentListBg);
                break;
        }
    }
    /**
     * @hidden
     * sets the padding classes
     * @param sizeType
     */
    _setSize(sizeType) {
        switch (sizeType) {
            case 'small':
                this._addClassNameToHostElement(CLASS_NAME.dynamicPageContentAreaSmall);
                break;
            case 'medium':
                this._addClassNameToHostElement(CLASS_NAME.dynamicPageContentAreaMedium);
                break;
            case 'large':
                this._addClassNameToHostElement(CLASS_NAME.dynamicPageContentAreaLarge);
                break;
            case 'extra-large':
            default:
                this._addClassNameToHostElement(CLASS_NAME.dynamicPageContentAreaExtraLarge);
                break;
        }
    }
    /** @hidden */
    _removeClassNameToHostElement(className) {
        this._renderer.removeClass(this.elementRef.nativeElement, className);
    }
    /** @hidden */
    _addClassNameToHostElement(className) {
        addClassNameToElement(this._renderer, this.elementRef.nativeElement, className);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageContentHostComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: DynamicPageContentHostComponent, isStandalone: true, selector: "fdp-dynamic-page-content-host", inputs: { id: "id", background: "background", size: "size" }, host: { properties: { "attr.id": "this.id" } }, ngImport: i0, template: '<ng-content></ng-content>', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageContentHostComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fdp-dynamic-page-content-host',
                    template: '<ng-content></ng-content>',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.Renderer2 }], propDecorators: { id: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.id']
            }], background: [{
                type: Input
            }], size: [{
                type: Input
            }] } });

/**
 * Dynamic Page Content Component.
 *
 */
class DynamicPageContentComponent {
    /** @hidden */
    constructor(elementRef) {
        this.elementRef = elementRef;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageContentComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: DynamicPageContentComponent, isStandalone: true, selector: "fdp-dynamic-page-content", inputs: { tabLabel: "tabLabel", id: "id", background: "background", size: "size" }, viewQueries: [{ propertyName: "contentTemplateRef", first: true, predicate: ["contentTemplateRef"], descendants: true }], ngImport: i0, template: `
        <ng-template #contentTemplateRef>
            <ng-content></ng-content>
        </ng-template>
    `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageContentComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fdp-dynamic-page-content',
                    template: `
        <ng-template #contentTemplateRef>
            <ng-content></ng-content>
        </ng-template>
    `,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { tabLabel: [{
                type: Input
            }], id: [{
                type: Input
            }], background: [{
                type: Input
            }], size: [{
                type: Input
            }], contentTemplateRef: [{
                type: ViewChild,
                args: ['contentTemplateRef']
            }] } });

class DynamicPageFooterComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageFooterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: DynamicPageFooterComponent, isStandalone: true, selector: "fdp-dynamic-page-footer", viewQueries: [{ propertyName: "contentTemplateRef", first: true, predicate: ["contentTemplateRef"], descendants: true }], ngImport: i0, template: '<ng-template #contentTemplateRef><ng-content></ng-content></ng-template>', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageFooterComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fdp-dynamic-page-footer',
                    template: '<ng-template #contentTemplateRef><ng-content></ng-content></ng-template>',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    standalone: true
                }]
        }], propDecorators: { contentTemplateRef: [{
                type: ViewChild,
                args: ['contentTemplateRef']
            }] } });

/** Dynamic Page collapse change event */
class DynamicPageCollapseChangeEvent {
    /**
     * Dynamic Page collapse change event
     * @param source Dynamic Page component
     * @param payload Collapse state
     */
    constructor(source, payload) {
        this.source = source;
        this.payload = payload;
    }
}
let dynamicPageHeaderId = 0;
/**
 * Dynamic Page Header Component.
 *
 * This component is part of Public API
 * used by supplier to declare inputs and template
 *
 */
class DynamicPageHeaderComponent {
    constructor() {
        /**
         * whether the header can be collapsed. True by default. If set to false, both pin/collapse buttons disappear
         * and the header stays visible
         */
        this.collapsible = true;
        /**
         * whether the header should be allowed to be pinned or unpinned. When set, the pin button shows up.
         * Pinning the header will make the header stay visible and the collapse button(if present) will disappear until unpinned.
         */
        this.pinnable = false;
        /** Header role  */
        this.role = 'region';
        /**
         * id for header
         */
        this.id = `fdp-dynamic-page-header-id-${dynamicPageHeaderId++}`;
        /** Collapse/Expand change event raised */
        this.collapsedChange = new EventEmitter();
    }
    /**
     * @hidden
     * Delegate collapse change event
     */
    _onCollapseChange(collapsed) {
        this.collapsed = collapsed;
        const event = new DynamicPageCollapseChangeEvent(this, collapsed);
        this.collapsedChange.emit(event);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageHeaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: DynamicPageHeaderComponent, isStandalone: true, selector: "fdp-dynamic-page-header", inputs: { collapsible: "collapsible", pinnable: "pinnable", collapsed: "collapsed", expandLabel: "expandLabel", collapseLabel: "collapseLabel", role: "role", id: "id", headerAriaLabel: "headerAriaLabel", pinAriaLabel: "pinAriaLabel", unpinAriaLabel: "unpinAriaLabel", background: "background", size: "size" }, outputs: { collapsedChange: "collapsedChange" }, viewQueries: [{ propertyName: "contentTemplateRef", first: true, predicate: ["contentTemplateRef"], descendants: true }], ngImport: i0, template: `
        <ng-template #contentTemplateRef>
            <ng-content></ng-content>
        </ng-template>
    `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageHeaderComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fdp-dynamic-page-header',
                    template: `
        <ng-template #contentTemplateRef>
            <ng-content></ng-content>
        </ng-template>
    `,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    standalone: true
                }]
        }], propDecorators: { collapsible: [{
                type: Input
            }], pinnable: [{
                type: Input
            }], collapsed: [{
                type: Input
            }], expandLabel: [{
                type: Input
            }], collapseLabel: [{
                type: Input
            }], role: [{
                type: Input
            }], id: [{
                type: Input
            }], headerAriaLabel: [{
                type: Input
            }], pinAriaLabel: [{
                type: Input
            }], unpinAriaLabel: [{
                type: Input
            }], background: [{
                type: Input
            }], size: [{
                type: Input
            }], collapsedChange: [{
                type: Output
            }], contentTemplateRef: [{
                type: ViewChild,
                args: ['contentTemplateRef']
            }] } });

class DynamicPageHeaderSubtitleDirective {
    constructor() {
        /** Template reference. */
        this.templateRef = inject(TemplateRef);
    }
    /** @hidden */
    static ngTemplateContextGuard(dir, ctx) {
        return true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageHeaderSubtitleDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.7", type: DynamicPageHeaderSubtitleDirective, isStandalone: true, selector: "[fdpDynamicPageHeaderSubtitle]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageHeaderSubtitleDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdpDynamicPageHeaderSubtitle]',
                    standalone: true
                }]
        }] });

class DynamicPageHeaderTitleDirective {
    constructor() {
        /** Template reference. */
        this.templateRef = inject(TemplateRef);
    }
    /** @hidden */
    static ngTemplateContextGuard(dir, ctx) {
        return true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageHeaderTitleDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.7", type: DynamicPageHeaderTitleDirective, isStandalone: true, selector: "[fdpDynamicPageHeaderTitle]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageHeaderTitleDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdpDynamicPageHeaderTitle]',
                    standalone: true
                }]
        }] });

class DynamicPageGlobalActionsComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageGlobalActionsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: DynamicPageGlobalActionsComponent, isStandalone: true, selector: "fdp-dynamic-page-global-actions", viewQueries: [{ propertyName: "contentTemplateRef", first: true, predicate: ["contentTemplateRef"], descendants: true }], ngImport: i0, template: '<ng-template #contentTemplateRef><ng-content></ng-content></ng-template>', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageGlobalActionsComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fdp-dynamic-page-global-actions',
                    template: '<ng-template #contentTemplateRef><ng-content></ng-content></ng-template>',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    standalone: true
                }]
        }], propDecorators: { contentTemplateRef: [{
                type: ViewChild,
                args: ['contentTemplateRef']
            }] } });

class DynamicPageLayoutActionsComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageLayoutActionsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: DynamicPageLayoutActionsComponent, isStandalone: true, selector: "fdp-dynamic-page-layout-actions", viewQueries: [{ propertyName: "contentTemplateRef", first: true, predicate: ["contentTemplateRef"], descendants: true }], ngImport: i0, template: '<ng-template #contentTemplateRef><ng-content></ng-content></ng-template>', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageLayoutActionsComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fdp-dynamic-page-layout-actions',
                    template: '<ng-template #contentTemplateRef><ng-content></ng-content></ng-template>',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    standalone: true
                }]
        }], propDecorators: { contentTemplateRef: [{
                type: ViewChild,
                args: ['contentTemplateRef']
            }] } });

class DynamicPageBreadcrumbComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageBreadcrumbComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: DynamicPageBreadcrumbComponent, isStandalone: true, selector: "fdp-dynamic-page-breadcrumb", viewQueries: [{ propertyName: "contentTemplateRef", first: true, predicate: ["contentTemplateRef"], descendants: true }], ngImport: i0, template: `
        <ng-template #contentTemplateRef>
            <ng-content></ng-content>
        </ng-template>
    `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageBreadcrumbComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fdp-dynamic-page-breadcrumb',
                    template: `
        <ng-template #contentTemplateRef>
            <ng-content></ng-content>
        </ng-template>
    `,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    standalone: true
                }]
        }], propDecorators: { contentTemplateRef: [{
                type: ViewChild,
                args: ['contentTemplateRef']
            }] } });

class DynamicPageKeyInfoComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageKeyInfoComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: DynamicPageKeyInfoComponent, isStandalone: true, selector: "fdp-dynamic-page-key-info", viewQueries: [{ propertyName: "contentTemplateRef", first: true, predicate: ["contentTemplateRef"], descendants: true }], ngImport: i0, template: `
        <ng-template #contentTemplateRef>
            <ng-content></ng-content>
        </ng-template>
    `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageKeyInfoComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fdp-dynamic-page-key-info',
                    template: `
        <ng-template #contentTemplateRef>
            <ng-content></ng-content>
        </ng-template>
    `,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    standalone: true
                }]
        }], propDecorators: { contentTemplateRef: [{
                type: ViewChild,
                args: ['contentTemplateRef']
            }] } });

class DynamicPageTitleImageComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageTitleImageComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: DynamicPageTitleImageComponent, isStandalone: true, selector: "fdp-dynamic-page-title-image", viewQueries: [{ propertyName: "contentTemplateRef", first: true, predicate: ["contentTemplateRef"], descendants: true }], ngImport: i0, template: `
        <ng-template #contentTemplateRef>
            <ng-content></ng-content>
        </ng-template>
    `, isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageTitleImageComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fdp-dynamic-page-title-image',
                    template: `
        <ng-template #contentTemplateRef>
            <ng-content></ng-content>
        </ng-template>
    `,
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    standalone: true
                }]
        }], propDecorators: { contentTemplateRef: [{
                type: ViewChild,
                args: ['contentTemplateRef']
            }] } });

/**
 * Dynamic Page Title Component.
 *
 */
class DynamicPageTitleComponent {
    constructor() {
        /** Whether title should wrap instead of truncation. */
        this.titleWrap = false;
        /** Whether subtitle should wrap instead of truncation. */
        this.subtitleWrap = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageTitleComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: DynamicPageTitleComponent, isStandalone: true, selector: "fdp-dynamic-page-title", inputs: { title: "title", titleWrap: "titleWrap", subtitle: "subtitle", subtitleWrap: "subtitleWrap", background: "background", size: "size" }, providers: [
            {
                provide: DYNAMIC_PAGE_HEADER_TOKEN,
                useExisting: DynamicPageTitleComponent
            }
        ], queries: [{ propertyName: "breadcrumbComponent", first: true, predicate: DynamicPageBreadcrumbComponent, descendants: true }, { propertyName: "globalActionsComponent", first: true, predicate: DynamicPageGlobalActionsComponent, descendants: true }, { propertyName: "layoutActionsComponent", first: true, predicate: DynamicPageLayoutActionsComponent, descendants: true }, { propertyName: "keyInfoComponent", first: true, predicate: DynamicPageKeyInfoComponent, descendants: true }, { propertyName: "imageComponent", first: true, predicate: DynamicPageTitleImageComponent, descendants: true }, { propertyName: "_titleDirective", first: true, predicate: DynamicPageHeaderTitleDirective, descendants: true }, { propertyName: "_subtitleDirective", first: true, predicate: DynamicPageHeaderSubtitleDirective, descendants: true }], viewQueries: [{ propertyName: "contentTemplateRef", first: true, predicate: ["contentTemplateRef"], descendants: true }], ngImport: i0, template: '<ng-content></ng-content>', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageTitleComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fdp-dynamic-page-title',
                    template: '<ng-content></ng-content>',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    providers: [
                        {
                            provide: DYNAMIC_PAGE_HEADER_TOKEN,
                            useExisting: DynamicPageTitleComponent
                        }
                    ],
                    standalone: true
                }]
        }], propDecorators: { title: [{
                type: Input
            }], titleWrap: [{
                type: Input
            }], subtitle: [{
                type: Input
            }], subtitleWrap: [{
                type: Input
            }], background: [{
                type: Input
            }], size: [{
                type: Input
            }], breadcrumbComponent: [{
                type: ContentChild,
                args: [DynamicPageBreadcrumbComponent]
            }], globalActionsComponent: [{
                type: ContentChild,
                args: [DynamicPageGlobalActionsComponent]
            }], layoutActionsComponent: [{
                type: ContentChild,
                args: [DynamicPageLayoutActionsComponent]
            }], keyInfoComponent: [{
                type: ContentChild,
                args: [DynamicPageKeyInfoComponent]
            }], imageComponent: [{
                type: ContentChild,
                args: [DynamicPageTitleImageComponent]
            }], _titleDirective: [{
                type: ContentChild,
                args: [DynamicPageHeaderTitleDirective]
            }], _subtitleDirective: [{
                type: ContentChild,
                args: [DynamicPageHeaderSubtitleDirective]
            }], contentTemplateRef: [{
                type: ViewChild,
                args: ['contentTemplateRef']
            }] } });

/**
 * Default options for platform dynamic-page
 * @deprecated use i18n coreDynamicPage key instead
 */
class DynamicPageConfig extends PlatformConfig {
    /** @hidden */
    constructor(platformConfig) {
        super();
        /**
         * aria label for expand/collapse button when the Dynamic Page is collapsed
         */
        this.expandLabel = 'Expand Header';
        /**
         * aria label for expand/collapse button when the Dynamic Page is expanded
         */
        this.collapseLabel = 'Collapse Header';
        /**
         * aria label for pin button when the Dynamic Page should be pinned
         */
        this.pinLabel = 'Pin Header';
        /**
         * aria label for pin button when the Panel should be unpinned
         */
        this.unpinLabel = 'Unpin Header';
        this.contentDensity = platformConfig.contentDensity;
    }
    /**
     * Create Provider factory function
     */
    static createProviderFactory(obj) {
        const useFactory = (platformConfig) => Object.assign(new DynamicPageConfig(platformConfig), obj);
        return useFactory;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageConfig, deps: [{ token: i1.PlatformConfig }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageConfig }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageConfig, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.PlatformConfig }] });

const FDP_DYNAMIC_PAGE = new InjectionToken('FdpDynamicPage Component');

/** Dynamic Page tab change event */
class DynamicPageTabChangeEvent {
    /**
     * Dynamic Page tab change event
     * @param source Dynamic Page component
     * @param payload Tab component
     */
    constructor(source, payload) {
        this.source = source;
        this.payload = payload;
    }
}
class DynamicPageComponent extends BaseComponent {
    constructor() {
        super(...arguments);
        /** Whether DynamicPage should snap on scroll */
        this.disableSnapOnScroll = false;
        /** Page role  */
        this.role = 'region';
        /** Whether or not tabs should be stacked. */
        this.stackContent = false;
        /**
         * sets background for content to `list`, `transparent`, or `solid` background color.
         * Default is `solid`.
         */
        this.background = 'solid';
        /**
         * sets size which in turn adds corresponding padding for the size type.
         * size can be `small`, `medium`, `large`, or `extra-large`.
         */
        this.size = 'extra-large';
        /**
         * provided offset in px
         * Should be added, when there is something else at the bottom and dynamic page is not expanded to bottom's corners
         */
        this.offset = 0;
        /** Whether DynamicPage should have responsive sides spacing changing with Page window width.
         * max-width: 599px                         - small
         * min-width: 600px and max-width: 1023px   - medium
         * min-width: 1024px and max-width: 1439px  - large
         * min-width: 1440px                        - extra large
         */
        this.autoResponsive = true;
        /**
         * Whether dynamic page should be expanded in whole page.
         */
        this.expandContent = true;
        /**
         * Tab Change event
         */
        this.tabChange = new EventEmitter();
        /** Whether Dynamic page is collapsed */
        this.collapsed = signal(false);
        /**
         * @hidden
         * whether tabbed content is present in this page
         */
        this._isTabbed = false;
        /**
         * @hidden
         * holds the tab content
         */
        this._tabs = [];
        /**
         * Heading level of the dynamic page header title.
         */
        this.headingLevel = input(2);
        /** @hidden */
        this._headingLevel = computed(() => Number.parseInt(`${this.headingLevel}`.replace(/\D/g, ''), 10));
        /** @hidden */
        this.elementRef = inject(ElementRef);
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
    }
    /** toggle the visibility of the header on click of title area. */
    toggleCollapse() {
        this._dynamicPageComponent.toggleCollapse();
    }
    /** Triggers recheck for spacing and sizing of elements inside DynamicPage. */
    refreshSize() {
        this._dynamicPageComponent.refreshSize();
    }
    /** @hidden */
    ngAfterContentInit() {
        this._listenToContentComponentsListChanges();
    }
    /** @hidden */
    ngAfterViewInit() {
        this.detectChanges();
        this._tabListComponent?.headerContainer?.nativeElement.classList.add('fd-dynamic-page__tabs');
        this.collapsed = this._dynamicPageComponent.collapsed;
    }
    /** @hidden */
    ngDoCheck() {
        /** Used to detect changes in projected components that displayed using templates,
         * https://github.com/angular/angular/issues/44112
         */
        this.markForCheck();
    }
    /**
     * marks the dynamic page tab as selected when the id of the tab is passed
     */
    setSelectedTab(id) {
        this._tabListComponent.selectTab(id);
    }
    /** @hidden */
    _onSelectedTabChange(event) {
        const content = this.contentComponents.find((contentComponent) => contentComponent.id === event.id);
        content && this.tabChange.emit(new DynamicPageTabChangeEvent(content, event));
    }
    /** @hidden */
    _listenToContentComponentsListChanges() {
        this.contentComponents.changes.pipe(startWith(this.contentComponents)).subscribe(() => {
            this._createContentTabs();
        });
    }
    /** @hidden */
    _createContentTabs() {
        const contentComponents = this.contentComponents.toArray();
        // reset array
        this._tabs = [];
        if (!this._isTabContentPresent(contentComponents)) {
            if (contentComponents.length > 1) {
                throw new Error('Cannot have more than one content section. Use `tabLabel` to have a tabbed navigation.');
            }
            return;
        }
        if (contentComponents) {
            contentComponents.forEach((contentItem) => {
                if (!contentItem.tabLabel && this._isTabbed) {
                    throw new Error('At least one element is already tabbed, please provide a `tabLabel`.');
                }
                else {
                    this._tabs.push(contentItem);
                }
            });
        }
    }
    /** @hidden */
    _isTabContentPresent(contentComponents) {
        contentComponents.forEach((contentComponent) => {
            if (contentComponent.tabLabel) {
                this._isTabbed = true;
                return;
            }
        });
        return this._isTabbed;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.0.7", type: DynamicPageComponent, isStandalone: true, selector: "fdp-dynamic-page", inputs: { disableSnapOnScroll: { classPropertyName: "disableSnapOnScroll", publicName: "disableSnapOnScroll", isSignal: false, isRequired: false, transformFunction: null }, role: { classPropertyName: "role", publicName: "role", isSignal: false, isRequired: false, transformFunction: null }, stackContent: { classPropertyName: "stackContent", publicName: "stackContent", isSignal: false, isRequired: false, transformFunction: null }, background: { classPropertyName: "background", publicName: "background", isSignal: false, isRequired: false, transformFunction: null }, size: { classPropertyName: "size", publicName: "size", isSignal: false, isRequired: false, transformFunction: null }, offset: { classPropertyName: "offset", publicName: "offset", isSignal: false, isRequired: false, transformFunction: null }, autoResponsive: { classPropertyName: "autoResponsive", publicName: "autoResponsive", isSignal: false, isRequired: false, transformFunction: null }, expandContent: { classPropertyName: "expandContent", publicName: "expandContent", isSignal: false, isRequired: false, transformFunction: null }, headingLevel: { classPropertyName: "headingLevel", publicName: "headingLevel", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { tabChange: "tabChange" }, host: { properties: { "attr.role": "this.role" } }, providers: [
            {
                provide: FD_LANGUAGE,
                useFactory: patchHeaderI18nTexts,
                deps: [[new Optional(), DynamicPageConfig]]
            },
            {
                provide: FDP_DYNAMIC_PAGE,
                useExisting: DynamicPageComponent
            }
        ], queries: [{ propertyName: "titleComponent", first: true, predicate: DynamicPageTitleComponent, descendants: true }, { propertyName: "headerComponent", first: true, predicate: DynamicPageHeaderComponent, descendants: true }, { propertyName: "footerComponent", first: true, predicate: DynamicPageFooterComponent, descendants: true }, { propertyName: "contentComponent", first: true, predicate: DynamicPageContentComponent, descendants: true }, { propertyName: "contentComponents", predicate: DynamicPageContentComponent, descendants: true }], viewQueries: [{ propertyName: "_dynamicPageComponent", first: true, predicate: FD_DYNAMIC_PAGE, descendants: true }, { propertyName: "_tabListComponent", first: true, predicate: FD_TABLIST, descendants: true }, { propertyName: "dynamicPageTabs", predicate: IconTabBarTabComponent, descendants: true }, { propertyName: "_contentHostComponents", predicate: DynamicPageContentHostComponent, descendants: true }], usesInheritance: true, ngImport: i0, template: "<fd-dynamic-page\n    [disableSnapOnScroll]=\"disableSnapOnScroll\"\n    [autoResponsive]=\"autoResponsive\"\n    [background]=\"background\"\n    [size]=\"size\"\n    [expandContent]=\"expandContent\"\n    [offset]=\"offset\"\n    [ariaLabel]=\"ariaLabel\"\n>\n    @if (titleComponent) {\n        <fd-dynamic-page-header\n            [title]=\"titleComponent.title\"\n            [titleWrap]=\"titleComponent.titleWrap\"\n            [subtitle]=\"titleComponent.subtitle\"\n            [subtitleWrap]=\"titleComponent.subtitleWrap\"\n            [headingLevel]=\"headingLevel()\"\n        >\n            @if (titleComponent.breadcrumbComponent) {\n                <fd-dynamic-page-breadcrumb>\n                    <ng-template\n                        [ngTemplateOutlet]=\"titleComponent.breadcrumbComponent.contentTemplateRef\"\n                    ></ng-template>\n                </fd-dynamic-page-breadcrumb>\n            }\n            @if (titleComponent._subtitleDirective) {\n                <ng-container\n                    *fdDynamicPageHeaderSubtitle=\"let hidden\"\n                    [ngTemplateOutlet]=\"titleComponent._subtitleDirective.templateRef\"\n                    [ngTemplateOutletContext]=\"{ $implicit: hidden }\"\n                >\n                </ng-container>\n            }\n            @if (titleComponent._titleDirective) {\n                <ng-container\n                    *fdDynamicPageHeaderTitle=\"let hidden\"\n                    [ngTemplateOutlet]=\"titleComponent._titleDirective.templateRef\"\n                    [ngTemplateOutletContext]=\"{ $implicit: hidden }\"\n                >\n                </ng-container>\n            }\n            @if (titleComponent.keyInfoComponent) {\n                <fd-dynamic-page-title-content>\n                    <ng-template [ngTemplateOutlet]=\"titleComponent.keyInfoComponent.contentTemplateRef\"></ng-template>\n                </fd-dynamic-page-title-content>\n            }\n            @if (titleComponent.imageComponent) {\n                <fd-facet type=\"image\">\n                    <ng-template [ngTemplateOutlet]=\"titleComponent.imageComponent.contentTemplateRef\"></ng-template>\n                </fd-facet>\n            }\n            @if (titleComponent.globalActionsComponent) {\n                <fd-dynamic-page-global-actions>\n                    <ng-template\n                        [ngTemplateOutlet]=\"titleComponent.globalActionsComponent.contentTemplateRef\"\n                    ></ng-template>\n                </fd-dynamic-page-global-actions>\n            }\n            @if (titleComponent.layoutActionsComponent) {\n                <fd-dynamic-page-layout-actions>\n                    <ng-template\n                        [ngTemplateOutlet]=\"titleComponent.layoutActionsComponent.contentTemplateRef\"\n                    ></ng-template>\n                </fd-dynamic-page-layout-actions>\n            }\n        </fd-dynamic-page-header>\n    }\n    @if (headerComponent) {\n        <fd-dynamic-page-subheader\n            [collapsed]=\"headerComponent.collapsed\"\n            [collapsible]=\"headerComponent.collapsible\"\n            [pinnable]=\"headerComponent.pinnable\"\n            [expandLabel]=\"headerComponent.expandLabel\"\n            [collapseLabel]=\"headerComponent.collapseLabel\"\n            [id]=\"headerComponent.id\"\n            [headerAriaLabel]=\"headerComponent.headerAriaLabel\"\n            [pinAriaLabel]=\"headerComponent.pinAriaLabel\"\n            [unpinAriaLabel]=\"headerComponent.unpinAriaLabel\"\n            (collapsedChange)=\"headerComponent._onCollapseChange($event)\"\n        >\n            <ng-template [ngTemplateOutlet]=\"headerComponent.contentTemplateRef\"></ng-template>\n        </fd-dynamic-page-subheader>\n    }\n    @if (_isTabbed) {\n        <fdp-icon-tab-bar\n            class=\"fd-tabs-custom\"\n            [stackContent]=\"stackContent\"\n            maxContentHeight=\"auto\"\n            (iconTabSelected)=\"_onSelectedTabChange($event)\"\n            [tabHeadingLevel]=\"_headingLevel() + 1\"\n        >\n            @for (tab of _tabs; track tab) {\n                <fdp-icon-tab-bar-tab [label]=\"tab.tabLabel\" [id]=\"tab.id\">\n                    <fd-dynamic-page-content>\n                        <ng-template\n                            [ngTemplateOutlet]=\"tab.contentTemplateRef\"\n                        ></ng-template> </fd-dynamic-page-content\n                ></fdp-icon-tab-bar-tab>\n            }\n        </fdp-icon-tab-bar>\n    }\n    @if (!_isTabbed && contentComponent) {\n        <fd-dynamic-page-content>\n            <ng-template [ngTemplateOutlet]=\"contentComponent.contentTemplateRef\"></ng-template>\n        </fd-dynamic-page-content>\n    }\n    @if (footerComponent) {\n        <fd-dynamic-page-footer>\n            <ng-template [ngTemplateOutlet]=\"footerComponent.contentTemplateRef\"></ng-template>\n        </fd-dynamic-page-footer>\n    }\n</fd-dynamic-page>\n", styles: [".fd-dynamic-page{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column}.fd-dynamic-page:after,.fd-dynamic-page:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__header-button,.fd-dynamic-page__sr-only{position:absolute;clip:rect(0 0 0 0);border:0;height:1px;margin-block:-1px;margin-inline:-1px;overflow:hidden;padding-block:0;padding-inline:0;white-space:nowrap;width:1px}.fd-dynamic-page__header-button.is-focus,.fd-dynamic-page__header-button:focus{z-index:5}.fd-dynamic-page__header-button.is-focus+.fd-dynamic-page__title-area,.fd-dynamic-page__header-button:focus+.fd-dynamic-page__title-area{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.25rem}.fd-dynamic-page__header-fixed{left:0;position:fixed;right:0;top:0;z-index:3}.fd-dynamic-page__header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-dynamic-page__header:after,.fd-dynamic-page__header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;min-height:3rem;word-wrap:break-word;background-color:var(--sapObjectHeader_Background);z-index:1}.fd-dynamic-page__title-area:after,.fd-dynamic-page__title-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title-area.is-hover,.fd-dynamic-page__title-area:hover{background:var(--sapObjectHeader_Hover_Background);border-bottom:var(--fdDynamicPage_Hover_Border_Bottom);cursor:pointer}.fd-dynamic-page__title-area--collapsed{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-dynamic-page__title-area--collapsed .fd-dynamic-page__title{font-size:var(--fdDynamicPage_Title_Collapsed_Font_Size)}.fd-dynamic-page__title-area[aria-hidden=true]{display:none}.fd-dynamic-page__main-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-dynamic-page__main-container:after,.fd-dynamic-page__main-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-dynamic-page__title-container:after,.fd-dynamic-page__title-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__breadcrumb{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:.5rem .25rem;padding-inline:0}.fd-dynamic-page__breadcrumb:after,.fd-dynamic-page__breadcrumb:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__breadcrumb-title-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-flex:1;-ms-flex:1;flex:1;min-width:0}.fd-dynamic-page__breadcrumb-title-container:after,.fd-dynamic-page__breadcrumb-title-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__breadcrumb-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-dynamic-page__breadcrumb-container:after,.fd-dynamic-page__breadcrumb-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdDynamicPage_Title_Color);font-family:var(--sapFontFamily);font-family:var(--fdDynamicPage_Title_Font_Family);font-size:var(--sapFontSize);font-size:var(--fdDynamicPage_Title_Font_Size);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-dynamic-page__title:after,.fd-dynamic-page__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title .fd-link{color:var(--sapGroup_TitleTextColor);font-size:var(--sapFontHeader3Size);max-width:100%;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;vertical-align:bottom;white-space:nowrap}.fd-dynamic-page__title--wrap{white-space:normal}.fd-dynamic-page__subtitle{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdDynamicPage_Subtitle_Color);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;margin-top:.25rem;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-dynamic-page__subtitle:after,.fd-dynamic-page__subtitle:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__subtitle--wrap{white-space:normal}.fd-dynamic-page__title-content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;padding-inline:1rem 0;text-overflow:ellipsis;vertical-align:baseline;white-space:nowrap}.fd-dynamic-page__title-content:after,.fd-dynamic-page__title-content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title-subtitle-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-dynamic-page__title-subtitle-container:after,.fd-dynamic-page__title-subtitle-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__toolbar-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-margin-start:auto;margin-inline-start:auto}.fd-dynamic-page__toolbar-container:after,.fd-dynamic-page__toolbar-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page .fd-dynamic-page__toolbar{margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-start:1rem;background:transparent;padding-inline-start:1rem}.fd-dynamic-page .fd-dynamic-page__toolbar--actions,.fd-dynamic-page .fd-dynamic-page__toolbar--content{padding-block:0;padding-inline:0}.fd-dynamic-page__summarized-title-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;word-wrap:break-word;background:var(--sapObjectHeader_Background);-webkit-box-shadow:var(--sapContent_HeaderShadow);box-shadow:var(--sapContent_HeaderShadow);height:2rem;z-index:1}.fd-dynamic-page__summarized-title-area:after,.fd-dynamic-page__summarized-title-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__summarized-title-area.is-focus,.fd-dynamic-page__summarized-title-area:focus{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.25rem}.fd-dynamic-page__summarized-title-area--no-shadow{-webkit-box-shadow:none;box-shadow:none}.fd-dynamic-page__summarized-title-area[aria-hidden=true]{display:none}.fd-dynamic-page__summarized-title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapGroup_TitleTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--sapFontHeader5Size);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:2rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-dynamic-page__summarized-title:after,.fd-dynamic-page__summarized-title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-dynamic-page__collapsible-header-container:after,.fd-dynamic-page__collapsible-header-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header{background-color:var(--sapObjectHeader_Background);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:1rem;padding-inline:0}.fd-dynamic-page__collapsible-header:after,.fd-dynamic-page__collapsible-header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header[aria-hidden=true]{display:none}.fd-dynamic-page .fd-dynamic-page__tabs{margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-dynamic-page .fd-dynamic-page__tabs--overflow{overflow:hidden}.fd-dynamic-page .fd-dynamic-page__tabs--add-shadow,.fd-dynamic-page__collapsible-header-visibility-container{-webkit-box-shadow:var(--sapContent_HeaderShadow);box-shadow:var(--sapContent_HeaderShadow)}.fd-dynamic-page__collapsible-header-visibility-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background-color:var(--sapObjectHeader_Background);min-height:.0625rem;z-index:2}.fd-dynamic-page__collapsible-header-visibility-container:after,.fd-dynamic-page__collapsible-header-visibility-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header-visibility-container--left-gradient{background-image:var(--fdDynamicPage_Button_Left_Gradient);height:.0625rem;width:4rem}.fd-dynamic-page__collapsible-header-visibility-container--left-gradient[dir=rtl],[dir=rtl] .fd-dynamic-page__collapsible-header-visibility-container--left-gradient{background-image:var(--fdDynamicPage_Button_Right_Gradient)}.fd-dynamic-page__collapsible-header-visibility-container--right-gradient{background-image:var(--fdDynamicPage_Button_Right_Gradient);height:.0625rem;width:4rem}.fd-dynamic-page__collapsible-header-visibility-container--right-gradient[dir=rtl],[dir=rtl] .fd-dynamic-page__collapsible-header-visibility-container--right-gradient{background-image:var(--fdDynamicPage_Button_Left_Gradient)}.fd-dynamic-page__collapsible-header-visibility-container--button-group{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:var(--fdDynamicPage_Button_Group_Background);height:.0625rem;width:4.25rem;z-index:1}.fd-dynamic-page__collapsible-header-visibility-container--button-group:after,.fd-dynamic-page__collapsible-header-visibility-container--button-group:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header-visibility-container[aria-hidden=true]{display:none}.fd-dynamic-page__collapsible-header-visibility-container--no-shadow{-webkit-box-shadow:none;box-shadow:none}.fd-dynamic-page__collapse-button,.fd-dynamic-page__expand-button,.fd-dynamic-page__pin-button{--fdButtonBackgroundColor:var(--fdDynamicPage_Button_Pin_Background);height:1.5rem;margin-block:0;margin-inline:.25rem;min-width:1.5rem;padding-block:0;padding-inline:0;width:1.5rem}.fd-dynamic-page__collapse-button:before,.fd-dynamic-page__expand-button:before,.fd-dynamic-page__pin-button:before{bottom:-.25rem;height:2rem;top:-.25rem;width:100%}.fd-dynamic-page__collapse-button[aria-hidden=true],.fd-dynamic-page__expand-button[aria-hidden=true],.fd-dynamic-page__pin-button[aria-hidden=true]{display:none}.fd-dynamic-page__content{background-color:var(--sapBackgroundColor);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow-y:auto;padding-block:0;padding-inline:0}.fd-dynamic-page__content:after,.fd-dynamic-page__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__footer{bottom:0;left:0;margin-block:0 .5rem;margin-inline:.5rem;position:fixed;right:0}.fd-dynamic-page--sm .fd-dynamic-page__title-area{padding-block:.5rem;padding-inline:1rem}.fd-dynamic-page--sm .fd-dynamic-page__title-area--collapsed{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-dynamic-page--sm .fd-dynamic-page__collapsible-header,.fd-dynamic-page--sm .fd-dynamic-page__content{padding-block:1rem;padding-inline:1rem}.fd-dynamic-page--sm .fd-dynamic-page__tabs{padding-block:0;padding-inline:1rem}.fd-dynamic-page--sm .fd-dynamic-page__summarized-title-area{padding-block:1rem;padding-inline:1rem}.fd-dynamic-page--sm .fd-dynamic-page__breadcrumb{padding-block:0;padding-inline:0}.fd-dynamic-page--sm .fd-dynamic-page__title-container{-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-dynamic-page--sm .fd-dynamic-page__toolbar{-webkit-padding-start:1rem;padding-inline-start:1rem;-webkit-margin-start:auto;margin-inline-start:auto}.fd-dynamic-page--sm .fd-dynamic-page__toolbar--content{-webkit-margin-start:0;margin-inline-start:0}.fd-dynamic-page--lg .fd-dynamic-page__title-area,.fd-dynamic-page--md .fd-dynamic-page__title-area{padding-block:.5rem;padding-inline:2rem}.fd-dynamic-page--lg .fd-dynamic-page__title-area--collapsed,.fd-dynamic-page--md .fd-dynamic-page__title-area--collapsed{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-dynamic-page--lg .fd-dynamic-page__collapsible-header,.fd-dynamic-page--lg .fd-dynamic-page__content,.fd-dynamic-page--md .fd-dynamic-page__collapsible-header,.fd-dynamic-page--md .fd-dynamic-page__content{padding-block:1rem;padding-inline:2rem}.fd-dynamic-page--lg .fd-dynamic-page__tabs,.fd-dynamic-page--md .fd-dynamic-page__tabs{padding-block:0;padding-inline:2rem}.fd-dynamic-page--lg .fd-dynamic-page__summarized-title-area,.fd-dynamic-page--md .fd-dynamic-page__summarized-title-area{padding-block:1rem;padding-inline:1rem}.fd-dynamic-page--xl .fd-dynamic-page__title-area{padding-block:.5rem;padding-inline:3rem}.fd-dynamic-page--xl .fd-dynamic-page__title-area--collapsed{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-dynamic-page--xl .fd-dynamic-page__collapsible-header,.fd-dynamic-page--xl .fd-dynamic-page__content{padding-block:1rem;padding-inline:3rem}.fd-dynamic-page--xl .fd-dynamic-page__tabs{padding-block:0;padding-inline:3rem}.fd-dynamic-page--xl .fd-dynamic-page__summarized-title-area{padding-block:1rem;padding-inline:1rem}.fd-dynamic-page--md .fd-dynamic-page__toolbar{padding-block:0;padding-inline:0}.fd-dynamic-page--list-bg .fd-dynamic-page__content{background-color:var(--fdDynamicPage_Content_List_Background)}.fd-dynamic-page--transparent-bg .fd-dynamic-page__content{background-color:var(--fdDynamicPage_Content_Transparent_Background)}.fd-dynamic-page--transparent-bg .fd-dynamic-page__title-area{background:var(--fdDynamicPage_Title_Header_Transparent_Background)}.fd-dynamic-page--transparent-bg .fd-dynamic-page__collapsible-header{background-color:var(--fdDynamicPage_Title_Header_Transparent_Background)}.fd-dynamic-page{display:flex;flex-direction:column;height:100%;width:100%}.fd-dynamic-page .fd-dynamic-page__header{z-index:2}.fd-dynamic-page .fd-dynamic-page__content,.fd-dynamic-page .fd-dynamic-page__tabs--overflow{display:block;flex:1}.fd-dynamic-page .fd-dynamic-page__tabs--overflow{display:flex}.fd-dynamic-page .fd-dynamic-page__tabs--overflow .fd-tabs-custom{height:100%;display:flex;flex-direction:column}.fd-dynamic-page .fd-dynamic-page__tabs--overflow .fd-tabs__content{flex:1;display:flex}.fd-dynamic-page .fd-dynamic-page__tabs--overflow .fd-tabs__panel.is-expanded{display:flex}.fd-dynamic-page .footer-spacer{height:3rem}.fd-dynamic-page .content-sticker{position:static}.fd-dynamic-page .fd-dynamic-page__header--not-collapsible .fd-dynamic-page__title-area.is-hover,.fd-dynamic-page .fd-dynamic-page__header--not-collapsible .fd-dynamic-page__title-area:hover{background-color:var(--sapObjectHeader_Background, #fff);cursor:default}\n/*! Bundled license information:\n\nfundamental-styles/dist/dynamic-page.css:\n  (*!\n   * Fundamental Library Styles v0.38.0\n   * Copyright (c) 2024 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "component", type: DynamicPageComponent$1, selector: "fd-dynamic-page", inputs: ["disableSnapOnScroll", "ariaLabel", "ariaRoledescription", "background", "autoResponsive", "size", "offset", "expandContent", "positionRelative"] }, { kind: "component", type: DynamicPageHeaderComponent$1, selector: "fd-dynamic-page-header", inputs: ["title", "titleWrap", "subtitle", "subtitleWrap", "headingLevel", "titleId"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: DynamicPageHeaderSubtitleDirective$1, selector: "[fdDynamicPageHeaderSubtitle]" }, { kind: "directive", type: DynamicPageHeaderTitleDirective$1, selector: "[fdDynamicPageHeaderTitle]" }, { kind: "component", type: DynamicPageTitleContentComponent, selector: "fd-dynamic-page-title-content" }, { kind: "component", type: FacetComponent, selector: "fd-facet", inputs: ["type", "facetTitle", "subtitle", "headingLevel", "id", "alignEnd"] }, { kind: "component", type: DynamicPageGlobalActionsComponent$1, selector: "fd-dynamic-page-global-actions" }, { kind: "component", type: DynamicPageLayoutActionsComponent$1, selector: "fd-dynamic-page-layout-actions" }, { kind: "component", type: DynamicPageSubheaderComponent, selector: "fd-dynamic-page-subheader", inputs: ["collapsible", "pinnable", "collapsed", "expandLabel", "collapseLabel", "id", "headerAriaLabel", "pinAriaLabel", "unpinAriaLabel"], outputs: ["collapsedChange"] }, { kind: "component", type: IconTabBarComponent, selector: "fdp-icon-tab-bar", inputs: ["stackContent", "tabHeadingLevel", "iconTabType", "tabsConfig", "densityMode", "iconTabFont", "enableTabReordering", "showTotalTab", "multiClick", "layoutMode", "iconTabBackground", "iconTabSize", "colorAssociations", "maxContentHeight"], outputs: ["tabsConfigChange", "densityModeChange", "iconTabSelected", "iconTabReordered", "closeTab"] }, { kind: "component", type: IconTabBarTabComponent, selector: "fdp-icon-tab-bar-tab", inputs: ["label", "color", "icon", "iconFont", "counter", "active", "badge", "closable", "id"] }, { kind: "component", type: DynamicPageFooterComponent$1, selector: "fd-dynamic-page-footer" }, { kind: "component", type: DynamicPageContentComponent$1, selector: "fd-dynamic-page-content", inputs: ["tabLabel", "id"] }, { kind: "component", type: DynamicPageBreadcrumbComponent$1, selector: "fd-dynamic-page-breadcrumb" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DynamicPageComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fdp-dynamic-page', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, providers: [
                        {
                            provide: FD_LANGUAGE,
                            useFactory: patchHeaderI18nTexts,
                            deps: [[new Optional(), DynamicPageConfig]]
                        },
                        {
                            provide: FDP_DYNAMIC_PAGE,
                            useExisting: DynamicPageComponent
                        }
                    ], imports: [
                        DynamicPageComponent$1,
                        DynamicPageHeaderComponent$1,
                        BreadcrumbComponent,
                        NgTemplateOutlet,
                        DynamicPageHeaderSubtitleDirective$1,
                        DynamicPageHeaderTitleDirective$1,
                        DynamicPageTitleContentComponent,
                        FacetComponent,
                        DynamicPageGlobalActionsComponent$1,
                        DynamicPageLayoutActionsComponent$1,
                        DynamicPageSubheaderComponent,
                        IconTabBarComponent,
                        IconTabBarTabComponent,
                        DynamicPageContentComponent,
                        DynamicPageFooterComponent,
                        DynamicPageFooterComponent$1,
                        DynamicPageContentComponent$1,
                        DynamicPageBreadcrumbComponent$1
                    ], template: "<fd-dynamic-page\n    [disableSnapOnScroll]=\"disableSnapOnScroll\"\n    [autoResponsive]=\"autoResponsive\"\n    [background]=\"background\"\n    [size]=\"size\"\n    [expandContent]=\"expandContent\"\n    [offset]=\"offset\"\n    [ariaLabel]=\"ariaLabel\"\n>\n    @if (titleComponent) {\n        <fd-dynamic-page-header\n            [title]=\"titleComponent.title\"\n            [titleWrap]=\"titleComponent.titleWrap\"\n            [subtitle]=\"titleComponent.subtitle\"\n            [subtitleWrap]=\"titleComponent.subtitleWrap\"\n            [headingLevel]=\"headingLevel()\"\n        >\n            @if (titleComponent.breadcrumbComponent) {\n                <fd-dynamic-page-breadcrumb>\n                    <ng-template\n                        [ngTemplateOutlet]=\"titleComponent.breadcrumbComponent.contentTemplateRef\"\n                    ></ng-template>\n                </fd-dynamic-page-breadcrumb>\n            }\n            @if (titleComponent._subtitleDirective) {\n                <ng-container\n                    *fdDynamicPageHeaderSubtitle=\"let hidden\"\n                    [ngTemplateOutlet]=\"titleComponent._subtitleDirective.templateRef\"\n                    [ngTemplateOutletContext]=\"{ $implicit: hidden }\"\n                >\n                </ng-container>\n            }\n            @if (titleComponent._titleDirective) {\n                <ng-container\n                    *fdDynamicPageHeaderTitle=\"let hidden\"\n                    [ngTemplateOutlet]=\"titleComponent._titleDirective.templateRef\"\n                    [ngTemplateOutletContext]=\"{ $implicit: hidden }\"\n                >\n                </ng-container>\n            }\n            @if (titleComponent.keyInfoComponent) {\n                <fd-dynamic-page-title-content>\n                    <ng-template [ngTemplateOutlet]=\"titleComponent.keyInfoComponent.contentTemplateRef\"></ng-template>\n                </fd-dynamic-page-title-content>\n            }\n            @if (titleComponent.imageComponent) {\n                <fd-facet type=\"image\">\n                    <ng-template [ngTemplateOutlet]=\"titleComponent.imageComponent.contentTemplateRef\"></ng-template>\n                </fd-facet>\n            }\n            @if (titleComponent.globalActionsComponent) {\n                <fd-dynamic-page-global-actions>\n                    <ng-template\n                        [ngTemplateOutlet]=\"titleComponent.globalActionsComponent.contentTemplateRef\"\n                    ></ng-template>\n                </fd-dynamic-page-global-actions>\n            }\n            @if (titleComponent.layoutActionsComponent) {\n                <fd-dynamic-page-layout-actions>\n                    <ng-template\n                        [ngTemplateOutlet]=\"titleComponent.layoutActionsComponent.contentTemplateRef\"\n                    ></ng-template>\n                </fd-dynamic-page-layout-actions>\n            }\n        </fd-dynamic-page-header>\n    }\n    @if (headerComponent) {\n        <fd-dynamic-page-subheader\n            [collapsed]=\"headerComponent.collapsed\"\n            [collapsible]=\"headerComponent.collapsible\"\n            [pinnable]=\"headerComponent.pinnable\"\n            [expandLabel]=\"headerComponent.expandLabel\"\n            [collapseLabel]=\"headerComponent.collapseLabel\"\n            [id]=\"headerComponent.id\"\n            [headerAriaLabel]=\"headerComponent.headerAriaLabel\"\n            [pinAriaLabel]=\"headerComponent.pinAriaLabel\"\n            [unpinAriaLabel]=\"headerComponent.unpinAriaLabel\"\n            (collapsedChange)=\"headerComponent._onCollapseChange($event)\"\n        >\n            <ng-template [ngTemplateOutlet]=\"headerComponent.contentTemplateRef\"></ng-template>\n        </fd-dynamic-page-subheader>\n    }\n    @if (_isTabbed) {\n        <fdp-icon-tab-bar\n            class=\"fd-tabs-custom\"\n            [stackContent]=\"stackContent\"\n            maxContentHeight=\"auto\"\n            (iconTabSelected)=\"_onSelectedTabChange($event)\"\n            [tabHeadingLevel]=\"_headingLevel() + 1\"\n        >\n            @for (tab of _tabs; track tab) {\n                <fdp-icon-tab-bar-tab [label]=\"tab.tabLabel\" [id]=\"tab.id\">\n                    <fd-dynamic-page-content>\n                        <ng-template\n                            [ngTemplateOutlet]=\"tab.contentTemplateRef\"\n                        ></ng-template> </fd-dynamic-page-content\n                ></fdp-icon-tab-bar-tab>\n            }\n        </fdp-icon-tab-bar>\n    }\n    @if (!_isTabbed && contentComponent) {\n        <fd-dynamic-page-content>\n            <ng-template [ngTemplateOutlet]=\"contentComponent.contentTemplateRef\"></ng-template>\n        </fd-dynamic-page-content>\n    }\n    @if (footerComponent) {\n        <fd-dynamic-page-footer>\n            <ng-template [ngTemplateOutlet]=\"footerComponent.contentTemplateRef\"></ng-template>\n        </fd-dynamic-page-footer>\n    }\n</fd-dynamic-page>\n", styles: [".fd-dynamic-page{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column}.fd-dynamic-page:after,.fd-dynamic-page:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__header-button,.fd-dynamic-page__sr-only{position:absolute;clip:rect(0 0 0 0);border:0;height:1px;margin-block:-1px;margin-inline:-1px;overflow:hidden;padding-block:0;padding-inline:0;white-space:nowrap;width:1px}.fd-dynamic-page__header-button.is-focus,.fd-dynamic-page__header-button:focus{z-index:5}.fd-dynamic-page__header-button.is-focus+.fd-dynamic-page__title-area,.fd-dynamic-page__header-button:focus+.fd-dynamic-page__title-area{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.25rem}.fd-dynamic-page__header-fixed{left:0;position:fixed;right:0;top:0;z-index:3}.fd-dynamic-page__header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-dynamic-page__header:after,.fd-dynamic-page__header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;min-height:3rem;word-wrap:break-word;background-color:var(--sapObjectHeader_Background);z-index:1}.fd-dynamic-page__title-area:after,.fd-dynamic-page__title-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title-area.is-hover,.fd-dynamic-page__title-area:hover{background:var(--sapObjectHeader_Hover_Background);border-bottom:var(--fdDynamicPage_Hover_Border_Bottom);cursor:pointer}.fd-dynamic-page__title-area--collapsed{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-dynamic-page__title-area--collapsed .fd-dynamic-page__title{font-size:var(--fdDynamicPage_Title_Collapsed_Font_Size)}.fd-dynamic-page__title-area[aria-hidden=true]{display:none}.fd-dynamic-page__main-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-dynamic-page__main-container:after,.fd-dynamic-page__main-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-dynamic-page__title-container:after,.fd-dynamic-page__title-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__breadcrumb{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:.5rem .25rem;padding-inline:0}.fd-dynamic-page__breadcrumb:after,.fd-dynamic-page__breadcrumb:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__breadcrumb-title-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-flex:1;-ms-flex:1;flex:1;min-width:0}.fd-dynamic-page__breadcrumb-title-container:after,.fd-dynamic-page__breadcrumb-title-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__breadcrumb-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.fd-dynamic-page__breadcrumb-container:after,.fd-dynamic-page__breadcrumb-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdDynamicPage_Title_Color);font-family:var(--sapFontFamily);font-family:var(--fdDynamicPage_Title_Font_Family);font-size:var(--sapFontSize);font-size:var(--fdDynamicPage_Title_Font_Size);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-dynamic-page__title:after,.fd-dynamic-page__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title .fd-link{color:var(--sapGroup_TitleTextColor);font-size:var(--sapFontHeader3Size);max-width:100%;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;vertical-align:bottom;white-space:nowrap}.fd-dynamic-page__title--wrap{white-space:normal}.fd-dynamic-page__subtitle{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdDynamicPage_Subtitle_Color);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;margin-top:.25rem;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-dynamic-page__subtitle:after,.fd-dynamic-page__subtitle:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__subtitle--wrap{white-space:normal}.fd-dynamic-page__title-content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;padding-inline:1rem 0;text-overflow:ellipsis;vertical-align:baseline;white-space:nowrap}.fd-dynamic-page__title-content:after,.fd-dynamic-page__title-content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__title-subtitle-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-dynamic-page__title-subtitle-container:after,.fd-dynamic-page__title-subtitle-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__toolbar-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-margin-start:auto;margin-inline-start:auto}.fd-dynamic-page__toolbar-container:after,.fd-dynamic-page__toolbar-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page .fd-dynamic-page__toolbar{margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-padding-start:1rem;background:transparent;padding-inline-start:1rem}.fd-dynamic-page .fd-dynamic-page__toolbar--actions,.fd-dynamic-page .fd-dynamic-page__toolbar--content{padding-block:0;padding-inline:0}.fd-dynamic-page__summarized-title-area{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;word-wrap:break-word;background:var(--sapObjectHeader_Background);-webkit-box-shadow:var(--sapContent_HeaderShadow);box-shadow:var(--sapContent_HeaderShadow);height:2rem;z-index:1}.fd-dynamic-page__summarized-title-area:after,.fd-dynamic-page__summarized-title-area:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__summarized-title-area.is-focus,.fd-dynamic-page__summarized-title-area:focus{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.25rem}.fd-dynamic-page__summarized-title-area--no-shadow{-webkit-box-shadow:none;box-shadow:none}.fd-dynamic-page__summarized-title-area[aria-hidden=true]{display:none}.fd-dynamic-page__summarized-title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapGroup_TitleTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-size:var(--sapFontHeader5Size);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:2rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-dynamic-page__summarized-title:after,.fd-dynamic-page__summarized-title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-dynamic-page__collapsible-header-container:after,.fd-dynamic-page__collapsible-header-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header{background-color:var(--sapObjectHeader_Background);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-block:1rem;padding-inline:0}.fd-dynamic-page__collapsible-header:after,.fd-dynamic-page__collapsible-header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header[aria-hidden=true]{display:none}.fd-dynamic-page .fd-dynamic-page__tabs{margin-block:0;margin-inline:0;padding-block:0;padding-inline:0}.fd-dynamic-page .fd-dynamic-page__tabs--overflow{overflow:hidden}.fd-dynamic-page .fd-dynamic-page__tabs--add-shadow,.fd-dynamic-page__collapsible-header-visibility-container{-webkit-box-shadow:var(--sapContent_HeaderShadow);box-shadow:var(--sapContent_HeaderShadow)}.fd-dynamic-page__collapsible-header-visibility-container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background-color:var(--sapObjectHeader_Background);min-height:.0625rem;z-index:2}.fd-dynamic-page__collapsible-header-visibility-container:after,.fd-dynamic-page__collapsible-header-visibility-container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header-visibility-container--left-gradient{background-image:var(--fdDynamicPage_Button_Left_Gradient);height:.0625rem;width:4rem}.fd-dynamic-page__collapsible-header-visibility-container--left-gradient[dir=rtl],[dir=rtl] .fd-dynamic-page__collapsible-header-visibility-container--left-gradient{background-image:var(--fdDynamicPage_Button_Right_Gradient)}.fd-dynamic-page__collapsible-header-visibility-container--right-gradient{background-image:var(--fdDynamicPage_Button_Right_Gradient);height:.0625rem;width:4rem}.fd-dynamic-page__collapsible-header-visibility-container--right-gradient[dir=rtl],[dir=rtl] .fd-dynamic-page__collapsible-header-visibility-container--right-gradient{background-image:var(--fdDynamicPage_Button_Left_Gradient)}.fd-dynamic-page__collapsible-header-visibility-container--button-group{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background:var(--fdDynamicPage_Button_Group_Background);height:.0625rem;width:4.25rem;z-index:1}.fd-dynamic-page__collapsible-header-visibility-container--button-group:after,.fd-dynamic-page__collapsible-header-visibility-container--button-group:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__collapsible-header-visibility-container[aria-hidden=true]{display:none}.fd-dynamic-page__collapsible-header-visibility-container--no-shadow{-webkit-box-shadow:none;box-shadow:none}.fd-dynamic-page__collapse-button,.fd-dynamic-page__expand-button,.fd-dynamic-page__pin-button{--fdButtonBackgroundColor:var(--fdDynamicPage_Button_Pin_Background);height:1.5rem;margin-block:0;margin-inline:.25rem;min-width:1.5rem;padding-block:0;padding-inline:0;width:1.5rem}.fd-dynamic-page__collapse-button:before,.fd-dynamic-page__expand-button:before,.fd-dynamic-page__pin-button:before{bottom:-.25rem;height:2rem;top:-.25rem;width:100%}.fd-dynamic-page__collapse-button[aria-hidden=true],.fd-dynamic-page__expand-button[aria-hidden=true],.fd-dynamic-page__pin-button[aria-hidden=true]{display:none}.fd-dynamic-page__content{background-color:var(--sapBackgroundColor);border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow-y:auto;padding-block:0;padding-inline:0}.fd-dynamic-page__content:after,.fd-dynamic-page__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-dynamic-page__footer{bottom:0;left:0;margin-block:0 .5rem;margin-inline:.5rem;position:fixed;right:0}.fd-dynamic-page--sm .fd-dynamic-page__title-area{padding-block:.5rem;padding-inline:1rem}.fd-dynamic-page--sm .fd-dynamic-page__title-area--collapsed{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-dynamic-page--sm .fd-dynamic-page__collapsible-header,.fd-dynamic-page--sm .fd-dynamic-page__content{padding-block:1rem;padding-inline:1rem}.fd-dynamic-page--sm .fd-dynamic-page__tabs{padding-block:0;padding-inline:1rem}.fd-dynamic-page--sm .fd-dynamic-page__summarized-title-area{padding-block:1rem;padding-inline:1rem}.fd-dynamic-page--sm .fd-dynamic-page__breadcrumb{padding-block:0;padding-inline:0}.fd-dynamic-page--sm .fd-dynamic-page__title-container{-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-dynamic-page--sm .fd-dynamic-page__toolbar{-webkit-padding-start:1rem;padding-inline-start:1rem;-webkit-margin-start:auto;margin-inline-start:auto}.fd-dynamic-page--sm .fd-dynamic-page__toolbar--content{-webkit-margin-start:0;margin-inline-start:0}.fd-dynamic-page--lg .fd-dynamic-page__title-area,.fd-dynamic-page--md .fd-dynamic-page__title-area{padding-block:.5rem;padding-inline:2rem}.fd-dynamic-page--lg .fd-dynamic-page__title-area--collapsed,.fd-dynamic-page--md .fd-dynamic-page__title-area--collapsed{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-dynamic-page--lg .fd-dynamic-page__collapsible-header,.fd-dynamic-page--lg .fd-dynamic-page__content,.fd-dynamic-page--md .fd-dynamic-page__collapsible-header,.fd-dynamic-page--md .fd-dynamic-page__content{padding-block:1rem;padding-inline:2rem}.fd-dynamic-page--lg .fd-dynamic-page__tabs,.fd-dynamic-page--md .fd-dynamic-page__tabs{padding-block:0;padding-inline:2rem}.fd-dynamic-page--lg .fd-dynamic-page__summarized-title-area,.fd-dynamic-page--md .fd-dynamic-page__summarized-title-area{padding-block:1rem;padding-inline:1rem}.fd-dynamic-page--xl .fd-dynamic-page__title-area{padding-block:.5rem;padding-inline:3rem}.fd-dynamic-page--xl .fd-dynamic-page__title-area--collapsed{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-dynamic-page--xl .fd-dynamic-page__collapsible-header,.fd-dynamic-page--xl .fd-dynamic-page__content{padding-block:1rem;padding-inline:3rem}.fd-dynamic-page--xl .fd-dynamic-page__tabs{padding-block:0;padding-inline:3rem}.fd-dynamic-page--xl .fd-dynamic-page__summarized-title-area{padding-block:1rem;padding-inline:1rem}.fd-dynamic-page--md .fd-dynamic-page__toolbar{padding-block:0;padding-inline:0}.fd-dynamic-page--list-bg .fd-dynamic-page__content{background-color:var(--fdDynamicPage_Content_List_Background)}.fd-dynamic-page--transparent-bg .fd-dynamic-page__content{background-color:var(--fdDynamicPage_Content_Transparent_Background)}.fd-dynamic-page--transparent-bg .fd-dynamic-page__title-area{background:var(--fdDynamicPage_Title_Header_Transparent_Background)}.fd-dynamic-page--transparent-bg .fd-dynamic-page__collapsible-header{background-color:var(--fdDynamicPage_Title_Header_Transparent_Background)}.fd-dynamic-page{display:flex;flex-direction:column;height:100%;width:100%}.fd-dynamic-page .fd-dynamic-page__header{z-index:2}.fd-dynamic-page .fd-dynamic-page__content,.fd-dynamic-page .fd-dynamic-page__tabs--overflow{display:block;flex:1}.fd-dynamic-page .fd-dynamic-page__tabs--overflow{display:flex}.fd-dynamic-page .fd-dynamic-page__tabs--overflow .fd-tabs-custom{height:100%;display:flex;flex-direction:column}.fd-dynamic-page .fd-dynamic-page__tabs--overflow .fd-tabs__content{flex:1;display:flex}.fd-dynamic-page .fd-dynamic-page__tabs--overflow .fd-tabs__panel.is-expanded{display:flex}.fd-dynamic-page .footer-spacer{height:3rem}.fd-dynamic-page .content-sticker{position:static}.fd-dynamic-page .fd-dynamic-page__header--not-collapsible .fd-dynamic-page__title-area.is-hover,.fd-dynamic-page .fd-dynamic-page__header--not-collapsible .fd-dynamic-page__title-area:hover{background-color:var(--sapObjectHeader_Background, #fff);cursor:default}\n/*! Bundled license information:\n\nfundamental-styles/dist/dynamic-page.css:\n  (*!\n   * Fundamental Library Styles v0.38.0\n   * Copyright (c) 2024 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], propDecorators: { disableSnapOnScroll: [{
                type: Input
            }], role: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.role']
            }], stackContent: [{
                type: Input
            }], background: [{
                type: Input
            }], size: [{
                type: Input
            }], offset: [{
                type: Input
            }], autoResponsive: [{
                type: Input
            }], expandContent: [{
                type: Input
            }], tabChange: [{
                type: Output
            }], titleComponent: [{
                type: ContentChild,
                args: [DynamicPageTitleComponent]
            }], headerComponent: [{
                type: ContentChild,
                args: [DynamicPageHeaderComponent]
            }], footerComponent: [{
                type: ContentChild,
                args: [DynamicPageFooterComponent]
            }], contentComponent: [{
                type: ContentChild,
                args: [DynamicPageContentComponent]
            }], contentComponents: [{
                type: ContentChildren,
                args: [DynamicPageContentComponent, { descendants: true }]
            }], _dynamicPageComponent: [{
                type: ViewChild,
                args: [FD_DYNAMIC_PAGE]
            }], _tabListComponent: [{
                type: ViewChild,
                args: [FD_TABLIST]
            }], dynamicPageTabs: [{
                type: ViewChildren,
                args: [IconTabBarTabComponent]
            }], _contentHostComponents: [{
                type: ViewChildren,
                args: [DynamicPageContentHostComponent]
            }] } });

const components = [
    DynamicPageComponent,
    DynamicPageTitleComponent,
    DynamicPageKeyInfoComponent,
    DynamicPageBreadcrumbComponent,
    DynamicPageGlobalActionsComponent,
    DynamicPageLayoutActionsComponent,
    DynamicPageHeaderComponent,
    DynamicPageContentComponent,
    DynamicPageFooterComponent,
    DynamicPageTitleImageComponent,
    DynamicPageHeaderSubtitleDirective,
    DynamicPageHeaderTitleDirective
];
class PlatformDynamicPageModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: PlatformDynamicPageModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.0.7", ngImport: i0, type: PlatformDynamicPageModule, imports: [DynamicPageComponent,
            DynamicPageTitleComponent,
            DynamicPageKeyInfoComponent,
            DynamicPageBreadcrumbComponent,
            DynamicPageGlobalActionsComponent,
            DynamicPageLayoutActionsComponent,
            DynamicPageHeaderComponent,
            DynamicPageContentComponent,
            DynamicPageFooterComponent,
            DynamicPageTitleImageComponent,
            DynamicPageHeaderSubtitleDirective,
            DynamicPageHeaderTitleDirective], exports: [DynamicPageComponent,
            DynamicPageTitleComponent,
            DynamicPageKeyInfoComponent,
            DynamicPageBreadcrumbComponent,
            DynamicPageGlobalActionsComponent,
            DynamicPageLayoutActionsComponent,
            DynamicPageHeaderComponent,
            DynamicPageContentComponent,
            DynamicPageFooterComponent,
            DynamicPageTitleImageComponent,
            DynamicPageHeaderSubtitleDirective,
            DynamicPageHeaderTitleDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: PlatformDynamicPageModule, imports: [DynamicPageComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: PlatformDynamicPageModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [...components],
                    exports: [...components]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { CLASS_NAME, DynamicPageBreadcrumbComponent, DynamicPageCollapseChangeEvent, DynamicPageComponent, DynamicPageConfig, DynamicPageContentComponent, DynamicPageContentHostComponent, DynamicPageFooterComponent, DynamicPageGlobalActionsComponent, DynamicPageHeaderComponent, DynamicPageHeaderSubtitleDirective, DynamicPageHeaderTitleDirective, DynamicPageKeyInfoComponent, DynamicPageLayoutActionsComponent, DynamicPageTabChangeEvent, DynamicPageTitleComponent, DynamicPageTitleImageComponent, FDP_DYNAMIC_PAGE, PlatformDynamicPageModule, addClassNameToElement, removeClassNameFromElement };
//# sourceMappingURL=fundamental-ngx-platform-dynamic-page.mjs.map
