import * as i0 from '@angular/core';
import { Input, Component, Directive, EventEmitter, Output, ChangeDetectionStrategy, ViewEncapsulation, inject, DestroyRef, ViewChild, TemplateRef, ContentChild, input, computed, ContentChildren, Optional, NgModule } from '@angular/core';
import { BehaviorSubject, Subject, of, startWith, tap, filter, take as take$1, Subscription, isObservable } from 'rxjs';
import { take } from 'rxjs/operators';
import { BaseDataProvider, DataProvider, isDataSource } from '@fundamental-ngx/platform/shared';
import { NgTemplateOutlet, SlicePipe } from '@angular/common';
import * as i1 from '@angular/forms';
import { NG_VALIDATORS, FormsModule } from '@angular/forms';
import { ButtonComponent } from '@fundamental-ngx/core/button';
import { FormLabelComponent, FormInputMessageGroupComponent, FormControlComponent, FormMessageComponent } from '@fundamental-ngx/core/form';
import { LayoutGridComponent, LayoutGridRowDirective, LayoutGridColDirective } from '@fundamental-ngx/core/layout-grid';
import { ListGroupHeaderDirective, ListTitleDirective, ListLinkDirective, ListIconDirective } from '@fundamental-ngx/core/list';
import { SelectComponent, OptionComponent } from '@fundamental-ngx/core/select';
import { TitleComponent } from '@fundamental-ngx/core/title';
import { FdTranslatePipe } from '@fundamental-ngx/i18n';
import { coerceNumberProperty } from '@angular/cdk/coercion';
import { CdkScrollable } from '@angular/cdk/overlay';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import * as i2 from '@fundamental-ngx/cdk/utils';
import { RepeatDirective, FocusableGridDirective, TemplateDirective, DisplayFnPipe } from '@fundamental-ngx/cdk/utils';
import { BarComponent, BarMiddleDirective, BarElementDirective, BarLeftDirective, BarRightDirective, ButtonBarComponent } from '@fundamental-ngx/core/bar';
import { CheckboxComponent } from '@fundamental-ngx/core/checkbox';
import { InfiniteScrollDirective } from '@fundamental-ngx/core/infinite-scroll';
import { ScrollbarDirective } from '@fundamental-ngx/core/scrollbar';
import { SkeletonComponent } from '@fundamental-ngx/core/skeleton';
import { TableComponent, TableHeaderDirective, TableRowDirective, TableCellDirective, TableBodyDirective, TableTextDirective } from '@fundamental-ngx/core/table';
import { ContentDensityModule } from '@fundamental-ngx/core/content-density';
import { BusyIndicatorComponent } from '@fundamental-ngx/core/busy-indicator';
import * as i1$1 from '@fundamental-ngx/core/dialog';
import { DialogComponent, DialogHeaderComponent, DialogBodyComponent, DialogFooterComponent } from '@fundamental-ngx/core/dialog';
import { TabNavComponent, TabItemDirective, TabLinkDirective, TabTagDirective } from '@fundamental-ngx/core/tabs';
import { TokenizerComponent, TokenComponent, TokenizerInputDirective } from '@fundamental-ngx/core/token';
import { ToolbarItemDirective, ToolbarComponent, ToolbarSpacerDirective } from '@fundamental-ngx/core/toolbar';
import { SearchFieldComponent } from '@fundamental-ngx/platform/search-field';
import { cloneDeep } from 'lodash-es';

class ValueHelpDialogDataSource {
    /** @hidden */
    get isDataLoading() {
        return this._dataLoading;
    }
    /** @hidden */
    constructor(dataProvider) {
        this.dataProvider = dataProvider;
        /** @hidden */
        this._dataChanges = new BehaviorSubject([]);
        /** @hidden */
        this._onDataRequested$ = new Subject();
        /** @hidden */
        this._onDataReceived$ = new Subject();
        /** @hidden */
        this._dataLoading = false;
    }
    /** @hidden */
    match(predicate) {
        this._onDataRequested$.next();
        this._dataLoading = true;
        let searchParam = new Map();
        if (typeof predicate === 'string') {
            searchParam.set('query', predicate);
        }
        else if (predicate instanceof Map) {
            searchParam = predicate;
        }
        this.dataProvider
            .fetch(searchParam)
            .pipe(take(1))
            .subscribe((result) => {
            this._onDataReceived$.next();
            this._dataLoading = false;
            this._dataChanges.next(result);
        }, () => {
            this._onDataReceived$.next();
            this._dataLoading = false;
        });
    }
    /** @hidden */
    open() {
        return this._dataChanges.asObservable();
    }
    /** @hidden */
    onDataRequested() {
        return this._onDataRequested$.asObservable();
    }
    /** @hidden */
    onDataReceived() {
        return this._onDataReceived$.asObservable();
    }
    /** @hidden */
    close() { }
}
class ArrayValueHelpDialogDataSource extends ValueHelpDialogDataSource {
    /** @hidden */
    constructor(data) {
        super(new BaseDataProvider(data));
    }
}
class ObservableValueHelpDialogDataSource extends ValueHelpDialogDataSource {
    /** @hidden */
    constructor(data) {
        super(new BaseDataProvider(data));
    }
}
class VhdDataProvider extends DataProvider {
    /** @hidden */
    constructor(values) {
        super();
        this.values = values;
    }
    /** @hidden */
    fetch(params) {
        let data = this.values;
        const arrayParams = Array.from(params);
        const filterFn = (row) => {
            const rowEntries = Object.entries(row);
            return arrayParams.every(([key, value]) => {
                if (key === '*') {
                    // eslint-disable-next-line @typescript-eslint/no-unused-vars
                    return rowEntries.some(([_rowEntryKey, rowEntryValue]) => String(rowEntryValue).toLowerCase().includes(value.toLowerCase()));
                }
                else {
                    return String(row[key]).toLowerCase().includes(value.toLowerCase());
                }
            });
        };
        if (params.size) {
            data = this.values.filter(filterFn);
        }
        return of(data);
    }
}

var VhdDefineIncludeStrategy;
(function (VhdDefineIncludeStrategy) {
    VhdDefineIncludeStrategy["contains"] = "contains";
    VhdDefineIncludeStrategy["equalTo"] = "equalTo";
    VhdDefineIncludeStrategy["between"] = "between";
    VhdDefineIncludeStrategy["startsWith"] = "startsWith";
    VhdDefineIncludeStrategy["endsWith"] = "endsWith";
    VhdDefineIncludeStrategy["lessThan"] = "lessThan";
    VhdDefineIncludeStrategy["lessThanEqual"] = "lessThanEqual";
    VhdDefineIncludeStrategy["greaterThan"] = "greaterThan";
    VhdDefineIncludeStrategy["greaterThanEqual"] = "greaterThanEqual";
    VhdDefineIncludeStrategy["empty"] = "empty";
})(VhdDefineIncludeStrategy || (VhdDefineIncludeStrategy = {}));
var VhdDefineExcludeStrategy;
(function (VhdDefineExcludeStrategy) {
    VhdDefineExcludeStrategy["not_equalTo"] = "not_equalTo";
    VhdDefineExcludeStrategy["not_empty"] = "not_empty";
})(VhdDefineExcludeStrategy || (VhdDefineExcludeStrategy = {}));

var VhdDefineType;
(function (VhdDefineType) {
    VhdDefineType["include"] = "include";
    VhdDefineType["exclude"] = "exclude";
})(VhdDefineType || (VhdDefineType = {}));

class BaseEntity {
    /** @hidden */
    constructor(strategy, key) {
        /** @hidden */
        this.key = '*';
        /** @hidden */
        this.value = '';
        /** @hidden */
        this.valueTo = '';
        if (key) {
            this.key = key;
        }
        this.strategy = strategy || VhdDefineIncludeStrategy.equalTo;
    }
}
class VhdIncludedEntity extends BaseEntity {
    constructor() {
        super(...arguments);
        /** @hidden */
        this.type = VhdDefineType.include;
    }
}
class VhdExcludedEntity extends BaseEntity {
    constructor() {
        super(...arguments);
        /** @hidden */
        this.type = VhdDefineType.exclude;
    }
}

var VhdTab;
(function (VhdTab) {
    VhdTab[VhdTab["selectFromList"] = 0] = "selectFromList";
    VhdTab[VhdTab["defineConditions"] = 1] = "defineConditions";
    VhdTab[VhdTab["advancedSearch"] = 2] = "advancedSearch";
})(VhdTab || (VhdTab = {}));

// eslint-disable-next-line @angular-eslint/component-class-suffix
class VhdBaseTab {
    /** @hidden */
    get type() {
        return VhdTab.defineConditions;
    }
    /** @hidden */
    constructor(_changeDetectorRef) {
        this._changeDetectorRef = _changeDetectorRef;
        /** Mobile view */
        this.mobile = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: VhdBaseTab, deps: [{ token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: VhdBaseTab, isStandalone: true, selector: "ng-component", inputs: { uid: "uid", tabTitle: "tabTitle", mobile: "mobile" }, ngImport: i0, template: '', isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: VhdBaseTab, decorators: [{
            type: Component,
            args: [{
                    template: '',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }], propDecorators: { uid: [{
                type: Input
            }], tabTitle: [{
                type: Input
            }], mobile: [{
                type: Input
            }] } });

const defaultConditionDisplayFn = (item, filters) => {
    const filter = (filters || []).find((f) => f.key === item.key);
    let value = (() => {
        switch (item.strategy) {
            case VhdDefineIncludeStrategy.empty:
            case VhdDefineExcludeStrategy.not_empty:
                return null;
            case VhdDefineIncludeStrategy.between:
                return `${item.value}...${item.valueTo}`;
            case VhdDefineIncludeStrategy.contains:
                return `*${item.value}*`;
            case VhdDefineIncludeStrategy.equalTo:
                return `=${item.value}`;
            case VhdDefineIncludeStrategy.startsWith:
                return `${item.value}*`;
            case VhdDefineIncludeStrategy.endsWith:
                return `*${item.value}`;
            case VhdDefineIncludeStrategy.greaterThan:
                return `>${item.value}`;
            case VhdDefineIncludeStrategy.greaterThanEqual:
                return `>=${item.value}`;
            case VhdDefineIncludeStrategy.lessThan:
                return `<${item.value}`;
            case VhdDefineIncludeStrategy.lessThanEqual:
                return `<=${item.value}`;
            case VhdDefineExcludeStrategy.not_equalTo:
                return `!(=${item.value})`;
        }
    })();
    if (value && item.type === 'exclude') {
        value = `!(${value})`;
    }
    if (filter) {
        return `${filter.label}: ${value}`;
    }
    return value;
};

const MAX_CHARACTER_HINT_COUNT = 7;

class ConditionCountMessageDirective {
    /** Max characters allowed */
    set maxCharacters(value) {
        this._maxCharacters = coerceNumberProperty(value);
    }
    get maxCharacters() {
        return this._maxCharacters;
    }
    /** @hidden */
    constructor() {
        /** @hidden */
        this._maxCharacters = Number.MAX_SAFE_INTEGER;
        this.validator = this.checkError();
    }
    /** @hidden */
    validate(control) {
        return this.validator(control);
    }
    /** @hidden */
    checkError() {
        return (control) => {
            if (control.dirty && control.value && control.value.length > this.maxCharacters) {
                return {
                    maxCharacters: {
                        actualLength: control.value.length,
                        requiredLength: this.maxCharacters
                    }
                };
            }
            return null;
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ConditionCountMessageDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.7", type: ConditionCountMessageDirective, isStandalone: true, selector: "[fdp-condition-count-message]", inputs: { maxCharacters: "maxCharacters" }, providers: [{ provide: NG_VALIDATORS, useExisting: ConditionCountMessageDirective, multi: true }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ConditionCountMessageDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[fdp-condition-count-message]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: ConditionCountMessageDirective, multi: true }],
                    standalone: true
                }]
        }], ctorParameters: () => [], propDecorators: { maxCharacters: [{
                type: Input
            }] } });

/* eslint-disable @typescript-eslint/member-ordering */
class ExtendedBaseEntity extends BaseEntity {
}
class ExtendedIncludedEntity extends VhdIncludedEntity {
}
class ExtendedExcludedEntity extends VhdExcludedEntity {
}
let titleUniqueId$1 = 0;
class DefineTabComponent extends VhdBaseTab {
    constructor() {
        super(...arguments);
        /** @hidden */
        this.defaultId = `fd-title-id-${titleUniqueId$1++}`;
        /** @hidden */
        this.defaultSelectId = `fd-select-title-id-${titleUniqueId$1++}`;
        /** title id for the table  */
        this.titleId = this.defaultId;
        /** seelcted value id for the table  */
        this.selectedId = this.defaultSelectId;
        /** @hidden */
        this.conditions = [];
        /** @hidden */
        this.strategyLabels = {};
        /** @hidden */
        this.includeChange = new EventEmitter();
        /** @hidden */
        this.excludeChange = new EventEmitter();
        /** @hidden */
        this.conditionChange = new EventEmitter();
        /** @hidden */
        this._conditions = [];
        /** @hidden */
        this._definePanelState = {
            included: false,
            excluded: false
        };
        /** @hidden */
        this._rules = {
            maxCharactersHintCount: MAX_CHARACTER_HINT_COUNT
        };
        /** @hidden */
        this._strategyIncludeValues = VhdDefineIncludeStrategy;
        /** @hidden */
        this._strategyExcludeValues = VhdDefineExcludeStrategy;
        /** @hidden */
        this._defineTypes = VhdDefineType;
        /** @hidden */
        this._includeStrategy = [];
        /** @hidden */
        this._excludeStrategy = [];
    }
    /** @hidden */
    ngOnChanges(changes) {
        if ('conditions' in changes) {
            this._conditions = this.conditions || [];
            this._initializeConditions();
        }
    }
    /** @hidden */
    ngAfterViewInit() {
        this._refreshStrategies();
    }
    /** @hidden Track function for main data */
    _trackByKeyAndType(_index, item) {
        if (item) {
            return item.id + item.key + item.type;
        }
        return undefined;
    }
    /** @hidden */
    _onSelectStrategy() {
        this._filterChanged();
    }
    /** @hidden */
    _filterChanged() {
        this.conditionChange.emit(this._conditions);
        this._changeDetectorRef.markForCheck();
    }
    /** @hidden */
    addEmptyCondition() {
        const item = new ExtendedBaseEntity();
        item.value = '';
        this._conditions.push(item);
        this._filterChanged();
    }
    /** @hidden */
    removeCondition(index) {
        this._conditions.splice(index, 1);
        this._initializeConditions();
        this._filterChanged();
        this._changeDetectorRef.markForCheck();
    }
    /** @hidden */
    _validateConditionValue(item, valid) {
        item.valid = Array.isArray(valid) ? valid.every(Boolean) : !!valid;
        this._filterChanged();
    }
    /** @hidden */
    _refreshStrategies() {
        this._includeStrategy = Object.keys(VhdDefineIncludeStrategy).map((key) => ({
            key,
            type: VhdDefineType.include
        }));
        this._excludeStrategy = Object.keys(VhdDefineExcludeStrategy).map((key) => ({
            key,
            type: VhdDefineType.exclude
        }));
    }
    /** @hidden */
    _initializeConditions() {
        if (this._conditions.length === 0) {
            this.addEmptyCondition();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DefineTabComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.0.7", type: DefineTabComponent, isStandalone: true, selector: "fdp-define-tab", inputs: { titleId: "titleId", selectedId: "selectedId", conditions: "conditions", strategyLabels: "strategyLabels" }, outputs: { includeChange: "includeChange", excludeChange: "excludeChange", conditionChange: "conditionChange" }, usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "<h5 [id]=\"titleId\" role=\"heading\" aria-level=\"5\" fd-title class=\"define-condition-title\">\n    {{ 'platformVHD.defineConditionTitle' | fdTranslate }}\n</h5>\n@for (item of _conditions; track _trackByKeyAndType(i, item); let i = $index) {\n    <fd-layout-grid class=\"condition-row\">\n        <div fdLayoutGridRow>\n            <div [fdLayoutGridCol]=\"4\">\n                <label id=\"CONDITIONPANEL_OPERATOR_LABEL\" fd-form-label class=\"fdp-value-help-dialog__hidden_label\">\n                    CONDITIONPANEL_OPERATOR_LABEL\n                </label>\n                <label [id]=\"selectedId\" fd-form-label class=\"fdp-value-help-dialog__hidden_label\">\n                    {{\n                        'platformVHD.defineConditionSelectedValueHiddenA11yLabel'\n                            | fdTranslate: { value: item.strategy }\n                    }}</label\n                >\n                <fd-select\n                    class=\"vhd-condition-filters\"\n                    fdLayoutGridCol\n                    colGrow\n                    [class.fd-select-custom-class]=\"false\"\n                    #sttr\n                    [controlTemplate]=\"customSelectTemplate\"\n                    [name]=\"uid + '-' + type + '-strategy-' + item.id\"\n                    [(ngModel)]=\"item.strategy\"\n                    (valueChange)=\"_filterChanged()\"\n                    role=\"combobox\"\n                    aria-roledescription=\"select\"\n                    aria-haspopup=\"listbox\"\n                    [inline]=\"false\"\n                    [ariaLabelledBy]=\"titleId + ' ' + 'CONDITIONPANEL_OPERATOR_LABEL' + ' ' + selectedId\"\n                >\n                    @if (_includeStrategy.length) {\n                        <li fd-list-group-header>\n                            <span fd-list-title>{{\n                                'platformVHD.defineConditionConditionsGroupHeaderInclude' | fdTranslate\n                            }}</span>\n                        </li>\n                        @for (strategy of _includeStrategy; track strategy) {\n                            <li fd-option [value]=\"strategy.key\">\n                                <ng-template\n                                    [ngTemplateOutlet]=\"conditionStrategyOption\"\n                                    [ngTemplateOutletContext]=\"{ type: _defineTypes.include, strategy: strategy }\"\n                                ></ng-template>\n                            </li>\n                        }\n                    }\n                    @if (_excludeStrategy.length) {\n                        <li fd-list-group-header>\n                            <span fd-list-title>{{\n                                'platformVHD.defineConditionConditionsGroupHeaderExclude' | fdTranslate\n                            }}</span>\n                        </li>\n                        @for (strategy of _excludeStrategy; track strategy) {\n                            <li fd-option [value]=\"strategy.key\">\n                                <ng-template\n                                    [ngTemplateOutlet]=\"conditionStrategyOption\"\n                                    [ngTemplateOutletContext]=\"{ type: _defineTypes.exclude, strategy: strategy }\"\n                                ></ng-template>\n                            </li>\n                        }\n                    }\n                </fd-select>\n            </div>\n            @if (item.strategy !== _strategyIncludeValues.empty && item.strategy !== _strategyExcludeValues.not_empty) {\n                <div fdLayoutGridCol colGrow>\n                    <div fdLayoutGridRow>\n                        @if (item.strategy === _strategyIncludeValues.between) {\n                            <div fdLayoutGridCol colGrow>\n                                <fd-form-input-message-group [triggers]=\"['focusin', 'focusout']\">\n                                    <input\n                                        fd-form-control\n                                        fdp-condition-count-message\n                                        [maxCharacters]=\"_rules.maxCharactersHintCount\"\n                                        type=\"text\"\n                                        [placeholder]=\"'platformVHD.defineConditionFromPlaceholder' | fdTranslate\"\n                                        placeholder=\"from\"\n                                        required\n                                        [state]=\"fromModel.invalid ? 'error' : null\"\n                                        [name]=\"uid + '-' + type + '-from-' + item.id\"\n                                        (blur)=\"_validateConditionValue(item, [!!fromModel.valid, !!toModel.valid])\"\n                                        #fromModel=\"ngModel\"\n                                        [(ngModel)]=\"item.value\"\n                                    />\n                                    <ng-template\n                                        [ngTemplateOutlet]=\"countError\"\n                                        [ngTemplateOutletContext]=\"{ $implicit: item.value && item.value.length }\"\n                                    ></ng-template>\n                                </fd-form-input-message-group>\n                            </div>\n                            <div fdLayoutGridCol colGrow>\n                                <fd-form-input-message-group [triggers]=\"['focusin', 'focusout']\">\n                                    <input\n                                        fd-form-control\n                                        fdp-condition-count-message\n                                        [maxCharacters]=\"_rules.maxCharactersHintCount\"\n                                        type=\"text\"\n                                        [placeholder]=\"'platformVHD.defineConditionToPlaceholder' | fdTranslate\"\n                                        required\n                                        [state]=\"toModel.invalid ? 'error' : null\"\n                                        [name]=\"uid + '-' + type + '-to-' + item.id\"\n                                        (blur)=\"_validateConditionValue(item, [!!fromModel.valid, !!toModel.valid])\"\n                                        #toModel=\"ngModel\"\n                                        [(ngModel)]=\"item.valueTo\"\n                                    />\n                                    <ng-template\n                                        [ngTemplateOutlet]=\"countError\"\n                                        [ngTemplateOutletContext]=\"{ $implicit: item.value && item.value.length }\"\n                                    ></ng-template>\n                                </fd-form-input-message-group>\n                            </div>\n                        } @else {\n                            <div fdLayoutGridCol colGrow>\n                                <fd-form-input-message-group>\n                                    <input\n                                        fd-form-control\n                                        fdp-condition-count-message\n                                        [maxCharacters]=\"_rules.maxCharactersHintCount\"\n                                        type=\"text\"\n                                        [placeholder]=\"'platformVHD.defineConditionValuePlaceholder' | fdTranslate\"\n                                        [state]=\"valueModel.invalid ? 'error' : null\"\n                                        [name]=\"uid + '-' + type + '-value-' + item.id\"\n                                        (blur)=\"_validateConditionValue(item, !!valueModel.valid)\"\n                                        #valueModel=\"ngModel\"\n                                        [(ngModel)]=\"item.value\"\n                                    />\n                                    @if (valueModel.invalid) {\n                                        <ng-template\n                                            [ngTemplateOutlet]=\"countError\"\n                                            [ngTemplateOutletContext]=\"{ $implicit: item.value && item.value.length }\"\n                                        ></ng-template>\n                                    }\n                                </fd-form-input-message-group>\n                            </div>\n                        }\n                    </div>\n                </div>\n            }\n            <div class=\"action-col\" fdLayoutGridCol colGrow>\n                <button\n                    fd-button\n                    [ariaLabel]=\"'platformVHD.defineConditionRemoveConditionButtonTitle' | fdTranslate\"\n                    fdType=\"transparent\"\n                    glyph=\"decline\"\n                    [title]=\"'platformVHD.defineConditionRemoveConditionButtonTitle' | fdTranslate\"\n                    (click)=\"removeCondition(i)\"\n                ></button>\n            </div>\n        </div>\n    </fd-layout-grid>\n}\n<fd-layout-grid class=\"condition-row new-condition-row\" [noGap]=\"true\">\n    <div fdLayoutGridRow>\n        <div fdLayoutGridCol colGrow>&nbsp;</div>\n        <div fdLayoutGridCol class=\"action-col\">\n            <button\n                fd-button\n                [attr.aria-label]=\"'platformVHD.defineConditionAddConditionButtonTitle' | fdTranslate\"\n                [label]=\"'platformVHD.defineConditionAddConditionButtonLabel' | fdTranslate\"\n                [title]=\"'platformVHD.defineConditionAddConditionButtonTitle' | fdTranslate\"\n                (click)=\"addEmptyCondition()\"\n            ></button>\n        </div>\n    </div>\n</fd-layout-grid>\n<ng-template #conditionStrategyOption let-type=\"type\" let-strategy=\"strategy\">\n    @switch (strategy.key) {\n        @case ('contains') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelContains' | fdTranslate }}\n        }\n        @case ('equalTo') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelEqualTo' | fdTranslate }}\n        }\n        @case ('between') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelBetween' | fdTranslate }}\n        }\n        @case ('startsWith') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelStartsWith' | fdTranslate }}\n        }\n        @case ('endsWith') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelEndsWith' | fdTranslate }}\n        }\n        @case ('lessThan') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelLessThan' | fdTranslate }}\n        }\n        @case ('lessThanEqual') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelLessThanEqual' | fdTranslate }}\n        }\n        @case ('greaterThan') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelGreaterThan' | fdTranslate }}\n        }\n        @case ('greaterThanEqual') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelGreaterThanEqual' | fdTranslate }}\n        }\n        @case ('empty') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelEmpty' | fdTranslate }}\n        }\n        @case ('not_equalTo') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelNotEqualTo' | fdTranslate }}\n        }\n        @case ('not_empty') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelNotEmpty' | fdTranslate }}\n        }\n    }\n</ng-template>\n<ng-template #countError let-count>\n    @if (count && count > 7) {\n        <fd-form-message type=\"error\">\n            {{ 'platformVHD.defineConditionMaxCountError' | fdTranslate: { count: 7 } }}\n        </fd-form-message>\n    }\n</ng-template>\n<ng-template #customSelectTemplate let-textValue>\n    {{ textValue }}\n</ng-template>\n", styles: [".fdp-value-help-dialog fdp-define-tab{height:100%;overflow:auto}.fdp-value-help-dialog fdp-define-tab .define-condition-title{padding:.625rem 0 0}.fdp-value-help-dialog fdp-define-tab .condition-row{padding:0}.fdp-value-help-dialog fdp-define-tab .condition-row .fd-col{padding-top:0;padding-bottom:0}.fdp-value-help-dialog .vhd-condition-filters fd-popover{width:100%}.fdp-value-help-dialog .condition-row{align-items:center}.fdp-value-help-dialog .condition-row .main-col{min-width:auto;flex:1 1 auto}.fdp-value-help-dialog .condition-row .action-col{display:flex;align-items:center;min-width:auto;flex:0 0 auto}.fdp-value-help-dialog .condition-row.new-condition-row{padding-top:.5rem}.fdp-value-help-dialog .condition-row.new-condition-row .fd-button{margin-right:1rem}.fd-list--dropdown .fd-list__item.fd-list__group-header{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_GroupHeaderBorderColor)}\n"], dependencies: [{ kind: "component", type: TitleComponent, selector: "[fd-title], [fdTitle]", inputs: ["headerSize", "wrap"], exportAs: ["fd-title"] }, { kind: "component", type: LayoutGridComponent, selector: "fd-layout-grid, [fdLayoutGrid]", inputs: ["class", "noGap", "noHorizontalGap", "noVerticalGap"] }, { kind: "directive", type: LayoutGridRowDirective, selector: "[fd-layout-grid-row], [fdLayoutGridRow]" }, { kind: "directive", type: LayoutGridColDirective, selector: "[fd-layout-grid-col], [fdLayoutGridCol]", inputs: ["fdLayoutGridCol", "colGrow", "colMd", "colLg", "colXl", "colOffset", "colOffsetMd", "colOffsetLg", "colOffsetXl", "class"] }, { kind: "component", type: FormLabelComponent, selector: "[fd-form-label]", inputs: ["required", "colon", "alignLabelEnd", "inlineHelpContent", "inlineHelpGlyph", "inlineHelpTriggers", "inlineHelpBodyPlacement", "inlineHelpPlacement", "allowWrap", "inlineHelpLabel", "id"] }, { kind: "component", type: SelectComponent, selector: "fd-select", inputs: ["extendedBodyTemplate", "scrollStrategy", "textOverflow", "controlId", "state", "mobile", "stateMessage", "disabled", "required", "readonly", "placeholder", "value", "maxHeight", "glyph", "glyphFont", "closeOnOutsideClick", "fillControlMode", "controlTemplate", "appendTo", "unselectMissingOption", "typeaheadDebounceInterval", "ariaLabelledBy", "ariaLabel", "mobileConfig", "inline", "selectControlClass", "selectDropdownButtonClass", "advancedStateMessage", "tabOutStrategy", "compareWith"], outputs: ["isOpenChange", "valueChange"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.RequiredValidator, selector: ":not([type=checkbox])[required][formControlName],:not([type=checkbox])[required][formControl],:not([type=checkbox])[required][ngModel]", inputs: ["required"] }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: ListGroupHeaderDirective, selector: "[fdListGroupHeader], [fd-list-group-header]", inputs: ["nativeElementId"], outputs: ["keyDown"] }, { kind: "directive", type: ListTitleDirective, selector: "[fd-list-title], [fdListTitle]", inputs: ["wrap"] }, { kind: "component", type: OptionComponent, selector: "[fd-option], fd-option", inputs: ["id", "value", "disabled"], outputs: ["selectionChange"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: FormInputMessageGroupComponent, selector: "fd-form-input-message-group", inputs: ["triggers", "closeOnOutsideClick", "fillControlMode", "noArrow", "closeOnEscapeKey", "placement", "placementContainer", "isOpen", "preventSpaceKeyScroll"], outputs: ["isOpenChange"] }, { kind: "component", type: FormControlComponent, selector: "input[fd-form-control], textarea[fd-form-control]", inputs: ["state", "type", "class", "ariaLabel", "ariaLabelledBy"] }, { kind: "directive", type: ConditionCountMessageDirective, selector: "[fdp-condition-count-message]", inputs: ["maxCharacters"] }, { kind: "component", type: ButtonComponent, selector: "button[fd-button], a[fd-button], span[fd-button]", inputs: ["class"], exportAs: ["fd-button"] }, { kind: "component", type: FormMessageComponent, selector: "fd-form-message", inputs: ["type", "static", "embedded", "class"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DefineTabComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fdp-define-tab', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, imports: [
                        TitleComponent,
                        LayoutGridComponent,
                        LayoutGridRowDirective,
                        LayoutGridColDirective,
                        FormLabelComponent,
                        SelectComponent,
                        FormsModule,
                        ListGroupHeaderDirective,
                        ListTitleDirective,
                        OptionComponent,
                        NgTemplateOutlet,
                        FormInputMessageGroupComponent,
                        FormControlComponent,
                        ConditionCountMessageDirective,
                        ButtonComponent,
                        FormMessageComponent,
                        FdTranslatePipe
                    ], template: "<h5 [id]=\"titleId\" role=\"heading\" aria-level=\"5\" fd-title class=\"define-condition-title\">\n    {{ 'platformVHD.defineConditionTitle' | fdTranslate }}\n</h5>\n@for (item of _conditions; track _trackByKeyAndType(i, item); let i = $index) {\n    <fd-layout-grid class=\"condition-row\">\n        <div fdLayoutGridRow>\n            <div [fdLayoutGridCol]=\"4\">\n                <label id=\"CONDITIONPANEL_OPERATOR_LABEL\" fd-form-label class=\"fdp-value-help-dialog__hidden_label\">\n                    CONDITIONPANEL_OPERATOR_LABEL\n                </label>\n                <label [id]=\"selectedId\" fd-form-label class=\"fdp-value-help-dialog__hidden_label\">\n                    {{\n                        'platformVHD.defineConditionSelectedValueHiddenA11yLabel'\n                            | fdTranslate: { value: item.strategy }\n                    }}</label\n                >\n                <fd-select\n                    class=\"vhd-condition-filters\"\n                    fdLayoutGridCol\n                    colGrow\n                    [class.fd-select-custom-class]=\"false\"\n                    #sttr\n                    [controlTemplate]=\"customSelectTemplate\"\n                    [name]=\"uid + '-' + type + '-strategy-' + item.id\"\n                    [(ngModel)]=\"item.strategy\"\n                    (valueChange)=\"_filterChanged()\"\n                    role=\"combobox\"\n                    aria-roledescription=\"select\"\n                    aria-haspopup=\"listbox\"\n                    [inline]=\"false\"\n                    [ariaLabelledBy]=\"titleId + ' ' + 'CONDITIONPANEL_OPERATOR_LABEL' + ' ' + selectedId\"\n                >\n                    @if (_includeStrategy.length) {\n                        <li fd-list-group-header>\n                            <span fd-list-title>{{\n                                'platformVHD.defineConditionConditionsGroupHeaderInclude' | fdTranslate\n                            }}</span>\n                        </li>\n                        @for (strategy of _includeStrategy; track strategy) {\n                            <li fd-option [value]=\"strategy.key\">\n                                <ng-template\n                                    [ngTemplateOutlet]=\"conditionStrategyOption\"\n                                    [ngTemplateOutletContext]=\"{ type: _defineTypes.include, strategy: strategy }\"\n                                ></ng-template>\n                            </li>\n                        }\n                    }\n                    @if (_excludeStrategy.length) {\n                        <li fd-list-group-header>\n                            <span fd-list-title>{{\n                                'platformVHD.defineConditionConditionsGroupHeaderExclude' | fdTranslate\n                            }}</span>\n                        </li>\n                        @for (strategy of _excludeStrategy; track strategy) {\n                            <li fd-option [value]=\"strategy.key\">\n                                <ng-template\n                                    [ngTemplateOutlet]=\"conditionStrategyOption\"\n                                    [ngTemplateOutletContext]=\"{ type: _defineTypes.exclude, strategy: strategy }\"\n                                ></ng-template>\n                            </li>\n                        }\n                    }\n                </fd-select>\n            </div>\n            @if (item.strategy !== _strategyIncludeValues.empty && item.strategy !== _strategyExcludeValues.not_empty) {\n                <div fdLayoutGridCol colGrow>\n                    <div fdLayoutGridRow>\n                        @if (item.strategy === _strategyIncludeValues.between) {\n                            <div fdLayoutGridCol colGrow>\n                                <fd-form-input-message-group [triggers]=\"['focusin', 'focusout']\">\n                                    <input\n                                        fd-form-control\n                                        fdp-condition-count-message\n                                        [maxCharacters]=\"_rules.maxCharactersHintCount\"\n                                        type=\"text\"\n                                        [placeholder]=\"'platformVHD.defineConditionFromPlaceholder' | fdTranslate\"\n                                        placeholder=\"from\"\n                                        required\n                                        [state]=\"fromModel.invalid ? 'error' : null\"\n                                        [name]=\"uid + '-' + type + '-from-' + item.id\"\n                                        (blur)=\"_validateConditionValue(item, [!!fromModel.valid, !!toModel.valid])\"\n                                        #fromModel=\"ngModel\"\n                                        [(ngModel)]=\"item.value\"\n                                    />\n                                    <ng-template\n                                        [ngTemplateOutlet]=\"countError\"\n                                        [ngTemplateOutletContext]=\"{ $implicit: item.value && item.value.length }\"\n                                    ></ng-template>\n                                </fd-form-input-message-group>\n                            </div>\n                            <div fdLayoutGridCol colGrow>\n                                <fd-form-input-message-group [triggers]=\"['focusin', 'focusout']\">\n                                    <input\n                                        fd-form-control\n                                        fdp-condition-count-message\n                                        [maxCharacters]=\"_rules.maxCharactersHintCount\"\n                                        type=\"text\"\n                                        [placeholder]=\"'platformVHD.defineConditionToPlaceholder' | fdTranslate\"\n                                        required\n                                        [state]=\"toModel.invalid ? 'error' : null\"\n                                        [name]=\"uid + '-' + type + '-to-' + item.id\"\n                                        (blur)=\"_validateConditionValue(item, [!!fromModel.valid, !!toModel.valid])\"\n                                        #toModel=\"ngModel\"\n                                        [(ngModel)]=\"item.valueTo\"\n                                    />\n                                    <ng-template\n                                        [ngTemplateOutlet]=\"countError\"\n                                        [ngTemplateOutletContext]=\"{ $implicit: item.value && item.value.length }\"\n                                    ></ng-template>\n                                </fd-form-input-message-group>\n                            </div>\n                        } @else {\n                            <div fdLayoutGridCol colGrow>\n                                <fd-form-input-message-group>\n                                    <input\n                                        fd-form-control\n                                        fdp-condition-count-message\n                                        [maxCharacters]=\"_rules.maxCharactersHintCount\"\n                                        type=\"text\"\n                                        [placeholder]=\"'platformVHD.defineConditionValuePlaceholder' | fdTranslate\"\n                                        [state]=\"valueModel.invalid ? 'error' : null\"\n                                        [name]=\"uid + '-' + type + '-value-' + item.id\"\n                                        (blur)=\"_validateConditionValue(item, !!valueModel.valid)\"\n                                        #valueModel=\"ngModel\"\n                                        [(ngModel)]=\"item.value\"\n                                    />\n                                    @if (valueModel.invalid) {\n                                        <ng-template\n                                            [ngTemplateOutlet]=\"countError\"\n                                            [ngTemplateOutletContext]=\"{ $implicit: item.value && item.value.length }\"\n                                        ></ng-template>\n                                    }\n                                </fd-form-input-message-group>\n                            </div>\n                        }\n                    </div>\n                </div>\n            }\n            <div class=\"action-col\" fdLayoutGridCol colGrow>\n                <button\n                    fd-button\n                    [ariaLabel]=\"'platformVHD.defineConditionRemoveConditionButtonTitle' | fdTranslate\"\n                    fdType=\"transparent\"\n                    glyph=\"decline\"\n                    [title]=\"'platformVHD.defineConditionRemoveConditionButtonTitle' | fdTranslate\"\n                    (click)=\"removeCondition(i)\"\n                ></button>\n            </div>\n        </div>\n    </fd-layout-grid>\n}\n<fd-layout-grid class=\"condition-row new-condition-row\" [noGap]=\"true\">\n    <div fdLayoutGridRow>\n        <div fdLayoutGridCol colGrow>&nbsp;</div>\n        <div fdLayoutGridCol class=\"action-col\">\n            <button\n                fd-button\n                [attr.aria-label]=\"'platformVHD.defineConditionAddConditionButtonTitle' | fdTranslate\"\n                [label]=\"'platformVHD.defineConditionAddConditionButtonLabel' | fdTranslate\"\n                [title]=\"'platformVHD.defineConditionAddConditionButtonTitle' | fdTranslate\"\n                (click)=\"addEmptyCondition()\"\n            ></button>\n        </div>\n    </div>\n</fd-layout-grid>\n<ng-template #conditionStrategyOption let-type=\"type\" let-strategy=\"strategy\">\n    @switch (strategy.key) {\n        @case ('contains') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelContains' | fdTranslate }}\n        }\n        @case ('equalTo') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelEqualTo' | fdTranslate }}\n        }\n        @case ('between') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelBetween' | fdTranslate }}\n        }\n        @case ('startsWith') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelStartsWith' | fdTranslate }}\n        }\n        @case ('endsWith') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelEndsWith' | fdTranslate }}\n        }\n        @case ('lessThan') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelLessThan' | fdTranslate }}\n        }\n        @case ('lessThanEqual') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelLessThanEqual' | fdTranslate }}\n        }\n        @case ('greaterThan') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelGreaterThan' | fdTranslate }}\n        }\n        @case ('greaterThanEqual') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelGreaterThanEqual' | fdTranslate }}\n        }\n        @case ('empty') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelEmpty' | fdTranslate }}\n        }\n        @case ('not_equalTo') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelNotEqualTo' | fdTranslate }}\n        }\n        @case ('not_empty') {\n            {{ 'platformVHD.defineConditionConditionStrategyLabelNotEmpty' | fdTranslate }}\n        }\n    }\n</ng-template>\n<ng-template #countError let-count>\n    @if (count && count > 7) {\n        <fd-form-message type=\"error\">\n            {{ 'platformVHD.defineConditionMaxCountError' | fdTranslate: { count: 7 } }}\n        </fd-form-message>\n    }\n</ng-template>\n<ng-template #customSelectTemplate let-textValue>\n    {{ textValue }}\n</ng-template>\n", styles: [".fdp-value-help-dialog fdp-define-tab{height:100%;overflow:auto}.fdp-value-help-dialog fdp-define-tab .define-condition-title{padding:.625rem 0 0}.fdp-value-help-dialog fdp-define-tab .condition-row{padding:0}.fdp-value-help-dialog fdp-define-tab .condition-row .fd-col{padding-top:0;padding-bottom:0}.fdp-value-help-dialog .vhd-condition-filters fd-popover{width:100%}.fdp-value-help-dialog .condition-row{align-items:center}.fdp-value-help-dialog .condition-row .main-col{min-width:auto;flex:1 1 auto}.fdp-value-help-dialog .condition-row .action-col{display:flex;align-items:center;min-width:auto;flex:0 0 auto}.fdp-value-help-dialog .condition-row.new-condition-row{padding-top:.5rem}.fdp-value-help-dialog .condition-row.new-condition-row .fd-button{margin-right:1rem}.fd-list--dropdown .fd-list__item.fd-list__group-header{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_GroupHeaderBorderColor)}\n"] }]
        }], propDecorators: { titleId: [{
                type: Input
            }], selectedId: [{
                type: Input
            }], conditions: [{
                type: Input
            }], strategyLabels: [{
                type: Input
            }], includeChange: [{
                type: Output
            }], excludeChange: [{
                type: Output
            }], conditionChange: [{
                type: Output
            }] } });

class VhdComponent {
}

/* eslint-disable @typescript-eslint/member-ordering */
let titleUniqueId = 0;
class SelectTabComponent extends VhdBaseTab {
    constructor() {
        super(...arguments);
        /** @hidden */
        this.defaultTitleId = `fd-select-tab-title-id-${titleUniqueId++}`;
        /** @hidden */
        this.defaultCountId = `fd-select-tab-title-count-id-${titleUniqueId++}`;
        /** Select tab title element ID */
        this.selectTabTitleId = this.defaultTitleId;
        /** Select tab count element ID */
        this.selectTabCountId = this.defaultCountId;
        /** Selected items */
        this.selected = [];
        /** Loading state */
        this.loading = false;
        /** Actual filters */
        this.filters = [];
        /** Close dialog immediately after select any row from search table. It'll be skipped if multi option is true */
        this.selection = 'single';
        /** Whether to allow users to select all table entries with one checkbox. */
        this.allowSelectAll = true;
        /** Uniq field from data source */
        this.uniqueKey = 'id';
        /** Count of default mobile header from search table */
        this.defaultMobileHeaders = 2;
        /** Displayed data for search table */
        this.displayedData = [];
        /** Event emitted when row was selected. */
        // eslint-disable-next-line @angular-eslint/no-output-native
        this.select = new EventEmitter();
        /** @hidden indeterminate flag for `select all` checkbox */
        this._selectedAll = false;
        /** @hidden Shown items count in mobile view */
        this._shownFrom = 0;
        /** @hidden Shown items count in mobile view */
        this._shownCount = 0;
        /** @hidden Current page in desktop view */
        this._currentPage = 0;
        /** @hidden Headers and body for search table */
        this._tableFilters = {
            main: [],
            secondary: []
        };
        /** @hidden */
        this._selectedMap = {};
        /** @hidden */
        this._columnDefMap = new Map();
        /** @hidden */
        this.selectedItems = [];
        /** @hidden */
        this._vhd = inject(VhdComponent, { optional: true });
        /** @hidden */
        this._destroyRef = inject(DestroyRef);
        /** @hidden Track function for main data */
        this._trackByTableRowFn = (_index, item) => {
            if (item) {
                return item[this.uniqueKey];
            }
            return undefined;
        };
    }
    /** Selection type getters */
    get isSingleSelection() {
        return this.selection === 'single';
    }
    /** Selection type getters */
    get isOnceSelection() {
        return this.selection === 'once';
    }
    /** Selection type getters */
    get isMultiSelection() {
        return this.selection === 'multi';
    }
    /** @hidden */
    ngAfterViewInit() {
        Promise.resolve(true).then(() => this._checkScrollAndShowMore());
        this._vhd?.columnDef.changes.pipe(startWith(null), takeUntilDestroyed(this._destroyRef)).subscribe(() => {
            this._columnDefMap.clear();
            this._vhd?.columnDef.forEach((item) => {
                this._columnDefMap.set(item.column, item);
            });
        });
    }
    /** @hidden  */
    ngOnChanges(changes) {
        if ('filters' in changes) {
            this._initializeFilters();
        }
        if ('displayedData' in changes) {
            this._refreshDisplayedData();
        }
        if ('selected' in changes) {
            this.selectedItems = this.selected || [];
            this._refreshSelectedMap();
            this._refreshTristate();
        }
    }
    /** @hidden Track function for filters */
    _trackByFilterFn(_index, item) {
        return item && item.key ? item.key : undefined;
    }
    /** @hidden Show more elements */
    _showMoreElements() {
        if (this.pageSize && this._shownCount !== this.displayedData.length) {
            this._shownCount += this.pageSize;
            this._shownCount = Math.min(this._shownCount, this.displayedData.length);
        }
        else {
            this._shownCount = this.displayedData.length;
        }
        this._changeDetectorRef.markForCheck();
    }
    /** @hidden Refresh page in desktop view */
    _updatePage(pageNumber = 1) {
        if (this.pageSize) {
            this._currentPage = pageNumber;
            this._shownFrom = (pageNumber - 1) * this.pageSize;
            this._shownCount = Math.min(this._shownFrom + this.pageSize, this.displayedData.length);
        }
        else {
            this._shownCount = this.displayedData.length;
        }
    }
    /** @hidden Method toggle selected state for all items  */
    _toggleAllRows() {
        if (this._selectedAll) {
            this.selectedItems = [];
        }
        else {
            this.selectedItems = this.displayedData;
        }
        this.select.emit(this.selectedItems);
        this._refreshSelectedMap();
        this._refreshTristate();
    }
    /** @hidden Method toggle selected state for one items  */
    _toggleSelectRow(item) {
        if (this.isMultiSelection) {
            const isSelected = this._selectedMap[item[this.uniqueKey]];
            if (isSelected) {
                this.selectedItems = this.selectedItems.filter((s) => s[this.uniqueKey] !== item[this.uniqueKey]);
            }
            else {
                this.selectedItems.push(item);
            }
            this._selectedMap[item[this.uniqueKey]] = !this._selectedMap[item[this.uniqueKey]];
        }
        else {
            this._clearSelectedItems();
            this.selectedItems = [item];
        }
        this.select.emit(this.selectedItems);
        this._refreshTristate();
    }
    /** @hidden */
    _checkScrollAndShowMore() {
        if (this.mobile) {
            return;
        }
        if (this.displayedData.length &&
            this._shownCount !== this.displayedData.length &&
            this.infiniteScrollTable?.shouldTriggerAction()) {
            this._showMoreElements();
            setTimeout(() => {
                this._checkScrollAndShowMore();
            }, 100);
        }
    }
    /** @hidden */
    _resetShown() {
        if (this.mobile) {
            this._showMoreElements();
        }
        else {
            this._checkScrollAndShowMore();
        }
    }
    /** @hidden Manually clear selected items */
    _clearSelectedItems() {
        this._selectedMap = {};
        this.selectedItems = [];
    }
    /** @hidden Refresh indeterminate attribute on `select all` checkbox */
    _refreshTristate() {
        const selected = Object.values(this._selectedMap).filter(Boolean).length;
        if (selected === 0) {
            this._selectedAll = false;
        }
        else if (selected === this.displayedData.length) {
            this._selectedAll = true;
        }
        else {
            this._selectedAll = null;
        }
    }
    /** @hidden Set up filters */
    _initializeFilters() {
        if (this.mobile) {
            let _mobileTableHeaders = this.filters.filter((f) => f.main).map((f) => f.key);
            if (!_mobileTableHeaders.length) {
                _mobileTableHeaders = this.filters.slice(0, this.defaultMobileHeaders).map((f) => f.key);
            }
            this._tableFilters = {
                main: this.filters.filter((filter) => _mobileTableHeaders.some((key) => key === filter.key)),
                secondary: this.filters.filter((filter) => !_mobileTableHeaders.some((key) => key === filter.key))
            };
        }
        else {
            this._tableFilters = {
                main: this.filters,
                secondary: []
            };
        }
    }
    /** @hidden Refresh display data */
    _refreshDisplayedData() {
        this._resetShown();
        this._refreshTristate();
    }
    /** @hidden Refresh selected map for display data */
    _refreshSelectedMap() {
        this._selectedMap = {};
        for (const item of this.displayedData) {
            this._selectedMap[item[this.uniqueKey]] = false;
        }
        for (const s of this.selectedItems) {
            this._selectedMap[s[this.uniqueKey]] = true;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: SelectTabComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.0.7", type: SelectTabComponent, isStandalone: true, selector: "fdp-select-tab", inputs: { selectTabTitleId: "selectTabTitleId", selectTabCountId: "selectTabCountId", selected: "selected", loading: "loading", filters: "filters", selection: "selection", allowSelectAll: "allowSelectAll", uniqueKey: "uniqueKey", pageSize: "pageSize", defaultMobileHeaders: "defaultMobileHeaders", displayedData: "displayedData" }, outputs: { select: "select" }, viewQueries: [{ propertyName: "infiniteScrollTable", first: true, predicate: InfiniteScrollDirective, descendants: true }], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "<div class=\"table-header\">\n    <h5 fd-title role=\"heading\" aria-level=\"5\">\n        {{ 'platformVHD.selectTabDisplayCountLabel' | fdTranslate: { count: displayedData.length } }}\n    </h5>\n</div>\n<div\n    class=\"fdp-value-help-dialog__table-holder table-content\"\n    fd-scrollbar\n    fdInfiniteScroll\n    (onScrollAction)=\"_showMoreElements()\"\n    [scrollPercent]=\"80\"\n    role=\"table\"\n>\n    <table\n        fd-table\n        [popIn]=\"mobile\"\n        [noBorderX]=\"mobile\"\n        [noBorderY]=\"false\"\n        [attr.aria-colcount]=\"_tableFilters.main.length\"\n        [attr.aria-rowcount]=\"displayedData.length\"\n        role=\"grid\"\n        aria-multiselectable=\"true\"\n        [attr.aria-labelledby]=\"selectTabTitleId + ' ' + selectTabCountId\"\n        [allCellsFocusable]=\"true\"\n    >\n        <label [id]=\"selectTabCountId\" fd-form-label class=\"fdp-value-help-dialog__hidden_label\">\n            {{\n                'platformVHD.selectTabCountHiddenA11yLabel'\n                    | fdTranslate: { rowCount: displayedData.length, colCount: _tableFilters.main.length }\n            }}\n        </label>\n        <label [id]=\"selectTabTitleId\" fd-form-label class=\"fdp-value-help-dialog__hidden_label\">\n            {{ 'platformVHD.selectTabDisplayCountLabel' | fdTranslate: { count: displayedData.length } }}\n        </label>\n        <thead fd-table-header>\n            @if (displayedData.length && _tableFilters) {\n                <tr fd-table-row>\n                    <th fd-table-cell [fitContent]=\"mobile\">\n                        @if (isMultiSelection && allowSelectAll) {\n                            <fd-checkbox\n                                [name]=\"uid + '-row-all'\"\n                                [tristate]=\"true\"\n                                [tristateSelectable]=\"false\"\n                                [ngModel]=\"_selectedAll\"\n                                (ngModelChange)=\"_toggleAllRows()\"\n                            ></fd-checkbox>\n                        }\n                    </th>\n                    @for (\n                        filter of _tableFilters.main;\n                        track _trackByFilterFn(colindex, filter);\n                        let colindex = $index\n                    ) {\n                        <th fd-table-cell [attr.aria-colindex]=\"colindex\">\n                            {{ filter.label }}\n                        </th>\n                    }\n                </tr>\n            }\n        </thead>\n        <tbody fd-table-body>\n            @for (\n                row of displayedData | slice: _shownFrom : _shownCount;\n                track _trackByTableRowFn(i, row);\n                let i = $index\n            ) {\n                <tr\n                    fd-table-row\n                    [hoverable]=\"!mobile\"\n                    [main]=\"mobile\"\n                    [attr.aria-selected]=\"_selectedMap[row[uniqueKey]]\"\n                    [activable]=\"!isMultiSelection\"\n                    (click)=\"!isMultiSelection && _toggleSelectRow(row)\"\n                >\n                    <td fd-table-cell [fitContent]=\"mobile\">\n                        @if (isMultiSelection) {\n                            <fd-checkbox\n                                [name]=\"uid + '-row-' + i\"\n                                [ngModel]=\"_selectedMap[row[uniqueKey]]\"\n                                (change)=\"_toggleSelectRow(row)\"\n                            ></fd-checkbox>\n                        }\n                    </td>\n                    @for (filter of _tableFilters.main; track filter; let rowIndex = $index) {\n                        <td fd-table-cell [attr.aria-rowindex]=\"rowIndex\">\n                            @if (_columnDefMap.get(filter.key); as columnDef) {\n                                <ng-template\n                                    [ngTemplateOutlet]=\"columnDef.templateRef\"\n                                    [ngTemplateOutletContext]=\"{\n                                        $implicit: row,\n                                        key: filter.key,\n                                        value: row[filter.key] || ''\n                                    }\"\n                                ></ng-template>\n                            } @else {\n                                {{ row[filter.key] || '' }}\n                            }\n                        </td>\n                    }\n                </tr>\n                @if (mobile && _tableFilters.secondary.length) {\n                    <tr fd-table-row [secondary]=\"true\" [attr.aria-selected]=\"_selectedMap[row[uniqueKey]]\">\n                        <td fd-table-cell></td>\n                        <td colspan=\"100%\" fd-table-cell [fitContent]=\"true\">\n                            @for (filter of _tableFilters.secondary; track filter) {\n                                <p fd-table-text>\n                                    <label>{{ filter.label }}:</label>\n                                    {{ row[filter.key] || '' }}\n                                </p>\n                            }\n                        </td>\n                    </tr>\n                }\n            }\n            @if (displayedData.length && mobile && _shownCount && _shownCount !== displayedData.length) {\n                <tr fd-table-row>\n                    <td colspan=\"100%\">\n                        <div fd-bar barDesign=\"header-with-subheader\">\n                            <div fd-bar-middle>\n                                <fd-bar-element>\n                                    <button\n                                        fd-button\n                                        fdType=\"transparent\"\n                                        [label]=\"'platformVHD.selectTabMoreBtnLabel' | fdTranslate\"\n                                        (click)=\"_showMoreElements()\"\n                                    ></button>\n                                </fd-bar-element>\n                            </div>\n                        </div>\n                    </td>\n                </tr>\n            }\n            @if (!displayedData.length) {\n                @if (loading) {\n                    <tr fd-table-row *fdkRepeat=\"3\">\n                        <td fd-table-cell *fdkRepeat=\"3\">\n                            <fd-skeleton [style.margin]=\"'auto 0'\" type=\"text\" textLines=\"1\" width=\"60%\"></fd-skeleton>\n                        </td>\n                    </tr>\n                } @else {\n                    <tr fd-table-row>\n                        <td fd-table-cell colspan=\"100%\">\n                            <div class=\"fdp-value-help-dialog__empty-message\">\n                                {{ 'platformVHD.searchTableEmptyMessage' | fdTranslate }}\n                            </div>\n                        </td>\n                    </tr>\n                }\n            }\n        </tbody>\n    </table>\n</div>\n", styles: [".fdp-value-help-dialog__advanced-filters .fd-col{padding-top:0}.fdp-value-help-dialog__content-holder fdp-select-tab{display:flex;flex-direction:column;overflow:hidden;height:100%}.fdp-value-help-dialog__content-holder .table-header{flex:0 0 auto}.fdp-value-help-dialog__content-holder .table-content{flex:1 1 auto;overflow:auto;min-height:5rem}.fdp-value-help-dialog__table-holder{padding-top:0;padding-bottom:0}.fdp-value-help-dialog__empty-message{padding:1rem 2rem}\n"], dependencies: [{ kind: "component", type: TitleComponent, selector: "[fd-title], [fdTitle]", inputs: ["headerSize", "wrap"], exportAs: ["fd-title"] }, { kind: "directive", type: ScrollbarDirective, selector: "[fdScrollbar], [fd-scrollbar]", inputs: ["noHorizontalScroll", "noVerticalScroll", "alwaysVisible"] }, { kind: "directive", type: InfiniteScrollDirective, selector: "[fdInfiniteScroll]", inputs: ["scrollPercent", "scrollOffset"], outputs: ["onScrollAction"] }, { kind: "component", type: TableComponent, selector: "table[fd-table]", inputs: ["noBorderX", "noBorderY", "noOuterBorder", "topBorder", "popIn", "responsive", "keys", "allCellsFocusable"], exportAs: ["fd-table"] }, { kind: "component", type: FormLabelComponent, selector: "[fd-form-label]", inputs: ["required", "colon", "alignLabelEnd", "inlineHelpContent", "inlineHelpGlyph", "inlineHelpTriggers", "inlineHelpBodyPlacement", "inlineHelpPlacement", "allowWrap", "inlineHelpLabel", "id"] }, { kind: "directive", type: TableHeaderDirective, selector: "[fdTableHeader], [fd-table-header]", inputs: ["noBorderX", "noBorderY", "nonInteractive"] }, { kind: "directive", type: TableRowDirective, selector: "[fdTableRow], [fd-table-row]", inputs: ["activable", "highlightActive", "hoverable", "focusable", "main", "secondary", "active"] }, { kind: "directive", type: TableCellDirective, selector: "[fdTableCell], [fd-table-cell]", inputs: ["noBorderX", "noBorderY", "activable", "focusable", "hoverable", "fitContent", "noPadding", "noData", "nonInteractive", "key"] }, { kind: "component", type: CheckboxComponent, selector: "fd-checkbox", inputs: ["wrapLabel", "valignLabel", "ariaLabel", "role", "value", "ariaLabelledBy", "ariaDescribedBy", "title", "inputId", "state", "name", "label", "disabled", "readonly", "tristate", "tristateSelectable", "labelClass", "required", "displayOnly", "values", "standalone"], outputs: ["focusChange"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: TableBodyDirective, selector: "[fdTableBody], [fd-table-body]", inputs: ["noBorderX", "noBorderY"] }, { kind: "directive", type: TableTextDirective, selector: "[fdTableText], [fd-table-text]", inputs: ["fdTableTextClass", "noWrap", "title", "maxWidth"] }, { kind: "component", type: BarComponent, selector: "[fd-bar]", inputs: ["class", "barDesign", "inPage", "inHomePage", "size"] }, { kind: "directive", type: BarMiddleDirective, selector: "[fd-bar-middle]" }, { kind: "directive", type: BarElementDirective, selector: "fd-bar-element", inputs: ["fullWidth"] }, { kind: "component", type: ButtonComponent, selector: "button[fd-button], a[fd-button], span[fd-button]", inputs: ["class"], exportAs: ["fd-button"] }, { kind: "directive", type: RepeatDirective, selector: "[fdkRepeat]", inputs: ["fdkRepeat"] }, { kind: "component", type: SkeletonComponent, selector: "fd-skeleton", inputs: ["animated", "type", "textLines", "width", "height"] }, { kind: "pipe", type: SlicePipe, name: "slice" }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: SelectTabComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fdp-select-tab', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, imports: [
                        TitleComponent,
                        CdkScrollable,
                        ScrollbarDirective,
                        InfiniteScrollDirective,
                        FocusableGridDirective,
                        TableComponent,
                        FormLabelComponent,
                        TableHeaderDirective,
                        TableRowDirective,
                        TableCellDirective,
                        CheckboxComponent,
                        FormsModule,
                        TableBodyDirective,
                        TableTextDirective,
                        BarComponent,
                        BarMiddleDirective,
                        BarElementDirective,
                        ButtonComponent,
                        RepeatDirective,
                        SkeletonComponent,
                        SlicePipe,
                        FdTranslatePipe,
                        NgTemplateOutlet
                    ], template: "<div class=\"table-header\">\n    <h5 fd-title role=\"heading\" aria-level=\"5\">\n        {{ 'platformVHD.selectTabDisplayCountLabel' | fdTranslate: { count: displayedData.length } }}\n    </h5>\n</div>\n<div\n    class=\"fdp-value-help-dialog__table-holder table-content\"\n    fd-scrollbar\n    fdInfiniteScroll\n    (onScrollAction)=\"_showMoreElements()\"\n    [scrollPercent]=\"80\"\n    role=\"table\"\n>\n    <table\n        fd-table\n        [popIn]=\"mobile\"\n        [noBorderX]=\"mobile\"\n        [noBorderY]=\"false\"\n        [attr.aria-colcount]=\"_tableFilters.main.length\"\n        [attr.aria-rowcount]=\"displayedData.length\"\n        role=\"grid\"\n        aria-multiselectable=\"true\"\n        [attr.aria-labelledby]=\"selectTabTitleId + ' ' + selectTabCountId\"\n        [allCellsFocusable]=\"true\"\n    >\n        <label [id]=\"selectTabCountId\" fd-form-label class=\"fdp-value-help-dialog__hidden_label\">\n            {{\n                'platformVHD.selectTabCountHiddenA11yLabel'\n                    | fdTranslate: { rowCount: displayedData.length, colCount: _tableFilters.main.length }\n            }}\n        </label>\n        <label [id]=\"selectTabTitleId\" fd-form-label class=\"fdp-value-help-dialog__hidden_label\">\n            {{ 'platformVHD.selectTabDisplayCountLabel' | fdTranslate: { count: displayedData.length } }}\n        </label>\n        <thead fd-table-header>\n            @if (displayedData.length && _tableFilters) {\n                <tr fd-table-row>\n                    <th fd-table-cell [fitContent]=\"mobile\">\n                        @if (isMultiSelection && allowSelectAll) {\n                            <fd-checkbox\n                                [name]=\"uid + '-row-all'\"\n                                [tristate]=\"true\"\n                                [tristateSelectable]=\"false\"\n                                [ngModel]=\"_selectedAll\"\n                                (ngModelChange)=\"_toggleAllRows()\"\n                            ></fd-checkbox>\n                        }\n                    </th>\n                    @for (\n                        filter of _tableFilters.main;\n                        track _trackByFilterFn(colindex, filter);\n                        let colindex = $index\n                    ) {\n                        <th fd-table-cell [attr.aria-colindex]=\"colindex\">\n                            {{ filter.label }}\n                        </th>\n                    }\n                </tr>\n            }\n        </thead>\n        <tbody fd-table-body>\n            @for (\n                row of displayedData | slice: _shownFrom : _shownCount;\n                track _trackByTableRowFn(i, row);\n                let i = $index\n            ) {\n                <tr\n                    fd-table-row\n                    [hoverable]=\"!mobile\"\n                    [main]=\"mobile\"\n                    [attr.aria-selected]=\"_selectedMap[row[uniqueKey]]\"\n                    [activable]=\"!isMultiSelection\"\n                    (click)=\"!isMultiSelection && _toggleSelectRow(row)\"\n                >\n                    <td fd-table-cell [fitContent]=\"mobile\">\n                        @if (isMultiSelection) {\n                            <fd-checkbox\n                                [name]=\"uid + '-row-' + i\"\n                                [ngModel]=\"_selectedMap[row[uniqueKey]]\"\n                                (change)=\"_toggleSelectRow(row)\"\n                            ></fd-checkbox>\n                        }\n                    </td>\n                    @for (filter of _tableFilters.main; track filter; let rowIndex = $index) {\n                        <td fd-table-cell [attr.aria-rowindex]=\"rowIndex\">\n                            @if (_columnDefMap.get(filter.key); as columnDef) {\n                                <ng-template\n                                    [ngTemplateOutlet]=\"columnDef.templateRef\"\n                                    [ngTemplateOutletContext]=\"{\n                                        $implicit: row,\n                                        key: filter.key,\n                                        value: row[filter.key] || ''\n                                    }\"\n                                ></ng-template>\n                            } @else {\n                                {{ row[filter.key] || '' }}\n                            }\n                        </td>\n                    }\n                </tr>\n                @if (mobile && _tableFilters.secondary.length) {\n                    <tr fd-table-row [secondary]=\"true\" [attr.aria-selected]=\"_selectedMap[row[uniqueKey]]\">\n                        <td fd-table-cell></td>\n                        <td colspan=\"100%\" fd-table-cell [fitContent]=\"true\">\n                            @for (filter of _tableFilters.secondary; track filter) {\n                                <p fd-table-text>\n                                    <label>{{ filter.label }}:</label>\n                                    {{ row[filter.key] || '' }}\n                                </p>\n                            }\n                        </td>\n                    </tr>\n                }\n            }\n            @if (displayedData.length && mobile && _shownCount && _shownCount !== displayedData.length) {\n                <tr fd-table-row>\n                    <td colspan=\"100%\">\n                        <div fd-bar barDesign=\"header-with-subheader\">\n                            <div fd-bar-middle>\n                                <fd-bar-element>\n                                    <button\n                                        fd-button\n                                        fdType=\"transparent\"\n                                        [label]=\"'platformVHD.selectTabMoreBtnLabel' | fdTranslate\"\n                                        (click)=\"_showMoreElements()\"\n                                    ></button>\n                                </fd-bar-element>\n                            </div>\n                        </div>\n                    </td>\n                </tr>\n            }\n            @if (!displayedData.length) {\n                @if (loading) {\n                    <tr fd-table-row *fdkRepeat=\"3\">\n                        <td fd-table-cell *fdkRepeat=\"3\">\n                            <fd-skeleton [style.margin]=\"'auto 0'\" type=\"text\" textLines=\"1\" width=\"60%\"></fd-skeleton>\n                        </td>\n                    </tr>\n                } @else {\n                    <tr fd-table-row>\n                        <td fd-table-cell colspan=\"100%\">\n                            <div class=\"fdp-value-help-dialog__empty-message\">\n                                {{ 'platformVHD.searchTableEmptyMessage' | fdTranslate }}\n                            </div>\n                        </td>\n                    </tr>\n                }\n            }\n        </tbody>\n    </table>\n</div>\n", styles: [".fdp-value-help-dialog__advanced-filters .fd-col{padding-top:0}.fdp-value-help-dialog__content-holder fdp-select-tab{display:flex;flex-direction:column;overflow:hidden;height:100%}.fdp-value-help-dialog__content-holder .table-header{flex:0 0 auto}.fdp-value-help-dialog__content-holder .table-content{flex:1 1 auto;overflow:auto;min-height:5rem}.fdp-value-help-dialog__table-holder{padding-top:0;padding-bottom:0}.fdp-value-help-dialog__empty-message{padding:1rem 2rem}\n"] }]
        }], propDecorators: { selectTabTitleId: [{
                type: Input
            }], selectTabCountId: [{
                type: Input
            }], selected: [{
                type: Input
            }], loading: [{
                type: Input
            }], filters: [{
                type: Input
            }], selection: [{
                type: Input
            }], allowSelectAll: [{
                type: Input
            }], uniqueKey: [{
                type: Input
            }], pageSize: [{
                type: Input
            }], defaultMobileHeaders: [{
                type: Input
            }], displayedData: [{
                type: Input
            }], select: [{
                type: Output
            }], infiniteScrollTable: [{
                type: ViewChild,
                args: [InfiniteScrollDirective]
            }] } });

class ValueHelpFilterDefDirective {
    constructor() {
        /** Template reference */
        this.templateRef = inject(TemplateRef);
    }
    /** @hidden */
    static ngTemplateContextGuard(dir, ctx) {
        return true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ValueHelpFilterDefDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.7", type: ValueHelpFilterDefDirective, isStandalone: true, selector: "[fdpValueHelpFilterDef]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ValueHelpFilterDefDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdpValueHelpFilterDef]',
                    standalone: true
                }]
        }] });

class VhdFilterComponent {
    constructor() {
        /** Allow to control which of filters should show as main in mobile view.
         * Apply for search table only */
        this.main = false;
        /** Initial filter's value for search section in `select from list tab` only */
        this.value = '';
        /** Allow to show filter in advanced search template */
        this.advanced = true;
        /** Allow to use filter for including in `define conditions tab` */
        this.include = true;
        /** Allow to use filter for excluding in `define conditions tab` */
        this.exclude = true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: VhdFilterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: VhdFilterComponent, isStandalone: true, selector: "fdp-value-help-dialog-filter", inputs: { key: "key", main: "main", label: "label", value: "value", advanced: "advanced", include: "include", exclude: "exclude" }, queries: [{ propertyName: "filterDef", first: true, predicate: ValueHelpFilterDefDirective, descendants: true }], ngImport: i0, template: '', isInline: true, changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: VhdFilterComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fdp-value-help-dialog-filter',
                    template: '',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    standalone: true
                }]
        }], propDecorators: { key: [{
                type: Input
            }], main: [{
                type: Input
            }], label: [{
                type: Input
            }], value: [{
                type: Input
            }], advanced: [{
                type: Input
            }], include: [{
                type: Input
            }], exclude: [{
                type: Input
            }], filterDef: [{
                type: ContentChild,
                args: [ValueHelpFilterDefDirective]
            }] } });

class ValueHelpColumnDefDirective {
    constructor() {
        /** Template reference */
        this.templateRef = inject(TemplateRef);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ValueHelpColumnDefDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.7", type: ValueHelpColumnDefDirective, isStandalone: true, selector: "[fdpValueHelpColumnDef]", inputs: { as: ["fdpValueHelpColumnDefAs", "as"], column: ["fdpValueHelpColumnDefColumn", "column"] }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ValueHelpColumnDefDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdpValueHelpColumnDef]',
                    standalone: true
                }]
        }], propDecorators: { as: [{
                type: Input,
                args: ['fdpValueHelpColumnDefAs']
            }], column: [{
                type: Input,
                args: ['fdpValueHelpColumnDefColumn']
            }] } });

let vhdHeaderUniqueId = 0;
let vhiUniqueId = 0;
class PlatformValueHelpDialogComponent extends VhdComponent {
    /** Data source */
    set dataSource(value) {
        if (value) {
            this._dataSource = this.toDataStream(value);
        }
    }
    get dataSource() {
        return this._dataSource;
    }
    /** @hidden */
    get loadingState() {
        return this.loading ?? this._internalLoadingState;
    }
    /** @hidden */
    constructor(elementRef, _changeDetectorRef, _dialogService, _rtlService) {
        super();
        this.elementRef = elementRef;
        this._changeDetectorRef = _changeDetectorRef;
        this._dialogService = _dialogService;
        this._rtlService = _rtlService;
        /** Id of the popover */
        this.id = 'fdp-vhd-' + vhiUniqueId++;
        /** Initial state of Value help dialog */
        this.value = {
            selected: [],
            conditions: []
        };
        /** Select from list tab activation */
        this.initialTab = VhdTab.selectFromList;
        /** Visible tabs */
        this.tabs = 'both';
        /** Initial expand state for advanced search panel */
        this.isOpenAdvanced = false;
        /** Dialog's custom config */
        this.dialogConfig = {};
        /** Id attribute for dialog title */
        this.headerId = `fdp-vhd-header-id-${vhdHeaderUniqueId++}`;
        /** Whether the value help dialog should be view in mobile mode */
        this.mobile = false;
        /** Tokenizer function for condition's token render */
        this.conditionDisplayFn = defaultConditionDisplayFn;
        /** Selection mode for search table */
        this.searchSelection = 'multi';
        /** Items per page for pagination below search table */
        this.searchTablePageSize = 20;
        /** Count of default mobile header from search table */
        this.searchTableMobileHeaders = 2;
        /** Max shown initial filters on open. Desktop only */
        this.maxShownInitialFilters = 4;
        /** Whether to allow users to select all table entries with one checkbox. */
        this.allowSelectAll = true;
        /** Custom strategies labels
         * Allowed keys: contains, equalTo, between, startsWith, endsWith, lessThan, lessThanEqual, greaterThan, greaterThanEqual, empty
         */
        this.defineStrategyLabels = {
            contains: 'contains',
            equalTo: 'equal to',
            between: 'between',
            startsWith: 'starts with',
            endsWith: 'ends with',
            lessThan: 'less than',
            lessThanEqual: 'less than or equal to',
            greaterThan: 'greater than',
            greaterThanEqual: 'greater than or equal to',
            empty: 'empty',
            not_equalTo: 'not equal to',
            not_empty: 'not empty'
        };
        /** Dialog outputs */
        /** Event emitted when filters/tokens were changed. */
        this.valueChange = new EventEmitter();
        /** Event emitted when data loading is started. */
        // eslint-disable-next-line @angular-eslint/no-output-on-prefix
        this.onDataRequested = new EventEmitter();
        /** Event emitted when data loading is finished. */
        // eslint-disable-next-line @angular-eslint/no-output-on-prefix
        this.onDataReceived = new EventEmitter();
        /**
         * Heading level of the dialog title.
         */
        this.headingLevel = input(5);
        /** @hidden */
        this._headingLevel = computed(() => this.headingLevel() ? Number.parseInt(`${this.headingLevel()}`.replace(/\D/g, ''), 10) : undefined);
        /** @hidden */
        this._tabTypes = VhdTab;
        /** @hidden */
        this._hasAdvanced = true;
        /** @hidden */
        this._displayedFilters = [];
        /** @hidden */
        this._displayedData = [];
        /** @hidden */
        this._mainSearch = '';
        /** handles rtl service
         * @hidden */
        this._dir$ = computed(() => (this._rtlService?.rtlSignal() ? 'rtl' : 'ltr'));
        /** @hidden */
        this.selectedTab = null;
        /** @hidden */
        this.shownFilterCount = Infinity;
        /** @hidden
         * To differentiate between first loading when skeletons be shown and subsequent loadings when busy indicator be shown
         */
        this._firstLoadingDone = false;
        /** @hidden */
        this._destroyed = inject(DestroyRef);
        /** @hidden Previous state */
        this._prevState = {
            selected: [],
            conditions: []
        };
        /** @hidden Current data for local manupulation */
        this._currentValue = {
            selected: [],
            conditions: []
        };
        /** @hidden */
        this._internalLoadingState = false;
        /** @hidden */
        this._onDestroy$ = new Subject();
        /** @hidden */
        this._trackBySelectedFn = (_index, item) => item && item[this.uniqueKey];
        /** Default display function for define conditions */
        if (!this.conditionDisplayFn || typeof this.conditionDisplayFn !== 'function') {
            this.conditionDisplayFn = defaultConditionDisplayFn;
        }
    }
    /** @hidden */
    get isMobileAdvancedSearchActive() {
        if (this.mobile) {
            return this.isOpenAdvanced;
        }
        return false;
    }
    /** @hidden */
    get hasSelectedTab() {
        return this.selectedTab != null && this.selectedTab in VhdTab;
    }
    /** @hidden */
    get showSelectionTab() {
        return this.tabs !== 'define';
    }
    /** @hidden */
    get showDefineTab() {
        return this.tabs !== 'select';
    }
    /** @hidden */
    get isSelectionTab() {
        return this.selectedTab === VhdTab.selectFromList || this.selectedTab === VhdTab.advancedSearch;
    }
    /** @hidden */
    get selectedItems() {
        return this._currentValue.selected || [];
    }
    /** @hidden */
    get conditionItems() {
        return this._currentValue.conditions || [];
    }
    /** @hidden */
    get validConditions() {
        return this._getValidCondition(this.conditionItems);
    }
    /** @hidden */
    get hasSelectedAndConditions() {
        return Boolean(this.selectedItems.length + this.validConditions.length);
    }
    /** @hidden */
    get isShowAllFilters() {
        return this.filters.length > this.maxShownInitialFilters && this.shownFilterCount > this.maxShownInitialFilters;
    }
    /** @hidden */
    get isOpen() {
        return !!this.activeDialog;
    }
    /** @hidden */
    ngOnChanges(changes) {
        if (this.isOpen) {
            if ('dataSource' in changes) {
                this._initializeDS();
            }
        }
    }
    /** @hidden */
    ngOnDestroy() {
        this._resetState();
        this._onDestroy$.next();
    }
    /** Open dialog */
    open() {
        if (!this.isValidOptions()) {
            throw new Error('Please check required fields');
        }
        if (this.isOpen) {
            return;
        }
        this._savePreviousState();
        this._updateFilters();
        this._initializeDS();
        this._initializeTab();
        if (!this.dialogConfig.ariaLabelledBy) {
            this.dialogConfig.ariaLabelledBy = this.headerId;
        }
        this.activeDialog = this._dialogService.open(this.dialogContainer, {
            backdropClickCloseable: false,
            hasBackdrop: true,
            verticalPadding: false,
            escKeyCloseable: false,
            dialogPanelClass: `fdp-value-help-dialog ${this.mobile ? 'fdp-value-help-dialog-mobile' : ''}`,
            ...this.dialogConfig,
            mobile: this.mobile,
            maxWidth: this.mobile ? undefined : '92%',
            width: this.mobile ? undefined : '1080px',
            height: this.mobile ? undefined : '98%'
        });
        this._listenDialogEvents();
    }
    /**
     * Toggle advanced search panel
     */
    toggleAdvancedSearch(state) {
        if (typeof state !== 'undefined') {
            this.isOpenAdvanced = state;
        }
        else {
            this.isOpenAdvanced = !this.isOpenAdvanced;
        }
        if (this.mobile) {
            this.selectedTab = this.isOpenAdvanced ? VhdTab.advancedSearch : VhdTab.selectFromList;
        }
    }
    /**
     * Clear all selected items
     */
    clearSelectedAndConditionItems() {
        this._currentValue.selected = [];
        this._currentValue.conditions = [];
        this._changeDetectorRef.markForCheck();
    }
    /** Search by only the search term. */
    search() {
        this.filter(true);
    }
    /**
     * Search by all filled filters, including the search term.
     */
    filter(onlySearch = false) {
        const nonEmptyFilters = new Map();
        if (!onlySearch) {
            this._displayedFilters
                .filter(({ value }) => !!value && typeof value === 'string' ? value.trim().length : value !== undefined)
                .forEach((e) => nonEmptyFilters.set(e.key, e.value));
        }
        if (this._mainSearch.length) {
            nonEmptyFilters.set('*', this._mainSearch);
        }
        this.dataSource?.match(nonEmptyFilters);
    }
    /**
     * Apply search from advanced filters view, using when mobile view is active
     */
    searchAdvanced() {
        this.filter();
        this.selectedTab = VhdTab.selectFromList;
        this.isOpenAdvanced = false;
    }
    /** Remove item from selected array */
    removeSelected(index) {
        this._currentValue.selected = this.selectedItems.filter((_, i) => i !== index);
        this._changeDetectorRef.markForCheck();
    }
    /**
     * Remove condition item
     */
    removeCondition(index) {
        this._currentValue.conditions = this.conditionItems.filter((_, i) => i !== index);
        this._changeDetectorRef.markForCheck();
    }
    /**
     * Switch tab by type
     */
    switchTab(type = null) {
        this.selectedTab = type;
    }
    /**
     * Close dialog with value;
     */
    success() {
        if (!this.activeDialog) {
            return;
        }
        const value = {
            selected: this.selectedItems,
            conditions: this.validConditions
        };
        this._internalLoadingState = true;
        this._changeDetectorRef.detectChanges();
        this._getValidatorFunction(value)
            .pipe(tap(() => {
            this._internalLoadingState = false;
            this._changeDetectorRef.detectChanges();
        }), filter((r) => r), take$1(1), takeUntilDestroyed(this._destroyed))
            .subscribe(() => {
            if (typeof this.formatToken === 'function') {
                this.formatToken(value);
            }
            this.activeDialog?.close(value);
        });
    }
    /**
     * Hide advanced search on mobile view and if it's opened
     * Close dialog with null value;
     */
    dismiss() {
        if (this.mobile && this.isOpenAdvanced) {
            this.isOpenAdvanced = false;
            this.switchTab(VhdTab.selectFromList);
        }
        else {
            this._currentValue = this._prevState;
            if (this.activeDialog) {
                this.activeDialog.close();
            }
        }
    }
    /** @hidden */
    _trackByFilterFn(_index, item) {
        return item && item.key;
    }
    /** @hidden */
    _trackByConditionFn(_index, item) {
        return item ? item.value + item.valueTo + item.strategy + item.key : undefined;
    }
    /** @hidden */
    onSelect($event) {
        this._currentValue.selected = $event;
        this._changeDetectorRef.markForCheck();
        if (this.searchSelection === 'once') {
            this.success();
        }
    }
    /** @hidden */
    onConditionChange($event) {
        this._currentValue.conditions = $event;
        this._changeDetectorRef.markForCheck();
    }
    /** @hidden */
    toggleShownFilters() {
        this.shownFilterCount =
            this.maxShownInitialFilters === this.shownFilterCount ? Infinity : this.maxShownInitialFilters;
    }
    /** @hidden */
    _initShownFilters() {
        this.shownFilterCount = this.maxShownInitialFilters || Infinity;
    }
    /** @hidden */
    _getValidCondition(items = []) {
        return items.filter((item) => {
            if (item.strategy === VhdDefineIncludeStrategy.empty ||
                item.strategy === VhdDefineExcludeStrategy.not_empty) {
                return true;
            }
            if (item.strategy === VhdDefineIncludeStrategy.between) {
                return Boolean(item.value.length && item.valueTo.length);
            }
            if (!item.valid) {
                return false;
            }
            return Boolean(item.value.length);
        });
    }
    /** @hidden */
    _initializeDS(ds = this.dataSource) {
        this._resetSourceStream();
        if (this.showSelectionTab) {
            this._dsSubscription = new Subscription();
            this._dsSubscription.add(ds?.onDataRequested().subscribe(() => {
                this._internalLoadingState = true;
                this.onDataRequested.emit();
            }));
            this._dsSubscription.add(ds?.onDataReceived().subscribe(() => {
                this._internalLoadingState = false;
                this._firstLoadingDone = true;
                this.onDataReceived.emit();
            }));
            const dsSub = this.openDataStream()
                .pipe(takeUntilDestroyed(this._destroyed))
                .subscribe((data) => {
                this._displayedData = data.slice();
                this._changeDetectorRef.markForCheck();
            });
            this._dsSubscription.add(dsSub);
        }
    }
    /** @hidden Save previous state */
    _savePreviousState() {
        const value = cloneDeep(this.value);
        this._currentValue = value;
        this._prevState = value;
    }
    /** @hidden */
    _initializeTab() {
        if (this.mobile) {
            this.isOpenAdvanced = false;
        }
        if (this.showSelectionTab && this.showDefineTab) {
            this.switchTab(this.mobile ? undefined : this.initialTab);
        }
        else if (this.showSelectionTab) {
            this.switchTab(VhdTab.selectFromList);
        }
        else if (this.showDefineTab) {
            this.switchTab(VhdTab.defineConditions);
        }
        this._initShownFilters();
    }
    /** @hidden */
    _listenDialogEvents() {
        if (!this.activeDialog) {
            return;
        }
        this.activeDialog.afterClosed.pipe(takeUntilDestroyed(this._destroyed)).subscribe((value) => {
            if (value) {
                this.value = value;
                this.valueChange.emit(value);
            }
            this._resetState();
        });
        this.filters.changes.pipe(takeUntilDestroyed(this._destroyed)).subscribe(() => {
            this._updateFilters();
        });
    }
    /** @hidden */
    _resetState() {
        this._resetSourceStream();
        this._mainSearch = '';
        this.activeDialog = undefined;
    }
    /** @hidden */
    _updateFilters() {
        this._displayedFilters = this.filters.map((e) => ({
            ...e,
            label: e.label || e.key
        }));
        this._hasAdvanced = this._displayedFilters.some((e) => !!e.advanced);
    }
    /** @hidden */
    openDataStream() {
        if (this._dataSource) {
            this._dataSource.match();
            return this._dataSource.open();
        }
        throw new Error(`[dataSource] source did not match an array, Observable, or DataSource`);
    }
    /** @hidden */
    toDataStream(ds) {
        if (isDataSource(ds)) {
            return ds;
        }
        else if (Array.isArray(ds)) {
            return new ArrayValueHelpDialogDataSource(ds);
        }
        else if (isObservable(ds)) {
            return new ObservableValueHelpDialogDataSource(ds);
        }
        return undefined;
    }
    /** @hidden */
    _resetSourceStream() {
        if (isDataSource(this.dataSource)) {
            this.dataSource.close();
        }
        if (this._dsSubscription) {
            this._dsSubscription.unsubscribe();
            this._dsSubscription = null;
        }
    }
    /** @hidden */
    isValidOptions() {
        if (this.showSelectionTab) {
            return (!!this.dataSource &&
                typeof this.uniqueKey === 'string' &&
                (typeof this.tokenViewField === 'string' || typeof this.tokenizerFn === 'function'));
        }
        return true;
    }
    _getValidatorFunction(value) {
        const validator = typeof this.tokenValidator === 'function' ? this.tokenValidator(value) : of(true);
        return isObservable(validator) ? validator : of(validator);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: PlatformValueHelpDialogComponent, deps: [{ token: i0.ElementRef }, { token: i0.ChangeDetectorRef }, { token: i1$1.DialogService }, { token: i2.RtlService, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.0.7", type: PlatformValueHelpDialogComponent, isStandalone: true, selector: "fdp-value-help-dialog", inputs: { id: { classPropertyName: "id", publicName: "id", isSignal: false, isRequired: false, transformFunction: null }, value: { classPropertyName: "value", publicName: "value", isSignal: false, isRequired: false, transformFunction: null }, dialogTitle: { classPropertyName: "dialogTitle", publicName: "dialogTitle", isSignal: false, isRequired: false, transformFunction: null }, initialTab: { classPropertyName: "initialTab", publicName: "initialTab", isSignal: false, isRequired: false, transformFunction: null }, tabs: { classPropertyName: "tabs", publicName: "tabs", isSignal: false, isRequired: false, transformFunction: null }, isOpenAdvanced: { classPropertyName: "isOpenAdvanced", publicName: "isOpenAdvanced", isSignal: false, isRequired: false, transformFunction: null }, dataSource: { classPropertyName: "dataSource", publicName: "dataSource", isSignal: false, isRequired: false, transformFunction: null }, dialogConfig: { classPropertyName: "dialogConfig", publicName: "dialogConfig", isSignal: false, isRequired: false, transformFunction: null }, uniqueKey: { classPropertyName: "uniqueKey", publicName: "uniqueKey", isSignal: false, isRequired: false, transformFunction: null }, headerId: { classPropertyName: "headerId", publicName: "headerId", isSignal: false, isRequired: false, transformFunction: null }, tokenViewField: { classPropertyName: "tokenViewField", publicName: "tokenViewField", isSignal: false, isRequired: false, transformFunction: null }, tokenizerFn: { classPropertyName: "tokenizerFn", publicName: "tokenizerFn", isSignal: false, isRequired: false, transformFunction: null }, mobile: { classPropertyName: "mobile", publicName: "mobile", isSignal: false, isRequired: false, transformFunction: null }, formatToken: { classPropertyName: "formatToken", publicName: "formatToken", isSignal: false, isRequired: false, transformFunction: null }, conditionDisplayFn: { classPropertyName: "conditionDisplayFn", publicName: "conditionDisplayFn", isSignal: false, isRequired: false, transformFunction: null }, tokenValidator: { classPropertyName: "tokenValidator", publicName: "tokenValidator", isSignal: false, isRequired: false, transformFunction: null }, searchSelection: { classPropertyName: "searchSelection", publicName: "searchSelection", isSignal: false, isRequired: false, transformFunction: null }, searchTablePageSize: { classPropertyName: "searchTablePageSize", publicName: "searchTablePageSize", isSignal: false, isRequired: false, transformFunction: null }, searchTableMobileHeaders: { classPropertyName: "searchTableMobileHeaders", publicName: "searchTableMobileHeaders", isSignal: false, isRequired: false, transformFunction: null }, maxShownInitialFilters: { classPropertyName: "maxShownInitialFilters", publicName: "maxShownInitialFilters", isSignal: false, isRequired: false, transformFunction: null }, loading: { classPropertyName: "loading", publicName: "loading", isSignal: false, isRequired: false, transformFunction: null }, allowSelectAll: { classPropertyName: "allowSelectAll", publicName: "allowSelectAll", isSignal: false, isRequired: false, transformFunction: null }, defineStrategyLabels: { classPropertyName: "defineStrategyLabels", publicName: "defineStrategyLabels", isSignal: false, isRequired: false, transformFunction: null }, headingLevel: { classPropertyName: "headingLevel", publicName: "headingLevel", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { valueChange: "valueChange", onDataRequested: "onDataRequested", onDataReceived: "onDataReceived" }, providers: [
            {
                provide: VhdComponent,
                useExisting: PlatformValueHelpDialogComponent
            }
        ], queries: [{ propertyName: "filters", predicate: VhdFilterComponent }, { propertyName: "columnDef", predicate: ValueHelpColumnDefDirective }], viewQueries: [{ propertyName: "dialogContainer", first: true, predicate: ["container"], descendants: true, read: TemplateRef }], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "<ng-template [fdDialogTemplate] let-dialog let-dialogConfig=\"dialogConfig\" #container>\n    <fd-dialog [dialogConfig]=\"dialogConfig\" [dialogRef]=\"dialog\">\n        <fd-dialog-header [attr.dir]=\"_dir$()\">\n            <ng-template fdkTemplate=\"header\">\n                <ng-template [ngTemplateOutlet]=\"mobile ? mobileDialogTitle : desktopDialogTitle\"></ng-template>\n            </ng-template>\n        </fd-dialog-header>\n        <fd-dialog-body [attr.dir]=\"_dir$()\">\n            @if (!mobile) {\n                <ng-template [ngTemplateOutlet]=\"advancedSearchContent\"></ng-template>\n            }\n            <div fd-scrollbar class=\"fdp-value-help-dialog__content-holder\">\n                @if (mobile) {\n                    <ng-template [ngTemplateOutlet]=\"advancedSearchContent\"></ng-template>\n                }\n                @if (selectedTab === _tabTypes.selectFromList) {\n                    <ng-template [ngTemplateOutlet]=\"selectionContent\"></ng-template>\n                }\n                @if (selectedTab === _tabTypes.defineConditions) {\n                    <ng-template [ngTemplateOutlet]=\"defineConditionsContent\"></ng-template>\n                }\n            </div>\n        </fd-dialog-body>\n        <fd-dialog-footer [attr.dir]=\"_dir$()\">\n            <ng-template fdkTemplate=\"footer\">\n                @if (!isMobileAdvancedSearchActive) {\n                    <div\n                        class=\"fdp-value-help-dialog__row fdp-value-help-dialog__selection-row\"\n                        [attr.aria-label]=\"'platformVHD.selectedAndConditionLabel' | fdTranslate\"\n                    >\n                        <span\n                            role=\"heading\"\n                            [attr.aria-level]=\"_headingLevel()\"\n                            fd-title\n                            class=\"selected-and-condition-title\"\n                            [id]=\"id + '-selected-item'\"\n                        >\n                            @if (hasSelectedAndConditions) {\n                                {{ 'platformVHD.selectedAndConditionLabel' | fdTranslate }}\n                                ({{ selectedItems.length + validConditions.length }})\n                            } @else {\n                                {{ 'platformVHD.selectedEmptyLabel' | fdTranslate }}\n                            }\n                        </span>\n                        <div class=\"fdp-value-help-dialog__tokens-wrapper\">\n                            <div class=\"fdp-value-help-dialog__tokens\">\n                                <!-- Selected items -->\n                                <fd-tokenizer>\n                                    @for (\n                                        item of selectedItems;\n                                        track _trackBySelectedFn(selectedIndex, item);\n                                        let selectedIndex = $index\n                                    ) {\n                                        <fd-token\n                                            fd-toolbar-item\n                                            fdOverflowPriority=\"high\"\n                                            class=\"fdp-value-help-dialog__selection-token\"\n                                            (onCloseClick)=\"removeSelected(selectedIndex)\"\n                                            >{{\n                                                !!tokenizerFn\n                                                    ? (item | displayFnPipe: tokenizerFn)\n                                                    : item[tokenViewField]\n                                            }}\n                                        </fd-token>\n                                    }\n                                    @for (\n                                        item of validConditions;\n                                        track _trackByConditionFn(conditionIndex, item);\n                                        let conditionIndex = $index\n                                    ) {\n                                        <fd-token\n                                            fd-toolbar-item\n                                            fdOverflowPriority=\"high\"\n                                            class=\"fdp-value-help-dialog__selection-token\"\n                                            (onCloseClick)=\"removeCondition(conditionIndex)\"\n                                        >\n                                            <ng-template\n                                                [ngTemplateOutlet]=\"conditionValue\"\n                                                [ngTemplateOutletContext]=\"{ item: item }\"\n                                            ></ng-template>\n                                        </fd-token>\n                                    }\n                                    <input fd-form-control fd-tokenizer-input [disabled]=\"!hasSelectedAndConditions\" />\n                                </fd-tokenizer>\n                            </div>\n                            <button\n                                (click)=\"clearSelectedAndConditionItems()\"\n                                class=\"fdp-value-help-dialog__tokens-clear\"\n                                fd-button\n                                [disabled]=\"!hasSelectedAndConditions\"\n                                fdType=\"transparent\"\n                                [title]=\"'platformVHD.footerClearSelectedTitle' | fdTranslate\"\n                                glyph=\"decline\"\n                                [ariaLabel]=\"'platformVHD.footerClearSelectedAriaLabel' | fdTranslate\"\n                            ></button>\n                        </div>\n                    </div>\n                }\n                <div class=\"fdp-value-help-dialog__actions-row\">\n                    @if (mobile && isOpenAdvanced) {\n                        <button\n                            fd-button\n                            data-go-advanced\n                            [label]=\"'platformVHD.searchButtonLabel' | fdTranslate\"\n                            fdType=\"emphasized\"\n                            (click)=\"searchAdvanced()\"\n                        ></button>\n                    }\n                    @if (selectedTab !== _tabTypes.advancedSearch) {\n                        <button\n                            fd-button\n                            data-succes\n                            [disabled]=\"loadingState\"\n                            [label]=\"'platformVHD.successButtonLabel' | fdTranslate\"\n                            fdType=\"emphasized\"\n                            (click)=\"success()\"\n                        ></button>\n                    }\n                    <button\n                        fd-button\n                        data-dismiss-dialog\n                        [label]=\"'platformVHD.cancelButtonLabel' | fdTranslate\"\n                        fdType=\"transparent\"\n                        (click)=\"dismiss()\"\n                    ></button>\n                </div>\n            </ng-template>\n        </fd-dialog-footer>\n    </fd-dialog>\n</ng-template>\n<ng-template #advancedSearchContent>\n    @if (isSelectionTab) {\n        <form class=\"fdp-value-help-dialog__row fdp-value-help-dialog__advanced-search\" [id]=\"'advanced-search-' + id\">\n            @if (!mobile || (mobile && !isOpenAdvanced)) {\n                <fd-layout-grid>\n                    <div fdLayoutGridRow>\n                        <div [fdLayoutGridCol]=\"12\" [colMd]=\"12\" [colLg]=\"mobile ? 12 : 6\" [colXl]=\"mobile ? 12 : 6\">\n                            <fdp-search-field\n                                [placeholder]=\"'platformVHD.searchPlaceholder' | fdTranslate\"\n                                (searchSubmit)=\"search()\"\n                                (inputChange)=\"_mainSearch = $event.text\"\n                            ></fdp-search-field>\n                        </div>\n                        @if (_hasAdvanced) {\n                            <div\n                                [fdLayoutGridCol]=\"12\"\n                                [colMd]=\"12\"\n                                [colLg]=\"mobile ? 12 : 6\"\n                                [colXl]=\"mobile ? 12 : 6\"\n                                class=\"fdp-value-help-dialog__advanced-actions\"\n                            >\n                                <fd-toolbar [clearBorder]=\"true\">\n                                    <fd-toolbar-spacer></fd-toolbar-spacer>\n                                    @if (_hasAdvanced) {\n                                        <button\n                                            fd-toolbar-item\n                                            fd-button\n                                            fdType=\"transparent\"\n                                            [label]=\"\n                                                (mobile\n                                                    ? 'platformVHD.searchAdvancedSearchLabel'\n                                                    : isOpenAdvanced\n                                                      ? 'platformVHD.searchHideAdvancedSearchLabel'\n                                                      : 'platformVHD.searchShowAdvancedSearchLabel'\n                                                ) | fdTranslate\n                                            \"\n                                            (click)=\"toggleAdvancedSearch()\"\n                                        ></button>\n                                    }\n                                    <button\n                                        fd-toolbar-item\n                                        type=\"submit\"\n                                        fd-button\n                                        fdType=\"emphasized\"\n                                        [label]=\"'platformVHD.searchButtonLabel' | fdTranslate\"\n                                        (click)=\"filter()\"\n                                    ></button>\n                                </fd-toolbar>\n                            </div>\n                        }\n                    </div>\n                </fd-layout-grid>\n            }\n            @if (isOpenAdvanced && _hasAdvanced) {\n                <div [id]=\"'advanced-search-content-' + id\" class=\"fdp-value-help-dialog__advanced-filters\">\n                    <fd-busy-indicator [loading]=\"loadingState && _firstLoadingDone\" [block]=\"true\">\n                        @if (_firstLoadingDone) {\n                            <fd-layout-grid\n                                [class.fdp-value-help-dialog__with-toggle-all]=\"filters.length > maxShownInitialFilters\"\n                            >\n                                <div fdLayoutGridRow>\n                                    @for (\n                                        filter of _displayedFilters | slice: 0 : shownFilterCount + 1;\n                                        track _trackByFilterFn($index, filter)\n                                    ) {\n                                        @if (filter.advanced) {\n                                            <div [fdLayoutGridCol]=\"12\" [colMd]=\"12\" [colLg]=\"6\" [colXl]=\"3\">\n                                                <label\n                                                    class=\"fd-form-group__header\"\n                                                    fd-form-label\n                                                    [for]=\"'input' + filter.key\"\n                                                    >{{ filter.label }}:</label\n                                                >\n                                                @if (filter.filterDef) {\n                                                    <ng-template\n                                                        [ngTemplateOutlet]=\"filter.filterDef.templateRef\"\n                                                        [ngTemplateOutletContext]=\"{ $implicit: filter }\"\n                                                    ></ng-template>\n                                                } @else {\n                                                    <input\n                                                        [(ngModel)]=\"filter.value\"\n                                                        fd-form-control\n                                                        type=\"text\"\n                                                        [name]=\"'search-by-' + filter.label\"\n                                                        [id]=\"'input' + filter.key\"\n                                                    />\n                                                }\n                                            </div>\n                                        }\n                                    }\n                                    @if (filters.length > maxShownInitialFilters) {\n                                        <div\n                                            colGrow\n                                            [fdLayoutGridCol]=\"12\"\n                                            [colMd]=\"12\"\n                                            [colLg]=\"6\"\n                                            [colXl]=\"3\"\n                                            class=\"fdp-value-help-dialog__toggle-filters\"\n                                        >\n                                            <button\n                                                fd-button\n                                                fdType=\"transparent\"\n                                                (click)=\"toggleShownFilters()\"\n                                                [label]=\"\n                                                    (isShowAllFilters\n                                                        ? 'platformVHD.searchHideAllAdvancedSearchLabel'\n                                                        : 'platformVHD.searchShowAllAdvancedSearchLabel'\n                                                    ) | fdTranslate\n                                                \"\n                                            ></button>\n                                        </div>\n                                    }\n                                </div>\n                            </fd-layout-grid>\n                        } @else {\n                            <fd-skeleton width=\"100%\" height=\"100px\">\n                                <svg:rect x=\"0\" y=\"0\" rx=\"4\" width=\"15%\" height=\"8\" />\n                                <svg:rect x=\"0\" y=\"20\" rx=\"4\" width=\"25%\" height=\"16\" />\n                                <svg:rect x=\"35%\" y=\"0\" rx=\"4\" width=\"15%\" height=\"8\" />\n                                <svg:rect x=\"35%\" y=\"20\" rx=\"4\" width=\"25%\" height=\"16\" />\n                                <svg:rect x=\"0\" y=\"60\" rx=\"4\" width=\"15%\" height=\"8\" />\n                                <svg:rect x=\"0\" y=\"80\" rx=\"4\" width=\"25%\" height=\"16\" />\n                            </fd-skeleton>\n                        }\n                    </fd-busy-indicator>\n                </div>\n            }\n        </form>\n    }\n</ng-template>\n<ng-template #selectionContent>\n    <fd-busy-indicator\n        [loading]=\"loadingState && _firstLoadingDone\"\n        [block]=\"true\"\n        class=\"fdp-value-help-dialog__table-busy-indicator\"\n    >\n        <fdp-select-tab\n            [selected]=\"selectedItems\"\n            [loading]=\"loadingState && !_firstLoadingDone\"\n            [uid]=\"id\"\n            [displayedData]=\"_displayedData\"\n            [tabTitle]=\"'platformVHD.selectTabTitle' | fdTranslate\"\n            [mobile]=\"mobile\"\n            [selection]=\"searchSelection\"\n            [uniqueKey]=\"uniqueKey\"\n            [pageSize]=\"searchTablePageSize\"\n            [defaultMobileHeaders]=\"searchTableMobileHeaders\"\n            [filters]=\"_displayedFilters\"\n            [allowSelectAll]=\"allowSelectAll\"\n            (select)=\"onSelect($event)\"\n        ></fdp-select-tab>\n    </fd-busy-indicator>\n</ng-template>\n<ng-template #defineConditionsContent>\n    <div fd-scrollbar>\n        <fdp-define-tab\n            [strategyLabels]=\"defineStrategyLabels\"\n            [conditions]=\"conditionItems\"\n            [uid]=\"id\"\n            [tabTitle]=\"'platformVHD.defineTabTitle' | fdTranslate\"\n            [mobile]=\"mobile\"\n            (conditionChange)=\"onConditionChange($event)\"\n        ></fdp-define-tab>\n    </div>\n</ng-template>\n<ng-template #dialogTitleText>\n    <span role=\"heading\" [attr.aria-level]=\"_headingLevel()\" [attr.id]=\"headerId\" fd-title>{{ dialogTitle }}</span>\n</ng-template>\n<ng-template #tabLink let-title=\"title\" let-type=\"type\">\n    @if (selectedTab === type && showSelectionTab && showDefineTab) {\n        <button\n            fd-button\n            glyph=\"navigation-left-arrow\"\n            fdType=\"transparent\"\n            (click)=\"switchTab()\"\n            [title]=\"'platformVHD.selectMobileTabBackBtnTitle' | fdTranslate\"\n        ></button>\n        <span role=\"heading\" [attr.aria-level]=\"_headingLevel()\" fd-title>{{ title }}</span>\n    }\n    @if (selectedTab !== type) {\n        <a\n            fd-list-link\n            (click)=\"switchTab(type)\"\n            [title]=\"'platformVHD.selectMobileTabBtnOpenDialogLabel' | fdTranslate\"\n        >\n            <span fd-list-title>{{ title }}</span>\n            <i fd-list-icon glyph=\"navigation-right-arrow\"></i>\n        </a>\n    }\n</ng-template>\n<ng-template #advancedHeader>\n    <button fd-button glyph=\"navigation-left-arrow\" fdType=\"transparent\" (click)=\"toggleAdvancedSearch()\"></button>\n    <span role=\"heading\" [attr.aria-level]=\"_headingLevel()\" fd-title>{{\n        'platformVHD.searchAdvancedSearchLabel' | fdTranslate\n    }}</span>\n</ng-template>\n<ng-template #desktopDialogTitle>\n    <ng-template [ngTemplateOutlet]=\"dialogTitleText\"></ng-template>\n    <ng-template [ngTemplateOutlet]=\"desktopTabs\"></ng-template>\n</ng-template>\n<ng-template #mobileDialogTitle>\n    <div class=\"fdp-value-help-dialog__mobile-title\">\n        @if (hasSelectedTab) {\n            <ng-template [ngTemplateOutlet]=\"selectedTabHeader\"></ng-template>\n        } @else {\n            <span role=\"heading\" [attr.aria-level]=\"_headingLevel()\" [attr.id]=\"headerId\" fd-title>{{\n                dialogTitle\n            }}</span>\n        }\n    </div>\n    <ng-template [ngTemplateOutlet]=\"mobileTabs\"></ng-template>\n</ng-template>\n<ng-template #desktopTabs>\n    @if (showSelectionTab && showDefineTab) {\n        <nav fd-tab-nav class=\"fdp-value-help-dialog__tabs\">\n            @if (showSelectionTab) {\n                <div fd-tab-item (click)=\"switchTab(_tabTypes.selectFromList)\">\n                    <a\n                        fd-tab-link\n                        [active]=\"selectedTab === _tabTypes.selectFromList\"\n                        [tabindex]=\"selectedTab === _tabTypes.selectFromList ? '0' : '-1'\"\n                        ><span fd-tab-tag>{{ 'platformVHD.selectTabTitle' | fdTranslate }}</span></a\n                    >\n                </div>\n            }\n            @if (showDefineTab) {\n                <div fd-tab-item (click)=\"switchTab(_tabTypes.defineConditions)\">\n                    <a\n                        fd-tab-link\n                        [active]=\"selectedTab === _tabTypes.defineConditions\"\n                        [tabindex]=\"selectedTab === _tabTypes.defineConditions ? '0' : '-1'\"\n                        ><span fd-tab-tag>{{ 'platformVHD.defineTabTitle' | fdTranslate }}</span></a\n                    >\n                </div>\n            }\n        </nav>\n    }\n</ng-template>\n<ng-template #mobileTabs>\n    @if (!hasSelectedTab && showSelectionTab && showDefineTab) {\n        <div>\n            @if (showSelectionTab) {\n                <div fd-bar [inPage]=\"true\">\n                    <div fd-bar-left>\n                        <fd-bar-element>\n                            {{ 'platformVHD.selectTabTitle' | fdTranslate }}\n                        </fd-bar-element>\n                    </div>\n                    <div fd-bar-right>\n                        <fd-bar-element>\n                            <fd-button-bar\n                                glyph=\"navigation-right-arrow\"\n                                (click)=\"switchTab(_tabTypes.selectFromList)\"\n                                [title]=\"\n                                    'platformVHD.selectMobileTabTitle'\n                                        | fdTranslate: { title: 'platformVHD.selectTabTitle' | fdTranslate }\n                                \"\n                            ></fd-button-bar>\n                        </fd-bar-element>\n                    </div>\n                </div>\n            }\n            @if (showDefineTab) {\n                <div fd-bar [inPage]=\"true\">\n                    <div fd-bar-left>\n                        <fd-bar-element>\n                            {{ 'platformVHD.defineTabTitle' | fdTranslate }}\n                        </fd-bar-element>\n                    </div>\n                    <div fd-bar-right>\n                        <fd-bar-element>\n                            <fd-button-bar\n                                glyph=\"navigation-right-arrow\"\n                                [title]=\"\n                                    'platformVHD.selectMobileTabTitle'\n                                        | fdTranslate: { title: 'platformVHD.defineTabTitle' | fdTranslate }\n                                \"\n                                (click)=\"switchTab(_tabTypes.defineConditions)\"\n                            >\n                            </fd-button-bar>\n                        </fd-bar-element>\n                    </div>\n                </div>\n            }\n        </div>\n    }\n</ng-template>\n<ng-template #selectedTabHeader>\n    @switch (selectedTab) {\n        @case (_tabTypes.selectFromList) {\n            <ng-template\n                [ngTemplateOutlet]=\"tabLink\"\n                [ngTemplateOutletContext]=\"{\n                    title: 'platformVHD.selectTabTitle' | fdTranslate,\n                    type: selectedTab\n                }\"\n            ></ng-template>\n        }\n        @case (_tabTypes.advancedSearch) {\n            <ng-template [ngTemplateOutlet]=\"advancedHeader\"></ng-template>\n        }\n        @case (_tabTypes.defineConditions) {\n            <ng-template\n                [ngTemplateOutlet]=\"tabLink\"\n                [ngTemplateOutletContext]=\"{\n                    title: 'platformVHD.defineTabTitle' | fdTranslate,\n                    type: selectedTab\n                }\"\n            ></ng-template>\n        }\n    }\n</ng-template>\n<ng-template #conditionValue let-item=\"item\">\n    @if (item.strategy !== 'empty' && item.strategy !== 'not_empty') {\n        <span>\n            {{ item | displayFnPipe: conditionDisplayFn : _displayedFilters }}\n        </span>\n    } @else {\n        @if (item.strategy === 'not_empty') {\n            !(<ng-template [ngTemplateOutlet]=\"emptyConditionText\"></ng-template>)\n        } @else {\n            &lt;{{ 'platformVHD.selectMobileConditionEmpty' | fdTranslate }}&gt;\n        }\n    }\n</ng-template>\n<ng-template #emptyConditionText> &lt;{{ 'platformVHD.selectMobileConditionEmpty' | fdTranslate }}&gt; </ng-template>\n", styles: [".fdp-value-help-dialog .fd-dialog__body{display:flex;flex-direction:column;overflow:hidden}.fdp-value-help-dialog .fd-title--h5{padding:.5rem 0}.fdp-value-help-dialog .fd-toolbar{background:none;border:none;padding:.1735rem .5rem;height:auto;min-height:1.625rem}.fdp-value-help-dialog__row.fdp-value-help-dialog__advanced-search{padding-top:1rem}.fdp-value-help-dialog__advanced-search,.fdp-value-help-dialog .fd-dialog__body{background-color:var(--sapBackgroundColor, #f7f7f7)}.fdp-value-help-dialog__advanced-filters{padding-top:1rem}.fdp-value-help-dialog__advanced-filters label{height:auto}.fdp-value-help-dialog__toggle-filters{display:flex;justify-content:flex-end;align-items:flex-end}.fdp-value-help-dialog__toggle-filters .fd-button{margin-bottom:.25rem}.fdp-value-help-dialog__advanced-actions{display:flex;align-items:center;justify-content:flex-end}.fdp-value-help-dialog-mobile .fdp-value-help-dialog__advanced-actions{justify-content:flex-start}.fdp-value-help-dialog__advanced-actions .fd-toolbar{padding:0}.fdp-value-help-dialog .fd-bar.fd-bar--cozy{height:auto}.fdp-value-help-dialog .fd-dialog__header{box-shadow:none}.fdp-value-help-dialog .fd-dialog__header .fd-title{display:flex;align-items:center;padding-left:2rem;padding-right:2rem;min-height:2.5rem;box-shadow:none;border-bottom:none;background-color:var(--sapObjectHeader_Background, #fff);position:relative;z-index:2}.fdp-value-help-dialog .fd-dialog__header .fdp-value-help-dialog__mobile-title{display:flex;border-bottom:1px solid #d9d9d9;border-bottom:1px solid var(--sapGroup_TitleBorderColor, #d9d9d9)}.fdp-value-help-dialog .fd-dialog__header .fdp-value-help-dialog__mobile-title .fd-title{flex:1 1 auto;border:none}.fdp-value-help-dialog .fd-dialog__header .fdp-value-help-dialog__tabs{position:relative}.fdp-value-help-dialog .fd-dialog__header,.fdp-value-help-dialog .fd-dialog__footer{height:auto;flex-direction:column}.fdp-value-help-dialog .fd-dialog__header.fd-bar,.fdp-value-help-dialog .fd-dialog__footer.fd-bar{padding:0}.fdp-value-help-dialog .fd-dialog__footer{border-top:none}.fdp-value-help-dialog__content-holder{padding:0 2rem 1rem;display:flex;flex-direction:column;height:100%;width:100%;overflow:hidden;min-height:20rem}.fdp-value-help-dialog__row{padding:0 2rem 1rem}.fdp-value-help-dialog__row.fdp-value-help-dialog__selection-row{background-color:var(--sapBackgroundColor, #f7f7f7)}.fdp-value-help-dialog__tokens-wrapper{display:flex}.fdp-value-help-dialog__tokens{flex:1 1 auto;overflow:hidden;align-items:center;border:1px solid var(--sapContent_ForegroundBorderColor, #89919a);margin-right:.5rem;border-radius:var(--sapElement_BorderCornerRadius, .25rem);background:none}.fdp-value-help-dialog__tokens fd-toolbar{flex:1 1 auto;overflow:hidden}.fdp-value-help-dialog__tokens-clear{height:auto;min-width:2rem;padding:.125rem 0;justify-content:center}.fdp-value-help-dialog__actions-row{padding:.5rem 1rem;display:flex;align-items:center;justify-content:flex-end;border-top:.0625rem solid #d9d9d9;border-top:.0625rem solid var(--sapPageFooter_BorderColor, #d9d9d9)}.fdp-value-help-dialog__actions-row .fd-button{margin-left:.5rem}.fdp-value-help-dialog .fdp-value-help-dialog__hidden_label{display:none!important}.fdp-value-help-dialog__table-busy-indicator{height:100%}\n"], dependencies: [{ kind: "component", type: DialogComponent, selector: "fd-dialog", inputs: ["class", "dialogRef", "dialogConfig"] }, { kind: "component", type: DialogHeaderComponent, selector: "fd-dialog-header" }, { kind: "directive", type: TemplateDirective, selector: "[fdkTemplate]", inputs: ["fdkTemplate"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: ScrollbarDirective, selector: "[fdScrollbar], [fd-scrollbar]", inputs: ["noHorizontalScroll", "noVerticalScroll", "alwaysVisible"] }, { kind: "component", type: DialogBodyComponent, selector: "fd-dialog-body", inputs: ["disablePaddings"] }, { kind: "component", type: DialogFooterComponent, selector: "fd-dialog-footer" }, { kind: "component", type: TitleComponent, selector: "[fd-title], [fdTitle]", inputs: ["headerSize", "wrap"], exportAs: ["fd-title"] }, { kind: "component", type: TokenizerComponent, selector: "fd-tokenizer", inputs: ["class", "disableKeyboardDeletion", "compactCollapse", "tokenizerFocusable", "inputValue", "glyph", "glyphFont", "moreTerm", "open", "showOverflowPopover"], outputs: ["moreClickedEvent"] }, { kind: "component", type: TokenComponent, selector: "fd-token", inputs: ["disabled", "selected", "readOnly"], outputs: ["onCloseClick", "onRemove", "onTokenClick", "onTokenKeydown", "elementFocused"] }, { kind: "directive", type: ToolbarItemDirective, selector: "[fd-toolbar-item], [fdOverflowGroup], [fdOverflowPriority]", inputs: ["fdOverflowPriority", "fdOverflowGroup"] }, { kind: "component", type: FormControlComponent, selector: "input[fd-form-control], textarea[fd-form-control]", inputs: ["state", "type", "class", "ariaLabel", "ariaLabelledBy"] }, { kind: "directive", type: TokenizerInputDirective, selector: "[fdTokenizerInput], [fd-tokenizer-input]", inputs: ["class"] }, { kind: "component", type: ButtonComponent, selector: "button[fd-button], a[fd-button], span[fd-button]", inputs: ["class"], exportAs: ["fd-button"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i1.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "component", type: LayoutGridComponent, selector: "fd-layout-grid, [fdLayoutGrid]", inputs: ["class", "noGap", "noHorizontalGap", "noVerticalGap"] }, { kind: "directive", type: LayoutGridRowDirective, selector: "[fd-layout-grid-row], [fdLayoutGridRow]" }, { kind: "directive", type: LayoutGridColDirective, selector: "[fd-layout-grid-col], [fdLayoutGridCol]", inputs: ["fdLayoutGridCol", "colGrow", "colMd", "colLg", "colXl", "colOffset", "colOffsetMd", "colOffsetLg", "colOffsetXl", "class"] }, { kind: "component", type: SearchFieldComponent, selector: "fdp-search-field", inputs: ["categoryMode", "appearance", "placeholder", "mobile", "mobileConfig", "disableRefresh", "disableSearch", "suggestions", "dataSource", "inputText", "categories", "currentCategory", "categoryLabel", "hideCategoryLabel", "isLoading", "forceSearchButton", "disableSuggestionsFoundAnnouncer"], outputs: ["inputChange", "searchSubmit", "cancelSearch", "isOpenChange"] }, { kind: "component", type: ToolbarComponent, selector: "fd-toolbar", inputs: ["titleId", "class", "shouldOverflow", "fdType", "title", "active", "clearBorder", "forceOverflow", "tabindex", "headingLevel", "ariaLabel", "ariaLabelledBy"] }, { kind: "directive", type: ToolbarSpacerDirective, selector: "fd-toolbar-spacer", inputs: ["width", "class", "fixed"] }, { kind: "component", type: BusyIndicatorComponent, selector: "fd-busy-indicator", inputs: ["loading", "size", "block", "ariaLabel", "title", "label", "ariaLive"] }, { kind: "component", type: FormLabelComponent, selector: "[fd-form-label]", inputs: ["required", "colon", "alignLabelEnd", "inlineHelpContent", "inlineHelpGlyph", "inlineHelpTriggers", "inlineHelpBodyPlacement", "inlineHelpPlacement", "allowWrap", "inlineHelpLabel", "id"] }, { kind: "component", type: SkeletonComponent, selector: "fd-skeleton", inputs: ["animated", "type", "textLines", "width", "height"] }, { kind: "component", type: SelectTabComponent, selector: "fdp-select-tab", inputs: ["selectTabTitleId", "selectTabCountId", "selected", "loading", "filters", "selection", "allowSelectAll", "uniqueKey", "pageSize", "defaultMobileHeaders", "displayedData"], outputs: ["select"] }, { kind: "component", type: DefineTabComponent, selector: "fdp-define-tab", inputs: ["titleId", "selectedId", "conditions", "strategyLabels"], outputs: ["includeChange", "excludeChange", "conditionChange"] }, { kind: "directive", type: ListLinkDirective, selector: "[fd-list-link], [fdListLink]", inputs: ["navigationIndicator", "navigated", "focusable"] }, { kind: "directive", type: ListTitleDirective, selector: "[fd-list-title], [fdListTitle]", inputs: ["wrap"] }, { kind: "directive", type: ListIconDirective, selector: "[fdListIcon], [fd-list-icon]", inputs: ["glyph", "glyphFont", "class", "role", "ariaHidden"] }, { kind: "component", type: TabNavComponent, selector: "[fd-tab-nav]", inputs: ["class", "mode", "size"] }, { kind: "directive", type: TabItemDirective, selector: "[fd-tab-item]", inputs: ["class", "tabItemState", "header", "disabled", "fdTabItemClass"] }, { kind: "directive", type: TabLinkDirective, selector: "[fd-tab-link]", inputs: ["active", "disabled"], outputs: ["keyDown", "focused"] }, { kind: "directive", type: TabTagDirective, selector: "[fdTabTag], [fd-tab-tag]" }, { kind: "component", type: BarComponent, selector: "[fd-bar]", inputs: ["class", "barDesign", "inPage", "inHomePage", "size"] }, { kind: "directive", type: BarLeftDirective, selector: "[fd-bar-left]" }, { kind: "directive", type: BarElementDirective, selector: "fd-bar-element", inputs: ["fullWidth"] }, { kind: "directive", type: BarRightDirective, selector: "[fd-bar-right]" }, { kind: "component", type: ButtonBarComponent, selector: "fd-button-bar", inputs: ["fullWidth", "fdType", "title", "ariaLabelledby", "id"] }, { kind: "pipe", type: SlicePipe, name: "slice" }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }, { kind: "pipe", type: DisplayFnPipe, name: "displayFnPipe" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: PlatformValueHelpDialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fdp-value-help-dialog', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        {
                            provide: VhdComponent,
                            useExisting: PlatformValueHelpDialogComponent
                        }
                    ], imports: [
                        DialogComponent,
                        DialogHeaderComponent,
                        TemplateDirective,
                        NgTemplateOutlet,
                        CdkScrollable,
                        ScrollbarDirective,
                        DialogBodyComponent,
                        DialogFooterComponent,
                        TitleComponent,
                        TokenizerComponent,
                        TokenComponent,
                        ToolbarItemDirective,
                        FormControlComponent,
                        TokenizerInputDirective,
                        ButtonComponent,
                        FormsModule,
                        LayoutGridComponent,
                        LayoutGridRowDirective,
                        LayoutGridColDirective,
                        SearchFieldComponent,
                        ToolbarComponent,
                        ToolbarSpacerDirective,
                        BusyIndicatorComponent,
                        FormLabelComponent,
                        SkeletonComponent,
                        SelectTabComponent,
                        DefineTabComponent,
                        ListLinkDirective,
                        ListTitleDirective,
                        ListIconDirective,
                        TabNavComponent,
                        TabItemDirective,
                        TabLinkDirective,
                        TabTagDirective,
                        BarComponent,
                        BarLeftDirective,
                        BarElementDirective,
                        BarRightDirective,
                        ButtonBarComponent,
                        SlicePipe,
                        FdTranslatePipe,
                        DisplayFnPipe
                    ], template: "<ng-template [fdDialogTemplate] let-dialog let-dialogConfig=\"dialogConfig\" #container>\n    <fd-dialog [dialogConfig]=\"dialogConfig\" [dialogRef]=\"dialog\">\n        <fd-dialog-header [attr.dir]=\"_dir$()\">\n            <ng-template fdkTemplate=\"header\">\n                <ng-template [ngTemplateOutlet]=\"mobile ? mobileDialogTitle : desktopDialogTitle\"></ng-template>\n            </ng-template>\n        </fd-dialog-header>\n        <fd-dialog-body [attr.dir]=\"_dir$()\">\n            @if (!mobile) {\n                <ng-template [ngTemplateOutlet]=\"advancedSearchContent\"></ng-template>\n            }\n            <div fd-scrollbar class=\"fdp-value-help-dialog__content-holder\">\n                @if (mobile) {\n                    <ng-template [ngTemplateOutlet]=\"advancedSearchContent\"></ng-template>\n                }\n                @if (selectedTab === _tabTypes.selectFromList) {\n                    <ng-template [ngTemplateOutlet]=\"selectionContent\"></ng-template>\n                }\n                @if (selectedTab === _tabTypes.defineConditions) {\n                    <ng-template [ngTemplateOutlet]=\"defineConditionsContent\"></ng-template>\n                }\n            </div>\n        </fd-dialog-body>\n        <fd-dialog-footer [attr.dir]=\"_dir$()\">\n            <ng-template fdkTemplate=\"footer\">\n                @if (!isMobileAdvancedSearchActive) {\n                    <div\n                        class=\"fdp-value-help-dialog__row fdp-value-help-dialog__selection-row\"\n                        [attr.aria-label]=\"'platformVHD.selectedAndConditionLabel' | fdTranslate\"\n                    >\n                        <span\n                            role=\"heading\"\n                            [attr.aria-level]=\"_headingLevel()\"\n                            fd-title\n                            class=\"selected-and-condition-title\"\n                            [id]=\"id + '-selected-item'\"\n                        >\n                            @if (hasSelectedAndConditions) {\n                                {{ 'platformVHD.selectedAndConditionLabel' | fdTranslate }}\n                                ({{ selectedItems.length + validConditions.length }})\n                            } @else {\n                                {{ 'platformVHD.selectedEmptyLabel' | fdTranslate }}\n                            }\n                        </span>\n                        <div class=\"fdp-value-help-dialog__tokens-wrapper\">\n                            <div class=\"fdp-value-help-dialog__tokens\">\n                                <!-- Selected items -->\n                                <fd-tokenizer>\n                                    @for (\n                                        item of selectedItems;\n                                        track _trackBySelectedFn(selectedIndex, item);\n                                        let selectedIndex = $index\n                                    ) {\n                                        <fd-token\n                                            fd-toolbar-item\n                                            fdOverflowPriority=\"high\"\n                                            class=\"fdp-value-help-dialog__selection-token\"\n                                            (onCloseClick)=\"removeSelected(selectedIndex)\"\n                                            >{{\n                                                !!tokenizerFn\n                                                    ? (item | displayFnPipe: tokenizerFn)\n                                                    : item[tokenViewField]\n                                            }}\n                                        </fd-token>\n                                    }\n                                    @for (\n                                        item of validConditions;\n                                        track _trackByConditionFn(conditionIndex, item);\n                                        let conditionIndex = $index\n                                    ) {\n                                        <fd-token\n                                            fd-toolbar-item\n                                            fdOverflowPriority=\"high\"\n                                            class=\"fdp-value-help-dialog__selection-token\"\n                                            (onCloseClick)=\"removeCondition(conditionIndex)\"\n                                        >\n                                            <ng-template\n                                                [ngTemplateOutlet]=\"conditionValue\"\n                                                [ngTemplateOutletContext]=\"{ item: item }\"\n                                            ></ng-template>\n                                        </fd-token>\n                                    }\n                                    <input fd-form-control fd-tokenizer-input [disabled]=\"!hasSelectedAndConditions\" />\n                                </fd-tokenizer>\n                            </div>\n                            <button\n                                (click)=\"clearSelectedAndConditionItems()\"\n                                class=\"fdp-value-help-dialog__tokens-clear\"\n                                fd-button\n                                [disabled]=\"!hasSelectedAndConditions\"\n                                fdType=\"transparent\"\n                                [title]=\"'platformVHD.footerClearSelectedTitle' | fdTranslate\"\n                                glyph=\"decline\"\n                                [ariaLabel]=\"'platformVHD.footerClearSelectedAriaLabel' | fdTranslate\"\n                            ></button>\n                        </div>\n                    </div>\n                }\n                <div class=\"fdp-value-help-dialog__actions-row\">\n                    @if (mobile && isOpenAdvanced) {\n                        <button\n                            fd-button\n                            data-go-advanced\n                            [label]=\"'platformVHD.searchButtonLabel' | fdTranslate\"\n                            fdType=\"emphasized\"\n                            (click)=\"searchAdvanced()\"\n                        ></button>\n                    }\n                    @if (selectedTab !== _tabTypes.advancedSearch) {\n                        <button\n                            fd-button\n                            data-succes\n                            [disabled]=\"loadingState\"\n                            [label]=\"'platformVHD.successButtonLabel' | fdTranslate\"\n                            fdType=\"emphasized\"\n                            (click)=\"success()\"\n                        ></button>\n                    }\n                    <button\n                        fd-button\n                        data-dismiss-dialog\n                        [label]=\"'platformVHD.cancelButtonLabel' | fdTranslate\"\n                        fdType=\"transparent\"\n                        (click)=\"dismiss()\"\n                    ></button>\n                </div>\n            </ng-template>\n        </fd-dialog-footer>\n    </fd-dialog>\n</ng-template>\n<ng-template #advancedSearchContent>\n    @if (isSelectionTab) {\n        <form class=\"fdp-value-help-dialog__row fdp-value-help-dialog__advanced-search\" [id]=\"'advanced-search-' + id\">\n            @if (!mobile || (mobile && !isOpenAdvanced)) {\n                <fd-layout-grid>\n                    <div fdLayoutGridRow>\n                        <div [fdLayoutGridCol]=\"12\" [colMd]=\"12\" [colLg]=\"mobile ? 12 : 6\" [colXl]=\"mobile ? 12 : 6\">\n                            <fdp-search-field\n                                [placeholder]=\"'platformVHD.searchPlaceholder' | fdTranslate\"\n                                (searchSubmit)=\"search()\"\n                                (inputChange)=\"_mainSearch = $event.text\"\n                            ></fdp-search-field>\n                        </div>\n                        @if (_hasAdvanced) {\n                            <div\n                                [fdLayoutGridCol]=\"12\"\n                                [colMd]=\"12\"\n                                [colLg]=\"mobile ? 12 : 6\"\n                                [colXl]=\"mobile ? 12 : 6\"\n                                class=\"fdp-value-help-dialog__advanced-actions\"\n                            >\n                                <fd-toolbar [clearBorder]=\"true\">\n                                    <fd-toolbar-spacer></fd-toolbar-spacer>\n                                    @if (_hasAdvanced) {\n                                        <button\n                                            fd-toolbar-item\n                                            fd-button\n                                            fdType=\"transparent\"\n                                            [label]=\"\n                                                (mobile\n                                                    ? 'platformVHD.searchAdvancedSearchLabel'\n                                                    : isOpenAdvanced\n                                                      ? 'platformVHD.searchHideAdvancedSearchLabel'\n                                                      : 'platformVHD.searchShowAdvancedSearchLabel'\n                                                ) | fdTranslate\n                                            \"\n                                            (click)=\"toggleAdvancedSearch()\"\n                                        ></button>\n                                    }\n                                    <button\n                                        fd-toolbar-item\n                                        type=\"submit\"\n                                        fd-button\n                                        fdType=\"emphasized\"\n                                        [label]=\"'platformVHD.searchButtonLabel' | fdTranslate\"\n                                        (click)=\"filter()\"\n                                    ></button>\n                                </fd-toolbar>\n                            </div>\n                        }\n                    </div>\n                </fd-layout-grid>\n            }\n            @if (isOpenAdvanced && _hasAdvanced) {\n                <div [id]=\"'advanced-search-content-' + id\" class=\"fdp-value-help-dialog__advanced-filters\">\n                    <fd-busy-indicator [loading]=\"loadingState && _firstLoadingDone\" [block]=\"true\">\n                        @if (_firstLoadingDone) {\n                            <fd-layout-grid\n                                [class.fdp-value-help-dialog__with-toggle-all]=\"filters.length > maxShownInitialFilters\"\n                            >\n                                <div fdLayoutGridRow>\n                                    @for (\n                                        filter of _displayedFilters | slice: 0 : shownFilterCount + 1;\n                                        track _trackByFilterFn($index, filter)\n                                    ) {\n                                        @if (filter.advanced) {\n                                            <div [fdLayoutGridCol]=\"12\" [colMd]=\"12\" [colLg]=\"6\" [colXl]=\"3\">\n                                                <label\n                                                    class=\"fd-form-group__header\"\n                                                    fd-form-label\n                                                    [for]=\"'input' + filter.key\"\n                                                    >{{ filter.label }}:</label\n                                                >\n                                                @if (filter.filterDef) {\n                                                    <ng-template\n                                                        [ngTemplateOutlet]=\"filter.filterDef.templateRef\"\n                                                        [ngTemplateOutletContext]=\"{ $implicit: filter }\"\n                                                    ></ng-template>\n                                                } @else {\n                                                    <input\n                                                        [(ngModel)]=\"filter.value\"\n                                                        fd-form-control\n                                                        type=\"text\"\n                                                        [name]=\"'search-by-' + filter.label\"\n                                                        [id]=\"'input' + filter.key\"\n                                                    />\n                                                }\n                                            </div>\n                                        }\n                                    }\n                                    @if (filters.length > maxShownInitialFilters) {\n                                        <div\n                                            colGrow\n                                            [fdLayoutGridCol]=\"12\"\n                                            [colMd]=\"12\"\n                                            [colLg]=\"6\"\n                                            [colXl]=\"3\"\n                                            class=\"fdp-value-help-dialog__toggle-filters\"\n                                        >\n                                            <button\n                                                fd-button\n                                                fdType=\"transparent\"\n                                                (click)=\"toggleShownFilters()\"\n                                                [label]=\"\n                                                    (isShowAllFilters\n                                                        ? 'platformVHD.searchHideAllAdvancedSearchLabel'\n                                                        : 'platformVHD.searchShowAllAdvancedSearchLabel'\n                                                    ) | fdTranslate\n                                                \"\n                                            ></button>\n                                        </div>\n                                    }\n                                </div>\n                            </fd-layout-grid>\n                        } @else {\n                            <fd-skeleton width=\"100%\" height=\"100px\">\n                                <svg:rect x=\"0\" y=\"0\" rx=\"4\" width=\"15%\" height=\"8\" />\n                                <svg:rect x=\"0\" y=\"20\" rx=\"4\" width=\"25%\" height=\"16\" />\n                                <svg:rect x=\"35%\" y=\"0\" rx=\"4\" width=\"15%\" height=\"8\" />\n                                <svg:rect x=\"35%\" y=\"20\" rx=\"4\" width=\"25%\" height=\"16\" />\n                                <svg:rect x=\"0\" y=\"60\" rx=\"4\" width=\"15%\" height=\"8\" />\n                                <svg:rect x=\"0\" y=\"80\" rx=\"4\" width=\"25%\" height=\"16\" />\n                            </fd-skeleton>\n                        }\n                    </fd-busy-indicator>\n                </div>\n            }\n        </form>\n    }\n</ng-template>\n<ng-template #selectionContent>\n    <fd-busy-indicator\n        [loading]=\"loadingState && _firstLoadingDone\"\n        [block]=\"true\"\n        class=\"fdp-value-help-dialog__table-busy-indicator\"\n    >\n        <fdp-select-tab\n            [selected]=\"selectedItems\"\n            [loading]=\"loadingState && !_firstLoadingDone\"\n            [uid]=\"id\"\n            [displayedData]=\"_displayedData\"\n            [tabTitle]=\"'platformVHD.selectTabTitle' | fdTranslate\"\n            [mobile]=\"mobile\"\n            [selection]=\"searchSelection\"\n            [uniqueKey]=\"uniqueKey\"\n            [pageSize]=\"searchTablePageSize\"\n            [defaultMobileHeaders]=\"searchTableMobileHeaders\"\n            [filters]=\"_displayedFilters\"\n            [allowSelectAll]=\"allowSelectAll\"\n            (select)=\"onSelect($event)\"\n        ></fdp-select-tab>\n    </fd-busy-indicator>\n</ng-template>\n<ng-template #defineConditionsContent>\n    <div fd-scrollbar>\n        <fdp-define-tab\n            [strategyLabels]=\"defineStrategyLabels\"\n            [conditions]=\"conditionItems\"\n            [uid]=\"id\"\n            [tabTitle]=\"'platformVHD.defineTabTitle' | fdTranslate\"\n            [mobile]=\"mobile\"\n            (conditionChange)=\"onConditionChange($event)\"\n        ></fdp-define-tab>\n    </div>\n</ng-template>\n<ng-template #dialogTitleText>\n    <span role=\"heading\" [attr.aria-level]=\"_headingLevel()\" [attr.id]=\"headerId\" fd-title>{{ dialogTitle }}</span>\n</ng-template>\n<ng-template #tabLink let-title=\"title\" let-type=\"type\">\n    @if (selectedTab === type && showSelectionTab && showDefineTab) {\n        <button\n            fd-button\n            glyph=\"navigation-left-arrow\"\n            fdType=\"transparent\"\n            (click)=\"switchTab()\"\n            [title]=\"'platformVHD.selectMobileTabBackBtnTitle' | fdTranslate\"\n        ></button>\n        <span role=\"heading\" [attr.aria-level]=\"_headingLevel()\" fd-title>{{ title }}</span>\n    }\n    @if (selectedTab !== type) {\n        <a\n            fd-list-link\n            (click)=\"switchTab(type)\"\n            [title]=\"'platformVHD.selectMobileTabBtnOpenDialogLabel' | fdTranslate\"\n        >\n            <span fd-list-title>{{ title }}</span>\n            <i fd-list-icon glyph=\"navigation-right-arrow\"></i>\n        </a>\n    }\n</ng-template>\n<ng-template #advancedHeader>\n    <button fd-button glyph=\"navigation-left-arrow\" fdType=\"transparent\" (click)=\"toggleAdvancedSearch()\"></button>\n    <span role=\"heading\" [attr.aria-level]=\"_headingLevel()\" fd-title>{{\n        'platformVHD.searchAdvancedSearchLabel' | fdTranslate\n    }}</span>\n</ng-template>\n<ng-template #desktopDialogTitle>\n    <ng-template [ngTemplateOutlet]=\"dialogTitleText\"></ng-template>\n    <ng-template [ngTemplateOutlet]=\"desktopTabs\"></ng-template>\n</ng-template>\n<ng-template #mobileDialogTitle>\n    <div class=\"fdp-value-help-dialog__mobile-title\">\n        @if (hasSelectedTab) {\n            <ng-template [ngTemplateOutlet]=\"selectedTabHeader\"></ng-template>\n        } @else {\n            <span role=\"heading\" [attr.aria-level]=\"_headingLevel()\" [attr.id]=\"headerId\" fd-title>{{\n                dialogTitle\n            }}</span>\n        }\n    </div>\n    <ng-template [ngTemplateOutlet]=\"mobileTabs\"></ng-template>\n</ng-template>\n<ng-template #desktopTabs>\n    @if (showSelectionTab && showDefineTab) {\n        <nav fd-tab-nav class=\"fdp-value-help-dialog__tabs\">\n            @if (showSelectionTab) {\n                <div fd-tab-item (click)=\"switchTab(_tabTypes.selectFromList)\">\n                    <a\n                        fd-tab-link\n                        [active]=\"selectedTab === _tabTypes.selectFromList\"\n                        [tabindex]=\"selectedTab === _tabTypes.selectFromList ? '0' : '-1'\"\n                        ><span fd-tab-tag>{{ 'platformVHD.selectTabTitle' | fdTranslate }}</span></a\n                    >\n                </div>\n            }\n            @if (showDefineTab) {\n                <div fd-tab-item (click)=\"switchTab(_tabTypes.defineConditions)\">\n                    <a\n                        fd-tab-link\n                        [active]=\"selectedTab === _tabTypes.defineConditions\"\n                        [tabindex]=\"selectedTab === _tabTypes.defineConditions ? '0' : '-1'\"\n                        ><span fd-tab-tag>{{ 'platformVHD.defineTabTitle' | fdTranslate }}</span></a\n                    >\n                </div>\n            }\n        </nav>\n    }\n</ng-template>\n<ng-template #mobileTabs>\n    @if (!hasSelectedTab && showSelectionTab && showDefineTab) {\n        <div>\n            @if (showSelectionTab) {\n                <div fd-bar [inPage]=\"true\">\n                    <div fd-bar-left>\n                        <fd-bar-element>\n                            {{ 'platformVHD.selectTabTitle' | fdTranslate }}\n                        </fd-bar-element>\n                    </div>\n                    <div fd-bar-right>\n                        <fd-bar-element>\n                            <fd-button-bar\n                                glyph=\"navigation-right-arrow\"\n                                (click)=\"switchTab(_tabTypes.selectFromList)\"\n                                [title]=\"\n                                    'platformVHD.selectMobileTabTitle'\n                                        | fdTranslate: { title: 'platformVHD.selectTabTitle' | fdTranslate }\n                                \"\n                            ></fd-button-bar>\n                        </fd-bar-element>\n                    </div>\n                </div>\n            }\n            @if (showDefineTab) {\n                <div fd-bar [inPage]=\"true\">\n                    <div fd-bar-left>\n                        <fd-bar-element>\n                            {{ 'platformVHD.defineTabTitle' | fdTranslate }}\n                        </fd-bar-element>\n                    </div>\n                    <div fd-bar-right>\n                        <fd-bar-element>\n                            <fd-button-bar\n                                glyph=\"navigation-right-arrow\"\n                                [title]=\"\n                                    'platformVHD.selectMobileTabTitle'\n                                        | fdTranslate: { title: 'platformVHD.defineTabTitle' | fdTranslate }\n                                \"\n                                (click)=\"switchTab(_tabTypes.defineConditions)\"\n                            >\n                            </fd-button-bar>\n                        </fd-bar-element>\n                    </div>\n                </div>\n            }\n        </div>\n    }\n</ng-template>\n<ng-template #selectedTabHeader>\n    @switch (selectedTab) {\n        @case (_tabTypes.selectFromList) {\n            <ng-template\n                [ngTemplateOutlet]=\"tabLink\"\n                [ngTemplateOutletContext]=\"{\n                    title: 'platformVHD.selectTabTitle' | fdTranslate,\n                    type: selectedTab\n                }\"\n            ></ng-template>\n        }\n        @case (_tabTypes.advancedSearch) {\n            <ng-template [ngTemplateOutlet]=\"advancedHeader\"></ng-template>\n        }\n        @case (_tabTypes.defineConditions) {\n            <ng-template\n                [ngTemplateOutlet]=\"tabLink\"\n                [ngTemplateOutletContext]=\"{\n                    title: 'platformVHD.defineTabTitle' | fdTranslate,\n                    type: selectedTab\n                }\"\n            ></ng-template>\n        }\n    }\n</ng-template>\n<ng-template #conditionValue let-item=\"item\">\n    @if (item.strategy !== 'empty' && item.strategy !== 'not_empty') {\n        <span>\n            {{ item | displayFnPipe: conditionDisplayFn : _displayedFilters }}\n        </span>\n    } @else {\n        @if (item.strategy === 'not_empty') {\n            !(<ng-template [ngTemplateOutlet]=\"emptyConditionText\"></ng-template>)\n        } @else {\n            &lt;{{ 'platformVHD.selectMobileConditionEmpty' | fdTranslate }}&gt;\n        }\n    }\n</ng-template>\n<ng-template #emptyConditionText> &lt;{{ 'platformVHD.selectMobileConditionEmpty' | fdTranslate }}&gt; </ng-template>\n", styles: [".fdp-value-help-dialog .fd-dialog__body{display:flex;flex-direction:column;overflow:hidden}.fdp-value-help-dialog .fd-title--h5{padding:.5rem 0}.fdp-value-help-dialog .fd-toolbar{background:none;border:none;padding:.1735rem .5rem;height:auto;min-height:1.625rem}.fdp-value-help-dialog__row.fdp-value-help-dialog__advanced-search{padding-top:1rem}.fdp-value-help-dialog__advanced-search,.fdp-value-help-dialog .fd-dialog__body{background-color:var(--sapBackgroundColor, #f7f7f7)}.fdp-value-help-dialog__advanced-filters{padding-top:1rem}.fdp-value-help-dialog__advanced-filters label{height:auto}.fdp-value-help-dialog__toggle-filters{display:flex;justify-content:flex-end;align-items:flex-end}.fdp-value-help-dialog__toggle-filters .fd-button{margin-bottom:.25rem}.fdp-value-help-dialog__advanced-actions{display:flex;align-items:center;justify-content:flex-end}.fdp-value-help-dialog-mobile .fdp-value-help-dialog__advanced-actions{justify-content:flex-start}.fdp-value-help-dialog__advanced-actions .fd-toolbar{padding:0}.fdp-value-help-dialog .fd-bar.fd-bar--cozy{height:auto}.fdp-value-help-dialog .fd-dialog__header{box-shadow:none}.fdp-value-help-dialog .fd-dialog__header .fd-title{display:flex;align-items:center;padding-left:2rem;padding-right:2rem;min-height:2.5rem;box-shadow:none;border-bottom:none;background-color:var(--sapObjectHeader_Background, #fff);position:relative;z-index:2}.fdp-value-help-dialog .fd-dialog__header .fdp-value-help-dialog__mobile-title{display:flex;border-bottom:1px solid #d9d9d9;border-bottom:1px solid var(--sapGroup_TitleBorderColor, #d9d9d9)}.fdp-value-help-dialog .fd-dialog__header .fdp-value-help-dialog__mobile-title .fd-title{flex:1 1 auto;border:none}.fdp-value-help-dialog .fd-dialog__header .fdp-value-help-dialog__tabs{position:relative}.fdp-value-help-dialog .fd-dialog__header,.fdp-value-help-dialog .fd-dialog__footer{height:auto;flex-direction:column}.fdp-value-help-dialog .fd-dialog__header.fd-bar,.fdp-value-help-dialog .fd-dialog__footer.fd-bar{padding:0}.fdp-value-help-dialog .fd-dialog__footer{border-top:none}.fdp-value-help-dialog__content-holder{padding:0 2rem 1rem;display:flex;flex-direction:column;height:100%;width:100%;overflow:hidden;min-height:20rem}.fdp-value-help-dialog__row{padding:0 2rem 1rem}.fdp-value-help-dialog__row.fdp-value-help-dialog__selection-row{background-color:var(--sapBackgroundColor, #f7f7f7)}.fdp-value-help-dialog__tokens-wrapper{display:flex}.fdp-value-help-dialog__tokens{flex:1 1 auto;overflow:hidden;align-items:center;border:1px solid var(--sapContent_ForegroundBorderColor, #89919a);margin-right:.5rem;border-radius:var(--sapElement_BorderCornerRadius, .25rem);background:none}.fdp-value-help-dialog__tokens fd-toolbar{flex:1 1 auto;overflow:hidden}.fdp-value-help-dialog__tokens-clear{height:auto;min-width:2rem;padding:.125rem 0;justify-content:center}.fdp-value-help-dialog__actions-row{padding:.5rem 1rem;display:flex;align-items:center;justify-content:flex-end;border-top:.0625rem solid #d9d9d9;border-top:.0625rem solid var(--sapPageFooter_BorderColor, #d9d9d9)}.fdp-value-help-dialog__actions-row .fd-button{margin-left:.5rem}.fdp-value-help-dialog .fdp-value-help-dialog__hidden_label{display:none!important}.fdp-value-help-dialog__table-busy-indicator{height:100%}\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: i1$1.DialogService }, { type: i2.RtlService, decorators: [{
                    type: Optional
                }] }], propDecorators: { id: [{
                type: Input
            }], value: [{
                type: Input
            }], dialogTitle: [{
                type: Input
            }], initialTab: [{
                type: Input
            }], tabs: [{
                type: Input
            }], isOpenAdvanced: [{
                type: Input
            }], dataSource: [{
                type: Input
            }], dialogConfig: [{
                type: Input
            }], uniqueKey: [{
                type: Input
            }], headerId: [{
                type: Input
            }], tokenViewField: [{
                type: Input
            }], tokenizerFn: [{
                type: Input
            }], mobile: [{
                type: Input
            }], formatToken: [{
                type: Input
            }], conditionDisplayFn: [{
                type: Input
            }], tokenValidator: [{
                type: Input
            }], searchSelection: [{
                type: Input
            }], searchTablePageSize: [{
                type: Input
            }], searchTableMobileHeaders: [{
                type: Input
            }], maxShownInitialFilters: [{
                type: Input
            }], loading: [{
                type: Input
            }], allowSelectAll: [{
                type: Input
            }], defineStrategyLabels: [{
                type: Input
            }], valueChange: [{
                type: Output
            }], onDataRequested: [{
                type: Output
            }], onDataReceived: [{
                type: Output
            }], filters: [{
                type: ContentChildren,
                args: [VhdFilterComponent]
            }], columnDef: [{
                type: ContentChildren,
                args: [ValueHelpColumnDefDirective]
            }], dialogContainer: [{
                type: ViewChild,
                args: ['container', { read: TemplateRef }]
            }] } });

const components = [PlatformValueHelpDialogComponent, VhdFilterComponent, ContentDensityModule];
class PlatformValueHelpDialogModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: PlatformValueHelpDialogModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.0.7", ngImport: i0, type: PlatformValueHelpDialogModule, imports: [PlatformValueHelpDialogComponent, VhdFilterComponent, ContentDensityModule], exports: [PlatformValueHelpDialogComponent, VhdFilterComponent, ContentDensityModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: PlatformValueHelpDialogModule, imports: [PlatformValueHelpDialogComponent, ContentDensityModule, ContentDensityModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: PlatformValueHelpDialogModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [...components],
                    exports: [...components]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ArrayValueHelpDialogDataSource, BaseEntity, ConditionCountMessageDirective, DefineTabComponent, MAX_CHARACTER_HINT_COUNT, ObservableValueHelpDialogDataSource, PlatformValueHelpDialogComponent, PlatformValueHelpDialogModule, SelectTabComponent, ValueHelpColumnDefDirective, ValueHelpDialogDataSource, ValueHelpFilterDefDirective, VhdBaseTab, VhdDataProvider, VhdDefineExcludeStrategy, VhdDefineIncludeStrategy, VhdDefineType, VhdExcludedEntity, VhdFilterComponent, VhdIncludedEntity, VhdTab, defaultConditionDisplayFn };
//# sourceMappingURL=fundamental-ngx-platform-value-help-dialog.mjs.map
