import { SelectionModel } from '@angular/cdk/collections';
import { EventEmitter, QueryList } from '@angular/core';
import { InLineLayoutCollectionBaseInput } from '@fundamental-ngx/platform/shared';
import { CheckboxComponent } from '../checkbox/checkbox.component';
import * as i0 from "@angular/core";
/**
 * Checkbox group implementation based on the
 * https://github.com/SAP/fundamental-ngx/wiki/Platform:-CheckboxGroup-Technical-Design
 * documents.
 */
export declare class CheckboxGroupComponent extends InLineLayoutCollectionBaseInput {
    /**
     * value for selected checkboxes.
     */
    set value(selectedValue: any[]);
    get value(): any[];
    /**
     * To Display multiple checkboxes in a line
     */
    set isInline(inline: boolean);
    get isInline(): boolean;
    /** Children checkboxes passed as content */
    contentCheckboxes: QueryList<CheckboxComponent>;
    /** Children checkboxes created from passed list values. */
    viewCheckboxes: QueryList<CheckboxComponent>;
    /** Emits checked change event */
    readonly valueChange: EventEmitter<string[]>;
    /** @hidden */
    readonly _selectionModel: SelectionModel<unknown>;
    /** @hidden */
    private readonly _rangeSelector;
    /**
     * @hidden
     * @param selectionState actual value of the checkbox
     * @param checkboxTrueValue thuthy value to compare the "selectionState" with
     */
    onModelChanged(selectionState: any, checkboxTrueValue: any): void;
    /** @hidden */
    onCheckboxClick(index: number, source: 'contentChildren' | 'list', event?: MouseEvent): void;
    /** @hidden */
    writeValue(selectedValue: any): void;
    /**
     * access display value for objects, acts as checkbox label.
     */
    getDisplayValue(item: any): string;
    /**
     * access lookup value for objects, acts as checkbox value.
     */
    getLookupValue(item: any): string;
    /** @hidden */
    getListItemDisabledValue(item: CheckboxGroupComponent['list'][number]): boolean;
    /** @inheritdoc */
    protected setValue(value: any, emitOnChange?: boolean): void;
    /** @hidden */
    private _setValueBySelectionModel;
    /** @hidden */
    private _updateSelectionModelByValue;
    static ɵfac: i0.ɵɵFactoryDeclaration<CheckboxGroupComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CheckboxGroupComponent, "fdp-checkbox-group", never, { "value": { "alias": "value"; "required": false; }; "isInline": { "alias": "isInline"; "required": false; }; }, { "valueChange": "valueChange"; }, ["contentCheckboxes"], never, true, never>;
}
