import { AfterViewInit, ElementRef, EventEmitter, Injector, OnInit, TemplateRef, ViewContainerRef } from '@angular/core';
import { DynamicComponentService } from '@fundamental-ngx/cdk/utils';
import { DialogConfig } from '@fundamental-ngx/core/dialog';
import { DataProvider, OptionItem } from '@fundamental-ngx/platform/shared';
import { ComboboxConfig } from '../combobox.config';
import { ComboboxInterface } from '../combobox.interface';
import { BaseCombobox } from '../commons/base-combobox';
import * as i0 from "@angular/core";
export declare class ComboboxSelectionChangeEvent {
    source: ComboboxComponent;
    payload: any;
    /**
     * Combobox selection event
     * @param source Combobox component
     * @param payload Selected option
     */
    constructor(source: ComboboxComponent, payload: any);
}
export declare class ComboboxComponent extends BaseCombobox implements ComboboxInterface, OnInit, AfterViewInit {
    readonly _dynamicComponentService: DynamicComponentService;
    private readonly _viewContainerRef;
    private readonly _injector;
    private providers;
    /** Event emitted when item is selected. */
    selectionChange: EventEmitter<ComboboxSelectionChangeEvent>;
    /** @hidden */
    searchInputElement: ElementRef<HTMLInputElement>;
    /** @hidden */
    controlTemplate: TemplateRef<any>;
    /** @hidden */
    listTemplate: TemplateRef<any>;
    /** @hidden */
    _selectedElement?: OptionItem;
    /** @hidden */
    constructor(_dialogConfig: DialogConfig, _dynamicComponentService: DynamicComponentService, _viewContainerRef: ViewContainerRef, _injector: Injector, providers: Map<string, DataProvider<any>>, _comboboxConfig: ComboboxConfig);
    /** @hidden */
    ngOnInit(): void;
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden */
    _onBlur(event: FocusEvent): void;
    /** @hidden Method to emit change event */
    emitChangeEvent<T>(modelValue: T): void;
    /** @hidden Method to set selected item */
    selectOptionItem(item: OptionItem): void;
    /** @hidden Method to set as selected */
    setAsSelected(item: OptionItem[]): void;
    /** @hidden Define is selected item selected */
    isSelectedOptionItem(selectedItem: any): boolean;
    /** @hidden Define is selected item selected by display value */
    isSelectedOptionItemByDisplayValue(selectedItem: any): boolean;
    /** Handle dialog dismissing, closes popover and sets backup data. */
    dialogDismiss(term: string): void;
    /** Handle dialog approval, closes popover and propagates data changes. */
    dialogApprove(): void;
    /** @hidden if not selected update model */
    private _checkAndUpdate;
    /** @hidden Update model */
    private _updateModel;
    /** @hidden */
    private _setUpMobileMode;
    /** @hidden */
    private _getSelectedOptionItem;
    static ɵfac: i0.ɵɵFactoryDeclaration<ComboboxComponent, [{ optional: true; }, null, null, null, { optional: true; }, null]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ComboboxComponent, "fdp-combobox", never, {}, { "selectionChange": "selectionChange"; }, never, ["*", "*"], true, never>;
}
