import { AfterViewInit, ElementRef, EventEmitter, OnDestroy, TemplateRef } from '@angular/core';
import { Observable, Subject } from 'rxjs';
import { FocusEscapeDirection } from '@fundamental-ngx/cdk/utils';
import { DialogConfig } from '@fundamental-ngx/core/dialog';
import { ListComponent } from '@fundamental-ngx/core/list';
import { MobileModeConfig } from '@fundamental-ngx/core/mobile-mode';
import { PopoverFillMode } from '@fundamental-ngx/core/shared';
import { CollectionBaseInput, ComboBoxDataSource, OptionItem } from '@fundamental-ngx/platform/shared';
import { SingleDropdownValueControl } from '@fundamental-ngx/cdk/forms';
import { AutoCompleteEvent } from '../../auto-complete/auto-complete.directive';
import { ComboboxConfig } from '../combobox.config';
import * as i0 from "@angular/core";
export type TextAlignment = 'left' | 'right';
export type FdpComboBoxDataSource<T> = ComboBoxDataSource<T> | Observable<T[]> | T[];
export declare abstract class BaseCombobox extends CollectionBaseInput implements SingleDropdownValueControl, AfterViewInit, OnDestroy {
    readonly dialogConfig: DialogConfig;
    protected comboboxConfig: ComboboxConfig;
    /** @hidden Method to emit change event */
    abstract emitChangeEvent<K>(value: K): void;
    /** @hidden Define is this item selected */
    abstract isSelectedOptionItem(selectedItem: OptionItem): boolean;
    /** @hidden Emit select OptionItem */
    abstract selectOptionItem(item: OptionItem): void;
    /** @hidden Define value as selected */
    abstract setAsSelected(item: OptionItem[]): void;
    /** Provides maximum height for the optionPanel */
    maxHeight: string;
    /** Whether the autocomplete should be enabled; Enabled by default */
    autoComplete: boolean;
    /**
     * Todo: Name of the entity for which DataProvider will be loaded. You can either pass list of
     * items or use this entityClass and internally we should be able to do lookup to some registry
     * and retrieve the best matching DataProvider that is set on application level
     */
    entityClass: string;
    /** Whether the combobox should be built on mobile mode */
    mobile: boolean;
    /** Multi Input Mobile Configuration, it's applied only, when mobile is enabled */
    mobileConfig: MobileModeConfig;
    /** Tells the combo if we need to group items */
    group: boolean;
    /** A field name to use to group data by (support dotted notation) */
    groupKey?: string;
    /** The field to show data in secondary column */
    secondaryKey?: string;
    /** Show the second column (Applicable for two columns layout) */
    showSecondaryText: boolean;
    /** Horizontally align text inside the second column (Applicable for two columns layout) */
    secondaryTextAlignment: TextAlignment;
    /** Turns on/off Adjustable Width feature */
    autoResize: boolean;
    /**
     * Preset options for the Select body width, whatever is chosen, the body has a 600px limit.
     * `at-least` will apply a minimum width to the body equivalent to the width of the control. - Default
     * `equal` will apply a width to the body equivalent to the width of the control.
     * 'fit-content' will apply width needed to properly display items inside, independent of control.
     */
    fillControlMode: PopoverFillMode;
    /**
     * Whether AddOn Button should be focusable
     * @default true
     */
    buttonFocusable: boolean;
    /**
     * The trigger events that will open/close the options popover.
     * Accepts any [HTML DOM Events](https://www.w3schools.com/jsref/dom_obj_event.asp).
     */
    triggers: string[];
    /** Whether the combobox should close, when a click is performed outside its boundaries. True by default */
    closeOnOutsideClick: boolean;
    /** Whether list item options should be rendered as byline. */
    byline: boolean;
    /** Datasource for suggestion list */
    set dataSource(value: FdpComboBoxDataSource<any>);
    get dataSource(): FdpComboBoxDataSource<any>;
    /** Value of the combobox */
    set value(value: any);
    get value(): any;
    /**
     * Action to perform when user shifts focus from the dropdown.
     * - `close` will close the dropdown preserving previously selected value.
     * - `closeAndSelect` will close the dropdown and select last focused dropdown item.
     */
    tabOutStrategy: 'close' | 'closeAndSelect';
    /** Event emitted when data loading is started. */
    onDataRequested: EventEmitter<void>;
    /** Event emitted when data loading is finished. */
    onDataReceived: EventEmitter<void>;
    /** @hidden */
    listComponent: ListComponent;
    /** @hidden */
    private readonly _customTemplates;
    /** @hidden */
    private readonly _customItemDef;
    /** @hidden Custom Option item Template */
    optionItemTemplate: TemplateRef<any>;
    /** @hidden Custom Group Header item Template */
    groupItemTemplate: TemplateRef<any>;
    /** @hidden Custom Secondary item Template */
    secondaryItemTemplate: TemplateRef<any>;
    /** @hidden Custom Selected option item Template */
    selectedItemTemplate: TemplateRef<any>;
    /** @hidden */
    searchInputElement: ElementRef<HTMLInputElement>;
    /** Input text of the input. */
    set inputText(value: string);
    get inputText(): string;
    /** Whether the combobox is opened. */
    isOpen: boolean;
    /** Whether a combobox can be closed */
    get canClose(): boolean;
    /** @hidden List of matched suggestions */
    _suggestions: OptionItem[];
    /** @hidden Max width of list container */
    maxWidth?: number;
    /** @hidden Min width of list container */
    minWidth?: number;
    /** @hidden Need for opening mobile version */
    openChange: Subject<boolean>;
    /** @hidden */
    get isGroup(): boolean;
    /** Is suggestions list empty */
    get isSuggestionsListEmpty(): boolean;
    /** @hidden */
    _flatSuggestions: OptionItem[];
    /** @hidden */
    protected _dataSource: FdpComboBoxDataSource<any>;
    /** @hidden */
    private _inputTextValue;
    /** @hidden */
    private readonly _matchingStrategy;
    /** @hidden */
    private _dsSubscription?;
    /** @hidden */
    private _element;
    /** Keys, that won't trigger the popover's open state, when dispatched on search input */
    private readonly _nonOpeningKeys;
    /** Keys, that are numbers from number keypad */
    private readonly _numberPadNumberKeys;
    /** @hidden */
    protected constructor(dialogConfig: DialogConfig, comboboxConfig: ComboboxConfig);
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden */
    ngOnDestroy(): void;
    /** Is empty search field */
    get isEmptyValue(): boolean;
    /** write value for ControlValueAccessor */
    writeValue(value: any): void;
    /** @hidden */
    searchTermChanged(text: string): void;
    /** @hidden */
    isOpenChangeHandle(isOpen: boolean): void;
    /** @hidden */
    _onOpenChange(isOpen: boolean): void;
    /** @hidden */
    handleOptionItem(value: OptionItem): void;
    /** @hidden */
    handlePressEnter(event: KeyboardEvent, value: OptionItem): void;
    /**
     * Handle Click on Button
     * @hidden
     */
    onPrimaryButtonClick(): void;
    /**
     * Handle click on input group in mobile mode
     * @hidden
     */
    openInMobileMode(): void;
    /**
     * Handle Keydown on Input
     * @hidden
     */
    onInputKeydownHandler(event: KeyboardEvent): void;
    /** Method passed to list component */
    handleListFocusEscape(direction: FocusEscapeDirection): void;
    /** @hidden */
    _onCompleteTerm(event: AutoCompleteEvent): void;
    /** @hidden */
    toggleSelectionByInputText(text?: string): void;
    /** @hidden */
    _close(): void;
    /** @hidden */
    protected _getSelectItemByInputValue(displayValue: string): OptionItem | undefined;
    /** @hidden */
    protected get ds(): ComboBoxDataSource<any>;
    /** @hidden Map grouped values to array. */
    protected _flatGroups(items: OptionItem[]): OptionItem[];
    /** @hidden */
    private _displayFn;
    /** @hidden */
    private _secondaryFn;
    /**
     * @hidden
     * Method that picks other value moved from current one by offset, called only when combobox is closed
     */
    private _chooseOtherItem;
    /** @hidden */
    private _getSelectItemByValue;
    /** @hidden */
    private _initializeDataSource;
    /** @hidden */
    private _openDataStream;
    /** @hidden */
    private _toDataStream;
    /** @hidden */
    private _initWindowResize;
    /** @hidden */
    private _getOptionsListWidth;
    /**
     * Convert original data to OptionItems Interface
     * @hidden
     */
    private _convertToOptionItems;
    /**
     * Convert data to OptionItems Interface
     * @hidden
     */
    private _convertObjectsToOptionItems;
    /**
     * Convert object[] data to Group OptionItems Interface
     * @hidden
     */
    private _convertObjectsToGroupOptionItems;
    /**
     * Convert object[] data to Secondary OptionItems Interface
     * @hidden
     */
    private _convertObjectsToSecondaryOptionItems;
    /**
     * Convert Primitive data(Boolean, String, Number) to OptionItems Interface
     * @hidden
     */
    private _convertPrimitiveToOptionItems;
    /**
     * Convert object[] to OptionItems Interface (Default)
     * @hidden
     */
    private _convertObjectsToDefaultOptionItems;
    /** @hidden Assign custom templates */
    private _assignCustomTemplates;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaseCombobox, [{ optional: true; }, null]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaseCombobox, never, never, { "maxHeight": { "alias": "maxHeight"; "required": false; }; "autoComplete": { "alias": "autoComplete"; "required": false; }; "entityClass": { "alias": "entityClass"; "required": false; }; "mobile": { "alias": "mobile"; "required": false; }; "mobileConfig": { "alias": "mobileConfig"; "required": false; }; "group": { "alias": "group"; "required": false; }; "groupKey": { "alias": "groupKey"; "required": false; }; "secondaryKey": { "alias": "secondaryKey"; "required": false; }; "showSecondaryText": { "alias": "showSecondaryText"; "required": false; }; "secondaryTextAlignment": { "alias": "secondaryTextAlignment"; "required": false; }; "autoResize": { "alias": "autoResize"; "required": false; }; "fillControlMode": { "alias": "fillControlMode"; "required": false; }; "buttonFocusable": { "alias": "buttonFocusable"; "required": false; }; "triggers": { "alias": "triggers"; "required": false; }; "closeOnOutsideClick": { "alias": "closeOnOutsideClick"; "required": false; }; "byline": { "alias": "byline"; "required": false; }; "dataSource": { "alias": "dataSource"; "required": false; }; "value": { "alias": "value"; "required": false; }; "tabOutStrategy": { "alias": "tabOutStrategy"; "required": false; }; }, { "onDataRequested": "onDataRequested"; "onDataReceived": "onDataReceived"; }, ["_customTemplates", "_customItemDef"], never, true, never>;
}
