import { AfterViewInit, ElementRef, EventEmitter } from '@angular/core';
import { NgControl } from '@angular/forms';
import { FormStates } from '@fundamental-ngx/cdk/forms';
import { CalendarYearGrid, DaysOfWeek, FdCalendarView } from '@fundamental-ngx/core/calendar';
import { DatetimePickerComponent } from '@fundamental-ngx/core/datetime-picker';
import { MobileModeConfig } from '@fundamental-ngx/core/mobile-mode';
import { Placement, SpecialDayRule } from '@fundamental-ngx/core/shared';
import { BaseInput } from '@fundamental-ngx/platform/shared';
import * as i0 from "@angular/core";
export declare class PlatformDatetimePickerComponent<D> extends BaseInput implements AfterViewInit {
    /**
     * value for datetime
     */
    set value(value: D);
    get value(): D;
    /**
     *  The placement of the popover. It can be one of: top, top-start, top-end, bottom,
     *  bottom-start, bottom-end, right, right-start, right-end, left, left-start, left-end.
     */
    placement: Placement;
    /** The element to which the popover should be appended. */
    appendTo: ElementRef;
    /**
     * Whether the time component should be meridian (am/pm).
     * Default value is based on the current locale format option
     * */
    meridian: boolean;
    /**
     * Whether the time component shows seconds.
     * Default value is based on the current locale format option
     * */
    displaySeconds: boolean;
    /**
     * Whether the time component shows minutes.
     * Default value is based on the current locale format option
     * */
    displayMinutes: boolean;
    /**
     * Whether the time component shows hours.
     * Default value is based on the current locale format option
     * */
    displayHours: boolean;
    /** Whether to perform visual validation on the picker input. */
    useValidation: boolean;
    /** Whether the popover is open. Two-way binding is supported. */
    isOpen: boolean;
    /** The starting day of week for the calendar. */
    startingDayOfWeek: DaysOfWeek;
    /** Actually shown active view one of 'day' | 'month' | 'year' in calendar component*/
    activeView: FdCalendarView;
    /** Whether a null input is considered valid. */
    allowNull: boolean;
    /**
     * @Input when set to true time component will use 2 digits for each number.
     * For example 9 will become 09
     * but 12 will be kept as 12.
     * Only uses by time component and does not change input format
     */
    keepTwoDigitsTime: boolean;
    /**
     *  The state of the form control - applies css classes.
     *  Can be `success`, `error`, `warning`, `information` or blank for default.
     */
    set state(state: FormStates | undefined);
    get state(): FormStates;
    /**
     * Whether AddOn Button should be focusable
     * @default true
     */
    buttonFocusable: boolean;
    /**
     * Special days mark, it can be used by passing array of object with
     * Special day number, list 1-20 [class:`fd-calendar__item--legend-{{number}}`] is available there:
     * https://sap.github.io/fundamental-styles/components/calendar.html calendar special days section
     * Rule accepts method with FdDate object as a parameter. ex:
     * `rule: (fdDate: FdDate) => fdDate.getDay() === 1`, which will mark all sundays as special day.
     */
    specialDaysRules: SpecialDayRule<D>[];
    /**
     * Object to customize year grid,
     * Row, Columns and method to display year can be modified
     */
    yearGrid: CalendarYearGrid;
    /**
     * Object to customize aggregated year grid,
     * Row, Columns and method to display year can be modified
     */
    aggregatedYearGrid: CalendarYearGrid;
    /**
     * Whether user wants to mark sunday/saturday with `fd-calendar__item--weekend` class
     */
    markWeekends: boolean;
    /** @Input Whether to show spinner buttons */
    spinnerButtons: boolean;
    /**
     * Whether user wants to show week numbers next to days
     */
    showWeekNumbers: boolean;
    /** Whether or not to show the datetime picker footer with submit/cancel buttons. */
    showFooter: boolean;
    /**
     * Whether to recalculate value from the input as user types or on blur.
     * By default, updates the value as user types.
     * @default false
     */
    processInputOnBlur: boolean;
    /**
     * Whether to prevent page scrolling when focusing date picker input field after calendar has been closed.
     */
    preventScrollOnFocus: boolean;
    /** Whether date picker should rendered in mobile mode. */
    mobile: boolean;
    /** Mobile mode configuration. */
    mobileConfig: MobileModeConfig;
    /** Whether calendar is used inside mobile in landscape mode, it also adds close button on right side */
    mobileLandscape: boolean;
    /** Whether calendar is used inside mobile in portrait mode */
    mobilePortrait: boolean;
    /** Event emitted when the state of the isOpen property changes. */
    readonly isOpenChange: EventEmitter<boolean>;
    /** Event thrown every time calendar active view is changed */
    readonly activeViewChange: EventEmitter<FdCalendarView>;
    /** Event emitted when the date changes. This can be a time or day change. */
    readonly datetimeChange: EventEmitter<D>;
    /** Event emitted when popover closes. */
    readonly onClose: EventEmitter<void>;
    /** @hidden */
    dateTimePickerComponent: DatetimePickerComponent<D>;
    /** @hidden */
    protected _elRef: ElementRef;
    /** @hidden */
    protected _control: NgControl;
    /** @hidden */
    get _isRequired(): boolean;
    /** @hidden */
    private readonly _dateTimeAdapter;
    /** @hidden */
    private readonly _dateTimeFormats;
    /** @hidden */
    constructor();
    /**
     * Function used to disable certain dates in the calendar.
     * @param fdDate FdDate
     */
    disableFunction: (value: D) => boolean;
    /**
     * @hidden
     */
    ngAfterViewInit(): void;
    /** @hidden */
    writeValue(value: D): void;
    /**
     * @hidden
     * override base functionality to catch new disabled state
     */
    setDisabledState(disabled: boolean): void;
    /**
     * @hidden
     * logic to handle validation from both platform forms and core datetiimepicker
     * @param datetime inputted
     */
    handleDatetimeInputChange(datetime: D): void;
    /**
     * Method that handles changes when popover is opened or closed.
     */
    handleOpenChange: (open: boolean) => void;
    /**
     * Method that handle calendar active view change and throws event.
     */
    handleActiveViewChange: (fdCalendarView: FdCalendarView) => void;
    /**
     * @hidden
     * method that adjusts width of datetimepicker to take 100% container space
     */
    private _adjustPickerWidth;
    static ɵfac: i0.ɵɵFactoryDeclaration<PlatformDatetimePickerComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PlatformDatetimePickerComponent<any>, "fdp-datetime-picker", never, { "value": { "alias": "value"; "required": false; }; "placement": { "alias": "placement"; "required": false; }; "appendTo": { "alias": "appendTo"; "required": false; }; "meridian": { "alias": "meridian"; "required": false; }; "displaySeconds": { "alias": "displaySeconds"; "required": false; }; "displayMinutes": { "alias": "displayMinutes"; "required": false; }; "displayHours": { "alias": "displayHours"; "required": false; }; "useValidation": { "alias": "useValidation"; "required": false; }; "isOpen": { "alias": "isOpen"; "required": false; }; "startingDayOfWeek": { "alias": "startingDayOfWeek"; "required": false; }; "activeView": { "alias": "activeView"; "required": false; }; "allowNull": { "alias": "allowNull"; "required": false; }; "keepTwoDigitsTime": { "alias": "keepTwoDigitsTime"; "required": false; }; "state": { "alias": "state"; "required": false; }; "buttonFocusable": { "alias": "buttonFocusable"; "required": false; }; "specialDaysRules": { "alias": "specialDaysRules"; "required": false; }; "yearGrid": { "alias": "yearGrid"; "required": false; }; "aggregatedYearGrid": { "alias": "aggregatedYearGrid"; "required": false; }; "markWeekends": { "alias": "markWeekends"; "required": false; }; "spinnerButtons": { "alias": "spinnerButtons"; "required": false; }; "showWeekNumbers": { "alias": "showWeekNumbers"; "required": false; }; "showFooter": { "alias": "showFooter"; "required": false; }; "processInputOnBlur": { "alias": "processInputOnBlur"; "required": false; }; "preventScrollOnFocus": { "alias": "preventScrollOnFocus"; "required": false; }; "mobile": { "alias": "mobile"; "required": false; }; "mobileConfig": { "alias": "mobileConfig"; "required": false; }; "mobileLandscape": { "alias": "mobileLandscape"; "required": false; }; "mobilePortrait": { "alias": "mobilePortrait"; "required": false; }; "disableFunction": { "alias": "disableFunction"; "required": false; }; }, { "isOpenChange": "isOpenChange"; "activeViewChange": "activeViewChange"; "datetimeChange": "datetimeChange"; "onClose": "onClose"; }, never, ["*"], true, never>;
}
