import { FormGroup } from '@angular/forms';
import { PlatformFormField, SelectItem } from '@fundamental-ngx/platform/shared';
import { BaseDynamicFormFieldItem, PreparedDynamicFormFieldItem } from './interfaces/dynamic-form-item';
import * as i0 from "@angular/core";
export interface BaseDynamicFormGeneratorControlInterface {
    formItem: PreparedDynamicFormFieldItem;
    name: string;
    id: string;
    form: FormGroup;
    formField: PlatformFormField;
}
/**
 * Abstract class that used as a base for the Dynamic Form Generator components.
 */
export declare abstract class BaseDynamicFormGeneratorControl<T extends BaseDynamicFormFieldItem = BaseDynamicFormFieldItem> implements BaseDynamicFormGeneratorControlInterface {
    /**
     * @description @see DynamicFormItem.
     */
    formItem: PreparedDynamicFormFieldItem<T>;
    /**
     * @description Id of the control.
     */
    id: string;
    /**
     * @description Represents form control name.
     */
    name: string;
    /**
     * @description Reference to the @see FormGroup class.
     */
    form: FormGroup;
    /**
     * @description Reference to the @see FormFieldComponent.
     */
    formField: PlatformFormField;
    /** @description Inner form group name */
    formGroupName: string;
    /** @description Returns form item choices. */
    get choices(): SelectItem[];
    /** @description Returns form item placeholder. */
    get placeholder(): string;
    /** @hidden */
    get readonly(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaseDynamicFormGeneratorControl<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaseDynamicFormGeneratorControl<any>, never, never, { "formItem": { "alias": "formItem"; "required": false; }; "id": { "alias": "id"; "required": false; }; "name": { "alias": "name"; "required": false; }; "form": { "alias": "form"; "required": false; }; "formField": { "alias": "formField"; "required": false; }; "formGroupName": { "alias": "formGroupName"; "required": false; }; }, {}, never, never, true, never>;
}
