import { Injector, OnInit, ViewContainerRef } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { ContentDensityMode } from '@fundamental-ngx/core/content-density';
import { PlatformFormField, PlatformFormFieldControl } from '@fundamental-ngx/platform/shared';
import { Observable } from 'rxjs';
import { FormGeneratorService } from './form-generator.service';
import { PreparedDynamicFormFieldItem } from './interfaces/dynamic-form-item';
import * as i0 from "@angular/core";
/**
 * Dynamic form control directive represents a renderer of the dynamic components
 * based on the information provided in `formItem` input
 */
export declare class DynamicFormControlDirective implements OnInit {
    private readonly _formGeneratorService;
    private readonly _vcRef;
    private readonly _injector;
    private contentDensityDirective;
    /**
     * @description @see DynamicFormItem
     */
    formItem: PreparedDynamicFormFieldItem;
    /**
     * @description Represents form control id.
     */
    id: string;
    /**
     * @description Represents form control name.
     */
    name: string;
    /**
     * @description Reference to the @see FormGroup class.
     */
    form: FormGroup;
    /** Form group name path */
    formGroupNamePath: string;
    /**
     * @description Reference to the @see FormFieldComponent
     */
    formField: PlatformFormField;
    /**
     * Control field instance.
     */
    formFieldControl: PlatformFormFieldControl;
    /** @hidden */
    constructor(_formGeneratorService: FormGeneratorService, _vcRef: ViewContainerRef, _injector: Injector, contentDensityDirective: Observable<ContentDensityMode>);
    /** @hidden */
    ngOnInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DynamicFormControlDirective, [null, null, null, { optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<DynamicFormControlDirective, "[fdpDynamicFormControl]", never, { "formItem": { "alias": "formItem"; "required": false; }; "id": { "alias": "id"; "required": false; }; "name": { "alias": "name"; "required": false; }; "form": { "alias": "form"; "required": false; }; "formGroupNamePath": { "alias": "formGroupNamePath"; "required": false; }; "formField": { "alias": "formField"; "required": false; }; }, {}, never, never, true, never>;
}
