import { Type } from '@angular/core';
import { BaseDynamicFormGeneratorControl } from './base-dynamic-form-generator-control';
import { FormComponentDefinition } from './interfaces/form-component-definition';
import * as i0 from "@angular/core";
/**
 * Since form generator service most probably will be provided by parent component,
 * so that forms map does not interfere with other form generators,
 * Components Accessor is a separate service with a global scope, which can be also provided per component.
 */
export declare class FormGeneratorComponentsAccessorService {
    /**
     * @hidden
     */
    private _formComponentDefinitions;
    /**
     * @description Adds custom component to the list of available components for the form generator items.
     * @param component Angular component.
     * @param types types of the form item.
     */
    addComponent(component: Type<BaseDynamicFormGeneratorControl>, types: string[]): boolean;
    /**
     * @description Returns best-matched component based on provided `type` argument
     * @param type form item type
     * @returns @see FormComponentDefinition Component definition for the form item
     */
    getComponentDefinitionByType(type: string): FormComponentDefinition | undefined;
    static ɵfac: i0.ɵɵFactoryDeclaration<FormGeneratorComponentsAccessorService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FormGeneratorComponentsAccessorService>;
}
