/**
 * @license
 * F. Kolar
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *
 */
import { AfterViewInit, ElementRef, EventEmitter, OnInit } from '@angular/core';
import { BaseInput } from '@fundamental-ngx/platform/shared';
import * as i0 from "@angular/core";
export type InputType = 'text' | 'number' | 'email' | 'password';
/**
 * Input field implementation to be compliant with our FormGroup/FormField design and also to
 * achieve certain this in Angular this component is re-using several ideas from MatDesign
 *
 */
export declare class InputComponent extends BaseInput implements OnInit, AfterViewInit {
    /** Input type */
    type: InputType;
    /**
     * @hidden
     * This `required` field is used internally by other components such as Input Group.
     * Input group will not be able to set required value to input, until `required` is input through the`@Input` property.
     */
    required: boolean;
    /** return the value in the text box */
    set value(value: any);
    get value(): any;
    /** Emits event on focus change */
    focusChange: EventEmitter<boolean>;
    /** @hidden */
    get inputElementRef(): ElementRef;
    /** @hidden */
    ngOnInit(): void;
    /** @hidden */
    _onFocus(): void;
    /** @hidden */
    _onBlur(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<InputComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<InputComponent, "fdp-input", never, { "type": { "alias": "type"; "required": false; }; "required": { "alias": "required"; "required": false; }; "value": { "alias": "value"; "required": false; }; }, { "focusChange": "focusChange"; }, never, never, true, never>;
}
