import { AfterViewInit, ElementRef, EventEmitter, InjectionToken, OnChanges, OnDestroy, QueryList, SimpleChanges, TemplateRef } from '@angular/core';
import { Observable, Subject } from 'rxjs';
import { ContentDensity, FocusEscapeDirection, Nullable, RangeSelector, TemplateDirective } from '@fundamental-ngx/cdk/utils';
import { DialogConfig } from '@fundamental-ngx/core/dialog';
import { ListComponent } from '@fundamental-ngx/core/list';
import { MobileModeConfig } from '@fundamental-ngx/core/mobile-mode';
import { PopoverFillMode } from '@fundamental-ngx/core/shared';
import { CollectionBaseInput, MultiComboBoxDataSource, SelectableOptionItem } from '@fundamental-ngx/platform/shared';
import { TextAlignment } from '../../combobox';
import { MultiComboboxConfig } from '../multi-combobox.config';
import * as i0 from "@angular/core";
export declare const MAP_LIMIT: InjectionToken<number>;
export type FdpMultiComboboxDataSource<T> = MultiComboBoxDataSource<T> | Observable<T[]> | T[];
export declare class MultiComboboxSelectionChangeEvent {
    source: BaseMultiCombobox;
    selectedItems: SelectableOptionItem['value'];
    /**
     * Multi Combobox selection change event
     * @param source Multi Combobox component
     * @param selectedItems Selected items
     */
    constructor(source: BaseMultiCombobox, selectedItems: SelectableOptionItem['value']);
}
export declare abstract class BaseMultiCombobox extends CollectionBaseInput implements OnChanges, AfterViewInit, OnDestroy {
    /**
     * @hidden
     * Method to set input text as item label.
     */
    abstract setInputTextFromOptionItem(item: SelectableOptionItem): void;
    /**
     * @hidden
     * Toggle item selection.
     */
    abstract toggleSelection(item: SelectableOptionItem): void;
    /**
     * @hidden
     * Toggle item selection by input text value.
     */
    abstract toggleSelectionByInputText(): void;
    /** Provides selected items. */
    selectedItems: any[];
    /** Provides maximum height for the optionPanel. */
    maxHeight: string;
    /**
     * Whether AddOn Button should be focusable
     * @default true
     */
    buttonFocusable: boolean;
    /** Datasource for suggestion list. */
    set dataSource(value: FdpMultiComboboxDataSource<any>);
    get dataSource(): FdpMultiComboboxDataSource<any>;
    /** Whether the autocomplete should be enabled; Enabled by default. */
    autoComplete: boolean;
    /**
     * TODO: Name of the entity for which DataProvider will be loaded. You can either pass list of
     * items or use this entityClass and internally we should be able to do lookup to some registry
     * and retrieve the best matching DataProvider that is set on application level
     */
    entityClass: string;
    /** Whether the multi-combobox should be built on mobile mode. */
    mobile: boolean;
    /** Multi Combobox Mobile Configuration, it's applied only, when mobile is enabled. */
    mobileConfig: MobileModeConfig;
    /** Tells the multi-combobox if we need to group items. */
    group: boolean;
    /** A field name to use to group data by (support dotted notation). */
    groupKey: string;
    /** The field to show data in secondary column. */
    secondaryKey: string;
    /** Show the second column (applicable for two columns layout). */
    showSecondaryText: boolean;
    /** Horizontally align text inside the second column (applicable for two columns layout). */
    secondaryTextAlignment: TextAlignment;
    /** Turns on/off Adjustable Width feature. */
    autoResize: boolean;
    /** Value of the multi combobox */
    set value(value: any);
    get value(): any;
    /**
     * Preset options for the Select body width, whatever is chosen, the body has a 600px limit.
     * * `at-least` will apply a minimum width to the body equivalent to the width of the control. - Default
     * * `equal` will apply a width to the body equivalent to the width of the control.
     * * 'fit-content' will apply width needed to properly display items inside, independent of control.
     */
    fillControlMode: PopoverFillMode;
    /** Sets title attribute to addon button. */
    addonIconTitle: string;
    /**
     * @deprecated Use the i18n module to modify the translation for this string.
     * Sets invalid entry message.
     * */
    invalidEntryMessage: Nullable<string>;
    /** Turns limitless mode, ON or OFF */
    limitless: boolean;
    /** Whether to open the dropdown when the addon button is clicked. */
    openDropdownOnAddOnClicked: boolean;
    /** Event emitted when item is selected. */
    selectionChange: EventEmitter<MultiComboboxSelectionChangeEvent>;
    /** @hidden Emits event when the menu is opened/closed. */
    isOpenChange: EventEmitter<boolean>;
    /** Event emitted when data loading is started. */
    onDataRequested: EventEmitter<void>;
    /** Event emitted when data loading is finished. */
    onDataReceived: EventEmitter<void>;
    /** Emits event when the addon button is clicked. */
    addOnButtonClicked: EventEmitter<Event>;
    /** @hidden */
    listComponent: ListComponent;
    /** @hidden */
    searchInputElement: ElementRef;
    /** @hidden */
    customTemplates: QueryList<TemplateDirective>;
    /**
     * @hidden
     * Custom Option item Template.
     */
    optionItemTemplate: TemplateRef<any>;
    /**
     * @hidden
     * Custom Group Header item Template.
     */
    groupItemTemplate: TemplateRef<any>;
    /**
     * @hidden
     * Custom Secondary item Template.
     */
    secondaryItemTemplate: TemplateRef<any>;
    /**
     * @hidden
     * Custom Selected option item Template.
     */
    selectedItemTemplate: TemplateRef<any>;
    /** @hidden */
    _contentDensity: ContentDensity;
    /** @hidden */
    listTemplate: TemplateRef<any>;
    /** Set the input text of the input. */
    set inputText(value: string);
    /** Get the input text of the input. */
    get inputText(): string;
    /** Is empty search field. */
    get isEmptyValue(): boolean;
    /** @hidden */
    get isGroup(): boolean;
    /** Whether the Multi Input is opened. */
    isOpen: boolean;
    /**
     * @hidden
     * List of matched suggestions
     */
    _suggestions: SelectableOptionItem[];
    /**
     * @hidden
     * Grouped suggestions mapped to array.
     */
    _flatSuggestions: SelectableOptionItem[];
    /** @hidden */
    _fullFlatSuggestions: SelectableOptionItem[];
    /**
     * @hidden
     * List of selected suggestions
     */
    _selectedSuggestions: SelectableOptionItem[];
    /**
     * @hidden
     * Max width of list container
     */
    maxWidth: number;
    /**
     * @hidden
     * Min width of list container
     */
    minWidth: number;
    /**
     * @hidden
     * Need for opening mobile version
     */
    openChange: Subject<boolean>;
    /** @hidden */
    selectedShown$: import("@angular/core").WritableSignal<boolean>;
    /** @hidden */
    protected readonly multiComboboxConfig: MultiComboboxConfig;
    /** @hidden */
    protected readonly _rangeSelector: RangeSelector;
    /** @hidden */
    protected readonly dialogConfig: DialogConfig<any> | null;
    /** @hidden */
    protected _dataSource: FdpMultiComboboxDataSource<any>;
    /** @hidden */
    private _inputTextValue;
    /** @hidden */
    private _previousInputText;
    /** @hidden */
    private _matchingStrategy;
    /** @hidden */
    private _dsSubscription;
    /** @hidden */
    private _element;
    /**
     * @hidden
     * Keys, that won't trigger the popover's open state, when dispatched on search input.
     */
    private readonly _nonOpeningKeys;
    /** @hidden */
    private _timerSub$;
    /** @hidden */
    private _previousState?;
    /** @hidden */
    private _previousStateMessage;
    /** @hidden */
    private readonly _mapLimit;
    /** @hidden */
    private readonly _lang$;
    /** @hidden */
    private _translationResolver;
    /** @hidden */
    protected constructor();
    /** @hidden */
    ngOnChanges(changes: SimpleChanges): void;
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden */
    ngOnDestroy(): void;
    /** write value for ControlValueAccessor */
    writeValue(value: any): void;
    /** @hidden */
    popoverOpenChangeHandle(isOpen: boolean): void;
    /** @hidden */
    _onOpenChange(isOpen: boolean): void;
    /** Opens the select popover body. */
    open(): void;
    /** Closes the select popover body. */
    close(): void;
    /** @hidden */
    showList(isOpen: boolean): void;
    /** @hidden */
    searchTermChanged(text?: string): void;
    /**
     * Handle Click on Button
     * @hidden
     */
    onPrimaryButtonClick(isOpen: boolean): void;
    /**
     * Handle Keydown on Input
     * @hidden
     */
    onInputKeydownHandler(event: KeyboardEvent): void;
    /** Method passed to list component */
    handleListFocusEscape(direction: FocusEscapeDirection): void;
    /** @hidden */
    setLimitless(limitless: boolean): void;
    /** @hidden */
    getMapLimit(): number;
    /**
     * @hidden
     * Method to emit change event
     */
    _emitChangeEvent(): void;
    /**
     * Used to change the value of a control.
     * @param value the value to be applied
     * @param emitOnChange whether to emit "onChange" event.
     * Should be "false", if the change is made programmatically (internally) by the control, "true" otherwise
     */
    protected setValue(value: any, emitOnChange?: boolean): void;
    /** @hidden */
    protected _setSelectedSuggestions(): void;
    /** @hidden */
    protected get ds(): MultiComboBoxDataSource<any>;
    /** @hidden */
    protected _focusToSearchField(): void;
    /** @hidden */
    protected _getSelectItemByInputValue(displayValue: string): SelectableOptionItem | undefined;
    /** @hidden
     *  Map grouped values to array. */
    protected _flattenGroups(items: SelectableOptionItem[]): SelectableOptionItem[];
    /**
     * Convert object[] data to Group OptionItems Interface
     * @hidden
     */
    protected _convertObjectsToGroupOptionItems<K>(items: K[]): SelectableOptionItem[];
    /** @hidden */
    private _displayFn;
    /** @hidden */
    private _secondaryFn;
    /** @hidden
     * Method that picks other value moved from current one by offset, called only when Multi Combobox is closed */
    private _chooseOtherItem;
    /** @hidden */
    private _initializeDataSource;
    /** @hidden */
    private _openDataStream;
    /** @hidden */
    private _processingEmptyData;
    /** @hidden */
    private _setInvalidEntry;
    /** @hidden */
    private _unsetInvalidEntry;
    /** @hidden */
    private _toDataStream;
    /** @hidden */
    private _initWindowResize;
    /** @hidden */
    private _getOptionsListWidth;
    /**
     * Convert original data to SelectableOptionItems Interface
     * @hidden
     */
    private _convertToOptionItems;
    /**
     * Convert data to SelectableOptionItems Interface
     * @hidden
     */
    private _convertObjectsToOptionItems;
    /**
     * Convert object[] data to Secondary SelectableOptionItems Interface
     * @hidden
     */
    private _convertObjectsToSecondaryOptionItems;
    /**
     * Convert Primitive data(Boolean, String, Number) to SelectableOptionItems Interface
     * @hidden
     */
    private _convertPrimitiveToOptionItems;
    /**
     * Convert object[] to SelectableOptionItems Interface (Default)
     * @hidden
     */
    private _convertObjectsToDefaultOptionItems;
    /**
     * @hidden
     * Assign custom templates
     */
    private _assignCustomTemplates;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaseMultiCombobox, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaseMultiCombobox, never, never, { "selectedItems": { "alias": "selectedItems"; "required": false; }; "maxHeight": { "alias": "maxHeight"; "required": false; }; "buttonFocusable": { "alias": "buttonFocusable"; "required": false; }; "dataSource": { "alias": "dataSource"; "required": false; }; "autoComplete": { "alias": "autoComplete"; "required": false; }; "entityClass": { "alias": "entityClass"; "required": false; }; "mobile": { "alias": "mobile"; "required": false; }; "mobileConfig": { "alias": "mobileConfig"; "required": false; }; "group": { "alias": "group"; "required": false; }; "groupKey": { "alias": "groupKey"; "required": false; }; "secondaryKey": { "alias": "secondaryKey"; "required": false; }; "showSecondaryText": { "alias": "showSecondaryText"; "required": false; }; "secondaryTextAlignment": { "alias": "secondaryTextAlignment"; "required": false; }; "autoResize": { "alias": "autoResize"; "required": false; }; "value": { "alias": "value"; "required": false; }; "fillControlMode": { "alias": "fillControlMode"; "required": false; }; "addonIconTitle": { "alias": "addonIconTitle"; "required": false; }; "invalidEntryMessage": { "alias": "invalidEntryMessage"; "required": false; }; "limitless": { "alias": "limitless"; "required": false; }; "openDropdownOnAddOnClicked": { "alias": "openDropdownOnAddOnClicked"; "required": false; }; }, { "selectionChange": "selectionChange"; "isOpenChange": "isOpenChange"; "onDataRequested": "onDataRequested"; "onDataReceived": "onDataReceived"; "addOnButtonClicked": "addOnButtonClicked"; }, ["customTemplates"], never, true, never>;
}
