import { AfterViewInit, Injector, OnInit, TemplateRef, ViewContainerRef } from '@angular/core';
import { DynamicComponentService } from '@fundamental-ngx/cdk/utils';
import { DataProvider, OptionItem, SelectableOptionItem } from '@fundamental-ngx/platform/shared';
import { ContentDensityObserver } from '@fundamental-ngx/core/content-density';
import { TokenizerComponent } from '@fundamental-ngx/core/token';
import { AutoCompleteEvent } from '../../auto-complete/auto-complete.directive';
import { BaseMultiCombobox } from '../commons/base-multi-combobox';
import * as i0 from "@angular/core";
/**
 * This component can work with both string primitives as well as with complex objects. In order
 * to use objects user must provide an unique ID to lookupkey, which will be used in comparing
 * each items of array. It is important to provide lookupkey value as there might be multiple
 * items with same name but different properties which is to be differently identified otherwise
 * it will be treated as same objects.
 */
export declare class MultiComboboxComponent extends BaseMultiCombobox implements OnInit, AfterViewInit {
    readonly _dynamicComponentService: DynamicComponentService;
    private _providers;
    private readonly _viewContainerRef;
    private readonly _injector;
    readonly contentDensityObserver: ContentDensityObserver;
    /** @hidden */
    mobileControlTemplate: TemplateRef<any>;
    /** @hidden */
    listTemplate: TemplateRef<any>;
    /** @hidden */
    _tokenizer: TokenizerComponent;
    /**
     * @hidden
     * List of selected suggestions
     */
    _selectedSuggestions: SelectableOptionItem[];
    /** @hidden */
    constructor(_dynamicComponentService: DynamicComponentService, _providers: Map<string, DataProvider<any>>, _viewContainerRef: ViewContainerRef, _injector: Injector, contentDensityObserver: ContentDensityObserver);
    /** @hidden */
    ngOnInit(): void;
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden */
    toggleSelection(item: SelectableOptionItem): void;
    /** @hidden */
    onOptionCheckboxClicked(event: MouseEvent, index: number): void;
    /** @hidden */
    onCompleteTerm(event: AutoCompleteEvent): void;
    /** @hidden */
    toggleSelectionByInputText(text?: string): void;
    /**
     * @hidden
     * Method that selects all possible options.
     * *select* attribute – if *true* select all, if *false* unselect all
     * */
    handleSelectAllItems(select: boolean): void;
    /** @hidden */
    navigateByTokens(event: KeyboardEvent): void;
    /** @hidden */
    removeToken(token: SelectableOptionItem, event?: MouseEvent): void;
    /** @hidden */
    moreClicked(): void;
    /** @hidden */
    onBlur(event: FocusEvent): void;
    /**
     * @hidden
     * Method to set input text as item label.
     */
    setInputTextFromOptionItem(item: OptionItem): void;
    /** @hidden */
    onItemKeyDownHandler(event: KeyboardEvent): void;
    /** @hidden */
    onOptionClicked(event: MouseEvent, index: number): void;
    /** @hidden */
    _addOnClicked(event: Event): void;
    /** @hidden Handle dialog dismissing, closes popover and sets backup data. */
    dialogDismiss(backup: SelectableOptionItem[]): void;
    /** @hidden Handle dialog approval, closes popover and propagates data changes. */
    dialogApprove(): void;
    /**
     * @hidden
     * applying range selection. Note, that this function will be invoked after combobox item's value has been changed
     */
    private _onListElementClicked;
    /** @hidden */
    private _getTokenIndexByIdlOrValue;
    /** @hidden */
    private _mapAndUpdateModel;
    /** @hidden */
    private _propagateChange;
    /** @hidden */
    private _setUpMobileMode;
    static ɵfac: i0.ɵɵFactoryDeclaration<MultiComboboxComponent, [null, { optional: true; }, null, null, null]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MultiComboboxComponent, "fdp-multi-combobox", never, {}, {}, never, ["*", "*"], true, never>;
}
