import { AfterViewInit, ElementRef, EventEmitter, OnChanges, OnDestroy, QueryList, SimpleChanges, TemplateRef } from '@angular/core';
import { Observable, Subject } from 'rxjs';
import { FocusEscapeDirection, TemplateDirective } from '@fundamental-ngx/cdk/utils';
import { DialogConfig } from '@fundamental-ngx/core/dialog';
import { MobileModeConfig } from '@fundamental-ngx/core/mobile-mode';
import { ListComponent } from '@fundamental-ngx/platform/list';
import { CollectionBaseInput, MultiInputDataSource, MultiInputOption } from '@fundamental-ngx/platform/shared';
import { TextAlignment } from '../combobox';
import { MultiInputConfig } from './multi-input.config';
import * as i0 from "@angular/core";
export type FdpMultiInputDataSource<T> = MultiInputDataSource<T> | Observable<T[]> | T[];
export declare abstract class BaseMultiInput extends CollectionBaseInput implements AfterViewInit, OnChanges, OnDestroy {
    /** @hidden */
    abstract controlTemplate: TemplateRef<any>;
    /** @hidden */
    abstract listTemplate: TemplateRef<any>;
    /**
     * @hidden
     * Define is this item selected
     */
    abstract isSelectedOptionItem(selectedItem: MultiInputOption): boolean;
    /**
     * @hidden
     * Emit select OptionItem
     * */
    abstract selectOptionItem(item: MultiInputOption): void;
    /**
     * @hidden
     * Define value as selected
     * */
    abstract setAsSelected(item: MultiInputOption[]): void;
    /**
     * @hidden
     * Mathod for marking list option as selected.
     */
    abstract _markListItemsAsSelected(): void;
    /** Provides maximum height for the optionPanel */
    maxHeight: string;
    /** Datasource for suggestion list */
    set dataSource(value: FdpMultiInputDataSource<any>);
    get dataSource(): FdpMultiInputDataSource<any>;
    /** Whether the autocomplete should be enabled; Enabled by default */
    autoComplete: boolean;
    /**
     * Todo: Name of the entity for which DataProvider will be loaded. You can either pass list of
     * items or use this entityClass and internally we should be able to do lookup to some registry
     * and retrieve the best matching DataProvider that is set on application level
     */
    entityClass: string;
    /** Whether the Multi Input should be built on mobile mode */
    mobile: boolean;
    /** Multi Input Mobile Configuration, it's applied only, when mobile is enabled */
    mobileConfig: MobileModeConfig;
    /**
     * Whether AddOn Button should be focusable
     * @default false
     */
    buttonFocusable: boolean;
    /** Tells the multi input if we need to group items */
    group: boolean;
    /** A field name to use to group data by (support dotted notation) */
    groupKey?: string;
    /** The field to show data in secondary column */
    description?: string;
    /** The field to show avatar image data in secondary column */
    avatarsrc?: string;
    /** Show the second column (Applicable for two columns layout) */
    showSecondaryText: boolean;
    /** Horizontally align text inside the second column (Applicable for two columns layout) */
    secondaryTextAlignment: TextAlignment;
    /** Turns on/off Adjustable Width feature */
    autoResize: boolean;
    /** Whether to open the dropdown when the addon button is clicked. */
    openDropdownOnAddOnClicked: boolean;
    /** Value of the multi input */
    set value(value: any);
    get value(): any;
    /** @hidden Emits event when the menu is opened/closed */
    readonly isOpenChange: EventEmitter<boolean>;
    /** Event emitted when data loading is started. */
    readonly onDataRequested: EventEmitter<void>;
    /** Event emitted when data loading is finished. */
    readonly onDataReceived: EventEmitter<void>;
    /** Event emitted when the search term changes. Use *$event* to access the new term. */
    readonly searchTermChange: EventEmitter<string>;
    /** Emits event when the addon button is clicked. */
    readonly addOnButtonClicked: EventEmitter<Event>;
    /** @hidden */
    listComponent: ListComponent<MultiInputOption>;
    /** @hidden */
    customTemplates: QueryList<TemplateDirective>;
    /** @hidden */
    searchInputElement: ElementRef;
    /** @hidden
     * Custom Option item Template
     * */
    optionItemTemplate: TemplateRef<any>;
    /** @hidden
     * Custom Group Header item Template
     * */
    groupItemTemplate: TemplateRef<any>;
    /** @hidden
     * Custom Secondary item Template
     * */
    secondaryItemTemplate: TemplateRef<any>;
    /** @hidden
     * Custom Selected option item Template
     * */
    selectedItemTemplate: TemplateRef<any>;
    /** input text of the input. */
    inputText: string;
    /** Whether the Multi Input is opened. */
    isOpen: boolean;
    /** @hidden */
    get canClose(): boolean;
    /**
     * @hidden
     * List of matched suggestions
     * */
    _suggestions: MultiInputOption[];
    /** @hidden
     * List of matched suggestions
     * */
    _newSuggestions: MultiInputOption[];
    /** @hidden
     * Max width of list container
     * */
    maxWidth?: number;
    /** @hidden
     * Min width of list container
     * */
    minWidth?: number;
    /**
     * Need for opening mobile version
     *
     * @hidden
     */
    openChange: Subject<boolean>;
    /** @hidden */
    protected readonly multiInputConfig: MultiInputConfig;
    /** @hidden */
    protected _dataSource: FdpMultiInputDataSource<any>;
    /** @hidden */
    protected readonly dialogConfig: DialogConfig<any> | null;
    /** @hidden emits whenever there're changes to the inputs, that affect the data creation from data source */
    private readonly _updateDataSourceValues$;
    /** @hidden */
    private _matchingStrategy;
    /** @hidden */
    private _dsSubscription?;
    /** @hidden */
    private _element;
    /** Keys, that won't trigger the popover's open state, when dispatched on search input */
    private readonly _nonOpeningKeys;
    /** @hidden */
    private _originalSuggestions;
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden */
    ngOnChanges(changes: SimpleChanges): void;
    /** @hidden */
    ngOnDestroy(): void;
    /** write value for ControlValueAccessor */
    writeValue(value: any): void;
    /** @hidden */
    _popoverOpenChangeHandle(isOpen: boolean): void;
    /** Opens the select popover body. */
    open(): void;
    /** Closes the select popover body. */
    close(): void;
    /** @hidden */
    convertObjectToMultiInputOption(items: any[]): MultiInputOption[];
    /** @hidden */
    searchTermChanged(text?: string): void;
    /** @hidden */
    showList(isOpen: boolean): void;
    /** @hidden */
    handleOptionItem(value: MultiInputOption): void;
    /** @hidden */
    handlePressEnter(event: KeyboardEvent, value: MultiInputOption): void;
    /**
     * Handle Keydown on Input
     * @hidden
     */
    onInputKeydownHandler(event: KeyboardEvent): void;
    /** Method passed to list component */
    handleListFocusEscape(direction: FocusEscapeDirection): void;
    /** @hidden */
    private _displayFn;
    /** @hidden */
    private _secondaryFn;
    /** @hidden */
    protected get ds(): MultiInputDataSource<any>;
    /** @hidden
     * Method that picks other value moved from current one by offset, called only when Multi Input is closed */
    private _chooseOtherItem;
    /** @hidden */
    private _initializeDataSource;
    /** @hidden */
    private _openDataStream;
    /** @hidden */
    private _toDataStream;
    /** @hidden */
    private _initWindowResize;
    /** @hidden */
    private _getOptionsListWidth;
    /**
     * Convert original data to OptionItems Interface
     * @hidden
     */
    private _convertToOptionItems;
    /**
     * Convert data to OptionItems Interface
     * @hidden
     */
    private _convertObjectsToOptionItems;
    /**
     * Convert object[] data to Group OptionItems Interface
     * @hidden
     */
    private _convertObjectsToGroupOptionItems;
    /**
     * Convert object[] data to Secondary OptionItems Interface
     * @hidden
     */
    private _convertObjectsToSecondaryOptionItems;
    /**
     * Convert Primitive data(Boolean, String, Number) to OptionItems Interface
     * @hidden
     */
    private _convertPrimitiveToOptionItems;
    /**
     * Convert object[] to OptionItems Interface (Default)
     * @hidden
     */
    private _convertObjectsToDefaultOptionItems;
    /** @hidden
     * Assign custom templates
     * */
    private _assignCustomTemplates;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaseMultiInput, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaseMultiInput, never, never, { "maxHeight": { "alias": "maxHeight"; "required": false; }; "dataSource": { "alias": "dataSource"; "required": false; }; "autoComplete": { "alias": "autoComplete"; "required": false; }; "entityClass": { "alias": "entityClass"; "required": false; }; "mobile": { "alias": "mobile"; "required": false; }; "mobileConfig": { "alias": "mobileConfig"; "required": false; }; "buttonFocusable": { "alias": "buttonFocusable"; "required": false; }; "group": { "alias": "group"; "required": false; }; "groupKey": { "alias": "groupKey"; "required": false; }; "description": { "alias": "description"; "required": false; }; "avatarsrc": { "alias": "avatarsrc"; "required": false; }; "showSecondaryText": { "alias": "showSecondaryText"; "required": false; }; "secondaryTextAlignment": { "alias": "secondaryTextAlignment"; "required": false; }; "autoResize": { "alias": "autoResize"; "required": false; }; "openDropdownOnAddOnClicked": { "alias": "openDropdownOnAddOnClicked"; "required": false; }; "value": { "alias": "value"; "required": false; }; }, { "isOpenChange": "isOpenChange"; "onDataRequested": "onDataRequested"; "onDataReceived": "onDataReceived"; "searchTermChange": "searchTermChange"; "addOnButtonClicked": "addOnButtonClicked"; }, ["customTemplates"], never, true, never>;
}
