import { AfterViewInit, EventEmitter, Injector, OnInit, TemplateRef, ViewContainerRef } from '@angular/core';
import { DynamicComponentService } from '@fundamental-ngx/cdk/utils';
import { TokenizerComponent } from '@fundamental-ngx/core/token';
import { ListComponent, ModifyItemEvent, SelectionType } from '@fundamental-ngx/platform/list';
import { DataProvider, MultiInputOption } from '@fundamental-ngx/platform/shared';
import { ContentDensityObserver } from '@fundamental-ngx/core/content-density';
import { PopoverFillMode } from '@fundamental-ngx/core/shared';
import { AutoCompleteEvent } from '../auto-complete/auto-complete.directive';
import { InputType } from '../input/input.component';
import { BaseMultiInput } from './base-multi-input';
import * as i0 from "@angular/core";
export declare class MultiInputSelectionChangeEvent {
    source: PlatformMultiInputComponent;
    payload: any;
    /**
     * Multi Input selection change event
     * @param source Multi Input component
     * @param payload Selected value
     */
    constructor(source: PlatformMultiInputComponent, payload: any);
}
export declare class PlatformMultiInputComponent extends BaseMultiInput implements OnInit, AfterViewInit {
    /** @hidden */
    readonly _dynamicComponentService: DynamicComponentService;
    /** @hidden */
    private readonly _viewContainerRef;
    /** @hidden */
    private readonly _injector;
    /** @hidden */
    private _providers;
    readonly contentDensityObserver: ContentDensityObserver;
    /** @hidden */
    protected tokenCountHiddenLabel: string;
    /** token  count hidden label */
    tokenHiddenId: string;
    /** type Represent the type of input used for the multi Input */
    type: InputType;
    /** boolean type represents the focus set for the respective multi input */
    autofocus: boolean;
    /**  */
    glyphAriaLabel: string;
    /** Title text for the add-on icon button. */
    addonIconTitle: string;
    /** @hidden */
    listTemplateDD: ListComponent<MultiInputOption>;
    /** Selected values from the list items. */
    _selected: any[];
    /** Selected items of the multi input. */
    set selected(selectedValue: any[]);
    get selected(): any[];
    /**
     *
     */
    selectionMode: SelectionType;
    /** Whether the list in byline mode. */
    hasByLine: boolean;
    /** @hidden */
    selectedValue?: MultiInputOption;
    /** @hidden */
    get isGroup(): boolean;
    /** @hidden Whether the input is disabled. */
    protected _disabled: boolean;
    /** Whether the multi input is disabled. */
    set disabled(value: boolean);
    get disabled(): boolean;
    /**
     * Preset options for the Select body width, whatever is chosen, the body has a 600px limit.
     * `at-least` will apply a minimum width to the body equivalent to the width of the control. - Default
     * `equal` will apply a width to the body equivalent to the width of the control.
     * 'fit-content' will apply width needed to properly display items inside, independent of control.
     */
    fillControlMode: PopoverFillMode;
    /**
     * The trigger events that will open/close the options popover.
     * Accepts any [HTML DOM Events](https://www.w3schools.com/jsref/dom_obj_event.asp).
     */
    triggers: string[];
    /** Whether the combobox should close, when a click is performed outside its boundaries. True by default */
    closeOnOutsideClick: boolean;
    /** Callback function when add-on button clicked. */
    addOnButtonClickFn: () => void;
    /** Event emitted when item is selected. */
    readonly selectionChange: EventEmitter<MultiInputSelectionChangeEvent>;
    /** @hidden */
    tokenizer: TokenizerComponent;
    /** @hidden */
    controlTemplate: TemplateRef<any>;
    /** @hidden */
    listTemplate: TemplateRef<any>;
    /** @hidden */
    private readonly _listItems;
    /** @hidden */
    constructor(
    /** @hidden */
    _dynamicComponentService: DynamicComponentService, 
    /** @hidden */
    _viewContainerRef: ViewContainerRef, 
    /** @hidden */
    _injector: Injector, 
    /** @hidden */
    _providers: Map<string, DataProvider<any>>, contentDensityObserver: ContentDensityObserver);
    /** Display function. Accepts an object of the same type as the
     * items passed to dropdownValues as argument, and outputs a string.
     * An arrow function can be used to access the *this* keyword in the calling component.
     * See multi input examples for details. */
    displayFn: (str: string) => string;
    /** @hidden */
    ngOnInit(): void;
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden Method to emit change event */
    emitChangeEvent<T>(modelValue: T): void;
    /** @hidden */
    _checkboxSelected(value: any, event: ModifyItemEvent): void;
    /** @hidden */
    addToArray(value: any, focusOnInput?: boolean): void;
    /** @hidden */
    addOnButtonClick(event: Event): void;
    /** @hidden */
    onInputGroupClicked(): void;
    /** @hidden */
    moreClicked(): void;
    /** @hidden */
    deleteToken(selectedValue: MultiInputOption): void;
    /** @hidden */
    removeToken(token: any): void;
    /** @hidden */
    removeSelectedTokens(event: KeyboardEvent): void;
    /** @hidden Define is selected item selected */
    isSelectedOptionItem(selectedItem: any): boolean;
    /** @hidden Method to set selected item */
    selectOptionItem(item: MultiInputOption): void;
    /** @hidden Method to set as selected */
    setAsSelected(item: MultiInputOption[]): void;
    /**
     * @hidden
     * Mathod for marking items in dropdown as selected.
     */
    _markListItemsAsSelected(): void;
    /** @hidden */
    _onAutoComplete(event: AutoCompleteEvent): void;
    /** @hidden */
    _onKeydownEnter(event: Event): void;
    /** @hidden Handle dialog dismissing, closes popover and sets backup data. */
    _dialogDismiss(selected: any[]): void;
    /** @hidden Handle dialog approval, closes popover and propagates data changes. */
    _dialogApprove(): void;
    /** @hidden if not selected update model */
    private _checkAndUpdate;
    /** @hidden */
    private _getSelectedOptionItem;
    /** @hidden Update model */
    private _updateModel;
    /** @hidden */
    private _setUpMobileMode;
    static ɵfac: i0.ɵɵFactoryDeclaration<PlatformMultiInputComponent, [null, null, null, { optional: true; }, null]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PlatformMultiInputComponent, "fdp-multi-input", never, { "tokenHiddenId": { "alias": "tokenHiddenId"; "required": false; }; "type": { "alias": "type"; "required": false; }; "autofocus": { "alias": "autofocus"; "required": false; }; "glyphAriaLabel": { "alias": "glyphAriaLabel"; "required": false; }; "addonIconTitle": { "alias": "addonIconTitle"; "required": false; }; "selected": { "alias": "selected"; "required": false; }; "selectionMode": { "alias": "selectionMode"; "required": false; }; "hasByLine": { "alias": "hasByLine"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "fillControlMode": { "alias": "fillControlMode"; "required": false; }; "triggers": { "alias": "triggers"; "required": false; }; "closeOnOutsideClick": { "alias": "closeOnOutsideClick"; "required": false; }; "addOnButtonClickFn": { "alias": "addOnButtonClickFn"; "required": false; }; "displayFn": { "alias": "displayFn"; "required": false; }; }, { "selectionChange": "selectionChange"; }, never, ["*"], true, never>;
}
