import { AfterViewInit, ElementRef, EventEmitter, OnDestroy, QueryList, TemplateRef } from '@angular/core';
import { Observable, Subscription } from 'rxjs';
import { SingleDropdownValueControl } from '@fundamental-ngx/cdk/forms';
import { ContentDensityService, FocusEscapeDirection, TemplateDirective } from '@fundamental-ngx/cdk/utils';
import { IconFont } from '@fundamental-ngx/core/icon';
import { ListComponent } from '@fundamental-ngx/core/list';
import { MobileModeConfig } from '@fundamental-ngx/core/mobile-mode';
import { PopoverFillMode } from '@fundamental-ngx/core/shared';
import { CollectionBaseInput } from '@fundamental-ngx/platform/shared';
import { TextAlignment } from '../../combobox';
import { SelectOptionItem } from '../models/select.models';
import { SelectConfig } from '../select.config';
import * as i0 from "@angular/core";
export type FdpSelectData<T> = SelectOptionItem[] | Observable<T[]> | T[];
/**
 * @deprecated
 * `FdpSelectionChangeEvent` will be removed in future versions in favour of plain value emission
 */
export declare class FdpSelectionChangeEvent {
    payload: any;
    /**
     * Select selection change event
     * @param payload selected value
     */
    constructor(payload: any);
}
export declare abstract class BaseSelect extends CollectionBaseInput implements SingleDropdownValueControl, AfterViewInit, OnDestroy {
    /** Provides maximum default height for the optionPanel */
    maxHeight: string;
    /** Whether the select should be built on mobile mode */
    mobile: boolean;
    /** Tells the select if we need to group items */
    group: boolean;
    /** A field name to use to group data by (support dotted notation) */
    groupKey?: string;
    /** The field to show data in secondary column */
    secondaryKey?: string;
    /** Show the second column (Applicable for two columns layout) */
    showSecondaryText: boolean;
    /** Glyph to add icon in the select component. */
    glyph: string;
    /** Glyph font family */
    glyphFont: IconFont;
    /** The element to which the popover should be appended. */
    appendTo: ElementRef;
    /** Trigger value */
    triggerValue: string;
    /**
     * Preset options for the select body width.
     * * `at-least` will apply a minimum width to the body equivalent to the width of the control.
     * * `equal` will apply a width to the body equivalent to the width of the control.
     * * Leave blank for no effect.
     */
    fillControlMode: PopoverFillMode;
    /** Horizontally align text inside the second column (Applicable for two columns layout) */
    secondaryTextAlignment: TextAlignment;
    /**
     * Max width of list container
     * */
    width: string;
    /** Whether the select component is readonly. */
    readonly: boolean;
    /** Placeholder for the select. Appears in the
     * triggerbox if no option is selected. */
    placeholder: string;
    /** Whether close the popover on outside click. */
    closeOnOutsideClick: boolean;
    /** Custom template used to build control body. */
    controlTemplate: TemplateRef<any> | undefined;
    /** Select Input Mobile Configuration */
    mobileConfig: MobileModeConfig;
    /**
     * String rendered as first value in the popup which let the user to make 'no selection' from
     * available list of values. When this option is active and use make this selection we save a
     * NULL value
     */
    noValueLabel: string;
    /** Whether not to wrap text */
    noWrapText: boolean;
    /** Turns on/off Adjustable Width feature */
    autoResize: boolean;
    /** First Column ratio */
    set firstColumnRatio(value: number);
    get firstColumnRatio(): number;
    /** Secoond Column ratio */
    set secondColumnRatio(value: number);
    get secondColumnRatio(): number;
    /**
     * Min width of list container
     *
     * */
    minWidth?: number;
    /**
     * Max width of list container
     * */
    maxWidth?: number;
    /**
     * Action to perform when user shifts focus from the dropdown.
     * - `close` will close the dropdown preserving previously selected value.
     * - `closeAndSelect` will close the dropdown and select last focused dropdown item.
     */
    tabOutStrategy: 'close' | 'closeAndSelect';
    /** Data for suggestion list */
    set list(value: any);
    get list(): any;
    /** @hidden */
    get canClose(): boolean;
    /** Event emitted when item is selected. */
    selectionChange: EventEmitter<FdpSelectionChangeEvent>;
    /** @hidden */
    listComponent: ListComponent;
    /** @hidden */
    customTemplates: QueryList<TemplateDirective>;
    /** Custom Option item Template
     * * @hidden
     * */
    _optionItemTemplate: TemplateRef<any>;
    /**
     * Custom Secondary item Template
     * @hidden
     * */
    _secondaryItemTemplate: TemplateRef<any>;
    /**
     * Custom Selected option item Template
     * @hidden
     * */
    _selectedItemTemplate: TemplateRef<any>;
    /** @hidden */
    _contentDensityService: ContentDensityService;
    /**
     * List of option items
     * @hidden
     * */
    _optionItems: SelectOptionItem[];
    /** @hidden */
    _subscriptions: Subscription;
    /** @hidden */
    protected readonly selectConfig: SelectConfig;
    /** @hidden */
    private _searchInputElement;
    /** Whether the select is opened. */
    private _isOpen;
    /**
     * Need for opening mobile version
     *
     * @hidden
     */
    private _openChange;
    /** @hidden */
    private _dsSubscription?;
    /** @hidden */
    private _element;
    /** @hidden */
    private _firstColumnRatio;
    /** @hidden */
    private _secondColumnRatio;
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden */
    ngOnDestroy(): void;
    /** Is empty search field */
    get isEmptyValue(): boolean;
    /** @hidden
     * Close list * */
    close(event?: MouseEvent | null, forceClose?: boolean): void;
    /** @hidden */
    showList(isOpen: boolean): void;
    /** @hidden */
    handlePressEnter(event: KeyboardEvent, value: SelectOptionItem): void;
    /** Method passed to list component */
    handleListFocusEscape(direction: FocusEscapeDirection): void;
    /** @hidden */
    protected setValue(newValue: any, emitOnChange?: boolean): void;
    /** @hidden */
    private _initWindowResize;
    /** @hidden */
    private _getOptionsListWidth;
    /**
     * Convert original data to OptionItems Interface
     * @hidden
     */
    private _convertToOptionItems;
    /**
     * Convert data to OptionItems Interface
     * @hidden
     */
    private _convertObjectsToOptionItems;
    /**
     * Convert object[] data to Secondary OptionItems Interface
     * @hidden
     */
    private _convertObjectsToSecondaryOptionItems;
    /**
     * Convert Primitive data(Boolean, String, Number) to OptionItems Interface
     * @hidden
     */
    private _convertPrimitiveToOptionItems;
    /**
     * Convert object[] to OptionItems Interface (Default)
     * @hidden
     */
    private _convertObjectsToDefaultOptionItems;
    /** @hidden
     * Assign custom templates
     * */
    private _assignCustomTemplates;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaseSelect, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaseSelect, never, never, { "maxHeight": { "alias": "maxHeight"; "required": false; }; "mobile": { "alias": "mobile"; "required": false; }; "group": { "alias": "group"; "required": false; }; "groupKey": { "alias": "groupKey"; "required": false; }; "secondaryKey": { "alias": "secondaryKey"; "required": false; }; "showSecondaryText": { "alias": "showSecondaryText"; "required": false; }; "glyph": { "alias": "glyph"; "required": false; }; "glyphFont": { "alias": "glyphFont"; "required": false; }; "appendTo": { "alias": "appendTo"; "required": false; }; "triggerValue": { "alias": "triggerValue"; "required": false; }; "fillControlMode": { "alias": "fillControlMode"; "required": false; }; "secondaryTextAlignment": { "alias": "secondaryTextAlignment"; "required": false; }; "width": { "alias": "width"; "required": false; }; "readonly": { "alias": "readonly"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "closeOnOutsideClick": { "alias": "closeOnOutsideClick"; "required": false; }; "controlTemplate": { "alias": "controlTemplate"; "required": false; }; "mobileConfig": { "alias": "mobileConfig"; "required": false; }; "noValueLabel": { "alias": "noValueLabel"; "required": false; }; "noWrapText": { "alias": "noWrapText"; "required": false; }; "autoResize": { "alias": "autoResize"; "required": false; }; "firstColumnRatio": { "alias": "firstColumnRatio"; "required": false; }; "secondColumnRatio": { "alias": "secondColumnRatio"; "required": false; }; "minWidth": { "alias": "minWidth"; "required": false; }; "maxWidth": { "alias": "maxWidth"; "required": false; }; "tabOutStrategy": { "alias": "tabOutStrategy"; "required": false; }; "list": { "alias": "list"; "required": false; }; }, { "selectionChange": "selectionChange"; }, ["customTemplates"], never, true, never>;
}
