import { ContentDensityObserver } from '@fundamental-ngx/core/content-density';
import { StepInputChangeEvent, StepInputComponent } from '../base.step-input';
import * as i0 from "@angular/core";
/**
 * Fundamental number-step-input component
 *
 * Example of usage
 * ```html
 * <fdp-number-step-input
 *   name="number"
 *   [value]="value"
 *   (valueChange)="onValueChange($event)"
 * ></fdp-number-step-input>
 * ```
 *
 * */
export declare class NumberStepInputComponent extends StepInputComponent {
    readonly localeId: string;
    readonly contentDensityObserver: ContentDensityObserver;
    /** Set description */
    description: string;
    /** @hidden */
    constructor(localeId: string, contentDensityObserver: ContentDensityObserver);
    /** @hidden
     * Create change event instance
     */
    createChangeEvent(value: number): StepInputChangeEvent;
    /** @hidden
     * Format value taking into account LOCALE_ID
     */
    formatValue(value: number | null): string;
    /** @hidden
     * In order to avoid issues trying to parse formatted number
     * (potentially specific for each local)
     * we have to simplify number format once it's in focus mode.
     * In this case we deal with a regular float number
     */
    formatValueInFocusMode(value: number | null): string;
    /** @hidden
     * Used to parse entered value
     */
    parseValueInFocusMode(value: string | null): number | null;
    static ɵfac: i0.ɵɵFactoryDeclaration<NumberStepInputComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NumberStepInputComponent, "fdp-number-step-input", never, { "description": { "alias": "description"; "required": false; }; }, {}, never, never, true, never>;
}
