import { AfterViewChecked, AfterViewInit, ElementRef, OnInit } from '@angular/core';
import { FormStates } from '@fundamental-ngx/cdk/forms';
import { Nullable } from '@fundamental-ngx/cdk/utils';
import { BaseInput } from '@fundamental-ngx/platform/shared';
import { TextAreaConfig } from './text-area.config';
import * as i0 from "@angular/core";
export type WrapType = 'hard' | 'soft' | 'off';
/**
 * Textarea field implementation that is compliant with Platform's FormGroup/FormField design
 *
 */
export declare class TextAreaComponent extends BaseInput implements AfterViewChecked, OnInit, AfterViewInit {
    protected _textAreaConfig: TextAreaConfig;
    /**
     * The height to which the textarea will grow when `growing` is set.
     */
    height: Nullable<string>;
    /**
     * The number of rows that will be visible when `growing` is set.
     * If both `growingMaxLines` and `height` are provided, `height` value takes precedence.
     */
    growingMaxLines: Nullable<number>;
    /**
     * The textarea `cols` attribute wrapped- the number of letters visible per line.
     * If width is set to auto, this attribute has no effect.
     */
    cols: number;
    /**
     * The textarea `wrap` attribute - can be one of three: 'off', 'hard' or 'soft'.
     */
    wrapType: WrapType;
    /** The maximum number of characters allowed to enter.
     * If `showExceededText` is false, `maxLength` has native textarea's behavior of disallowing typing beyond `maxLength`.
     * If `showExceededText` is true, user is allowed to type beyond `maxLength`, but error states and counter messages showing
     * the exceeded count is displayed.
     */
    maxLength: number;
    /**
     * Whether counter message should be shown.
     * If `showExceededText` is false, no state changes or error messages are shown. User is simply not allowed to type
     * beyond the `maxLength` characters.
     */
    showExceededText: boolean;
    /**
     * Whether this textarea can grow.
     */
    growing: boolean;
    /**
     * The textarea's value
     */
    set value(value: any);
    get value(): any;
    /** @hidden */
    _textareaCounter?: ElementRef<HTMLDivElement>;
    /** @hidden */
    hasTextExceeded: boolean;
    /** @hidden excess character count */
    exceededCharCount: number;
    /** @hidden a string placeholder that toggles between 'remaining' and 'excess' for the select ICU expression */
    counterExcessOrRemaining: string;
    /** @hidden flag to check if there is an initial value set */
    isValueCustomSet: boolean;
    /** @hidden */
    /** to keep track of number of characters in the textarea */
    private _textAreaCharCount;
    /** @hidden */
    private _isPasted;
    /** for i18n counter message translation */
    private readonly remainingText;
    /** for i18n counter message translation */
    private readonly excessText;
    /**
     * @hidden
     * @see PlatformFormFieldControl.extraContentHeightPx
     */
    get extraContentHeightPx(): number | undefined;
    /** @hidden */
    private get _shouldTrackTextLimit();
    /** @hidden */
    constructor(_textAreaConfig: TextAreaConfig);
    /** when backpress or delete key is pressed when showExceededText field is not set, simply remove excess characters,
     /* else handle autogrow case
     */
    handleBackPress(event: KeyboardEvent): void;
    /** @hidden */
    ngOnInit(): void;
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden */
    ngAfterViewChecked(): void;
    /** write value for ControlValueAccessor */
    writeValue(value: any): void;
    /** update the counter message and related interactions */
    updateCounterInteractions(): void;
    /** if exceeded maxlength when set as a value in code, highlight the exceeded text. */
    validateLengthOnCustomSet(): void;
    /** handle exceeded maxlength case when text is pasted */
    handlePasteInteraction(): void;
    /** handle auto growing of textarea */
    autoGrowTextArea(): void;
    /**
     * get line height of textarea
     */
    getTextareaLineHeight(): number;
    /**
     * get the updated state when character count breaches `maxLength`
     */
    getUpdatedState(): FormStates;
    /** @hidden Native element  */
    get _targetElement(): HTMLTextAreaElement;
    /** @hidden get the length of the textarea content */
    private _getContentLength;
    /** @hidden get the total height including borders and scroll height */
    private _getTextareaTotalHeight;
    /** @hidden set initial max height **/
    private _setMaxHeight;
    static ɵfac: i0.ɵɵFactoryDeclaration<TextAreaComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TextAreaComponent, "fdp-textarea", never, { "height": { "alias": "height"; "required": false; }; "growingMaxLines": { "alias": "growingMaxLines"; "required": false; }; "cols": { "alias": "cols"; "required": false; }; "wrapType": { "alias": "wrapType"; "required": false; }; "maxLength": { "alias": "maxLength"; "required": false; }; "showExceededText": { "alias": "showExceededText"; "required": false; }; "growing": { "alias": "growing"; "required": false; }; "value": { "alias": "value"; "required": false; }; }, {}, never, never, true, never>;
}
