import { AfterViewInit, EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { FormStates } from '@fundamental-ngx/cdk/forms';
import { Placement } from '@fundamental-ngx/core/shared';
import { TimePickerComponent } from '@fundamental-ngx/core/time-picker';
import { BaseInput } from '@fundamental-ngx/platform/shared';
import * as i0 from "@angular/core";
export declare class PlatformTimePickerComponent<D> extends BaseInput implements OnInit, AfterViewInit, OnDestroy {
    /**
     * @Input date time object representation
     */
    set value(value: D | null);
    get value(): D | null;
    /**
     * @Input date time object representation
     */
    time: D;
    /** @Input Whether to show spinner buttons */
    spinnerButtons: boolean;
    /** @deprecated
     * Meridian is deprecated. Use displayFormat and parseFormat inputs or
     * DateTimeFormats.display.timeInput and DateTimeFormats.parse.timeInput instead.
     * @Input When set to false, uses the 24 hour clock (hours ranging from 0 to 23).
     * Default value based on the current locale format option
     */
    set meridian(value: boolean);
    get meridian(): boolean;
    /**
     * @Input When set to false, hides the input for seconds.
     * Default value based on the current locale format option
     * */
    displaySeconds: boolean;
    /**
     * @Input When set to false, hides the input for minutes.
     * Default value based on the current locale format option
     * */
    displayMinutes: boolean;
    /**
     * @Input When set to false, hides the input for hours.
     * Default value based on the current locale format option
     * */
    displayHours: boolean;
    /** @Input Default time picker placeholder which is set dependant on the hours, minutes and seconds.
     * Otherwise, It can be set to a default value
     */
    placeholder: string;
    /** Aria label for the time picker input. */
    timePickerInputLabel: string;
    /** Whether a null input is considered valid(success). */
    allowNull: boolean;
    /** Defines if time component should be used with tablet mode */
    tablet: boolean;
    /**
     *  The placement of the popover. It can be one of: top, top-start, top-end, bottom,
     *  bottom-start, bottom-end, right, right-start, right-end, left, left-start, left-end.
     */
    placement: Placement;
    /**
     *  The state of the form control - applies css classes.
     *  Can be `success`, `error`, `warning`, `information` or blank for default.
     */
    set state(state: FormStates | undefined);
    get state(): FormStates;
    /**
     * Whether AddOn Button should be focusable
     * @default true
     */
    buttonFocusable: boolean;
    /** Whether to validate the time picker input. */
    useValidation: boolean;
    /**
     * @Input when set to true, time inputs won't allow to have 1 digit
     * for example 9 will become 09
     * but 12 will be kept as 12.
     */
    keepTwoDigitsTime: boolean;
    /**
     * Display format option to customize time format in input control.
     * Must be a format option that is understandable by DatetimeAdapter.
     */
    displayFormat: unknown;
    /**
     * Parse format option to customize time format in input control.
     * Must be a format option that is understandable by DatetimeAdapter.
     */
    parseFormat: unknown;
    /** Event emitted when the state of the isOpen property changes. */
    readonly isOpenChange: EventEmitter<boolean>;
    /** @hidden */
    timePickerComponent: TimePickerComponent<D>;
    /** @hidden */
    private _meridian;
    /** @hidden */
    constructor();
    /**
     * Method that handles changes when popover is opened or closed.
     */
    handleOpenChange(open: boolean): void;
    /**
     * logic to handle validation from both platform forms and core datetiimepicker
     * @param value inputted
     */
    handleTimeChange(value: D): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<PlatformTimePickerComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PlatformTimePickerComponent<any>, "fdp-time-picker", never, { "value": { "alias": "value"; "required": false; }; "time": { "alias": "time"; "required": false; }; "spinnerButtons": { "alias": "spinnerButtons"; "required": false; }; "meridian": { "alias": "meridian"; "required": false; }; "displaySeconds": { "alias": "displaySeconds"; "required": false; }; "displayMinutes": { "alias": "displayMinutes"; "required": false; }; "displayHours": { "alias": "displayHours"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "timePickerInputLabel": { "alias": "timePickerInputLabel"; "required": false; }; "allowNull": { "alias": "allowNull"; "required": false; }; "tablet": { "alias": "tablet"; "required": false; }; "placement": { "alias": "placement"; "required": false; }; "state": { "alias": "state"; "required": false; }; "buttonFocusable": { "alias": "buttonFocusable"; "required": false; }; "useValidation": { "alias": "useValidation"; "required": false; }; "keepTwoDigitsTime": { "alias": "keepTwoDigitsTime"; "required": false; }; "displayFormat": { "alias": "displayFormat"; "required": false; }; "parseFormat": { "alias": "parseFormat"; "required": false; }; }, { "isOpenChange": "isOpenChange"; }, never, ["*"], true, never>;
}
