import { ChangeDetectorRef, ElementRef, EventEmitter, OnChanges, QueryList, SimpleChanges } from '@angular/core';
import { PopoverComponent } from '@fundamental-ngx/core/popover';
import { IconTabBarItem } from '../../interfaces/icon-tab-bar-item.interface';
import * as i0 from "@angular/core";
export declare abstract class IconTabBarPopoverBase implements OnChanges {
    protected _cd: ChangeDetectorRef;
    /** @hidden list of tab html elements, that can receive focus. Each item should have "data-flatIndex" attribute */
    abstract _tabExtraUIElements: QueryList<ElementRef<HTMLElement>>;
    /**
     * @description Flag representing rtl mode
     */
    isRtl: boolean;
    /**
     * @description Reference to PopoverComponent
     */
    popover: PopoverComponent;
    /**
     * @description Sub items array
     */
    extraTabs: IconTabBarItem[];
    /**
     * @description Should we show separator between subItems
     */
    isSeparators: boolean;
    /**
     * @description Emits when some tab is selected.
     */
    selectedExtraItem: EventEmitter<IconTabBarItem>;
    /** @description Emits when popover is closed and focus should be applied to first visible tab */
    focusFirstVisibleItem: EventEmitter<void>;
    /** @description Emits when popover is closed and focus should be applied to last visible tab */
    focusLastVisibleItem: EventEmitter<void>;
    /** Event emits when user clicks on x button in tab. */
    closeTab: EventEmitter<string>;
    /**
     * @description Associations for colors of the tabs.
     * If any of the color associations provided, they'll be read by screenreader instead of the actual color
     */
    colorAssociations: import("@angular/core").InputSignal<Partial<Record<import("@fundamental-ngx/platform/icon-tab-bar").SemanticColor, string>> | undefined>;
    /**
     * @hidden
     * @description state of popover
     */
    _isOpen: boolean;
    /** @hidden */
    constructor(_cd: ChangeDetectorRef);
    /** @hidden */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * @hidden
     * @param focusLast whether to focus first or last item in the popover
     */
    _openPopover(focusLast?: boolean): void;
    /** @hidden */
    _focusPreviousPopoverItem(currentIndex: number): void;
    /** @hidden */
    _focusNextPopoverItem(currentIndex: number): void;
    /** @hidden */
    _focusPopoverItem(index: number): void;
    /**
     * @hidden
     * @param selectedItem
     */
    _selectItem(selectedItem: IconTabBarItem): void;
    /** @hidden */
    _keyDownHandler(event: KeyboardEvent, tab: IconTabBarItem, currentIndex: number): void;
    /**
     * @hidden
     * @description Generate styles for subItems
     */
    protected _setStyles(items: IconTabBarItem[]): void;
    /** @hidden */
    private _getOrderedTabExtraUIElements;
    static ɵfac: i0.ɵɵFactoryDeclaration<IconTabBarPopoverBase, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<IconTabBarPopoverBase, never, never, { "isRtl": { "alias": "isRtl"; "required": false; }; "extraTabs": { "alias": "extraTabs"; "required": false; }; "isSeparators": { "alias": "isSeparators"; "required": false; }; "colorAssociations": { "alias": "colorAssociations"; "required": false; "isSignal": true; }; }, { "selectedExtraItem": "selectedExtraItem"; "focusFirstVisibleItem": "focusFirstVisibleItem"; "focusLastVisibleItem": "focusLastVisibleItem"; "closeTab": "closeTab"; }, never, never, true, never>;
}
