import { Point } from '@angular/cdk/drag-drop';
import { ElementRef, EventEmitter } from '@angular/core';
import { IconTabBarDndItem, IconTabBarDndList, IconTabBarItem } from '../../interfaces/icon-tab-bar-item.interface';
import * as i0 from "@angular/core";
export interface FdDnDEvent {
    draggableItem: IconTabBarItem;
    targetItem: IconTabBarItem;
    action: 'replace' | 'insert';
}
export declare class IconBarDndContainerDirective {
    elementRef: ElementRef;
    /**
     * @description Defines if drag and drop feature should be enabled for list items
     */
    set draggable(draggable: boolean);
    /**
     * @description Event that is thrown, when the item is dropped
     */
    dropped: EventEmitter<FdDnDEvent>;
    /** @hidden */
    private _dragRefItems;
    /** @hidden  */
    private dndItemDirectives;
    /** @hidden  */
    private _dndListDirectives;
    /** @hidden */
    private _elementsCoordinates;
    /** @hidden */
    private _virtualSeparatorsCoordinates;
    /** @hidden */
    private _closestItemIndex;
    /** @hidden */
    private _closestSeparatorIndex;
    /** @hidden */
    private _draggable;
    /** @hidden */
    private readonly _destroyRef;
    /** @hidden */
    constructor(elementRef: ElementRef);
    /**
     * @description Method called, when element is started to be dragged
     */
    dragStart(): void;
    /**
     * @param mousePosition
     * @description Method called, when the item is being moved by 1 px
     */
    onMove(mousePosition: Point): void;
    /**
     * @param dragDir
     * @description Method called, when element is released
     */
    dragEnd(dragDir: IconTabBarDndItem): void;
    /**
     * @param dragItem
     * @description Register IconTabBarDndItem to current container
     */
    registerDragItem(dragItem: IconTabBarDndItem): void;
    /**
     * @param dragItem
     * @description Remove registered IconTabBarDndItem to current container
     */
    removeDragItem(dragItem: IconTabBarDndItem): void;
    /**
     * @param listDir
     * @description Register IconTabBarDndList to current container
     */
    registerDndList(listDir: IconTabBarDndList): void;
    /**
     * @param listDir
     * @description Remove registered IconTabBarDndList to current container
     */
    removeDndList(listDir: IconTabBarDndList): void;
    /**
     * @description Generate virtual elements as separator between tabs
     */
    private _generateVirtualSeparators;
    /** @hidden */
    private _changeDraggableState;
    /** @hidden */
    private _isMouseOnFlipper;
    /** @hidden */
    private _isMouseOnElement;
    static ɵfac: i0.ɵɵFactoryDeclaration<IconBarDndContainerDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<IconBarDndContainerDirective, "[fdpIconBarDndContainer], [fdp-icon-bar-dnd-container]", never, { "draggable": { "alias": "draggable"; "required": false; }; }, { "dropped": "dropped"; }, never, never, true, never>;
}
