import { ChangeDetectorRef, ElementRef, OnInit } from '@angular/core';
import { ContentDensityService, Nullable, RtlService } from '@fundamental-ngx/cdk/utils';
import { IconFont } from '@fundamental-ngx/core/icon';
import { ScrollbarDirective } from '@fundamental-ngx/core/scrollbar';
import { TabList } from '@fundamental-ngx/core/shared';
import { IconTabBarTabComponent, IconTabBarTabContentDirective } from './components/icon-tab-bar-tab/icon-tab-bar-tab.component';
import { IconTabBarItem } from './interfaces/icon-tab-bar-item.interface';
import { TabConfig } from './interfaces/tab-config.interface';
import { IconTabBarBackground, IconTabBarSize, TabDestinyMode, TabType } from './types';
import * as i0 from "@angular/core";
export declare class IconTabBarComponent implements OnInit, TabList {
    private _cd;
    private _contentDensityService;
    private _rtlService;
    /**
     * Whether to open tab content one under another without collapsing.
     * Works only for content-projected tab content.
     */
    stackContent: boolean;
    /** Heading level of the tab. */
    tabHeadingLevel: import("@angular/core").InputSignal<number | null>;
    /** @description Type of tab bar view. */
    iconTabType: import("@angular/core").InputSignal<TabType>;
    /**
     * @description A tab bar configuration that stores the state of each tab. Based on this configuration, a tab bar is representing.
     */
    tabsConfig: import("@angular/core").ModelSignal<import("@fundamental-ngx/cdk/utils").NullableObject<{
        icon?: import("@fundamental-ngx/cdk/utils").FdkAsyncProperty<string | undefined>;
        label: import("@fundamental-ngx/cdk/utils").FdkAsyncProperty<string>;
        color: import("@fundamental-ngx/cdk/utils").FdkAsyncProperty<import("./types").SemanticColor | undefined>;
        counter: import("@fundamental-ngx/cdk/utils").FdkAsyncProperty<number>;
        active: boolean;
        badge: boolean;
        subItems: TabConfig[];
        closable: boolean;
        iconFont: IconFont;
        renderer?: import("@angular/core").TemplateRef<any>;
        titleTemplate?: import("@angular/core").TemplateRef<any>;
        id: string;
    }>[] | undefined>;
    /** @description Destiny mode. */
    densityMode: import("@angular/core").ModelSignal<TabDestinyMode>;
    /** @description Icon font */
    iconTabFont: import("@angular/core").InputSignal<IconFont>;
    /** @description Disable or enable reordering(drag and drop) feature. (supported by text type only) */
    enableTabReordering: import("@angular/core").InputSignal<boolean>;
    /** @description Boolean flag indicating to show total tab.(supported by filter type only) */
    showTotalTab: import("@angular/core").InputSignal<boolean>;
    /** Whether to render icon tab item as multi-click variant. */
    multiClick: import("@angular/core").InputSignal<boolean>;
    /** @description Layout type for tab (supported by text type only) */
    layoutMode: import("@angular/core").InputSignal<"row" | "column">;
    /** @description Icon tab bar background type. */
    iconTabBackground: import("@angular/core").InputSignal<IconTabBarBackground>;
    /** @description Icon tab bar size. */
    iconTabSize: import("@angular/core").InputSignal<IconTabBarSize | undefined>;
    /**
     * @description Associations for colors of the tabs.
     * If any of the color associations provided, they'll be read by screenreader instead of the actual color
     */
    colorAssociations: import("@angular/core").InputSignal<Partial<Record<import("./types").SemanticColor, string>> | undefined>;
    /**
     * Maximum height of the content.
     * Works only for content-projected tab content.
     */
    maxContentHeight: import("@angular/core").InputSignal<string>;
    /** @description Emits when some tab is selected. */
    iconTabSelected: import("@angular/core").OutputEmitterRef<IconTabBarItem>;
    /** @description Emits when user drop tab. */
    iconTabReordered: import("@angular/core").OutputEmitterRef<IconTabBarItem[]>;
    /** Event emitted when user clicks on x icon in tab. */
    closeTab: import("@angular/core").OutputEmitterRef<IconTabBarItem>;
    /** @hidden */
    children: import("@angular/core").Signal<readonly IconTabBarTabComponent[]>;
    /** @hidden */
    _scrollbar: import("@angular/core").Signal<ScrollbarDirective | undefined>;
    /** @hidden */
    tabDirectives: import("@angular/core").Signal<readonly IconTabBarTabContentDirective[]>;
    private get _customTabs();
    /** @hidden */
    get headerContainer(): Nullable<ElementRef>;
    /** @hidden */
    _cssClassForContainer: string[];
    /** @hidden */
    _disableScrollSpy: boolean;
    /** @hidden */
    _init: boolean;
    /** Scrollable element reference. */
    get scrollableElement(): Nullable<ElementRef>;
    /** @hidden */
    readonly _selectedUid: import("@angular/core").WritableSignal<string | undefined>;
    /** @hidden */
    readonly _tabs$: import("@angular/core").Signal<IconTabBarItem[]>;
    /** @hidden */
    readonly _flatTabs$: import("@angular/core").Signal<IconTabBarItem[]>;
    /** @hidden */
    readonly _tabRenderer$: import("@angular/core").WritableSignal<IconTabBarItem | null>;
    /** @hidden */
    readonly _rtl$: import("@angular/core").Signal<boolean>;
    /** @hidden */
    readonly _tabsConfig$: import("@angular/core").Signal<import("@fundamental-ngx/cdk/utils").NullableObject<{
        icon?: import("@fundamental-ngx/cdk/utils").FdkAsyncProperty<string | undefined>;
        label: import("@fundamental-ngx/cdk/utils").FdkAsyncProperty<string>;
        color: import("@fundamental-ngx/cdk/utils").FdkAsyncProperty<import("./types").SemanticColor | undefined>;
        counter: import("@fundamental-ngx/cdk/utils").FdkAsyncProperty<number>;
        active: boolean;
        badge: boolean;
        subItems: TabConfig[];
        closable: boolean;
        iconFont: IconFont;
        renderer?: import("@angular/core").TemplateRef<any>;
        titleTemplate?: import("@angular/core").TemplateRef<any>;
        id: string;
    }>[]>;
    /** @hidden */
    private readonly _destroyRef;
    private readonly _inDynamicPage;
    private readonly _iconTabBarCmp;
    /** @hidden */
    constructor(_cd: ChangeDetectorRef, _contentDensityService: ContentDensityService, _rtlService: RtlService);
    /** @hidden */
    ngOnInit(): void;
    /**
     * @hidden
     * @param event reordered array of IconTabBarItem
     */
    _onReorder(event: IconTabBarItem[]): void;
    /**
     * @hidden
     * @param selectedItem
     */
    _selectItem(selectedItem: IconTabBarItem): void;
    /** @hidden */
    _closeTab(item: IconTabBarItem): void;
    /** Programmatically select tab. */
    selectTab(id: Nullable<string>): void;
    /** @hidden */
    highlightActiveTab(id: Nullable<string>, scroll?: boolean): void;
    /**
     * @hidden
     * @returns array of css classes for icon-tab-bar container
     */
    private _generateContainerStyles;
    private _generateTabConfig;
    /** @hidden */
    private _scrollToPanel;
    /**
     * @hidden
     * @description generate IconTabItems from TabConfig array
     */
    private _generateTabBarItems;
    private _generateFlatTabs;
    static ɵfac: i0.ɵɵFactoryDeclaration<IconTabBarComponent, [null, { optional: true; }, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IconTabBarComponent, "fdp-icon-tab-bar", never, { "stackContent": { "alias": "stackContent"; "required": false; }; "tabHeadingLevel": { "alias": "tabHeadingLevel"; "required": false; "isSignal": true; }; "iconTabType": { "alias": "iconTabType"; "required": false; "isSignal": true; }; "tabsConfig": { "alias": "tabsConfig"; "required": false; "isSignal": true; }; "densityMode": { "alias": "densityMode"; "required": false; "isSignal": true; }; "iconTabFont": { "alias": "iconTabFont"; "required": false; "isSignal": true; }; "enableTabReordering": { "alias": "enableTabReordering"; "required": false; "isSignal": true; }; "showTotalTab": { "alias": "showTotalTab"; "required": false; "isSignal": true; }; "multiClick": { "alias": "multiClick"; "required": false; "isSignal": true; }; "layoutMode": { "alias": "layoutMode"; "required": false; "isSignal": true; }; "iconTabBackground": { "alias": "iconTabBackground"; "required": false; "isSignal": true; }; "iconTabSize": { "alias": "iconTabSize"; "required": false; "isSignal": true; }; "colorAssociations": { "alias": "colorAssociations"; "required": false; "isSignal": true; }; "maxContentHeight": { "alias": "maxContentHeight"; "required": false; "isSignal": true; }; }, { "tabsConfig": "tabsConfigChange"; "densityMode": "densityModeChange"; "iconTabSelected": "iconTabSelected"; "iconTabReordered": "iconTabReordered"; "closeTab": "closeTab"; }, ["children"], ["[fdpIconTabBarFreeContent]"], true, never>;
    static ngAcceptInputType_stackContent: unknown;
}
