import { FocusKeyManager, LiveAnnouncer } from '@angular/cdk/a11y';
import { AfterViewInit, ElementRef, EventEmitter, OnDestroy, OnInit, QueryList } from '@angular/core';
import { Observable } from 'rxjs';
import { Nullable } from '@fundamental-ngx/cdk/utils';
import { ListUnreadIndicator } from '@fundamental-ngx/core/list';
import { FdLanguage } from '@fundamental-ngx/i18n';
import { CollectionBaseInput, ListDataSource } from '@fundamental-ngx/platform/shared';
import { BaseListItem, ListItemDef } from './base-list-item';
import { LoadMoreContentContext, LoadMoreContentDirective } from './load-more-content.directive';
import { FdpList, FdpListDataSource, ListType, SelectionType } from './models/list';
import * as i0 from "@angular/core";
export declare class SelectionChangeEvent {
    /** Selected items */
    selectedItems: BaseListItem[];
    /** Index */
    index: number;
}
/**
 * The List component represents a container for list item types.
 * It is used to display a list features.
 */
export declare class ListComponent<T> extends CollectionBaseInput implements ListUnreadIndicator, OnInit, AfterViewInit, OnDestroy, FdpList<BaseListItem> {
    private readonly _liveAnnouncer;
    private readonly _language$;
    /**  An array that holds a list of all selected items. **/
    selectedItems: BaseListItem[];
    /** define size of items for screen reader. */
    ariaSetsize: number;
    /** Defines whether items are multiselectable for screen reader. */
    ariaMultiselectable: boolean;
    /** Title used on button when data loads on button click. */
    loadTitle: string;
    /** Label used on announce message of data was loaded for screen readers. */
    loadingLabel: string;
    /** Wait time for new items. */
    delayTime: number;
    /** Items to be loaded at once. Intinity (no limit) by default. */
    itemSize: number;
    /** Enables lazy loadMore of data. */
    loadMore: boolean;
    /**
     * Enables data load on scroll for true
     * false: enables data loading on button click.
     */
    loadOnScroll: boolean;
    /** define the role to custom requirement. */
    role: string;
    /** ListType 'inactive' | 'active' | 'navigation' | 'detail' */
    listType: ListType;
    /** Max height for viewport to display scroll. */
    maxHeight: string;
    /** Whether list component has removed borders. */
    noBorder: boolean;
    /** Scroll offset percentage to trigger scroll event. */
    scrollOffsetPercentage: number;
    /** Eenables selection styles. */
    selection: boolean;
    /**
     * The type of the selection. Types include:
     * 'none'| 'multi' | 'single'|'delete'.
     * Leave empty for default ().'
     * Default value is set to 'none'.
     */
    selectionMode: SelectionType;
    /** setter and getter for radio button and checkbox. */
    set value(value: any);
    get value(): any;
    /** setter and getter for row level Selection. */
    set rowSelection(value: boolean);
    get rowSelection(): boolean;
    /** Datasource for suggestion list. */
    set dataSource(value: FdpListDataSource<T>);
    get dataSource(): FdpListDataSource<T>;
    /** setter and getter for _navigated. */
    set navigated(value: boolean);
    get navigated(): boolean;
    /** setter and getter for _navigationIndicator. */
    set navigationIndicator(value: boolean);
    get navigationIndicator(): boolean;
    /** setter and getter for hasByLine. */
    set hasByLine(value: boolean);
    get hasByLine(): boolean;
    /** setter and getter for hasObject. */
    set hasObject(value: boolean);
    get hasObject(): boolean;
    /** Whether to display unread notification indicator. */
    unreadIndicator: boolean;
    /** Whether to intercept tab key navigation. */
    interceptTabKey: boolean;
    /** Event thrown, when selected item is changed */
    selectedItemChange: EventEmitter<SelectionChangeEvent>;
    /** Access child element, for checking link content */
    anchor: ElementRef<HTMLLinkElement>;
    /** @hidden */
    listItemDef: ListItemDef;
    /** Show More List item content */
    loadMoreContent: LoadMoreContentDirective;
    /** Child items of the List. */
    listItems: QueryList<BaseListItem>;
    /** @hidden */
    get _ulElement(): Nullable<HTMLUListElement>;
    /**
     * @hidden
     * To display loading symbol
     */
    _loading: boolean;
    /** @hidden
     * To differentiate between first loading when skeletons be shown and subsequent loadings when busy indicator be shown
     */
    _firstLoadingDone: boolean;
    /**
     * @hidden
     * keyManger to handle keybord events used in template
     */
    _keyManager: Nullable<FocusKeyManager<BaseListItem>>;
    /** @hidden */
    _items: T[];
    /** @hidden */
    _ariaSetSize: Observable<number>;
    /** @hidden */
    protected _dataSource: ListDataSource<T>;
    /**
     * @hidden
     * Verfies partial navigation enabled
     */
    protected _partialNavigation: boolean;
    /** @hidden */
    private _translationResolver;
    /**
     * @hidden
     * Whether Navigation mode is included to list component
     * for all the items
     */
    private _navigated;
    /**
     * @hidden
     * Whether By line is present in list item
     */
    private _hasByLine;
    /**
     * @hidden
     * Whether Navigation mode is included to list component
     * only a subset of the list items are navigable
     * you should indicate those by displaying a navigation arrow
     */
    private _navigationIndicator;
    /**
     * @hidden
     * Whether object present in list item
     */
    private _hasObject;
    /**
     * @hidden
     * The model backing of the component.
     */
    private _selectionModel;
    /**
     * @hidden
     * Whether list component has multiselection
     * binding in tempate to append class
     */
    private _multiSelect;
    /** @hidden */
    private _selectedvalue;
    /**
     * @hidden
     * Whether row level selection mode is enabled to list component
     * for all the items
     */
    private _rowSelection;
    /** @hidden To store */
    private _tempItems;
    /** @hidden */
    private _startIndex;
    /** @hidden */
    private _lastIndex;
    /** @hidden */
    private _dsItems;
    /**
     * @hidden
     * for data source handling
     */
    private _dsSubscription;
    /** @hidden */
    private _language;
    /** @hidden */
    private _afterViewInit$;
    /** @hidden */
    constructor(_liveAnnouncer: LiveAnnouncer, _language$: Observable<FdLanguage>);
    /**
     * @hidden
     * on Update navgiation styles for non navigated items
     * event:any to avoid code duplication
     * seprate PR for custom event
     */
    _updateNavigation(event: Event): void;
    /** Get context for load more button */
    getLoadMoreContentContext(): LoadMoreContentContext;
    /**
     * @hidden
     * Initialization of the lis component with selection mode
     */
    ngOnInit(): void;
    /**
     * @hidden
     * Keyboard manager on list items, set values when passed via array
     */
    ngAfterViewInit(): void;
    /** @hidden */
    ngOnDestroy(): void;
    /**
     * @hidden
     * handline keyboard operations
     * in template on list and list items
     */
    _handleKeyDown(event: KeyboardEvent): Nullable<boolean>;
    /** @hidden */
    _setCurrentActiveItemIndex(activeItemIndex: number): void;
    /**
     * @hidden
     * binded in template on scroll
     */
    _scrollHandler(): void;
    /**
     * @hidden
     * show more on enter or space press
     */
    _loadOnKeyPress(event: KeyboardEvent): void;
    /**
     * @hidden
     * Handles lazy loading data
     * used in template
     * onscroll and on more button click
     */
    _getMoreData(): void;
    /**
     * @hidden
     * used in tempate to get Selected items from a list
     * event:any to avoid code duplication
     */
    _onSelectionChanged(event: Event): void;
    /** @hidden */
    _setupListItem(item: BaseListItem): void;
    /** @hidden */
    _selectItem(item: BaseListItem): void;
    /** @hidden */
    private _setItems;
    /** @hidden */
    private _initializeDS;
    /** @hidden */
    private _toDataStream;
    /** @hidden */
    private _openDataStream;
    /** @hidden */
    private _loadNewItems;
    /**
     * @hidden
     * List item with radio button styles, check, uncheckupdates
     * event:any to avoid code duplication
     */
    private _handleSingleSelect;
    /** @hidden */
    private _handleRowSelect;
    /**
     * @hidden
     * List item with checkbox styles,check,uncheckupdates
     * event:any to avoid code duplication
     */
    private _handleMultiSelect;
    /**
     * @hidden
     * Setting values from list to list items
     * example:
     * Does list item has navigation,
     * should show arrows,
     * will it be compact mode,
     * should be in which selection mode
     * set values when passed via datasource
     */
    private _updateListItems;
    /** @hidden */
    private _waitForViewInit;
    /** @hidden */
    private _init;
    static ɵfac: i0.ɵɵFactoryDeclaration<ListComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ListComponent<any>, "fdp-list", never, { "selectedItems": { "alias": "selectedItems"; "required": false; }; "ariaSetsize": { "alias": "ariaSetsize"; "required": false; }; "ariaMultiselectable": { "alias": "ariaMultiselectable"; "required": false; }; "loadTitle": { "alias": "loadTitle"; "required": false; }; "loadingLabel": { "alias": "loadingLabel"; "required": false; }; "delayTime": { "alias": "delayTime"; "required": false; }; "itemSize": { "alias": "itemSize"; "required": false; }; "loadMore": { "alias": "loadMore"; "required": false; }; "loadOnScroll": { "alias": "loadOnScroll"; "required": false; }; "role": { "alias": "role"; "required": false; }; "listType": { "alias": "listType"; "required": false; }; "maxHeight": { "alias": "maxHeight"; "required": false; }; "noBorder": { "alias": "noBorder"; "required": false; }; "scrollOffsetPercentage": { "alias": "scrollOffsetPercentage"; "required": false; }; "selection": { "alias": "selection"; "required": false; }; "selectionMode": { "alias": "selectionMode"; "required": false; }; "value": { "alias": "value"; "required": false; }; "rowSelection": { "alias": "rowSelection"; "required": false; }; "dataSource": { "alias": "dataSource"; "required": false; }; "navigated": { "alias": "navigated"; "required": false; }; "navigationIndicator": { "alias": "navigationIndicator"; "required": false; }; "hasByLine": { "alias": "hasByLine"; "required": false; }; "hasObject": { "alias": "hasObject"; "required": false; }; "unreadIndicator": { "alias": "unreadIndicator"; "required": false; }; "interceptTabKey": { "alias": "interceptTabKey"; "required": false; }; }, { "selectedItemChange": "selectedItemChange"; }, ["listItemDef", "loadMoreContent", "listItems"], ["fd-toolbar", "*", "*", "#load"], true, never>;
}
