import { FocusOrigin } from '@angular/cdk/a11y';
import { AfterContentInit, AfterViewInit, EventEmitter, OnDestroy, QueryList, TemplateRef } from '@angular/core';
import { Observable } from 'rxjs';
import { RtlService } from '@fundamental-ngx/cdk/utils';
import { ContentDensityObserver } from '@fundamental-ngx/core/content-density';
import { MenuItemComponent } from './menu-item.component';
import * as i0 from "@angular/core";
export type MenuCloseMethod = void | 'mouse' | 'keyboard' | 'tab' | 'arrow';
/**
 * @deprecated
 * Menu component is deprecated. Use `fd-menu` from `@fundamental-ngx/core/menu` instead.
 */
export declare class MenuComponent implements AfterViewInit, AfterContentInit, OnDestroy {
    private _rtl;
    readonly contentDensityObserver: ContentDensityObserver;
    /** Menu ID */
    set id(id: string);
    get id(): string;
    /**
     * Whether menu can be opened using arrow keys
     * @default true
     */
    openByArrowKeys: boolean;
    /**
     * Horizontal position of menu in relation to trigger element.
     */
    xPosition: 'before' | 'after';
    /**
     * The templateRef needs to be available to the menu trigger for
     * opening in a CDK overlay.
     */
    templateRef: TemplateRef<any>;
    /**
     * Child items of the menu.
     */
    menuItems: QueryList<MenuItemComponent>;
    /**
     * Emitted event when menu closes
     */
    close: EventEmitter<MenuCloseMethod>;
    /** Menu direction */
    direction: 'ltr' | 'rtl';
    /** @hidden */
    menuId: string;
    /** @hidden */
    private _id;
    /** @hidden */
    private _keyManager;
    /** @hidden */
    private _tabSubscription;
    /** @hidden */
    private _dirChangeSubscription;
    /** @hidden */
    constructor(_rtl: RtlService, contentDensityObserver: ContentDensityObserver);
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden */
    ngAfterContentInit(): void;
    /** @hidden */
    ngOnDestroy(): void;
    /**
     * Set focus on first item
     * @param origin FocusOrigin
     */
    focusOnFirstItem(origin?: FocusOrigin): void;
    /**
     * Close menu
     * @param method menu close method
     */
    closeMenu(method: MenuCloseMethod): void;
    /**
     * @hidden
     * Menu keydown handler
     */
    _onKeydown(event: KeyboardEvent): void;
    /**
     * @hidden
     * Menu click handler
     */
    _onClick(): void;
    /**
     * @hidden
     * Get stream of menu items hover change
     */
    _menuItemHoverChange(): Observable<MenuItemComponent>;
    /** @hidden */
    _setMenuItemCascadeDirection(): void;
    /**
     * @hidden
     * Check if cascade menu should appear from right
     */
    _cascadesRight(): boolean;
    /**
     * @hidden
     * Check if cascade menu should appear from left
     */
    _cascadesLeft(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<MenuComponent, [{ optional: true; }, null]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MenuComponent, "fdp-menu", never, { "id": { "alias": "id"; "required": false; }; "openByArrowKeys": { "alias": "openByArrowKeys"; "required": false; }; "xPosition": { "alias": "xPosition"; "required": false; }; }, { "close": "close"; }, ["menuItems"], ["*"], true, never>;
}
