import { AfterViewInit, DestroyRef, OnDestroy } from '@angular/core';
import { FormGroupDirective, NgForm } from '@angular/forms';
import { PlatformFormFieldControl } from '@fundamental-ngx/platform/shared';
import { Subject } from 'rxjs';
import { MessagePopoverConfig } from '../../default-config';
import { MessagePopoverErrorGroup } from '../../models/message-popover-entry.interface';
import { MessagePopoverWrapper } from '../../models/message-popover-wrapper.interface';
import { MessagePopover } from '../../models/message-popover.interface';
import * as i0 from "@angular/core";
export type MessagePopoverForm = NgForm | FormGroupDirective;
export declare class MessagePopoverFormWrapperComponent implements MessagePopoverWrapper, AfterViewInit, OnDestroy {
    private readonly _destroyRef;
    private readonly _config;
    /** @hidden */
    private readonly _projectedForm;
    /** @hidden */
    private readonly _projectedFormFieldControls;
    /** @hidden */
    private readonly _directiveItems;
    /** Message Popover instance. */
    messagePopover$: Subject<MessagePopover>;
    /**
     * User-passed forms.
     */
    set forms(forms: MessagePopoverForm | MessagePopoverForm[]);
    /** User-passed form fields. */
    set formFields(value: PlatformFormFieldControl[]);
    get formFields(): PlatformFormFieldControl[];
    /**
     * Error models Signal. Emitted when form submitted and contains invalid fields.
     */
    readonly errors$: import("@angular/core").WritableSignal<MessagePopoverErrorGroup[]>;
    /** @hidden */
    private _formFields;
    /** @hidden */
    private _formErrorsSubscription;
    /** @hidden */
    private _ngForms;
    /** @hidden */
    private _formItemErrorsSubscription;
    /** @hidden */
    private _formSubmitted;
    /** @hidden */
    constructor(_destroyRef: DestroyRef, _config: MessagePopoverConfig);
    /** @hidden */
    ngAfterViewInit(): void;
    /**
     * Sets Message Popover component instance.
     */
    setMessagePopover(messagePopover: MessagePopover): void;
    /**
     * Programmatically add new form to array of forms.
     * @param forms
     */
    addForms(forms: MessagePopoverForm | MessagePopoverForm[]): void;
    /**
     * Programmatically add new form fields to array of listened form fields.
     * @param formFields
     */
    addFormFields(formFields: PlatformFormFieldControl[]): void;
    /** @hidden */
    ngOnDestroy(): void;
    /**
     * @hidden
     * Listens to the form submission and collects form control errors.
     */
    private _startListeningForErrors;
    /** @hidden */
    private _listenToFormFieldErrors;
    /** @hidden */
    private _collectPlainFormData;
    /** @hidden */
    private _collectAdvancedFormData;
    /**
     * @hidden
     * Creates error model
     */
    private _getErrorModel;
    /**
     * @hidden
     * Creates error text based on the type of the error.
     * @param field Form Field Control.
     * @param errorDirective Optional Error directive
     * @param section Section where text should be rendered.
     * @param errorKey
     * @param error
     */
    private _getErrorText;
    /** @hidden */
    private _getGroupName;
    /** @hidden */
    private _getConfigErrorModel;
    /** @hidden */
    private _isAdvancedError;
    static ɵfac: i0.ɵɵFactoryDeclaration<MessagePopoverFormWrapperComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MessagePopoverFormWrapperComponent, "fdp-message-popover-form-wrapper", ["messagePopoverWrapper"], { "forms": { "alias": "forms"; "required": false; }; "formFields": { "alias": "formFields"; "required": false; }; }, {}, ["_projectedForm", "_projectedFormFieldControls", "_directiveItems"], ["*"], true, never>;
}
