import { EventEmitter, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { BaseComponent } from '@fundamental-ngx/platform/shared';
import { Nullable } from '@fundamental-ngx/cdk/utils';
import { ContentDensityObserver } from '@fundamental-ngx/core/content-density';
import { PanelTitleDirective } from '@fundamental-ngx/core/panel';
import { PanelContentComponent } from './panel-content/panel-content.component';
import { PanelConfig } from './panel.config';
import * as i0 from "@angular/core";
/** Panel change event instance */
export declare class PanelExpandChangeEvent {
    source: PanelComponent;
    payload: boolean;
    /**
     * Panel expand change event
     * @param source Panel component
     * @param payload Panel expand state
     */
    constructor(source: PanelComponent, payload: boolean);
}
/**
 * Fundamental Panel component
 *
 * ```html
 * <fdp-panel title="Panel Header">
 *     <fdp-panel-content>
 *        Panel Content
 *     </fdp-panel-content>
 * </fdp-panel>
 * ```
 *
 * */
export declare class PanelComponent extends BaseComponent implements OnInit, OnChanges {
    protected _panelConfig: PanelConfig;
    readonly contentDensityObserver: ContentDensityObserver;
    /**
     * sets Panel title.
     */
    title: string;
    /**
     * Whether the Panel Content is expanded
     */
    expanded: boolean;
    /**
     * Whether the Panel is expandable
     */
    expandable: boolean;
    /**
     * ARIA label for button when the Panel is collapsed
     */
    expandLabel: string;
    /**
     * ARIA label for button when the Panel is expanded
     */
    collapseLabel: string;
    /** Output event triggered when the Expand button is clicked */
    panelExpandChange: EventEmitter<PanelExpandChangeEvent>;
    /** @hidden */
    _panelContentComponent: Nullable<PanelContentComponent>;
    /** @hidden */
    _panelTitleDirective: Nullable<PanelTitleDirective>;
    /**
     * @hidden
     * Button label based on the current state
     */
    _expandAriaLabel: string;
    /** @hidden id of the title element */
    _titleId: string;
    /** @hidden */
    constructor(_panelConfig: PanelConfig, contentDensityObserver: ContentDensityObserver);
    /** @hidden */
    ngOnInit(): void;
    /** @hidden */
    ngOnChanges(changes: SimpleChanges): void;
    /** Handles expanded/collapsed event */
    onExpandedChange(expanded: boolean): void;
    /**
     * @hidden
     * Calculate expandAriaLabel based on panel state
     */
    private _calculateExpandAriaLabel;
    static ɵfac: i0.ɵɵFactoryDeclaration<PanelComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PanelComponent, "fdp-panel", never, { "title": { "alias": "title"; "required": false; }; "expanded": { "alias": "expanded"; "required": false; }; "expandable": { "alias": "expandable"; "required": false; }; "expandLabel": { "alias": "expandLabel"; "required": false; }; "collapseLabel": { "alias": "collapseLabel"; "required": false; }; }, { "panelExpandChange": "panelExpandChange"; }, ["_panelContentComponent"], ["fdp-panel-actions", "fdp-panel-content"], true, never>;
}
