import { ElementRef, OnDestroy } from '@angular/core';
import { Nullable } from '@fundamental-ngx/cdk/utils';
import { FormGeneratorComponent } from '@fundamental-ngx/platform/form';
import { BehaviorSubject, Observable, Subject } from 'rxjs';
import { SettingsModel } from './models/settings.model';
import * as i0 from "@angular/core";
export type SettingsGeneratorReturnValue = Record<string, unknown>;
export declare class SettingsGeneratorService implements OnDestroy {
    /**
     * Settings configuration subject.
     */
    readonly settings: BehaviorSubject<Nullable<SettingsModel>>;
    /**
     * Stream emitted when user clicked on message popover error entry.
     */
    readonly onItemFocus: Subject<{
        path: string;
        element: ElementRef<HTMLElement>;
    }>;
    /**
     * Stream emitted when mobile state has been changed.
     */
    readonly mobileState$: BehaviorSubject<boolean>;
    /**
     * @hidden
     * Form generators collected from all items and groups.
     */
    private readonly _formGenerators;
    /** @hidden */
    private readonly _messagePopover;
    /** @hidden */
    private readonly _destroyRef;
    /** @hidden */
    constructor();
    /** @hidden */
    _addFormGenerator(path: string[], formGenerator: FormGeneratorComponent): void;
    /** @hidden */
    _removeFormGenerator(path: string[]): void;
    /**
     * Submits registered forms and emits result if submission status was successful (no errors).
     */
    submit(): Observable<SettingsGeneratorReturnValue>;
    /**
     * Sets mobile state.
     * @param isMobile Whether mobile state should be applied.
     */
    setMobileState(isMobile: boolean): void;
    /** @hidden */
    ngOnDestroy(): void;
    /**
     * @hidden
     * Subscribes to click events from message popover and tries to open the section where invalid input is located.
     */
    private _listenToMessagePopoverItemClick;
    static ɵfac: i0.ɵɵFactoryDeclaration<SettingsGeneratorService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SettingsGeneratorService>;
}
