import { ChangeDetectorRef, OnDestroy } from '@angular/core';
import { Subscription } from 'rxjs';
import { Nullable } from '@fundamental-ngx/cdk/utils';
import * as i0 from "@angular/core";
/**
 * This class contains common properties used across components.
 * this can be extended to reduce the code duplication across components.
 * @hidden for form related Base , see BaseInput.
 */
export declare abstract class BaseComponent implements OnDestroy {
    /** Sets the `aria-label` attribute to the element. */
    ariaLabel: Nullable<string>;
    /** Sets the `aria-labelledby` attribute to the element. */
    ariaLabelledBy: Nullable<string>;
    /**
     * @deprecated
     * Use `ariaLabelledBy` instead.
     */
    set ariaLabelledby(value: Nullable<string>);
    /** Sets the `aria-describedby` attribute to the element. */
    ariaDescribedBy: Nullable<string>;
    /** id for the Element */
    id: string;
    /** name for the element */
    name: string;
    /** width of the element */
    width: string;
    /** disabled status of the element */
    set disabled(disabled: boolean);
    get disabled(): boolean;
    /** @hidden */
    protected _disabled: boolean;
    /** @hidden */
    protected _subscriptions: Subscription;
    /**
     * @hidden
     * Change detector ref.
     */
    protected readonly _cdr: ChangeDetectorRef;
    /** @hidden */
    ngOnDestroy(): void;
    /**
     * @hidden
     * For internal usage only
     *
     * Since all components use OnPush strategy in the fundamental lib
     * it's tricky to update a child input directly from a parent component class
     *
     */
    markForCheck(): void;
    /**
     * @hidden
     * For internal usage only
     *
     * Since all components use OnPush strategy in the fundamental lib
     * it's tricky to update a child input directly from a parent component class
     *
     */
    detectChanges(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaseComponent, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaseComponent, never, never, { "ariaLabel": { "alias": "ariaLabel"; "required": false; }; "ariaLabelledBy": { "alias": "ariaLabelledBy"; "required": false; }; "ariaLabelledby": { "alias": "ariaLabelledby"; "required": false; }; "ariaDescribedBy": { "alias": "ariaDescribedBy"; "required": false; }; "id": { "alias": "id"; "required": false; }; "name": { "alias": "name"; "required": false; }; "width": { "alias": "width"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; }, {}, never, never, true, never>;
}
