import { TemplateRef } from '@angular/core';
/**
 * Interface SelectItem is used to deal with complex object in order to be able to format
 * custom label that is shown in the options.
 *
 * Used in various controls: Select, RadioGroup, CheckboxGroup, Combobox
 */
export interface SelectItem<T = any> {
    /**
     * Item text shown in the popup
     */
    label: string;
    /**
     * References to the object instance
     */
    value: T;
    disabled?: boolean;
    icon?: string;
    /**
     * Trigger values is a text for selected item
     */
    triggerValue?: string;
    isGroup?: boolean;
    secondaryText?: string;
    children?: SelectItem[];
    /**
     * @hidden
     * Used in settings generator only.
     */
    description?: string;
    /**
     * @hidden
     * Used in settings generator only.
     */
    template?: TemplateRef<any>;
}
export interface OptionItem {
    /** Item text */
    label: string;
    /**
     * References to the object instance
     */
    value: any;
    id?: string;
    isGroup?: boolean;
    secondaryText?: string;
    children?: OptionItem[];
}
export interface SelectableOptionItem extends OptionItem {
    selected?: boolean;
    children?: SelectableOptionItem[];
}
/** @hidden */
export declare function isSelectableItem(item: SelectItem): item is SelectItem;
/** @hidden */
export declare function isSelectItem(item: SelectItem): item is SelectItem;
export interface MultiInputOption {
    /** Item text */
    label: string;
    /**
     * References to the object instance
     */
    value: any;
    /**
     * Item Avatar
     */
    avatarSrc?: string;
    isGroup?: boolean;
    description?: string;
    children?: MultiInputOption[];
}
export declare const isOptionItem: typeof isSelectItem;
export declare const isSelectableOptionItem: typeof isSelectableItem;
/**
 * Wraps the provided value in an array, unless it is an array already.
 * If `null` or `undefined` is received, will return an empty array.
 */
export declare function coerceArraySafe<T>(value: T | T[]): T[];
