import { SelectItem } from '../domain/data-model';
import { BaseInput } from './base.input';
import * as i0 from "@angular/core";
/**
 * Defines specific behavior for Input controls which deals with list of values including:
 *  - Select
 *  - RadioGroup
 *  - CheckboxGroup
 *  - ComboBox
 *  ...
 *
 */
export declare abstract class CollectionBaseInput extends BaseInput {
    /**
     * List of values, it can be of type SelectItem, string or any object.
     * Generic object type is among the list of types,
     * because we allow to get labels and values using `displayKey` and `lookupKey` inputs accordingly.
     */
    set list(value: Array<SelectItem | string | object>);
    get list(): Array<SelectItem | string | object>;
    /**
     * Used in filters and any kind of comparators when we work with objects and this identify
     * unique field name based on which we are going to do the job
     */
    lookupKey: string;
    /**
     * When we deal with unknown object we can use `displayKey` to retrieve value from specific
     * property of the object to act as display value.
     *
     * @See ComboBox, Select, RadioGroup, CheckBox Group
     */
    displayKey: string;
    /** @hidden */
    private _list;
    /** @hidden */
    lookupValue(item: any): string;
    /** @hidden */
    displayValue(item: any): string;
    /** @hidden */
    objectGet(obj: any, is: string | string[] | undefined): any;
    static ɵfac: i0.ɵɵFactoryDeclaration<CollectionBaseInput, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<CollectionBaseInput, never, never, { "list": { "alias": "list"; "required": false; }; "lookupKey": { "alias": "lookupKey"; "required": false; }; "displayKey": { "alias": "displayKey"; "required": false; }; }, {}, never, never, true, never>;
}
