import { AfterViewInit, DestroyRef, EventEmitter, Injector, OnDestroy, TemplateRef } from '@angular/core';
import { Nullable } from '@fundamental-ngx/cdk/utils';
import { DialogService } from '@fundamental-ngx/core/dialog';
import { DynamicFormItem, FormGeneratorComponent, FormGeneratorService } from '@fundamental-ngx/platform/form';
import { SearchInput } from '@fundamental-ngx/platform/search-field';
import { CollectionFilterGroup } from '@fundamental-ngx/platform/table';
import { SmartFilterBarSubjectDirective } from './directives/smart-filter-bar-subject.directive';
import { SmartFilterBarManagedPreset, SmartFilterChangeObject } from './interfaces/smart-filter-bar-change';
import { SmartFilterBarCondition } from './interfaces/smart-filter-bar-condition';
import { SmartFilterBar } from './smart-filter-bar.class';
import * as i0 from "@angular/core";
export declare class SmartFilterBarComponent extends SmartFilterBar implements AfterViewInit, OnDestroy {
    private _dialogService;
    private _fgService;
    private _injector;
    private readonly _destroyRef;
    /**
     * @hidden
     * Form generator component instance.
     */
    _formGenerator: FormGeneratorComponent;
    /**
     * Subject which will provide configuration data: data source, columns definitions, etc.
     */
    set subject(value: SmartFilterBarSubjectDirective);
    get subject(): SmartFilterBarSubjectDirective;
    /**
     * Whether smart filter bar background should be transparent.
     */
    transparent: boolean;
    /**
     * Columns layout.
     */
    filtersColumnLayout: Nullable<string>;
    /**
     * Whether to update filters when they are selected. Otherwise, filters will be applied only by pressing "Go" button.
     */
    liveUpdate: boolean;
    /**
     * Whether to hide Toolbar.
     */
    hideToolbar: boolean;
    /**
     * Event emitted when the selected filters have been changed.
     */
    smartFiltersChanged: EventEmitter<SmartFilterChangeObject>;
    /**
     * Event emitted when selected filters has been applied (User clicked on Go button).
     */
    smartFiltersApplied: EventEmitter<SmartFilterChangeObject>;
    /**
     * Event emitted when search input field value has been changed.
     */
    searchInputChanged: EventEmitter<SearchInput>;
    /** @hidden */
    private readonly _toolbarItemRefs;
    /**
     * Calculated array of filters to apply for the subject's data source.
     */
    filterBy: CollectionFilterGroup[];
    /** Whether the filters section should be shown. */
    showFilterBar$: import("@angular/core").WritableSignal<boolean>;
    /**
     * Search field value to apply for the subject's data source.
     */
    search: SearchInput | undefined;
    /** @Hidden */
    _toolbarItems: TemplateRef<any>[];
    /** @hidden */
    _formItems: import("@angular/core").WritableSignal<DynamicFormItem[] | null>;
    /** Selected filters. */
    selectedFilters$: import("@angular/core").WritableSignal<string[]>;
    /** Selected filters count. */
    selectedFiltersCount$: import("@angular/core").Signal<number>;
    /** Loading state. */
    get loading(): boolean;
    /** @hidden */
    private _subscriptions;
    /** @hidden */
    private _subjectSubscriptions;
    /** @hidden */
    private readonly _formGeneratorReady;
    /** @hidden */
    private _ignorePresetChange;
    /** @hidden */
    private _subject;
    /** @hidden */
    private _refresh$;
    /**
     * @hidden
     * Smart filter bar service may be provided by parent component that adds custom configuration, so we need to check if it's provided.
     */
    private readonly _smartFilterBarService;
    /** @hidden */
    constructor(_dialogService: DialogService, _fgService: FormGeneratorService, _injector: Injector, _destroyRef: DestroyRef);
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden */
    ngOnDestroy(): void;
    /**
     * Transforms condition value into human-readable text.
     * @param condition Smart filter bar condition.
     * @param filterType Condition filter type.
     */
    getDisplayValue(condition: SmartFilterBarCondition, filterType: string): Promise<string>;
    /** Open Filtering Settings Dialog */
    showFilteringSettings(): void;
    /** Callback function when search query changed. */
    onSearchInputChange(event: SearchInput): void;
    /** Clear search query. */
    cancelSearch(): void;
    /**
     * Submits filters and search form.
     */
    submitForm(): void;
    /** Method for setting predefined configuration. */
    setPreset(data: SmartFilterBarManagedPreset): Promise<void>;
    /** Returns current preset configuration. */
    getCurrentPreset(): SmartFilterBarManagedPreset;
    /**
     * @hidden
     * Callback function when form generator form has been successfully validated and submitted.
     */
    _onFormSubmitted(event: any): void;
    /**
     * @hidden
     * Callback method when form has been created.
     * Populates selected filters array with user-defined default filters.
     */
    _onFormCreated(): void;
    /**
     * Toggles Smart Filter Bar filters section.
     */
    toggleFilterBar(): void;
    /**
     * Formats raw filters object into array of grouped filters.
     * @returns Array of grouped filters.
     */
    getFormattedConditions(): Promise<CollectionFilterGroup[]>;
    /** @hidden */
    private _generateCollectionFilterGroups;
    /** @hidden */
    private _setSubject;
    /** @hidden */
    private unsubscribeFromSubject;
    /** @hidden */
    private _listenToSubjectColumns;
    /**
     * @hidden
     * Generates form items to be consumed by form generator component.
     * @param columns columns definition
     */
    private _generateForm;
    /** @hidden */
    private _generateCustomFilterFieldItem;
    /**
     * @hidden
     * Generates form item based on data type.
     * @param column
     * @param item
     * @returns
     */
    private _generateInputFieldItem;
    /**
     * @hidden
     * Generates base form item object to be consumed by form generator component.
     * @param column column definition
     * @returns base form item object.
     */
    private _generateBaseFieldItem;
    /**
     * @hidden
     * Retrieves available options for particular column by using data source method.
     * @param column property name of the data source items.
     * @returns {Observable<SelectItem[]>} Observable with the array of available options.
     */
    private _getFilterAvailableOptions;
    /** @hidden */
    private _getFilterDefaultOptions;
    /** @hidden */
    private _getFieldVariants;
    /** @hidden */
    private _getSubjectDefinitions;
    /**
     * @hidden
     * Sets provided filters directly to the data source.
     * @param filters array of filters.
     */
    private _applyFiltering;
    /** @hidden */
    private _unsubscribeFromSubject;
    /** @hidden */
    private _setSelectedFilters;
    static ɵfac: i0.ɵɵFactoryDeclaration<SmartFilterBarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SmartFilterBarComponent, "fdp-smart-filter-bar", never, { "subject": { "alias": "subject"; "required": false; }; "transparent": { "alias": "transparent"; "required": false; }; "filtersColumnLayout": { "alias": "filtersColumnLayout"; "required": false; }; "liveUpdate": { "alias": "liveUpdate"; "required": false; }; "hideToolbar": { "alias": "hideToolbar"; "required": false; }; }, { "smartFiltersChanged": "smartFiltersChanged"; "smartFiltersApplied": "smartFiltersApplied"; "searchInputChanged": "searchInputChanged"; }, ["_toolbarItemRefs"], never, true, never>;
    static ngAcceptInputType_transparent: unknown;
    static ngAcceptInputType_liveUpdate: unknown;
    static ngAcceptInputType_hideToolbar: unknown;
}
