import { FormGeneratorService, PreparedDynamicFormFieldItem } from '@fundamental-ngx/platform/form';
import { SelectItem } from '@fundamental-ngx/platform/shared';
import { CollectionFilterGroup, FilterAllStrategy, FilterableColumnDataType } from '@fundamental-ngx/platform/table';
import { SmartFilterBarCondition } from './interfaces/smart-filter-bar-condition';
import { SmartFilterBarCustomFilterConfig } from './interfaces/smart-filter-bar-custom-filter-config';
import * as i0 from "@angular/core";
export declare class SmartFilterBarService {
    private _fgService;
    /** @hidden */
    private _customFilterConditions;
    /** @hidden */
    constructor(_fgService: FormGeneratorService);
    /**
     * Adds custom filter type to the smart filter bar.
     * @param options Configuration options.
     * @returns true if component was added successfully.
     */
    addCustomFilter(options: SmartFilterBarCustomFilterConfig): boolean;
    /**
     * Returns provided configuration object of the custom filter.
     * @param type Filter type.
     * @returns Configuration object.
     */
    getCustomFilterConfiguration(type: string): SmartFilterBarCustomFilterConfig | undefined;
    /**
     * Returns applicable condition options of the filter.
     * @param type Filter type.
     * @param dataType Filter data type.
     * @returns Array of applicable condition options.
     */
    getApplicableFilterConditions(type: string, dataType?: FilterableColumnDataType): FilterAllStrategy[];
    /** @hidden */
    getDisplayValue(condition: SmartFilterBarCondition, filterType: string): Promise<string>;
    /**
     * Method for normalizing generated conditions to display in human-readable format.
     * @returns Formatted array of conditions.
     * @param formItem
     * @param conditions
     */
    normalizeConditions(formItem: PreparedDynamicFormFieldItem, conditions: SmartFilterBarCondition[]): Promise<SmartFilterBarCondition[]>;
    /**
     * Returns formatted condition variants.
     */
    getConditionFieldSelectedVariants(formItem: PreparedDynamicFormFieldItem, conditions: SmartFilterBarCondition[]): Promise<SelectItem[]>;
    /**
     * Transforms collection filter into smart filter bar condition.
     */
    transformCollectionFilter(filterGroup: CollectionFilterGroup): SmartFilterBarCondition[];
    /**
     * @hidden
     * Normalizes condition value.
     * @param value
     * @returns
     */
    private _normalizeValue;
    static ɵfac: i0.ɵɵFactoryDeclaration<SmartFilterBarService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SmartFilterBarService>;
}
