import { EventEmitter, OnDestroy } from '@angular/core';
import { DataSourceDirective } from '@fundamental-ngx/cdk/data-source';
import { BehaviorSubject, Subject } from 'rxjs';
import { ChildTableDataSource, TableDataSource } from '../domain';
import { TableRow } from '../models';
import { Table } from '../table';
import * as i0 from "@angular/core";
export declare class TableDataSourceDirective<T> extends DataSourceDirective<T, TableDataSource<T>> implements OnDestroy {
    /**
     * Data source.
     * @param source
     */
    set childDataSource(source: ChildTableDataSource<T> | null);
    get childDataSource(): ChildTableDataSource<T> | null;
    /** Event emitted when child data source instance being changed. */
    childDataSourceChanged: EventEmitter<void>;
    /** Event emitted when data loading is started. */
    readonly onDataRequested: EventEmitter<void>;
    /** Event emitted when data loading is finished. */
    readonly onDataReceived: EventEmitter<void>;
    /** Total items count stream. */
    totalItems$: import("@angular/core").WritableSignal<number>;
    /** Items stream. */
    items$: BehaviorSubject<T[]>;
    /** Child items stream. */
    childItems$: Subject<Map<TableRow<T>, T[]>>;
    /** @hidden */
    _tableDataSource: TableDataSource<T>;
    /** @hidden */
    _firstLoadingDone: boolean;
    /** @hidden */
    _internalLoadingState: boolean;
    /** @hidden */
    _internalChildrenLoadingState: boolean;
    /** @hidden */
    private _childDataSource;
    /** @hidden */
    private _childDsSubscription;
    /** @hidden */
    set totalItems(value: number);
    get totalItems(): number;
    /** @hidden for data source handling */
    private _tableDsSubscription;
    /** @hidden */
    private _table;
    /** @hidden */
    private readonly initialState;
    /** @hidden */
    private readonly _tableService;
    /** @hidden */
    initializeDataSource(): void;
    /** @hidden */
    ngOnDestroy(): void;
    /** @hidden */
    setTable(table: Table): void;
    /**
     * @hidden
     * Initializes the child data source to fetch child rows.
     */
    private _initializeChildDataSource;
    /**
     * @hidden
     * This is a single point of data entry to the component. We don't want to set data on different
     * places. If any new data comes in, or you do a search, and you want to pass initial data
     * its here.
     */
    private _listenToDataSource;
    /** @hidden */
    private _closeDataSource;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableDataSourceDirective<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TableDataSourceDirective<any>, "[fdpTableDataSource]", never, { "childDataSource": { "alias": "childDataSource"; "required": false; }; }, { "childDataSourceChanged": "childDataSourceChanged"; "onDataRequested": "onDataRequested"; "onDataReceived": "onDataReceived"; }, never, never, true, never>;
}
