import { EventEmitter } from '@angular/core';
import { DragoverPredicate, DropPredicate, FdDndDropType, FdDropEvent } from '@fundamental-ngx/cdk/utils';
import { TableRow, TableRowsRearrangeEvent } from '../models';
import { TableDraggable } from '../models/directives';
import { Table } from '../table';
import * as i0 from "@angular/core";
export declare class TableDraggableDirective<T = any> extends TableDraggable<T> {
    /** Whether to allow for row reordering on tree tables via drag and drop. */
    enableRowReordering: boolean;
    /** Whether tree mode is enabled. */
    isTreeTable: boolean;
    /**
     * Row drop mode.
     */
    dropMode: FdDndDropType;
    /** Predicate function that checks whether the item can be dropped over another item. */
    dropPredicate: DropPredicate<TableRow<T>>;
    /**
     * Predicate function that checks whether the item can be dragged over another item.
     * If the function returns `false`, dragged over item will not be highlighted, and drop event will be canceled.
     */
    dragoverPredicate: DragoverPredicate<TableRow<T>>;
    /** Event fired when tree rows rearranged through drag & drop. Consider that rows rearranged with their children rows. */
    readonly rowsRearrange: EventEmitter<TableRowsRearrangeEvent<T>>;
    /** @hidden */
    get _rowsDraggable(): boolean;
    /** @hidden */
    dragDropInProgress: boolean;
    /** @hidden */
    private _table;
    /** @hidden */
    private readonly _ngZone;
    /** @hidden */
    private readonly _cdr;
    /** Sets table reference. */
    setTable(table: Table): void;
    /**
     * Initiates drag&drop sequence.
     */
    dragDropStart(): void;
    /** Method called when dnd performed with the keyboard. */
    dragRowFromKeyboard(dir: string, event: Event, currentRowIndex: number, mode: 'shift' | 'group'): void;
    /** Method called when drag&drop event being cancelled. */
    dropCancelled(): void;
    /** Method called when dragged item being dropped. */
    dragDropItemDrop(event: FdDropEvent<TableRow>): void;
    /**
     * @hidden
     * Create table rows rearrange event
     */
    _emitRowsRearrangeEvent(row: TableRow, dropRow: TableRow, event: FdDropEvent<TableRow>): void;
    /** @hidden */
    private _isDroppedInsideItself;
    /** @hidden */
    private _dragDropUpdateDragParentRowAttributes;
    /** @hidden */
    private _dragDropUpdateDropRowAttributes;
    /** @hidden */
    private _dragDropRearrangeTreeRows;
    /** @hidden */
    private _getNewDragDropRowsPosition;
    /** @hidden */
    private _handleShiftDropAction;
    /** @hidden */
    private _handleReplaceDropAction;
    /** @hidden */
    private _onZoneFree;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableDraggableDirective<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TableDraggableDirective<any>, "fdp-table[isTreeTable], fdp-table[enableRowReordering]", never, { "enableRowReordering": { "alias": "enableRowReordering"; "required": false; }; "isTreeTable": { "alias": "isTreeTable"; "required": false; }; "dropMode": { "alias": "dropMode"; "required": false; }; "dropPredicate": { "alias": "dropPredicate"; "required": false; }; "dragoverPredicate": { "alias": "dragoverPredicate"; "required": false; }; }, { "rowsRearrange": "rowsRearrange"; }, never, never, true, never>;
}
