import { ElementRef, NgZone, OnDestroy, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { TableScrollable, TableScrollDispatcherService } from '../services/table-scroll-dispatcher.service';
import * as i0 from "@angular/core";
/**
 * Table Scrollable.
 * That directive should be assigned to table scrollable area.
 * It registers itself in table scroll dispatcher
 * and notify once element scrolled.
 *
 * For internal usage.
 */
export declare class TableScrollableDirective implements TableScrollable, OnInit, OnDestroy {
    elementRef: ElementRef<HTMLElement>;
    protected scrollDispatcher: TableScrollDispatcherService;
    protected ngZone: NgZone;
    /** @hidden */
    private _skipEvent;
    /** @hidden */
    private _prevScrollTop;
    /** @hidden */
    private _prevScrollLeft;
    /** @hidden */
    private readonly _destroyRef;
    /** @hidden */
    private readonly _document;
    /** Scroll events stream */
    private _elementScrollStream;
    /** Vertical scroll stream */
    private _elementVerticalScrollStream;
    /** Horizontal scroll stream */
    private _elementHorizontalScrollStream;
    /** @hidden */
    constructor(elementRef: ElementRef<HTMLElement>, scrollDispatcher: TableScrollDispatcherService, ngZone: NgZone);
    /** @hidden */
    ngOnInit(): void;
    /** @hidden */
    ngOnDestroy(): void;
    /** Returns observable that emits when a scroll event is fired on the host element. */
    getScrollStream(): Observable<Event>;
    /** Returns observable that emits when a vertical scroll event is happened on the host element. */
    getVerticalScrollStream(): Observable<Event>;
    /** Returns observable that emits when a horizontal scroll event is happened on the host element. */
    getHorizontalScrollStream(): Observable<Event>;
    /** Returns scrollTop position of the host element. */
    getScrollTop(): number;
    /** Returns scrollLeft position of the host element. */
    getScrollLeft(): number;
    /** Set scrollTop position of the host element. */
    setScrollTop(scrollTop: number, emitEvent?: boolean): void;
    /** Set scrollLeft position of the host element. */
    setScrollLeft(scrollLeft: number, emitEvent?: boolean): void;
    /** Scrolls to overlapped cell. */
    scrollToOverlappedCell(rtl: boolean, freezableColumnsSize: number, freezableEndColumnSize: number): void;
    /** Set Scroll Position during component initialization. */
    initializeScrollTop(scrollTop: number): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableScrollableDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TableScrollableDirective, "[fdpTableScrollable]", ["tableScrollable"], {}, {}, never, never, true, never>;
}
