import { BehaviorSubject, Observable, Subject } from 'rxjs';
import { DataSource } from '@fundamental-ngx/platform/shared';
import { TableState } from '../interfaces/table-state.interface';
import { TableRow } from '../models';
import { TableChildrenDataProvider, TableDataProvider } from './table-data-provider';
export declare abstract class BaseTableDataSource<T, P = T[], L = boolean> implements DataSource<T, P, L> {
    /**
     * Method for retrieving the data of the provided data source.
     * @param tableState @see TableState Set of table parameters.
     * @param parentRows
     */
    abstract fetch(tableState: TableState, parentRows?: TableRow<T>[]): void;
    /** @hidden */
    protected readonly _dataChanges$: BehaviorSubject<P>;
    /** @hidden */
    protected readonly _onDataRequested$: Subject<boolean>;
    /** @hidden */
    protected readonly _onDataReceived$: Subject<boolean>;
    /** @hidden */
    protected _dataLoading: L;
    /** @hidden */
    protected readonly _dataLoading$: BehaviorSubject<L>;
    /** @hidden */
    protected readonly _destroy$: Subject<void>;
    /** @hidden */
    protected constructor();
    /**
     * Emitted when new data has been requested.
     * @returns Observable
     */
    get dataRequested(): Observable<boolean>;
    /**
     * Emitted when new data has been received.
     * @returns Observable
     */
    get dataReceived(): Observable<boolean>;
    /**
     * Emitted when loading state has been changed.
     * @returns Observable.
     */
    get dataLoading(): Observable<L>;
    /**
     * Emits when the data from the provider has been changed.
     * @returns Observable of data source objects.
     */
    get dataChanges(): Observable<P>;
    /** @hidden */
    get isDataLoading(): L;
    /** @hidden */
    get data(): P;
    /** @hidden */
    open(): Observable<P>;
    /** @hidden */
    onDataRequested(): Observable<void>;
    /** @hidden */
    onDataReceived(): Observable<void>;
    /** @hidden */
    close(): void;
    /**
     * Closes the stream
     */
    unsubscribe(): void;
}
export declare class TableDataSource<T> extends BaseTableDataSource<T> {
    readonly dataProvider: TableDataProvider<T>;
    /**
     * @hidden
     */
    constructor(dataProvider: TableDataProvider<T>);
    /**
     * Method for retrieving the data of the provided data source.
     * @param tableState @see TableState Set of table parameters.
     */
    fetch(tableState: TableState): void;
}
export declare class ChildTableDataSource<T> extends BaseTableDataSource<T, Map<TableRow<T>, T[]>, {
    row?: TableRow<T>;
    loading: boolean;
}[]> {
    readonly dataProvider: TableChildrenDataProvider<T>;
    /**
     * @hidden
     */
    constructor(dataProvider: TableChildrenDataProvider<T>);
    /**
     * Method responsible for retrieving the items from the data provider.
     * Additionaly, it sets the loading state along with the dataLoading and dataChanges streams.
     * @param tableState
     * @param parentRows
     */
    fetch(tableState: TableState, parentRows?: TableRow<T>[]): void;
}
