import { FdLanguageKeyIdentifier } from '@fundamental-ngx/i18n';
import { FilterableColumnDataType } from './filter-type.enum';
/** All possible strategies */
export declare const FILTER_STRATEGY: {
    readonly EQ: "equalTo";
    readonly CONTAINS: "contains";
    readonly BETWEEN: "between";
    readonly BEGINS_WITH: "beginsWith";
    readonly ENDS_WITH: "endsWith";
    readonly GT: "greaterThan";
    readonly GTE: "greaterThanOrEqualTo";
    readonly LT: "lessThan";
    readonly LTE: "lessThanOrEqualTo";
    readonly AFTER: "after";
    readonly ON_OR_AFTER: "onOrAfter";
    readonly BEFORE: "before";
    readonly BEFORE_OR_ON: "beforeOrOn";
};
type FilterStrategyType = typeof FILTER_STRATEGY;
export type FilterStrategy = FilterStrategyType[keyof FilterStrategyType];
export declare const FILTER_STRATEGY_LABEL: Record<FilterStrategy, FdLanguageKeyIdentifier>;
/** Date Filter Strategies */
export declare const FILTER_DATE_STRATEGY: Pick<FilterStrategyType, 'BETWEEN' | 'EQ' | 'AFTER' | 'ON_OR_AFTER' | 'BEFORE' | 'BEFORE_OR_ON'>;
export type FilterDateStrategy = (typeof FILTER_DATE_STRATEGY)[keyof typeof FILTER_DATE_STRATEGY];
export declare const FILTER_DATE_STRATEGIES: ReadonlyArray<FilterDateStrategy>;
/** Number Filter Strategies */
export declare const FILTER_NUMBER_STRATEGY: Pick<FilterStrategyType, 'BETWEEN' | 'EQ' | 'GT' | 'GTE' | 'LT' | 'LTE'>;
export type FilterNumberStrategy = (typeof FILTER_NUMBER_STRATEGY)[keyof typeof FILTER_NUMBER_STRATEGY];
export declare const FILTER_NUMBER_STRATEGIES: ReadonlyArray<FilterNumberStrategy>;
/** String Filter Strategies */
export declare const FILTER_STRING_STRATEGY: Pick<FilterStrategyType, 'BETWEEN' | 'CONTAINS' | 'EQ' | 'BEGINS_WITH' | 'ENDS_WITH' | 'GT' | 'GTE' | 'LT' | 'LTE'>;
export type FilterAllStrategy = (typeof FILTER_STRATEGY)[keyof typeof FILTER_STRATEGY];
export type FilterStringStrategy = (typeof FILTER_STRING_STRATEGY)[keyof typeof FILTER_STRING_STRATEGY];
export declare const FILTER_STRING_STRATEGIES: ReadonlyArray<FilterStringStrategy>;
/** Boolean Filter Strategies */
export declare const FILTER_BOOLEAN_STRATEGY: Pick<FilterStrategyType, 'EQ'>;
export type FilterBooleanStrategy = (typeof FILTER_BOOLEAN_STRATEGY)[keyof typeof FILTER_BOOLEAN_STRATEGY];
export declare const FILTER_BOOLEAN_STRATEGIES: ReadonlyArray<FilterStringStrategy>;
/** Default Filter Strategies for undefined data type */
export declare const FILTER_DEFAULT_STRATEGY: Pick<FilterStrategyType, 'EQ'>;
export type FilterDefaultStrategy = (typeof FILTER_DEFAULT_STRATEGY)[keyof typeof FILTER_DEFAULT_STRATEGY];
export declare const FILTER_DEFAULT_STRATEGIES: ReadonlyArray<FilterStringStrategy>;
export declare const getFilterStrategiesBasedOnDataType: (dataType: FilterableColumnDataType) => readonly FilterStringStrategy[] | readonly FilterDateStrategy[];
export {};
