import { TableDataSource } from './domain/table-data-source';
import { SelectionModeValue } from './enums/selection-mode.enum';
import { CollectionGroup } from './interfaces/collection-group.interface';
import { FdpTableDataSource } from './models/data-source.type';
import { RowComparator } from './models/row-comparator.model';
import { TableRow } from './models/table-row.model';
import { TreeLike } from './models/tree-table.model';
import { TableColumn } from './table-column';
/** @hidden */
export declare function newTableRow<T = any>(row: Partial<TableRow<T>>): TableRow<T>;
/** @hidden */
export declare function getSelectableRows(rows: TableRow[], selectableKey: string): TableRow[];
/** @hidden */
export declare function isSelectableRow(row: TableRow, selectableKey: string): boolean;
/** @hidden */
export declare function isItemRow(row: TableRow): boolean;
/** @hidden */
export declare function isTreeRow(row: TableRow): boolean;
/**
 * Since we dont work with the tree, we need to convert incoming tree to
 * flat format while maintaining original state.
 *
 * @hidden
 */
export declare function convertTreeTableRowToFlatList<T>(rows: TableRow<T>[], rowNavigatable: string | boolean): TableRow<T>[];
/** @hidden */
export declare function isRowNavigatable<T>(row: T, rowNavigatable: string | boolean): boolean;
/** @hidden */
export declare function getFreezableColumns(columns: TableColumn[], freezeColumnsTo: string): Map<string, number>;
/** @hidden */
export declare function getFreezableEndColumns(columns: TableColumn[], freezeEndColumnsTo: string): Map<string, number>;
/** @hidden */
export declare function convertTreeObjectsToTableRows<T>(source: T[], selectionMode: SelectionModeValue, tableRows: TableRow<T>[], rowComparator: RowComparator<T>, relationKey: string, hasChildrenKey: string, selectedKey: string, expandedStateKey: string, rowNavigatable: string | boolean, enableTristateMode?: boolean): TableRow<T>[];
/**
 * @hidden
 * Runs `rowComparator` function against checked rows and compares them with the new `source`
 * If matched, creates an association between the source item and checked status of corresponding row.
 *
 * @returns `Map` object with the `checked` status for particular source item
 */
export declare function getSelectionStatusByRowValue<T>(source: T[], selectionMode: SelectionModeValue, tableRows: TableRow[], rowComparator: RowComparator<T>): Map<T, boolean | null>;
/** @hidden */
export declare function applySelectionToChildren<T>(allRows: Array<TableRow<T>>, row: TableRow, addedRows: TableRow<T>[], removedRows: TableRow<T>[]): void;
/** @hidden */
export declare function findRowChildren<T>(row: TableRow<T>, allRows: TableRow<T>[]): TableRow<T>[];
/**
 * Get row parents path where the first is the direct parent
 * @param row Row which parents we need to find
 * @param untilParent Parent to stop a search on. Default is "null" that means look up until the root
 * @returns parents list [direct parent, ..., ancestor]
 * @hidden
 */
export declare function getRowParents<T>(row: TableRow<T>, untilParent?: TableRow<T> | null): TableRow<T>[];
/** @hidden */
export declare function toDataStream<T>(source: FdpTableDataSource<T>): TableDataSource<T> | undefined;
/**
 * @hidden
 * Creates an empty column skeleton object.
 * @returns Column model.
 */
export declare function buildNewRowSkeleton<T>(editableRowSkeleton: T, columns: TableColumn[]): T;
/** @hidden */
export declare function isGroupRow(row: TableRow): boolean;
/** @hidden */
export declare function sortTreeLikeGroupedRows(groupedRows: TreeLike<TableRow>[], groupRulesMap: Map<string, CollectionGroup>): TreeLike<TableRow>[];
/** @hidden */
export declare function convertTreeLikeToFlatList<K>(treeLikeList: TreeLike<K>[]): K[];
/**
 * @hidden
 * Group table rows and return tree like rows list.
 * It's intended to be called recursively.
 * @param rules group rules to group by
 * @param rows source table rows
 * @param parent row parent
 * @param level level of nesting
 */
export declare function createGroupedTableRowsTree(rules: CollectionGroup[], rows: TableRow[], parent?: TableRow | null, level?: number): TreeLike<TableRow>[];
/** @hidden */
export declare function convertObjectsToTableRows<T>(source: T[], addedItems: T[], selectedKey: string, rowNavigatable: boolean | string, selectionMode: SelectionModeValue, rows: TableRow[], rowComparator: RowComparator): TableRow<T>[];
/** @hidden */
export declare function isTreeRowFirstCell(cellIndex: number, row: TableRow, event?: Event): boolean;
