import { ElementRef, OnDestroy } from '@angular/core';
import { BehaviorSubject, Observable } from 'rxjs';
import { RtlService } from '@fundamental-ngx/cdk/utils';
import { Table } from '../table';
import { TableScrollDispatcherService } from './table-scroll-dispatcher.service';
import * as i0 from "@angular/core";
export declare const TABLE_RESIZER_BORDER_WIDTH = 3;
/**
 * Service to handle all things related to column resizing:
 * - Setting resizer
 * - Processing resize
 * - Calculating the real columns width
 */
export declare class TableColumnResizeService implements OnDestroy {
    private readonly _tableScrollDispatcherService;
    private readonly _rtlService;
    /** Subject that emits new map of fixed columns and their respective width. */
    readonly fixedColumsWidthChange: BehaviorSubject<Map<string, string>>;
    /** Indicate if resizing process in progress. */
    get resizeInProgress(): boolean;
    /** Resize progress stream. */
    readonly resizeInProgress$: BehaviorSubject<boolean>;
    /** Whether cell mock should be visible. */
    readonly cellMockVisible$: import("@angular/core").WritableSignal<boolean>;
    /** Current column resizer position. */
    get resizerPosition(): number;
    /** Resizer position stream. */
    readonly resizerPosition$: BehaviorSubject<number>;
    /** Observable to notify to run CD */
    get markForCheck(): Observable<void>;
    /** table has fixed width if all of it's columns are fixed */
    get fixedWidth(): boolean;
    /** @hidden */
    private _fixedColumnsWidthMap;
    /** @hidden */
    private _columnsCellMap;
    /** @hidden */
    private _visibleColumnNames;
    /** @hidden */
    private _visibleColumnLeftNeighbourMap;
    /** @hidden */
    private _visibleColumnRightNeighbourMap;
    /** @hidden */
    private _visibleColumnLeftOffsetPxMap;
    /** @hidden */
    private _visibleColumnRightOffsetPxMap;
    /** @hidden */
    private _startX;
    /** @hidden */
    private _clientStartX;
    /** @hidden */
    private _resizeInProgress;
    /** @hidden */
    private _resizedColumn;
    /** @hidden */
    private _resizerPosition;
    /** @hidden */
    private _scrollLeft;
    /** @hidden */
    private _markForCheck;
    /** @hidden */
    private _destroyed;
    /** @hidden */
    private _resizerMoveSubscription;
    /** @hidden */
    private _tableRef;
    /** @hidden */
    private readonly _rtl$;
    /** @hidden */
    constructor(_tableScrollDispatcherService: TableScrollDispatcherService, _rtlService: RtlService);
    /** @hidden */
    ngOnDestroy(): void;
    /** @hidden */
    setTableRef(ref: Table): void;
    /** @hidden initializes service with data, trigger columns width calculation. */
    setColumnNames(visibleColumnNames: string[]): void;
    /** @hidden */
    updateFrozenColumnsWidth(): void;
    /** @hidden */
    updateFrozenColumnsWidthAfterResize(columnName: string, diffX: number): void;
    /** Retrieves custom column value or returns `unset` */
    getColumnWidthStyle(columnName: string): string;
    /** Previous column name */
    getPreviousColumnName(columnName: string): string | undefined;
    /** Previous column name */
    getNextColumnName(columnName: string): string | undefined;
    /** Overall previous columns width. Used to calculate offset for the absolute positioned cells. */
    getPrevColumnsWidth(columnName: string): number;
    /** Overall next columns width. Used to calculate offset for the absolute positioned cells. */
    getNextColumnsWidth(columnName: string): number;
    /** Register column's cell to get its dimensions in further. */
    registerColumnCell(columnName: string, cellElRef: ElementRef): void;
    /** Unregister column's cell. */
    unregisterColumnCell(columnName: string, cellElRef: ElementRef): void;
    /** Register the value of column width that changed from  input */
    setCustomWidth(columnName: string, value: string): void;
    /** Set the appropriate column resizer position. */
    setInitialResizerPosition(resizerPosition: number, resizedColumn: string): void;
    /** Hide the column resizer. */
    hideResizer(): void;
    /** Handle start resizing. */
    startResize(event: MouseEvent): void;
    /** Handle end resizing. */
    finishResize(event: MouseEvent): void;
    /** Update columns width after resizing, prevent from having too small columns. */
    _processResize(diffX: number): void;
    /** Update column resizer position. */
    private _updateResizerPositionOnMouseMove;
    /**
     * Check if the header text length goes over the column width. In such case applies text truncation with
     * ellipsis and make sure we also show a tooltip.
     *
     * @private
     */
    private _updateHeaderOverflowState;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableColumnResizeService, [null, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TableColumnResizeService>;
}
