import { ElementRef } from '@angular/core';
import { FdpColumnResponsiveState } from '../interfaces/column-responsive-state.interface';
import { Table } from '../table';
import { TableColumn } from '../table-column';
import { TableService } from './table.service';
import * as i0 from "@angular/core";
export interface FdpTableBreakpoint {
    min: number;
    max: number;
    visibility: FdpColumnResponsiveState;
}
export declare class TableResponsiveService {
    private readonly _table;
    private readonly _tableService;
    private readonly _elmRef;
    /** @hidden */
    private readonly _responsiveBreakpoints;
    /** @hidden */
    private readonly _destroyRef;
    /** @hidden */
    private _resizeSubscription;
    /** @hidden */
    constructor(_table: Table, _tableService: TableService, _elmRef: ElementRef);
    /**
     * Registers responsive column with it's breakpoint configuration.
     * @param column Table Column
     * @param breakpoints Breakpoint configuration.
     */
    registerResponsiveColumn(column: TableColumn, breakpoints: Record<string, FdpColumnResponsiveState>): void;
    /**
     * @hidden
     * Transforms plain breakpoints into a list with minimal/maximal element width with it's visibility state.
     */
    private _normalizeBreakpoints;
    /**
     * @hidden
     * Listens to the table element resize and calculates columns visibility based on the current breakpoint.
     */
    private _listenToTableResize;
    /** @hidden */
    private _processResponsiveColumns;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableResponsiveService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TableResponsiveService>;
}
