import { FocusableItemPosition } from '@fundamental-ngx/cdk/utils';
import { Observable, Subject } from 'rxjs';
import { CollectionGroup } from '../interfaces';
import { TableRow } from '../models';
import { TableCellActivateEvent } from '../models/table-cell-activate-event.model';
import { EditableTableCell } from '../table-cell.class';
import * as i0 from "@angular/core";
export type ToggleRowModel = {
    type: 'toggleRow';
    row: TableRow;
} | {
    type: 'toggleSingleSelectableRow';
    row: TableRow;
} | {
    type: 'toggleMultiSelectRow';
    row: TableRow;
    event?: Event;
};
export interface CellClickedModel {
    index: number;
    row: TableRow;
}
export declare class TableRowService<T = any> {
    /** Stream that emits when toggling all selectable rows is needed. */
    readonly toggleAllSelectableRows$: Observable<boolean>;
    /** Stream that emits when table cell being clicked. */
    readonly cellClicked$: Observable<CellClickedModel>;
    /** Stream that emits when scrolling to overlapped cell is needed. */
    readonly scrollToOverlappedCell$: Observable<void>;
    /** Stream that emits when the table cell being focused. */
    readonly cellFocused$: Observable<FocusableItemPosition>;
    /** Stream that emits when the table cell being focused. */
    readonly cellActivate$: Observable<TableCellActivateEvent<any>>;
    /** Toggle row stream. */
    readonly toggleRow$: Observable<ToggleRowModel>;
    /** Editable cells map. */
    readonly editableCells: Map<TableRow<any>, EditableTableCell[]>;
    /** @hidden */
    readonly childRowsAdded$: Subject<{
        row: TableRow;
        rowIndex: number;
        items: T[];
    }>;
    /** Stream to load child items for a particular rows. */
    readonly loadChildRows$: Subject<TableRow<T>[]>;
    /** @hidden */
    private readonly _toggleRowSubject;
    /** @hidden */
    private readonly _scrollToOverlappedCellSubject;
    /** @hidden */
    private readonly _cellClickedSubject;
    /** @hidden */
    private readonly _cellActivateSubject;
    /** @hidden */
    private readonly _cellFocusedSubject;
    /** @hidden */
    private readonly _toggleAllSelectableRowsSubject;
    /** @hidden */
    constructor();
    /** `toggleRow$` stream trigger. */
    toggleRow(evt: ToggleRowModel): void;
    /** `scrollToOverlappedCell$` stream trigger. */
    scrollToOverlappedCell(): void;
    /** `cellClicked$` stream trigger. */
    cellClicked(evt: CellClickedModel): void;
    /** @hidden */
    cellActivate(columnIndex: number, row: TableRow): void;
    /** `cellFocused$` stream trigger. */
    cellFocused(evt: FocusableItemPosition): void;
    /** `toggleAllSelectableRows$` stream trigger. */
    toggleAllSelectableRows(selectAll: boolean): void;
    /** Groups the table rows. */
    groupTableRows(sourceRows: TableRow[], groups: Iterable<CollectionGroup>, groupRulesMap: Map<string, CollectionGroup>): TableRow[];
    /** Sets editable cells for particular row. */
    updateEditableCells(row: TableRow, cells: EditableTableCell[]): void;
    /** Removes editable cells of particular row. */
    removeEditableCells(row: TableRow): void;
    /** Triggers stream to load child items for a particular rows. */
    loadChildRows(rows: TableRow<T> | TableRow<T>[]): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableRowService<any>, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TableRowService<any>>;
}
