import { ElementRef, InjectionToken, OnDestroy } from '@angular/core';
import { Observable } from 'rxjs';
import * as i0 from "@angular/core";
export interface TableScrollable {
    /** Get scrollable ElementRef of. */
    elementRef: ElementRef<HTMLElement>;
    /** Returns observable that emits when a scroll event is fired on the host element. */
    getScrollStream(): Observable<Event>;
    /** Returns observable that emits when a vertical scroll event is happened on the host element. */
    getVerticalScrollStream(): Observable<Event>;
    /** Returns observable that emits when a horizontal scroll event is happened on the host element. */
    getHorizontalScrollStream(): Observable<Event>;
    /** Returns scrollTop position of the host element. */
    getScrollTop(): number;
    /** Returns scrollLeft position of the host element. */
    getScrollLeft(): number;
    /** Set scrollTop position of the host element. */
    setScrollTop(scrollTop: number, emitEvent: boolean): void;
    /** Set scrollLeft position of the host element. */
    setScrollLeft(scrollLeft: number, emitEvent: boolean): void;
    /** Scrolls to overlapped cell. */
    scrollToOverlappedCell(rtl: boolean, freezableColumnsSize: number, freezableEndColumnSize: number): void;
    /** Set Scroll Position during component initialization. */
    initializeScrollTop(scrollTop: number): void;
}
export declare const TABLE_SCROLLABLE: InjectionToken<TableScrollable>;
export declare class TableScrollDispatcherService implements OnDestroy {
    /** @hidden */
    private _scrollSubject;
    /** @hidden */
    private _verticalScrollSubject;
    /** @hidden */
    private _horizontalScrollSubject;
    /** @hidden */
    private _scrollableSubscriptionsMap;
    /** @hidden */
    register(scrollable: TableScrollable): void;
    /** @hidden */
    deregister(scrollable: TableScrollable): void;
    /** Scroll stream */
    scrolled(): Observable<TableScrollable>;
    /** Horizontal scroll stream */
    horizontallyScrolled(): Observable<TableScrollable>;
    /** Vertical scroll stream */
    verticallyScrolled(): Observable<TableScrollable>;
    /** @hidden */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableScrollDispatcherService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TableScrollDispatcherService>;
}
