import { ChangeDetectorRef, OnDestroy, OnInit } from '@angular/core';
import { TableDialogCommonData } from '@fundamental-ngx/platform/table-helpers';
import { BehaviorSubject } from 'rxjs';
import { DialogRef } from '@fundamental-ngx/core/dialog';
import { SearchInput } from '@fundamental-ngx/platform/search-field';
import { Resettable } from '../../reset-button/reset-button.component';
import * as i0 from "@angular/core";
export interface DialogTableColumn {
    label: string;
    key: string;
}
type VisibleColumnType = string;
export interface ColumnsDialogData extends TableDialogCommonData {
    availableColumns: DialogTableColumn[];
    visibleColumns: VisibleColumnType[];
}
export interface ColumnsDialogResultData {
    visibleColumns: VisibleColumnType[];
}
declare class SelectableColumn {
    /** Selected */
    selected: boolean;
    /** Active */
    active: boolean;
    /** Table Column it belongs to */
    column: DialogTableColumn;
    /** Table column order */
    order: number;
    constructor(
    /** Selected */
    selected: boolean, 
    /** Active */
    active: boolean, 
    /** Table Column it belongs to */
    column: DialogTableColumn, 
    /** Table column order */
    order: number);
}
export declare class P13ColumnsDialogComponent implements Resettable, OnInit, OnDestroy {
    dialogRef: DialogRef<ColumnsDialogData>;
    private cdr;
    /** Indicates when reset command is available */
    readonly isResetAvailable$: import("@angular/core").WritableSignal<boolean>;
    /** Table columns available for grouping */
    readonly availableColumns: DialogTableColumn[];
    /** All available columns for interacting */
    _selectableColumns: SelectableColumn[];
    /** filtered columns that are rendered in the list */
    _filteredColumns: SelectableColumn[];
    /** Search Query subject */
    _searchQuerySubject: BehaviorSubject<string>;
    /** Show All flag subject */
    _showAllItemsSubject: BehaviorSubject<boolean>;
    /** Selected columns count */
    _selectedColumnsCount: number;
    /** Flag to track disabled state for move-down move-up buttons */
    _moveUpDisabled: boolean;
    /** Flag to track disabled state for move-down move-up buttons */
    _moveDownDisabled: boolean;
    /** @hidden */
    get _isShownAllItems(): boolean;
    /** @hidden */
    get _selectAllDisabled(): boolean;
    /** @hidden */
    private _subscriptions;
    /** @hidden */
    constructor(dialogRef: DialogRef<ColumnsDialogData>, cdr: ChangeDetectorRef);
    /** @hidden */
    ngOnInit(): void;
    /** @hidden */
    ngOnDestroy(): void;
    /** Reset to the initial state */
    reset(): void;
    /** Close dialog */
    cancel(): void;
    /** Confirm changes and close dialog */
    confirm(): void;
    /** @hidden */
    _toggleSelectAll(selectAll: boolean): void;
    /** @hidden */
    _onToggleColumn(): void;
    /** @hidden */
    _recalculateResetAvailability(): void;
    /** @hidden */
    _searchInputChange({ text }: SearchInput): void;
    /** @hidden */
    _toggleShowAll(): void;
    /** @hidden */
    _setActiveColumn(column: SelectableColumn | null): void;
    /** @hidden */
    _moveActiveToTop(event: Event): void;
    /** @hidden */
    _moveActiveToBottom(event: Event): void;
    /** @hidden */
    _moveActiveUp(event: Event): void;
    /** @hidden */
    _moveActiveDown(event: Event): void;
    /** @hidden */
    _isReorderColumnButtonShowable(item: SelectableColumn): boolean;
    /** @hidden */
    _filterByColumnKy(index: number, item: SelectableColumn): string;
    /**
     * @hidden
     * @param visibleColumnKeys keys of columns that should be displayed as selected.
     * Also, their order matters: it will be used
     */
    private _initiateColumns;
    /** @hidden */
    private _listenToFilterOptions;
    /** @hidden */
    private _onChangeFilteredColumnsList;
    /** @hidden */
    private _getVisibleColumnsFromSelectedColumns;
    /** @hidden */
    private _getActiveColumnIndexInFilteredList;
    /** @hidden */
    private _moveColumnInFilteredListByIndex;
    /**
     * @hidden
     * Move column in selectable list.
     */
    private _moveColumnInSelectableList;
    /**
     * @hidden
     * Move element in the list
     * @return moved item and replaced item.
     */
    private _moveElementInTheListByIndex;
    /** @hidden */
    private _countSelectedColumns;
    /** @hidden */
    private _calculateMovementButtonsState;
    static ɵfac: i0.ɵɵFactoryDeclaration<P13ColumnsDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<P13ColumnsDialogComponent, "ng-component", never, {}, {}, never, never, true, never>;
}
export {};
