import { CollectionFilter, FilterableColumnDataType, FilterStrategy, TableDialogCommonData } from '@fundamental-ngx/platform/table-helpers';
export interface FilterableColumn {
    label: string;
    key: string;
    dataType: FilterableColumnDataType;
    filterable?: boolean;
    filterSelectOptions?: string[];
}
export interface FilterDialogData extends TableDialogCommonData {
    collectionFilter: CollectionFilter[];
    columns: FilterableColumn[];
    validator?: ((rules: CollectionFilter[]) => boolean) | undefined;
}
export interface FilterDialogResultData {
    collectionFilter: CollectionFilter[];
}
/**
 * Filter Rule
 *
 * represents one rule per row
 */
export declare class FilterRule<T = any> {
    readonly columns: ReadonlyArray<FilterableColumn>;
    /** Column key the rule belongs to */
    columnKey?: string | undefined;
    /** Data type */
    strategy?: FilterStrategy | undefined;
    /** Main filter value */
    value?: (T | null) | undefined;
    /** Additional filter value */
    value2?: (T | null) | undefined;
    /** Validation flg */
    isValid: boolean;
    /** Available strategies options */
    strategies: ReadonlyArray<FilterStrategy>;
    /** Data type */
    dataType?: FilterableColumnDataType;
    /**
     * Optional array of available filter options.
     * Providing values to this input will cause the filter to change from a text-type input to a select-type input.
     * */
    filterSelectOptions: string[];
    /** returns whether filter rule has value */
    get hasValue(): boolean;
    /** @hidden */
    constructor(columns: ReadonlyArray<FilterableColumn>, 
    /** Column key the rule belongs to */
    columnKey?: string | undefined, 
    /** Data type */
    strategy?: FilterStrategy | undefined, 
    /** Main filter value */
    value?: (T | null) | undefined, 
    /** Additional filter value */
    value2?: (T | null) | undefined);
    /** @hidden */
    setValid(isValid: boolean): void;
    /** @hidden */
    setValue(value: T | null): void;
    /** @hidden */
    setValue2(value: T | null): void;
    /** @hidden */
    setStrategy(strategy: FilterStrategy): void;
    /** @hidden */
    setStrategiesByColumnKey(columnKey?: string): void;
    /** @hidden */
    setColumnKey(columnKey: string): void;
    /** @hidden */
    setDataTypeByColumnKey(columnKey?: string): void;
    /** @hidden */
    setFilterSelectOptionsByColumnKey(columnKey?: string): void;
    /** @hidden */
    private valueExists;
}
