import { ChangeDetectorRef, PipeTransform } from '@angular/core';
import { CollectionSort, SortDirection, TableDialogCommonData } from '@fundamental-ngx/platform/table-helpers';
import { DialogRef } from '@fundamental-ngx/core/dialog';
import { Resettable } from '../../reset-button/reset-button.component';
import * as i0 from "@angular/core";
export interface SortDialogColumn {
    label: string;
    key: string;
}
export interface SortDialogData extends TableDialogCommonData {
    collectionSort: CollectionSort[];
    columns: SortDialogColumn[];
}
export interface SortDialogResultData {
    collectionSort: CollectionSort[];
}
export interface SortRule {
    columnKey: string | null;
    direction: SortDirection;
}
declare class ValidatedSortRule implements SortRule {
    /** Column key the rule belongs to */
    columnKey: string | null;
    /** Sort direction */
    direction: SortDirection;
    get isValid(): boolean;
    constructor(
    /** Column key the rule belongs to */
    columnKey?: string | null, 
    /** Sort direction */
    direction?: SortDirection);
}
export declare class P13SortingDialogComponent implements Resettable {
    dialogRef: DialogRef<SortDialogData>;
    private cdr;
    /** Table columns available for sorting */
    readonly columns: SortDialogColumn[];
    /** Indicates when reset command is available */
    readonly isResetAvailable$: import("@angular/core").WritableSignal<boolean>;
    /** @hidden */
    readonly SORT_DIRECTION: typeof SortDirection;
    /** Sort rules to render */
    rules: ValidatedSortRule[];
    /** @hidden */
    constructor(dialogRef: DialogRef<SortDialogData>, cdr: ChangeDetectorRef);
    /** Reset changes to the initial state */
    reset(): void;
    /** Close dialog */
    cancel(): void;
    /** Confirm changes and close dialog */
    confirm(): void;
    /** @hidden */
    _removeRule(rule: ValidatedSortRule): void;
    /** @hidden */
    _addNew(index: number): void;
    /** @hidden */
    _onRuleColumnKeyChange(rule: ValidatedSortRule, columnKey: string): void;
    /** @hidden */
    _onRuleDirectionChange(rule: ValidatedSortRule, direction: SortDirection): void;
    /** @hidden */
    _recalculateResetAvailability(): void;
    /** @hidden */
    _trackByColumnKey(index: number, rule: ValidatedSortRule): string | null;
    /** @hidden */
    private _initiateRules;
    /** @hidden */
    private _createRules;
    /** @hidden */
    private _getCollectionSortFromSortRules;
    /** @hidden */
    private _getUniqueRules;
    /** @hidden */
    private _isRuleValid;
    static ɵfac: i0.ɵɵFactoryDeclaration<P13SortingDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<P13SortingDialogComponent, "ng-component", never, {}, {}, never, never, true, never>;
}
export declare class GetAvailableSortColumnsPipe implements PipeTransform {
    /** @hidden */
    transform(columns: SortDialogColumn[], rules: SortRule[], currentKey: string | null): SortDialogColumn[];
    static ɵfac: i0.ɵɵFactoryDeclaration<GetAvailableSortColumnsPipe, never>;
    static ɵpipe: i0.ɵɵPipeDeclaration<GetAvailableSortColumnsPipe, "getAvailableSortColumns", true>;
}
export {};
