import { EventEmitter, OnDestroy } from '@angular/core';
import { DialogRef, DialogService } from '@fundamental-ngx/core/dialog';
import { Table, TableDialogCommonData } from '@fundamental-ngx/platform/table-helpers';
import { TableP13ColumnsComponent } from './table-p13-columns.component';
import { TableP13FilterComponent } from './table-p13-filter.component';
import { TableP13GroupComponent } from './table-p13-group.component';
import { TableP13SortComponent } from './table-p13-sort.component';
import * as i0 from "@angular/core";
/**
 * View settings dialog component.
 *
 * Used to link view settings filters options to the grid table.
 *
 * ```html
 * <fdp-table #myTable></fdp-table>
 * ...
 * <fdp-table-p13-dialog [table]="myTable">
 *   <!-- Sort Panel -->
 *   <fdp-table-p13-sort></fdp-table-p13-sort>
 *
 *   <!-- Filter Panel -->
 *   <fdp-table-p13-filter></fdp-table-p13-filter>
 *
 *   <!-- Group Panel -->
 *   <fdp-table-p13-group></fdp-table-p13-group>
 *
 *   <!-- Columns Panel -->
 *   <fdp-table-p13-columns></fdp-table-p13-columns>
 * </fdp-table-p13-dialog>
 * ```
 * */
export declare class TableP13DialogComponent implements OnDestroy {
    private readonly _dialogService;
    /** Reference to table component. */
    set table(table: Table);
    get table(): Table;
    /** Event emitted when dialog is closed. */
    dialogClosed: EventEmitter<string[]>;
    /** @hidden */
    sort: TableP13SortComponent;
    /** @hidden */
    filter: TableP13FilterComponent;
    /** @hidden */
    group: TableP13GroupComponent;
    /** @hidden */
    columns: TableP13ColumnsComponent;
    /** @hidden */
    _table: Table;
    /** @hidden */
    _dialogRef: DialogRef<TableDialogCommonData, any>;
    /** @hidden */
    private _subscriptions;
    /** @hidden */
    private _tableSubscriptions;
    /** @hidden */
    constructor(_dialogService: DialogService);
    /** @hidden */
    ngOnDestroy(): void;
    /** Open Sort Settings Dialog */
    showSortingSettings(): void;
    /** Open Filtering Settings Dialog */
    showFilteringSettings(): void;
    /** Open Grouping Settings Dialog */
    showGroupingSettings(): void;
    /** Open Columns Settings Dialog */
    showColumnsSettings(): void;
    /** @hidden */
    private _setTable;
    /** @hidden */
    private _subscribeToTable;
    /** @hidden */
    private _listenToTableTriggersToOpenDialogs;
    /** @hidden */
    private _listenToTableColumns;
    /** @hidden */
    private _getTableState;
    /** @hidden */
    private _getTableColumns;
    /** @hidden */
    private _applySorting;
    /** @hidden */
    private _applyFiltering;
    /** @hidden */
    private _applyGrouping;
    /** @hidden */
    private _applyColumns;
    /** @hidden */
    private _unsubscribeFromTable;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableP13DialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TableP13DialogComponent, "fdp-table-p13-dialog", never, { "table": { "alias": "table"; "required": false; }; }, { "dialogClosed": "dialogClosed"; }, ["sort", "filter", "group", "columns"], never, true, never>;
}
