import { AfterViewInit, EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { FocusableItemPosition } from '@fundamental-ngx/cdk/utils';
import { ContentDensityObserver } from '@fundamental-ngx/core/content-density';
import { TableRowDirective } from '@fundamental-ngx/core/table';
import { SelectionMode, SelectionModeValue, TableColumn, TableColumnResizeService, TableRow, TableRowKeyboardDrag, TableRowService, TableService, isTreeRow, isTreeRowFirstCell } from '@fundamental-ngx/platform/table-helpers';
import * as i0 from "@angular/core";
export declare class TableRowComponent<T> extends TableRowDirective implements OnInit, AfterViewInit, OnDestroy, OnChanges {
    /** Row ID. */
    rowId: string;
    /** Table Row. */
    row: TableRow<T>;
    /** Row index. */
    index: number;
    /** Selection mode. */
    selectionMode: SelectionModeValue;
    /** Selectable flag key. */
    selectableKey: string;
    /** Whether to enable checkbox tristate mode. */
    enableTristateMode: boolean;
    /**
     * Whether to fix the table header and footer. Default is true.
     * Note that if the table contains freezable columns, the header and
     * footer will be fixed automatically, regardless of this input value.
     * */
    fixed: boolean;
    /** Selection column width. */
    selectionColumnWidth: number;
    /** The column `name` to freeze columns up to and including. */
    freezeColumnsTo: string;
    /** The column `name` to freeze columns after and including. */
    freezeEndColumnsTo: string;
    /**
     * Event emitted when keyboard drag performed.
     */
    keyboardDrag: EventEmitter<TableRowKeyboardDrag>;
    /** @hidden */
    private set _focusableViewCellItems(value);
    /** @hidden */
    private readonly _editableCells;
    /** @hidden */
    private get _ariaSelected();
    /** @hidden */
    _hasRowHeaderColumn$: import("@angular/core").Signal<boolean>;
    /** @hidden */
    readonly _rtl$: import("@angular/core").Signal<boolean>;
    /** @hidden */
    _rowSelectionHelperTextId: string;
    /** @hidden */
    readonly _isTreeRowFirstCell: typeof isTreeRowFirstCell;
    /** @hidden */
    readonly SELECTION_MODE: typeof SelectionMode;
    /** @hidden */
    readonly _contentDensityObserver: ContentDensityObserver;
    /** @hidden */
    readonly _tableColumnResizeService: TableColumnResizeService;
    /** @hidden */
    readonly _fdpTableService: TableService;
    /** @hidden */
    readonly _tableRowService: TableRowService<any>;
    /** @hidden */
    readonly _isTreeRow: typeof isTreeRow;
    /** @hidden */
    private readonly _refreshChildRows$;
    /** @hidden */
    private readonly _rtlService;
    /** @hidden */
    private readonly _cdr;
    /** @hidden */
    private readonly _zone;
    /** @hidden */
    private readonly _elmRef;
    /** @hidden */
    private readonly _dndTableDirective;
    /** @hidden */
    constructor();
    /** @hidden */
    ngOnInit(): void;
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden */
    ngOnChanges(changes: SimpleChanges): void;
    /** @hidden */
    ngOnDestroy(): void;
    /** @hidden */
    _toggleGroupRow(): void;
    /** @hidden */
    _toggleSingleSelectableRow(event?: Event): void;
    /** @hidden */
    _toggleMultiSelectRow(row: TableRow<T>, event?: Event): void;
    /** @hidden */
    _columnTrackBy(index: number, column: TableColumn): string;
    /** @hidden */
    _itemFocusedEventAnnouncer: (position: FocusableItemPosition) => string;
    /** @hidden */
    protected _handleCellSpaceKey(colIdx: number, tableCellElement: HTMLTableCellElement, $event: Event): void;
    /** @hidden */
    private _listenToRowExpansion;
    /** @hidden */
    private _onKeyDown;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableRowComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TableRowComponent<any>, "[fdp-table-row]", never, { "rowId": { "alias": "rowId"; "required": false; }; "row": { "alias": "row"; "required": false; }; "index": { "alias": "index"; "required": false; }; "selectionMode": { "alias": "selectionMode"; "required": false; }; "selectableKey": { "alias": "selectableKey"; "required": false; }; "enableTristateMode": { "alias": "enableTristateMode"; "required": false; }; "fixed": { "alias": "fixed"; "required": false; }; "selectionColumnWidth": { "alias": "selectionColumnWidth"; "required": false; }; "freezeColumnsTo": { "alias": "freezeColumnsTo"; "required": false; }; "freezeEndColumnsTo": { "alias": "freezeEndColumnsTo"; "required": false; }; }, { "keyboardDrag": "keyboardDrag"; }, never, ["*"], true, never>;
}
