import { EventEmitter, Signal, TemplateRef } from '@angular/core';
import { Observable } from 'rxjs';
import { Nullable } from '@fundamental-ngx/cdk/utils';
import { HeadingLevel } from '@fundamental-ngx/core/shared';
import { SearchInput, SuggestionItem } from '@fundamental-ngx/platform/search-field';
import { Table, TableService } from '@fundamental-ngx/platform/table-helpers';
import { TableToolbarInterface } from './table-toolbar';
import { TableToolbarActionsComponent } from './table-toolbar-actions.component';
import { TableToolbarLeftActionsComponent } from './table-toolbar-left-actions.component';
import * as i0 from "@angular/core";
export interface TableAppliedFilter {
    columnName: string;
    params: string;
}
export interface ToolbarContext {
    counter: Signal<number>;
    sortable: Signal<boolean>;
    filterable: Signal<boolean>;
    groupable: Signal<boolean>;
    columns: Signal<boolean>;
    settings: Signal<boolean>;
    hasAnyActions: Signal<boolean>;
    appliedFilters: Signal<TableAppliedFilter[]>;
}
export type EditMode = 'none' | 'inline';
export declare class TableToolbarTemplateDirective {
    /** @hidden */
    readonly templateRef: TemplateRef<ToolbarContext>;
    /** @hidden */
    static ngTemplateContextGuard(_directive: TableToolbarTemplateDirective, context: unknown): context is ToolbarContext;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableToolbarTemplateDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TableToolbarTemplateDirective, "[fdpTableToolbarTemplate]", never, {}, {}, never, never, true, never>;
}
/**
 * The component that represents a table toolbar.
 *
 * ```html
 * <fdp-table-toolbar
 *   title="Order Line Items"
 *   [hideItemCount]="false">
 * </fdp-table-toolbar>
 * ```
 * */
export declare class TableToolbarComponent implements TableToolbarInterface {
    private _tableService;
    private readonly _table;
    /**
     * Whether the toolbar should hide elements in popover when they overflow.
     * */
    shouldOverflow: boolean;
    /** Table title. */
    title: string;
    /** Aria label for the search field. */
    searchFieldAriaLabel: Nullable<string>;
    /** Toggle to show table item count. */
    hideItemCount: boolean;
    /** Toggle to show search input. */
    hideSearchInput: boolean;
    /** Toggle to expand and collapse all feature */
    showExpandCollapseButtons: boolean;
    /** Suggestions for search field. */
    searchSuggestions: SuggestionItem[];
    /** Table rows edit/add mode. */
    editMode: EditMode;
    /** Whether display Refresh button in the search field */
    disableRefresh: boolean;
    /** Whether display search button in the search field */
    disableSearch: boolean;
    /**
     * Heading level of the table toolbar title.
     */
    headingLevel: HeadingLevel;
    /** Search field input text. */
    set searchFieldInputText(text: string);
    get searchFieldInputText(): string;
    /** Event emitted when the search field input is changed. */
    searchFieldInputChange: EventEmitter<string>;
    /** @hidden */
    tableToolbarActionsComponent: TableToolbarActionsComponent;
    /** @hidden */
    _tableToolbarLeftActionsComponent: TableToolbarLeftActionsComponent;
    /** @hidden */
    contentTemplateRef: TemplateRef<any>;
    /** @hidden */
    tableToolbarTitleId: string;
    /** @hidden */
    _showSaveButton: boolean;
    /** @hidden */
    _searchInputText: string;
    /** @hidden */
    readonly tableLoading$: Observable<boolean>;
    /** @hidden */
    private readonly _destroyRef;
    /** @hidden */
    constructor(_tableService: TableService, _table: Table);
    /** @hidden */
    submitSearch(search: SearchInput): void;
    /** @hidden */
    searchInputChanged(event: SearchInput): void;
    /** @hidden */
    openSorting(): void;
    /** @hidden */
    openFiltering(): void;
    /** @hidden */
    openGrouping(): void;
    /** @hidden */
    openColumns(): void;
    /** @hidden */
    _addRow(): void;
    /** @hidden */
    _saveRows(): void;
    /** @hidden */
    _cancelEditing(): void;
    /** @hidden */
    _expandAll(): void;
    /** @hidden */
    _formatAppliedFilters(appliedFilters: {
        columnName: string;
        params: string;
    }[]): string;
    /** @hidden */
    _closeFilterToolbar(): void;
    /** @hidden */
    _collapseAll(): void;
    /** @hidden */
    private _listenToTableEvents;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableToolbarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TableToolbarComponent, "fdp-table-toolbar", never, { "shouldOverflow": { "alias": "shouldOverflow"; "required": false; }; "title": { "alias": "title"; "required": false; }; "searchFieldAriaLabel": { "alias": "searchFieldAriaLabel"; "required": false; }; "hideItemCount": { "alias": "hideItemCount"; "required": false; }; "hideSearchInput": { "alias": "hideSearchInput"; "required": false; }; "showExpandCollapseButtons": { "alias": "showExpandCollapseButtons"; "required": false; }; "searchSuggestions": { "alias": "searchSuggestions"; "required": false; }; "editMode": { "alias": "editMode"; "required": false; }; "disableRefresh": { "alias": "disableRefresh"; "required": false; }; "disableSearch": { "alias": "disableSearch"; "required": false; }; "headingLevel": { "alias": "headingLevel"; "required": false; }; "searchFieldInputText": { "alias": "searchFieldInputText"; "required": false; }; }, { "searchFieldInputChange": "searchFieldInputChange"; }, ["tableToolbarActionsComponent", "_tableToolbarLeftActionsComponent"], never, true, never>;
}
