import { AfterViewInit, ChangeDetectorRef, OnInit } from '@angular/core';
import { Nullable } from '@fundamental-ngx/cdk/utils';
import { CollectionFilter, TableColumn } from '@fundamental-ngx/platform/table-helpers';
import { TableViewSettingsFilterComponent } from '../table-view-settings-filter.component';
import { ACTIVE_STEP, FiltersDialogData, FiltersDialogResultData } from '../table-view-settings.model';
import { FiltersViewStep } from './filters-active-step';
import { SelectableFilter } from './filters-list-step.component';
import * as i0 from "@angular/core";
export declare class FiltersComponent implements AfterViewInit, OnInit {
    private readonly _cd;
    /** Data for the filtering dialog */
    set filteringData(value: FiltersDialogData);
    /** Initial set of filters applied */
    initialFilters: import("@angular/core").InputSignal<CollectionFilter[]>;
    /** Emits when the active filter step view changes */
    activeFilterStepViewChange: import("@angular/core").OutputEmitterRef<FiltersViewStep>;
    /** Emits the final result of filter changes */
    filterChange: import("@angular/core").OutputEmitterRef<FiltersDialogResultData>;
    /** Emits whether the reset button should be enabled */
    resetAvailabilityChange: import("@angular/core").OutputEmitterRef<boolean>;
    /** Signal to hold currently applied filter rules */
    filterBy: import("@angular/core").WritableSignal<CollectionFilter[]>;
    /** Signal for table columns, used to retrieve the column key */
    columns: import("@angular/core").WritableSignal<TableColumn[]>;
    /** Signal for declared filter options */
    viewSettingsFilters: import("@angular/core").WritableSignal<TableViewSettingsFilterComponent[]>;
    /** Signal to track the currently selected filter step */
    activeStep: import("@angular/core").WritableSignal<ACTIVE_STEP>;
    /** Signal to track the currently selected filter */
    activeFilter: import("@angular/core").WritableSignal<Nullable<TableViewSettingsFilterComponent>>;
    /** Signal to track the column key associated with the active filter */
    activeFilterColumnKey: import("@angular/core").WritableSignal<Nullable<string>>;
    /** Signal for the currently active filter step view */
    activeFilterStepView: import("@angular/core").WritableSignal<Nullable<FiltersViewStep>>;
    /** Reference to the available steps */
    readonly ACTIVE_STEP: typeof ACTIVE_STEP;
    /** hidden */
    constructor(_cd: ChangeDetectorRef);
    /** hidden */
    ngOnInit(): void;
    /** hidden */
    ngAfterViewInit(): void;
    /** Setter for the active filter step view to trigger updates */
    set setActiveFilterStepView(view: FiltersViewStep);
    /**
     * Select a filter to drill down and update the active filter step.
     * @param filter The filter to be selected and applied.
     */
    selectFilter(filter: SelectableFilter): void;
    /** Navigate back to the top-level filters list */
    goToFilters(): void;
    /**
     * Apply changes to the selected filter and emit the filter change event.
     * @param filter The filter to apply
     * @param filterComponent The component for the filter (provides type info)
     */
    applyFilter(filter: CollectionFilter, filterComponent: Nullable<TableViewSettingsFilterComponent>): void;
    /**
     * Private method to initialize filter data on component initialization.
     * Extracts the initial filter values and table column data.
     */
    private _initializeFilterData;
    /**
     * Private method to compare the current selected filters against the initial state.
     * Enables or disables the reset button based on filter state comparison.
     */
    private _compareSelectedFilters;
    static ɵfac: i0.ɵɵFactoryDeclaration<FiltersComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<FiltersComponent, "fdp-filters", never, { "filteringData": { "alias": "filteringData"; "required": false; }; "initialFilters": { "alias": "initialFilters"; "required": false; "isSignal": true; }; }, { "activeFilterStepViewChange": "activeFilterStepViewChange"; "filterChange": "filterChange"; "resetAvailabilityChange": "resetAvailabilityChange"; }, never, never, true, never>;
}
