import { OnInit } from '@angular/core';
import { Nullable } from '@fundamental-ngx/cdk/utils';
import { SortDirection } from '@fundamental-ngx/platform/table-helpers';
import { SettingsGroupDialogColumn, SettingsGroupDialogData, SettingsGroupDialogResultData } from '../table-view-settings.model';
import * as i0 from "@angular/core";
export declare class GroupingComponent implements OnInit {
    /** Input data for grouping */
    groupingData: import("@angular/core").InputSignal<SettingsGroupDialogData | undefined>;
    /** @hidden Initial grouping settings */
    initialGrouping: import("@angular/core").InputSignal<Nullable<SettingsGroupDialogResultData>>;
    /** Event emitter for group changes */
    groupChange: import("@angular/core").OutputEmitterRef<SettingsGroupDialogResultData>;
    /** Event emitter for reset availability changes */
    resetAvailabilityChange: import("@angular/core").OutputEmitterRef<boolean>;
    /** Current selected grouping direction */
    direction: import("@angular/core").WritableSignal<SortDirection>;
    /** Current selected grouping field */
    field: import("@angular/core").WritableSignal<string | null>;
    /** Table columns available for grouping */
    columns: import("@angular/core").WritableSignal<SettingsGroupDialogColumn[]>;
    /** @hidden */
    groupOrderHeaderId: string;
    /** Constants for grouping directions */
    readonly SORT_DIRECTION: typeof SortDirection;
    /** Constant for 'Not grouped' option */
    readonly NOT_GROUPED_OPTION_VALUE: null;
    /** hidden */
    ngOnInit(): void;
    /**
     * Handle changes to grouping direction.
     * @param direction New grouping direction.
     */
    _groupOrderChange(direction: SortDirection): void;
    /**
     * Handle changes to the grouping field.
     * @param field New grouping field.
     */
    _groupFieldChange(field: string): void;
    /**
     * Initialize grouping data and signals.
     * @param groupingData Input grouping data.
     * @hidden
     */
    private _initGroupingData;
    /**
     * Compare current grouping state with the initial state, emit events for group and reset availability changes.
     * @hidden
     */
    private _onModelChange;
    /**
     * Compare the initial grouping state with the current state and emit reset availability change if needed.
     * @hidden
     */
    private _compareInitialGrouping;
    static ɵfac: i0.ɵɵFactoryDeclaration<GroupingComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GroupingComponent, "fdp-grouping", never, { "groupingData": { "alias": "groupingData"; "required": false; "isSignal": true; }; "initialGrouping": { "alias": "initialGrouping"; "required": false; "isSignal": true; }; }, { "groupChange": "groupChange"; "resetAvailabilityChange": "resetAvailabilityChange"; }, never, never, true, never>;
}
