import { Nullable } from '@fundamental-ngx/cdk/utils';
import { DialogRef } from '@fundamental-ngx/core/dialog';
import { CollectionFilter, CollectionSort, Table } from '@fundamental-ngx/platform/table-helpers';
import { Resettable } from '../../reset-button/reset-button.component';
import { FiltersViewStep } from '../filtering/filters-active-step';
import { ActiveTab, FiltersDialogData, FiltersDialogResultData, SettingsGroupDialogData, SettingsGroupDialogResultData, SettingsSortDialogData, SettingsSortDialogResultData } from '../table-view-settings.model';
import * as i0 from "@angular/core";
export declare class SettingsDialogComponent implements Resettable {
    private readonly dialogRef;
    private readonly _table;
    /** Data for sorting */
    sortingData: import("@angular/core").WritableSignal<Nullable<SettingsSortDialogData>>;
    /** Data for filtering */
    filteringData: import("@angular/core").WritableSignal<Nullable<FiltersDialogData>>;
    /** Data for grouping */
    groupingData: import("@angular/core").WritableSignal<Nullable<SettingsGroupDialogData>>;
    /** The active tab to display ('sort', 'filter', or 'group') */
    activeTab: import("@angular/core").WritableSignal<Nullable<ActiveTab>>;
    /** Flag indicating whether the subheader should be shown */
    showSubheader: import("@angular/core").WritableSignal<boolean>;
    /** Current step component to render for filtering */
    activeFilterStepView: import("@angular/core").WritableSignal<Nullable<FiltersViewStep>>;
    /** Signal to track reset availability */
    readonly isResetAvailable$: import("@angular/core").WritableSignal<boolean>;
    /** @hidden Initial sorting configuration */
    _initialSorting: import("@angular/core").WritableSignal<Nullable<CollectionSort>>;
    /** @hidden Initial filter configurations */
    _initialFilters: import("@angular/core").WritableSignal<CollectionFilter[]>;
    /** @hidden Initial grouping configurations */
    _initialGrouping: import("@angular/core").WritableSignal<Nullable<SettingsGroupDialogResultData>>;
    /**
     * Constructor that initializes dialog data and sets initial values for sorting, filtering, and grouping.
     */
    constructor(dialogRef: DialogRef<{
        sortingData: Nullable<SettingsSortDialogData>;
        filteringData: Nullable<FiltersDialogData>;
        groupingData: Nullable<SettingsGroupDialogData>;
    }>, _table: Table);
    /**
     * Confirm the dialog action and close the dialog, returning updated settings data.
     */
    confirm(): void;
    /**
     * Cancel the dialog and close it without saving any changes.
     */
    cancel(): void;
    /**
     * Reset the settings based on the currently active tab (sort, filter, group).
     */
    reset(): void;
    /**
     * Handle sort change event and update sorting data.
     * @param event Updated sorting data.
     */
    onSortChange(event: SettingsSortDialogResultData): void;
    /**
     * Handle filter change event and update filtering data.
     * @param event Updated filtering data.
     */
    onFilterChange(event: FiltersDialogResultData): void;
    /**
     * Handle group change event and update grouping data.
     * @param event Updated grouping data.
     */
    onGroupChange(event: SettingsGroupDialogResultData): void;
    /**
     * Update the active filter step view when a change occurs.
     * @param event The new active filter step view.
     */
    onActiveFilterStepViewChange(event: FiltersViewStep): void;
    /**
     * Handle changes to the reset availability.
     * @param event Boolean indicating if reset is available.
     */
    onResetAvailabilityChange(event: boolean): void;
    /**
     * Determine the initial active tab based on available data.
     * @returns The name of the active tab to display.
     */
    private _getInitialActiveTab;
    /**
     * Determine if the subheader should be shown based on the availability of sorting, filtering, and grouping data.
     */
    private _shouldRenderSubheader;
    /**
     * Set initial sorting configuration from the table's state.
     */
    private _setInitialSorting;
    /**
     * Set initial filter configuration from the table's state.
     */
    private _setInitialFilters;
    /**
     * Set initial grouping configuration from the table's state.
     */
    private _setInitialGrouping;
    static ɵfac: i0.ɵɵFactoryDeclaration<SettingsDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SettingsDialogComponent, "fdp-settings-dialog-settings", never, {}, {}, never, never, true, never>;
}
