import { OnInit } from '@angular/core';
import { Nullable } from '@fundamental-ngx/cdk/utils';
import { CollectionSort, SortDirection } from '@fundamental-ngx/platform/table-helpers';
import { SettingsSortDialogColumn, SettingsSortDialogData, SettingsSortDialogResultData } from '../table-view-settings.model';
import * as i0 from "@angular/core";
export declare class SortingComponent implements OnInit {
    /** Input data for sorting */
    sortingData: import("@angular/core").InputSignal<SettingsSortDialogData | undefined>;
    /** @hidden Initial sorting state */
    initialSorting: import("@angular/core").InputSignal<Nullable<CollectionSort>>;
    /** Event emitter for sort changes */
    sortChange: import("@angular/core").OutputEmitterRef<SettingsSortDialogResultData>;
    /** Event emitter for reset availability changes */
    resetAvailabilityChange: import("@angular/core").OutputEmitterRef<boolean>;
    /** Current selected sorting direction */
    direction: import("@angular/core").WritableSignal<SortDirection>;
    /** Current selected sorting field */
    field: import("@angular/core").WritableSignal<string | null>;
    /** Whether disabling sorting is allowed */
    allowDisablingSorting: import("@angular/core").WritableSignal<boolean>;
    /** Available table columns for sorting */
    columns: import("@angular/core").WritableSignal<SettingsSortDialogColumn[]>;
    /** @hidden */
    sortOrderHeaderId: string;
    /** @hidden */
    sortDialogSortByHeaderId: string;
    /** @hidden Constants for sort direction */
    readonly SORT_DIRECTION: typeof SortDirection;
    /** @hidden Constant for 'Not sorted' option value */
    readonly NOT_SORTED_OPTION_VALUE: null;
    /** hidden */
    ngOnInit(): void;
    /**
     * Handle sort direction changes.
     * @param direction New sorting direction.
     */
    _sortDirectionChange(direction: SortDirection): void;
    /**
     * Handle sort field changes.
     * @param field New sorting field.
     */
    _sortFieldChange(field: string): void;
    /**
     * Initialize sorting data and signals.
     * @param sortingData Input sorting data.
     * @hidden
     */
    private _initSortingData;
    /**
     * Emit changes to the model and compare with initial sorting.
     * @hidden
     */
    private _onModelChange;
    /**
     * Compare the current sorting state with the initial state.
     * Emit reset availability if the sorting has changed.
     * @hidden
     */
    private _compareInitialSorting;
    static ɵfac: i0.ɵɵFactoryDeclaration<SortingComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SortingComponent, "fdp-sorting", never, { "sortingData": { "alias": "sortingData"; "required": false; "isSignal": true; }; "initialSorting": { "alias": "initialSorting"; "required": false; "isSignal": true; }; }, { "sortChange": "sortChange"; "resetAvailabilityChange": "resetAvailabilityChange"; }, never, never, true, never>;
}
