import { AfterViewInit, QueryList } from '@angular/core';
import { DialogConfig, DialogRef, DialogService } from '@fundamental-ngx/core/dialog';
import { Table, TableDialogCommonData } from '@fundamental-ngx/platform/table-helpers';
import { TableViewSettingsFilterComponent } from './table-view-settings-filter.component';
import { FiltersDialogData, SettingsGroupDialogData, SettingsSortDialogData } from './table-view-settings.model';
import * as i0 from "@angular/core";
export declare const dialogConfig: DialogConfig;
export interface CombinedTableDialogData {
    sortingData: SettingsSortDialogData | null;
    filteringData: FiltersDialogData | null;
    groupingData: SettingsGroupDialogData | null;
}
/**
 * View settings dialog component.
 *
 * Used to link view settings filters options to the grid table.
 *
 * ```html
 * <fdp-table #myTable></fdp-table>
 * ...
 * <fdp-table-view-settings-dialog [table]="myTable">
 *     <fdp-table-view-settings-filter
 *         column="status"
 *         label="Status"
 *         type="single-select"
 *         values="[{value: 'filterValue', label: 'Filter label'}]">
 *     </fdp-table-view-settings-filter>
 * </fdp-table-view-settings-dialog>
 * ```
 * */
export declare class TableViewSettingsDialogComponent implements AfterViewInit {
    private readonly _dialogService;
    /** Reference to table component. */
    set table(table: Table);
    get table(): Table;
    /** Whether to allow selecting '(Not sorted)' option in sorting dialog. */
    allowDisablingSorting: boolean;
    /** @hidden */
    filters: QueryList<TableViewSettingsFilterComponent>;
    /** @hidden */
    _table: Table;
    /** @hidden */
    _dialogRef: DialogRef<TableDialogCommonData | CombinedTableDialogData, any>;
    private readonly destroyRef;
    /** @hidden */
    constructor(_dialogService: DialogService);
    /** @hidden */
    ngAfterViewInit(): void;
    /** Open Sort Settings Dialog */
    showViewSettingsDialog(): void;
    /** @hidden */
    private _listenToFilters;
    /** @hidden */
    private _setTable;
    /** @hidden */
    private _subscribeToTable;
    /** @hidden */
    private _getTableState;
    /** @hidden */
    private _getTableColumns;
    /** @hidden */
    private _applySorting;
    /** @hidden */
    private _applyFiltering;
    /** @hidden */
    private _applyGrouping;
    static ɵfac: i0.ɵɵFactoryDeclaration<TableViewSettingsDialogComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TableViewSettingsDialogComponent, "fdp-table-view-settings-dialog", never, { "table": { "alias": "table"; "required": false; }; "allowDisablingSorting": { "alias": "allowDisablingSorting"; "required": false; }; }, {}, ["filters"], never, true, never>;
}
