import { TemplateRef } from '@angular/core';
import { FdpViewSettingsFilterCustomDef, FilterType, TableFilterSelectOption } from '@fundamental-ngx/platform/table-helpers';
import * as i0 from "@angular/core";
/**
 * View settings dialog filter component.
 *
 * ```html
 * <!-- With custom form -->
 * <fdp-table-view-settings-filter
 *     column="name"
 *     label="Name"
 *     type="custom">
 *         <ng-container *fdpViewSettingsFilterCustomDef="let model">
 *             <label>Enter name:</label>
 *             <fdp-input type="text" name="name" [(ngModel)]="model.name"></fdp-input>
 *         </ng-container>
 * </fdp-table-view-settings-filter>
 *
 * <!-- Single select -->
 * <fdp-table-view-settings-filter
 *     column="status"
 *     label="Status"
 *     type="single-select"
 *     values="[{value: 'OUT_OF_STOCK', label: 'Out of stock'}, { value: 'AVAILABLE', label: 'Available'}]">
 * </fdp-table-view-settings-filter>
 * ```
 *
 * */
export declare class TableViewSettingsFilterComponent {
    /** Table column name on which to filter. */
    column: string;
    /** Label for the column. */
    label: string;
    /**
     * Type of filter interface.
     * @type {'single-select' | 'multi-select' | 'custom' 'category'}
     */
    type: FilterType;
    /** Selection values for 'single-select' or 'multi-select' filter types. */
    values: TableFilterSelectOption[];
    /** Custom filter template directive reference */
    customFilterTemplate: TemplateRef<any>;
    /** @hidden */
    set _filterCustomDef(filterCustomDef: FdpViewSettingsFilterCustomDef);
    static ɵfac: i0.ɵɵFactoryDeclaration<TableViewSettingsFilterComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TableViewSettingsFilterComponent, "fdp-table-view-settings-filter", never, { "column": { "alias": "column"; "required": false; }; "label": { "alias": "label"; "required": false; }; "type": { "alias": "type"; "required": false; }; "values": { "alias": "values"; "required": false; }; }, {}, ["_filterCustomDef"], never, true, never>;
}
