import { AfterViewInit, EventEmitter, OnChanges, SimpleChanges } from '@angular/core';
import { InfiniteScrollDirective } from '@fundamental-ngx/core/infinite-scroll';
import { ValueHelpColumnDefDirective } from '../../directives/value-help-column-def.directive';
import { VdhTableSelection, VhdFilter } from '../../models';
import { VhdBaseTab } from '../base-tab/vhd-base-tab.component';
import * as i0 from "@angular/core";
export declare class SelectTabComponent<T> extends VhdBaseTab implements OnChanges, AfterViewInit {
    /** @hidden */
    protected defaultTitleId: string;
    /** @hidden */
    protected defaultCountId: string;
    /** Select tab title element ID */
    selectTabTitleId: string;
    /** Select tab count element ID */
    selectTabCountId: string;
    /** Selected items */
    selected: T[];
    /** Loading state */
    loading: boolean;
    /** Actual filters */
    filters: VhdFilter[];
    /** Close dialog immediately after select any row from search table. It'll be skipped if multi option is true */
    selection: VdhTableSelection;
    /** Whether to allow users to select all table entries with one checkbox. */
    allowSelectAll: boolean;
    /** Uniq field from data source */
    uniqueKey: string;
    /** Items per page for pagination below search table */
    pageSize: number;
    /** Count of default mobile header from search table */
    defaultMobileHeaders: number;
    /** Displayed data for search table */
    displayedData: T[];
    /** Event emitted when row was selected. */
    select: EventEmitter<T[]>;
    /** @hidden */
    infiniteScrollTable: InfiniteScrollDirective;
    /** @hidden indeterminate flag for `select all` checkbox */
    _selectedAll: boolean | null;
    /** @hidden Shown items count in mobile view */
    _shownFrom: number;
    /** @hidden Shown items count in mobile view */
    _shownCount: number;
    /** @hidden Current page in desktop view */
    _currentPage: number;
    /** @hidden Headers and body for search table */
    _tableFilters: {
        main: VhdFilter[];
        secondary: VhdFilter[];
    };
    /** @hidden */
    _selectedMap: {
        [key: string]: boolean;
    };
    /** Selection type getters */
    get isSingleSelection(): boolean;
    /** Selection type getters */
    get isOnceSelection(): boolean;
    /** Selection type getters */
    get isMultiSelection(): boolean;
    /** @hidden */
    _columnDefMap: Map<string, ValueHelpColumnDefDirective<any>>;
    /** @hidden */
    private selectedItems;
    /** @hidden */
    private readonly _vhd;
    /** @hidden */
    private readonly _destroyRef;
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden  */
    ngOnChanges(changes: SimpleChanges): void;
    /** @hidden Track function for main data */
    _trackByTableRowFn: (_index: number, item: T) => string | undefined;
    /** @hidden Track function for filters */
    _trackByFilterFn(_index: number, item: VhdFilter): number | string | undefined;
    /** @hidden Show more elements */
    _showMoreElements(): void;
    /** @hidden Refresh page in desktop view */
    _updatePage(pageNumber?: number): void;
    /** @hidden Method toggle selected state for all items  */
    _toggleAllRows(): void;
    /** @hidden Method toggle selected state for one items  */
    _toggleSelectRow(item: T): void;
    /** @hidden */
    private _checkScrollAndShowMore;
    /** @hidden */
    private _resetShown;
    /** @hidden Manually clear selected items */
    private _clearSelectedItems;
    /** @hidden Refresh indeterminate attribute on `select all` checkbox */
    private _refreshTristate;
    /** @hidden Set up filters */
    private _initializeFilters;
    /** @hidden Refresh display data */
    private _refreshDisplayedData;
    /** @hidden Refresh selected map for display data */
    private _refreshSelectedMap;
    static ɵfac: i0.ɵɵFactoryDeclaration<SelectTabComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SelectTabComponent<any>, "fdp-select-tab", never, { "selectTabTitleId": { "alias": "selectTabTitleId"; "required": false; }; "selectTabCountId": { "alias": "selectTabCountId"; "required": false; }; "selected": { "alias": "selected"; "required": false; }; "loading": { "alias": "loading"; "required": false; }; "filters": { "alias": "filters"; "required": false; }; "selection": { "alias": "selection"; "required": false; }; "allowSelectAll": { "alias": "allowSelectAll"; "required": false; }; "uniqueKey": { "alias": "uniqueKey"; "required": false; }; "pageSize": { "alias": "pageSize"; "required": false; }; "defaultMobileHeaders": { "alias": "defaultMobileHeaders"; "required": false; }; "displayedData": { "alias": "displayedData"; "required": false; }; }, { "select": "select"; }, never, never, true, never>;
}
