import { ChangeDetectorRef, ElementRef, EventEmitter, OnChanges, OnDestroy, QueryList, SimpleChanges, TemplateRef } from '@angular/core';
import { Observable } from 'rxjs';
import { Direction } from '@angular/cdk/bidi';
import { RtlService } from '@fundamental-ngx/cdk/utils';
import { DialogConfig, DialogRef, DialogService } from '@fundamental-ngx/core/dialog';
import { HeadingLevel } from '@fundamental-ngx/core/shared';
import { VhdFilterComponent } from '../components/value-help-dialog-filter/value-help-dialog-filter.component';
import { ValueHelpColumnDefDirective } from '../directives/value-help-column-def.directive';
import { ArrayValueHelpDialogDataSource, BaseEntity, ObservableValueHelpDialogDataSource, ValueHelpDialogDataSource, VdhTableSelection, VhdDefineExcludeStrategy, VhdDefineIncludeStrategy, VhdFilter, VhdTab, VhdValue, VhdValueChangeEvent } from '../models';
import { VhdComponent } from '../models/vhd-component.model';
import * as i0 from "@angular/core";
export type FdpValueHelpDialogDataSource<T> = ValueHelpDialogDataSource<T> | ArrayValueHelpDialogDataSource<T> | ObservableValueHelpDialogDataSource<T>;
export declare class PlatformValueHelpDialogComponent<T = any> extends VhdComponent implements OnChanges, OnDestroy {
    readonly elementRef: ElementRef;
    private readonly _changeDetectorRef;
    private readonly _dialogService;
    private readonly _rtlService;
    /** Id of the popover */
    id: string;
    /** Initial state of Value help dialog */
    value: VhdValue<T>;
    /** Dialog title */
    dialogTitle: string;
    /** Select from list tab activation */
    initialTab: VhdTab;
    /** Visible tabs */
    tabs: 'both' | 'select' | 'define';
    /** Initial expand state for advanced search panel */
    isOpenAdvanced: boolean;
    /** Data source */
    set dataSource(value: FdpValueHelpDialogDataSource<any> | undefined);
    get dataSource(): FdpValueHelpDialogDataSource<any> | undefined;
    /** Dialog's custom config */
    dialogConfig: DialogConfig;
    /** Unique key from the source field names. Required field. */
    uniqueKey: string;
    /** Id attribute for dialog title */
    headerId: string;
    /** Field name for default render from data.
     * Required field if tokenizerFn is not exist. */
    tokenViewField: string;
    /** Tokenizer function for custom token render, it has higher prio that `tokenViewField`.
     * Required field if tokenViewField is not exist. */
    tokenizerFn: (item: T) => string;
    /** Whether the value help dialog should be view in mobile mode */
    mobile: boolean;
    /** It should be able if you use multiple selection */
    formatToken: (value: VhdValueChangeEvent<T>) => void;
    /** Tokenizer function for condition's token render */
    conditionDisplayFn: (item: import("../models").VhdIncludedEntity | import("../models").VhdExcludedEntity, filters?: VhdFilter[]) => string | null;
    /** Validator function. Called when user submits VHD dialog. */
    tokenValidator: ((value: VhdValueChangeEvent) => Observable<boolean> | boolean) | undefined;
    /** Selection mode for search table */
    searchSelection: VdhTableSelection;
    /** Items per page for pagination below search table */
    searchTablePageSize: number;
    /** Count of default mobile header from search table */
    searchTableMobileHeaders: number;
    /** Max shown initial filters on open. Desktop only */
    maxShownInitialFilters: number;
    /** Loading state */
    loading: boolean | undefined;
    /** Whether to allow users to select all table entries with one checkbox. */
    allowSelectAll: boolean;
    /** Custom strategies labels
     * Allowed keys: contains, equalTo, between, startsWith, endsWith, lessThan, lessThanEqual, greaterThan, greaterThanEqual, empty
     */
    defineStrategyLabels: {
        [key in keyof (typeof VhdDefineIncludeStrategy | typeof VhdDefineExcludeStrategy)]?: string;
    };
    /** Dialog outputs */
    /** Event emitted when filters/tokens were changed. */
    valueChange: EventEmitter<VhdValueChangeEvent<T>>;
    /** Event emitted when data loading is started. */
    onDataRequested: EventEmitter<void>;
    /** Event emitted when data loading is finished. */
    onDataReceived: EventEmitter<void>;
    /** @hidden Fitlers for search table and defince conditions */
    filters: QueryList<VhdFilterComponent>;
    /** Column definitions. */
    columnDef: QueryList<ValueHelpColumnDefDirective>;
    /** @hidden Internal container for dialog */
    dialogContainer: TemplateRef<any>;
    /**
     * Heading level of the dialog title.
     */
    headingLevel: import("@angular/core").InputSignal<HeadingLevel>;
    /** @hidden */
    _headingLevel: import("@angular/core").Signal<number | undefined>;
    /** @hidden */
    activeDialog?: DialogRef;
    /** @hidden */
    _tabTypes: typeof VhdTab;
    /** @hidden */
    _hasAdvanced: boolean;
    /** @hidden */
    _displayedFilters: VhdFilter[];
    /** @hidden */
    _displayedData: T[];
    /** @hidden */
    _mainSearch: string;
    /** handles rtl service
     * @hidden */
    _dir$: import("@angular/core").Signal<Direction>;
    /** @hidden */
    selectedTab: VhdTab | null;
    /** @hidden */
    shownFilterCount: number;
    /** @hidden */
    get loadingState(): boolean;
    /** @hidden
     * To differentiate between first loading when skeletons be shown and subsequent loadings when busy indicator be shown
     */
    _firstLoadingDone: boolean;
    /** @hidden */
    private _destroyed;
    /** @hidden */
    private _dataSource;
    /** @hidden for data source handling */
    private _dsSubscription;
    /** @hidden Previous state */
    private _prevState;
    /** @hidden Current data for local manupulation */
    private _currentValue;
    /** @hidden */
    private _internalLoadingState;
    /** @hidden */
    private readonly _onDestroy$;
    /** @hidden */
    constructor(elementRef: ElementRef, _changeDetectorRef: ChangeDetectorRef, _dialogService: DialogService, _rtlService: RtlService);
    /** @hidden */
    get isMobileAdvancedSearchActive(): boolean;
    /** @hidden */
    get hasSelectedTab(): boolean;
    /** @hidden */
    get showSelectionTab(): boolean;
    /** @hidden */
    get showDefineTab(): boolean;
    /** @hidden */
    get isSelectionTab(): boolean;
    /** @hidden */
    get selectedItems(): T[];
    /** @hidden */
    get conditionItems(): BaseEntity[];
    /** @hidden */
    get validConditions(): BaseEntity[];
    /** @hidden */
    get hasSelectedAndConditions(): boolean;
    /** @hidden */
    get isShowAllFilters(): boolean;
    /** @hidden */
    get isOpen(): boolean;
    /** @hidden */
    ngOnChanges(changes: SimpleChanges): void;
    /** @hidden */
    ngOnDestroy(): void;
    /** Open dialog */
    open(): void;
    /**
     * Toggle advanced search panel
     */
    toggleAdvancedSearch(state?: boolean): void;
    /**
     * Clear all selected items
     */
    clearSelectedAndConditionItems(): void;
    /** Search by only the search term. */
    search(): void;
    /**
     * Search by all filled filters, including the search term.
     */
    filter(onlySearch?: boolean): void;
    /**
     * Apply search from advanced filters view, using when mobile view is active
     */
    searchAdvanced(): void;
    /** Remove item from selected array */
    removeSelected(index: number): void;
    /**
     * Remove condition item
     */
    removeCondition(index: number): void;
    /**
     * Switch tab by type
     */
    switchTab(type?: VhdTab | null): void;
    /**
     * Close dialog with value;
     */
    success(): void;
    /**
     * Hide advanced search on mobile view and if it's opened
     * Close dialog with null value;
     */
    dismiss(): void;
    /** @hidden */
    _trackBySelectedFn: (_index: number, item: T) => number | string;
    /** @hidden */
    _trackByFilterFn(_index: number, item: VhdFilter): number | string;
    /** @hidden */
    _trackByConditionFn(_index: number, item: BaseEntity): number | string | undefined;
    /** @hidden */
    onSelect($event: T[]): void;
    /** @hidden */
    onConditionChange($event: BaseEntity[]): void;
    /** @hidden */
    toggleShownFilters(): void;
    /** @hidden */
    private _initShownFilters;
    /** @hidden */
    private _getValidCondition;
    /** @hidden */
    private _initializeDS;
    /** @hidden Save previous state */
    private _savePreviousState;
    /** @hidden */
    private _initializeTab;
    /** @hidden */
    private _listenDialogEvents;
    /** @hidden */
    private _resetState;
    /** @hidden */
    private _updateFilters;
    /** @hidden */
    private openDataStream;
    /** @hidden */
    private toDataStream;
    /** @hidden */
    private _resetSourceStream;
    /** @hidden */
    private isValidOptions;
    private _getValidatorFunction;
    static ɵfac: i0.ɵɵFactoryDeclaration<PlatformValueHelpDialogComponent<any>, [null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PlatformValueHelpDialogComponent<any>, "fdp-value-help-dialog", never, { "id": { "alias": "id"; "required": false; }; "value": { "alias": "value"; "required": false; }; "dialogTitle": { "alias": "dialogTitle"; "required": false; }; "initialTab": { "alias": "initialTab"; "required": false; }; "tabs": { "alias": "tabs"; "required": false; }; "isOpenAdvanced": { "alias": "isOpenAdvanced"; "required": false; }; "dataSource": { "alias": "dataSource"; "required": false; }; "dialogConfig": { "alias": "dialogConfig"; "required": false; }; "uniqueKey": { "alias": "uniqueKey"; "required": false; }; "headerId": { "alias": "headerId"; "required": false; }; "tokenViewField": { "alias": "tokenViewField"; "required": false; }; "tokenizerFn": { "alias": "tokenizerFn"; "required": false; }; "mobile": { "alias": "mobile"; "required": false; }; "formatToken": { "alias": "formatToken"; "required": false; }; "conditionDisplayFn": { "alias": "conditionDisplayFn"; "required": false; }; "tokenValidator": { "alias": "tokenValidator"; "required": false; }; "searchSelection": { "alias": "searchSelection"; "required": false; }; "searchTablePageSize": { "alias": "searchTablePageSize"; "required": false; }; "searchTableMobileHeaders": { "alias": "searchTableMobileHeaders"; "required": false; }; "maxShownInitialFilters": { "alias": "maxShownInitialFilters"; "required": false; }; "loading": { "alias": "loading"; "required": false; }; "allowSelectAll": { "alias": "allowSelectAll"; "required": false; }; "defineStrategyLabels": { "alias": "defineStrategyLabels"; "required": false; }; "headingLevel": { "alias": "headingLevel"; "required": false; "isSignal": true; }; }, { "valueChange": "valueChange"; "onDataRequested": "onDataRequested"; "onDataReceived": "onDataReceived"; }, ["filters", "columnDef"], never, true, never>;
}
