import { AfterViewInit, OnDestroy } from '@angular/core';
import { VariantManagement } from '../../models/variant-management';
import * as i0 from "@angular/core";
/**
 * Wrapper component used to wrap components that implement `PresetManagedComponent`.
 * It automatically bounds existing presets from `Variant Management` component to `PresetManagedComponent`.
 * Wrapper component supports two ways of providing Variant Management component.
 * First one is to pass reference via Input property.
 * Second one is to put Variant Management component inside wrapper component so it would be accessible via @ContentChild.
 * Usage example:
 *
 * ```html
 *  Usage outside wrapper component:
 *  <fdp-variant-management #variantManagement [variants]="..."></fdp-variant-management>
 *  <fdp-variant-management-wrapper [variantManager]="variantManagement">
 *      <fdp-smart-filter-bar>...</fdp-smart-filter-bar>
 *      <fdp-table>...</fdp-table>
 *  </fdp-variant-management-wrapper>
 *
 *  Usage inside wrapper component:
 *  <fdp-variant-management-wrapper>
 *      <fdp-variant-management [variants]="..."></fdp-variant-management>
 *      <fdp-smart-filter-bar>...</fdp-smart-filter-bar>
 *      <fdp-table>...</fdp-table>
 *  </fdp-variant-management-wrapper>
 * ```
 */
export declare class VariantManagementWrapperComponent implements AfterViewInit, OnDestroy {
    /** Variant management component. */
    variantManager: VariantManagement;
    /** @hidden */
    private readonly _managedComponents;
    /** @hidden */
    private set _projectedVariantManager(value);
    private get _projectedVariantManager();
    /** @hidden */
    private get _variantManagement();
    /** @hidden */
    private _variantManager;
    /** @hidden */
    private _activeVariantSubscription;
    /** @hidden */
    private _componentsPresetChangeSubscription;
    /** @hidden */
    private _destroyRef;
    /** @hidden */
    ngAfterViewInit(): void;
    /** @hidden */
    ngOnDestroy(): void;
    /**
     * @hidden
     * Listens to the preset change in Variant Management component and applies new configuration across projected components..
     */
    private _setPresets;
    /**
     * @hidden
     * Listens to preset configuration changes in projected components and sends updated config to Variant Management component.
     */
    private _listenToPresetChanges;
    /** @hidden */
    private _getComponentPreset;
    static ɵfac: i0.ɵɵFactoryDeclaration<VariantManagementWrapperComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<VariantManagementWrapperComponent, "fdp-variant-management-wrapper", never, { "variantManager": { "alias": "variantManager"; "required": false; }; }, {}, ["_projectedVariantManager", "_managedComponents"], ["*"], true, never>;
}
