import { NewVariant, Variant, VariantAccess } from './models/variant.interface';
export declare class VariantItem<T = any> implements Variant<T> {
    /** Visibility of the variant. If public, available for everyone. */
    access: VariantAccess;
    /** Whether to automatically apply changes in preset managed component. */
    applyAutomatically?: boolean | undefined;
    /** Variant's author name. */
    createdBy: string;
    /** Variant data. Can contain any type of data. */
    data: T;
    /** Whether variant is marked as favourite. */
    favourite: boolean;
    /** Variant ID. */
    id: string;
    /** Whether to apply variant automatically. */
    isDefault: boolean;
    /** Variant name to be displayed in popover list. */
    name: string;
    /** Whether variant is editable. */
    readonly: boolean;
    /** @hidden */
    constructor(config: Partial<Variant>);
    /**
     * Clones current variant and applies new config on top of it.
     * @param newVariantData New config.
     * @param refreshId Whether to assign new ID to the new variant.
     */
    clone(newVariantData?: NewVariant, refreshId?: boolean): VariantItem;
}
