import { ChangeDetectorRef, EventEmitter } from '@angular/core';
import { Nullable } from '@fundamental-ngx/cdk/utils';
import { DialogService } from '@fundamental-ngx/core/dialog';
import { DynamicPage } from '@fundamental-ngx/core/dynamic-page';
import { PopoverComponent, TriggerConfig } from '@fundamental-ngx/core/popover';
import { HeaderSizes } from '@fundamental-ngx/core/title';
import { SearchInput } from '@fundamental-ngx/platform/search-field';
import { BehaviorSubject } from 'rxjs';
import { VariantManagementDirtyLabelDirective } from './directives/variant-management-dirty-label.directive';
import { VariantManagement } from './models/variant-management';
import { Variant } from './models/variant.interface';
import { VariantItem } from './variant-item.class';
import * as i0 from "@angular/core";
export declare class VariantManagementComponent<T = any> implements VariantManagement<T> {
    private readonly _dialogService;
    private readonly _cdr;
    /** Initial variants array. */
    set variants(items: Variant<T>[]);
    /** Header size. */
    headerSize: HeaderSizes;
    /** Popover trigger events. */
    popoverTriggers: (string | TriggerConfig)[];
    /** User's name which will be applied to all new variants user creates. */
    userName: string;
    /** Whether to display search field for variants list. */
    displaySearch: boolean;
    /** Whether the variant management component is in readonly mode. */
    readonly: boolean;
    /** Event emitted when variants data has been updated. */
    variantsChange: EventEmitter<Variant<T>[]>;
    /** Event emitted when new variant selected. */
    activeVariantChange: EventEmitter<Variant<T>>;
    /**
     * Custom dirty label directive.
     */
    dirtyLabel: VariantManagementDirtyLabelDirective;
    /** @hidden */
    _popover: PopoverComponent;
    /** @hidden */
    private readonly _initialClass;
    /**
     * Used internally for communicating with wrapper component.
     */
    activeVariantChangeSubject: BehaviorSubject<Variant<T> | null>;
    /** @hidden */
    _variantChanged: boolean;
    /** Selected variant. */
    activeVariant: VariantItem<T>;
    /** @hidden */
    _variants: VariantItem<T>[];
    /** @Hidden */
    _filterPhrase: Nullable<string>;
    /** @hidden */
    get _dynamicPage(): DynamicPage | null;
    /** @hidden */
    protected _dynamicPageCollapsed$: BehaviorSubject<boolean>;
    /** @hidden */
    protected _coreDynamicPage: DynamicPage | null;
    /** @hidden */
    protected _platformDynamicPage: import("@fundamental-ngx/platform/dynamic-page").PlatformDynamicPage | null;
    /** @Hidden */
    private _originalActiveVariant;
    /** @hidden */
    constructor(_dialogService: DialogService, _cdr: ChangeDetectorRef);
    /**
     * Manually select variant.
     * @param variant Variant to select.
     */
    selectVariant(variant: VariantItem<T>): void;
    /** Returns original variant data. */
    getOriginalActiveVariantData(): Variant<T>['data'];
    /** Returns current active variant data with applied changes. */
    getActiveVariantData(): Variant<T>['data'];
    /**
     * Saves current variant with its configuration.
     */
    saveCurrentVariant(): void;
    /** @hidden */
    _openSaveDialog(): void;
    /**
     * Updates current active preset with new configuration.
     * @param preset Preset configuration.
     * @param componentName component to which this preset belongs to.
     */
    updateActivePreset(preset: T, componentName: string): void;
    /** @hidden */
    _openManageDialog(): void;
    /** @hidden */
    _onSearchSubmit(search: SearchInput): void;
    /** @hidden */
    _cancelSearch(): void;
    /** @Hidden */
    _trackFn(index: number, item: VariantItem<T>): string;
    /** @hidden */
    private _transformVariants;
    static ɵfac: i0.ɵɵFactoryDeclaration<VariantManagementComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<VariantManagementComponent<any>, "fdp-variant-management", never, { "variants": { "alias": "variants"; "required": false; }; "headerSize": { "alias": "headerSize"; "required": false; }; "popoverTriggers": { "alias": "popoverTriggers"; "required": false; }; "userName": { "alias": "userName"; "required": false; }; "displaySearch": { "alias": "displaySearch"; "required": false; }; "readonly": { "alias": "readonly"; "required": false; }; }, { "variantsChange": "variantsChange"; "activeVariantChange": "activeVariantChange"; }, ["dirtyLabel"], never, true, never>;
    static ngAcceptInputType_displaySearch: unknown;
    static ngAcceptInputType_readonly: unknown;
}
