import { ChangeDetectorRef, DestroyRef, EventEmitter } from '@angular/core';
import { Observable } from 'rxjs';
import { Nullable } from '@fundamental-ngx/cdk/utils';
import { WizardStepStatus } from '@fundamental-ngx/core/wizard';
import { WizardGeneratorFormsValue, WizardStepSubmittedForms } from './interfaces/wizard-generator-forms.interface';
import { PreparedWizardGeneratorItem, WizardGeneratorItem } from './interfaces/wizard-generator-item.interface';
import { WizardNavigationButtons } from './interfaces/wizard-navigation-buttons.interface';
import { WizardGeneratorService } from './wizard-generator.service';
import * as i0 from "@angular/core";
/**
 * @description Default button labels.
 */
export declare const DEFAULT_WIZARD_NAVIGATION_BUTTONS: Required<WizardNavigationButtons>;
/**
 * @description Base Wizard Generator component with necessary inputs and methods.
 */
export declare class BaseWizardGenerator {
    /**
     * @description Whether or not apply responsive paddings styling.
     */
    responsivePaddings: boolean;
    /**
     * @description Button labels to be used in Wizard navigation
     */
    set navigationButtonLabels(value: WizardNavigationButtons);
    get navigationButtonLabels(): WizardNavigationButtons;
    /**
     * @description Array of Wizard Steps.
     */
    set items(items: WizardGeneratorItem[]);
    get items(): WizardGeneratorItem[];
    /**
     * Whether to append the step to the wizard. If false, each step will be displayed on a different page.
     * Default is true.
     */
    set appendToWizard(value: boolean);
    get appendToWizard(): boolean;
    /** If navigation buttons should be visible. */
    navigationButtons: boolean;
    /**
     * Custom height to use for the wizard's content pane. By default, this value is calc(100vh - 144px), where 144px
     * is the combined height of the shellbar, wizard header and wizard footer.
     */
    contentHeight: Nullable<string>;
    /**
     * @description Boolean flag indicating whether to display Summary step in Wizard progress bar.
     */
    displaySummaryStep: boolean;
    /** Whether all form items should have identical layout provided for form group. */
    unifiedLayout: boolean;
    /**
     * @description Emits wizard value when it's completed.
     */
    wizardFinished: EventEmitter<WizardGeneratorFormsValue>;
    /**
     * Flag indicating that wizard is ready to be shown
     */
    wizardCreated: boolean;
    /**
     * @description Is current step is summary step.
     */
    get isSummaryStep(): boolean;
    /**
     * @description Array of visible Wizard Steps.
     */
    set visibleItems(items: PreparedWizardGeneratorItem[]);
    get visibleItems(): PreparedWizardGeneratorItem[];
    /**
     * @description Whether or not Wizard is currently on the first step
     */
    get isFirstStep(): boolean;
    /**
     * @description Whether or not Wizard is currently on the last step
     */
    get isLastStep(): boolean;
    /**
     * Whether current step is a branching step.
     */
    get isBranchingStep(): boolean;
    /**
     * Whether the next step is a Summary step.
     */
    get isNextStepSummary(): boolean;
    /** Whether the current step is completed */
    get isCurrentStepCompleted(): boolean;
    /**
     * @hidden
     */
    _visibleItems: PreparedWizardGeneratorItem[];
    /** @hidden */
    _nextStepIndex: number;
    /** @hidden */
    _stepsOrderChanged: boolean;
    /**
     * @hidden
     */
    _navigationButtonLabels: Required<WizardNavigationButtons>;
    /**
     * @hidden
     */
    protected readonly _destroyRef: DestroyRef;
    /** @hidden */
    protected readonly _wizardGeneratorService: WizardGeneratorService;
    /** @hidden */
    protected readonly _cd: ChangeDetectorRef;
    /**
     * @hidden
     */
    private _items;
    /** @hidden */
    private _appendToWizard;
    /**
     * @hidden
     */
    private _formPending;
    /** @hidden */
    constructor();
    /**
     * @description Reverts Wizard progress one step back.
     */
    goBack(): void;
    /**
     * @description Progresses the Wizard one step further.
     */
    goNext(): Promise<void>;
    /**
     * @description Submits step forms.
     * @param currentStepIndex current step index.
     * @returns {Observable<WizardStepSubmittedForms | null>} Observable with form values.
     */
    submitStepForms(currentStepIndex?: string): Observable<WizardStepSubmittedForms | null>;
    /**
     * @description Completes the wizard and emits it's formatted value.
     */
    finish(): Promise<void>;
    /**
     * @description Callback function to update steps status.
     * @param stepId Step ID to be updated.
     * @param status New step status.
     */
    stepStatusChanged(stepId: string, status: WizardStepStatus): Promise<void>;
    /**
     * @hidden
     */
    private _setVisibleSteps;
    static ɵfac: i0.ɵɵFactoryDeclaration<BaseWizardGenerator, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<BaseWizardGenerator, never, never, { "responsivePaddings": { "alias": "responsivePaddings"; "required": false; }; "navigationButtonLabels": { "alias": "navigationButtonLabels"; "required": false; }; "items": { "alias": "items"; "required": false; }; "appendToWizard": { "alias": "appendToWizard"; "required": false; }; "navigationButtons": { "alias": "navigationButtons"; "required": false; }; "contentHeight": { "alias": "contentHeight"; "required": false; }; "displaySummaryStep": { "alias": "displaySummaryStep"; "required": false; }; "unifiedLayout": { "alias": "unifiedLayout"; "required": false; }; }, { "wizardFinished": "wizardFinished"; }, never, never, true, never>;
}
