import { TemplateRef } from '@angular/core';
import { DialogRef } from '@fundamental-ngx/core/dialog';
import { BaseWizardGenerator } from '../../base-wizard-generator';
import { WizardDialogData } from '../../interfaces/wizard-dialog-data.interface';
import { WizardTitle } from '../../interfaces/wizard-title.interface';
import * as i0 from "@angular/core";
export declare class DialogWizardGeneratorComponent extends BaseWizardGenerator {
    private _dialogRef;
    /** @hidden */
    defaultConfirmationDialogTemplate: TemplateRef<HTMLElement>;
    /**
     * @description Wizards dialog title configuration.
     */
    title: WizardTitle;
    /**
     * @description Confirmation message when wizard dialog close button has been clicked.
     */
    confirmationDialogText: string;
    /**
     * @description Confirm button text for close confirmation dialog.
     */
    confirmationDialogCloseText: string;
    /**
     * @description Cancel button text for close confirmation dialog.
     */
    confirmationDialogCancelText: string;
    /**
     * User-defined template for "Go Next" button.
     */
    goNextButtonTemplate?: TemplateRef<HTMLElement>;
    /**
     * User-defined template for "Go Back" button.
     */
    goBackButtonTemplate?: TemplateRef<HTMLElement>;
    /**
     * User-defined template for "Finish" button.
     */
    finishButtonTemplate?: TemplateRef<HTMLElement>;
    /**
     * User-defined template for "Cancel" button.
     */
    cancelButtonTemplate?: TemplateRef<HTMLElement>;
    /**
     * User-defined template for cancellation confirmation dialog.
     */
    confirmationDialogTemplate?: TemplateRef<HTMLElement>;
    /**
     * User-defined template for summary step.
     */
    summaryStepTemplate?: TemplateRef<HTMLElement>;
    /** User-defined template for "Review" button */
    reviewButtonTemplate?: TemplateRef<HTMLElement>;
    /** @hidden */
    private readonly _messageBoxService;
    /** @hidden */
    constructor(_dialogRef: DialogRef<WizardDialogData>);
    /**
     * @description Cancels Wizard progress and closes the dialog.
     */
    cancel(): void;
    /**
     * @description Completes Wizard process, emits Wizard result and closes the dialog.
     */
    finish(): Promise<void>;
    /**
     * @hidden
     */
    _goBackFn: () => void;
    /**
     * @hidden
     */
    _goNextFn: () => Promise<void>;
    /**
     * @hidden
     */
    _finishFn: () => Promise<void>;
    /**
     * @hidden
     */
    _cancelFn: () => void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DialogWizardGeneratorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DialogWizardGeneratorComponent, "fdp-dialog-wizard-generator", never, {}, {}, never, never, true, never>;
}
