import { ChangeDetectorRef, EventEmitter, OnInit, TemplateRef } from '@angular/core';
import { Nullable } from '@fundamental-ngx/cdk/utils';
import { WizardStepStatus } from '@fundamental-ngx/core/wizard';
import { PreparedWizardGeneratorItem, WizardGeneratorItem } from '../../interfaces/wizard-generator-item.interface';
import { WizardNavigationButtons } from '../../interfaces/wizard-navigation-buttons.interface';
import { WizardGeneratorService } from '../../wizard-generator.service';
import * as i0 from "@angular/core";
export interface WizardStepChange {
    id: string;
    status: WizardStepStatus;
}
export declare class WizardBodyComponent implements OnInit {
    private _wizardGeneratorService;
    private _cd;
    /**
     * @description Whether or not apply responsive paddings styling.
     */
    responsivePaddings: boolean;
    /**
     * @description Button labels to be used in Wizard navigation
     */
    navigationButtonLabels: Required<WizardNavigationButtons>;
    /**
     * @description Whether or not to append the step to the wizard. If false, each step will be displayed on a different page.
     * Default is true.
     */
    appendToWizard: boolean;
    /**
     * @description Custom height to use for the wizard's content pane. By default, this value is calc(100vh - 144px), where 144px
     * is the combined height of the Shellbar, wizard header and wizard footer.
     */
    contentHeight: Nullable<string>;
    /**
     * @description Whether or not Wizard is currently on the first step
     */
    isFirstStep: boolean;
    /**
     * @description Whether Wizard is currently on the last step.
     */
    isLastStep: boolean;
    /**
     * Whether next step is a Summary step.
     */
    isNextStepSummary: boolean;
    /**
     * @description Boolean flag indicating whether to display Summary step in Wizard progress bar.
     */
    displaySummaryStep: boolean;
    /**
     * User-defined template for "Go Next" button.
     */
    goNextButtonTemplate: TemplateRef<any>;
    /**
     * User-defined template for "Finish" button.
     */
    finishButtonTemplate: TemplateRef<any>;
    /**
     * User-defined template for summary step.
     */
    customSummaryStepTemplate?: TemplateRef<HTMLElement>;
    /** User-defined template for "Review" button */
    reviewButtonTemplate?: TemplateRef<HTMLElement>;
    /**
     * @description Is current step is summary step.
     */
    isSummaryStep: boolean;
    /** If navigation buttons should be visible. */
    navigationButtons: boolean;
    /** Whether or not all form items should have identical layout provided for form group. */
    unifiedLayout: boolean;
    /** Whether current step is a branching step. */
    isBranchingStep: boolean;
    /** Whether current step is completed */
    isCurrentStepCompleted: boolean;
    /** Whether order of steps was changed  */
    stepsOrderChanged: boolean;
    /**
     * @description Emits when some step status has been changed.
     */
    statusChange: EventEmitter<WizardStepChange>;
    /**
     * @description Emits when "Go next" button has been clicked
     */
    goNext: EventEmitter<void>;
    /**
     * @description Emits when "Finish" button has been clicked
     */
    finish: EventEmitter<void>;
    /**
     * @hidden
     * An RxJS Subject that will kill the data stream upon component’s destruction (for unsubscribing)
     */
    private readonly _destroyRef;
    /**
     * @hidden
     */
    private _visibleItems;
    /**
     * @description Array of visible Wizard Steps.
     */
    set visibleItems(items: PreparedWizardGeneratorItem[]);
    get visibleItems(): PreparedWizardGeneratorItem[];
    /** @hidden */
    constructor(_wizardGeneratorService: WizardGeneratorService, _cd: ChangeDetectorRef);
    /**
     * @hidden
     */
    _goNextFn: () => void;
    /**
     * @hidden
     */
    _finishFn: () => void;
    /**
     * @description Custom step status change validator function.
     * @param index Current step index.
     * @returns {Promise<boolean>} If this step status can be changed.
     */
    stepClickValidatorFn(index: number): () => Promise<boolean>;
    /**
     * @hidden
     */
    ngOnInit(): void;
    /**
     * @description Callback function for status change.
     * @param id step ID.
     * @param status new step status.
     */
    stepStatusChanged(id: string, status: WizardStepStatus): void;
    /** @hidden */
    stepClicked(stepId: string): void;
    /**
     * @hidden
     * @param _index
     * @param item
     * @returns
     */
    _trackFn(_index: number, item: WizardGeneratorItem): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<WizardBodyComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<WizardBodyComponent, "fdp-wizard-body", never, { "responsivePaddings": { "alias": "responsivePaddings"; "required": false; }; "navigationButtonLabels": { "alias": "navigationButtonLabels"; "required": false; }; "appendToWizard": { "alias": "appendToWizard"; "required": false; }; "contentHeight": { "alias": "contentHeight"; "required": false; }; "isFirstStep": { "alias": "isFirstStep"; "required": false; }; "isLastStep": { "alias": "isLastStep"; "required": false; }; "isNextStepSummary": { "alias": "isNextStepSummary"; "required": false; }; "displaySummaryStep": { "alias": "displaySummaryStep"; "required": false; }; "goNextButtonTemplate": { "alias": "goNextButtonTemplate"; "required": false; }; "finishButtonTemplate": { "alias": "finishButtonTemplate"; "required": false; }; "customSummaryStepTemplate": { "alias": "customSummaryStepTemplate"; "required": false; }; "reviewButtonTemplate": { "alias": "reviewButtonTemplate"; "required": false; }; "isSummaryStep": { "alias": "isSummaryStep"; "required": false; }; "navigationButtons": { "alias": "navigationButtons"; "required": false; }; "unifiedLayout": { "alias": "unifiedLayout"; "required": false; }; "isBranchingStep": { "alias": "isBranchingStep"; "required": false; }; "isCurrentStepCompleted": { "alias": "isCurrentStepCompleted"; "required": false; }; "stepsOrderChanged": { "alias": "stepsOrderChanged"; "required": false; }; }, { "statusChange": "statusChange"; "goNext": "goNext"; "finish": "finish"; }, never, never, true, never>;
}
