import { EventEmitter, OnChanges, OnDestroy, OnInit, QueryList, SimpleChanges } from '@angular/core';
import { WizardStepStatus } from '@fundamental-ngx/core/wizard';
import { DynamicFormGroup, DynamicFormValue, FormGeneratorComponent, FormGeneratorService, SubmitFormEventResult } from '@fundamental-ngx/platform/form';
import { Subject } from 'rxjs';
import { WizardStepForms, WizardStepSubmittedForms } from '../../interfaces/wizard-generator-forms.interface';
import { WizardGeneratorItem } from '../../interfaces/wizard-generator-item.interface';
import { WizardGeneratorStep } from '../../interfaces/wizard-step.interface';
import { WizardGeneratorService } from '../../wizard-generator.service';
import * as i0 from "@angular/core";
export declare class WizardGeneratorStepComponent implements WizardGeneratorStep, OnInit, OnDestroy, OnChanges {
    private _wizardGeneratorService;
    private _formGeneratorService;
    /**
     * @description Step Form Generator components.
     */
    formGenerators: QueryList<FormGeneratorComponent>;
    /**
     * @description Current step.
     */
    item: WizardGeneratorItem;
    /**
     * Wizard step status.
     */
    stepStatus: WizardStepStatus;
    /** Whether all form items should have identical layout provided for form group. */
    unifiedLayout: boolean;
    /**
     * @description Emits when all forms in the step has been submited
     */
    formsSubmitted: EventEmitter<DynamicFormValue[]>;
    /**
     * @description Emits when all forms in the step has been created
     */
    formsCreated: EventEmitter<WizardStepForms>;
    /**
     * @hidden
     */
    _visibleFormGroupIds: Record<string, boolean>;
    /**
     * @hidden
     */
    private _submittedForms;
    /**
     * @hidden
     */
    private _formSubmitted$;
    /**
     * @hidden
     */
    private _forms;
    /**
     * @hidden
     */
    private _trackedFields;
    /**
     * @hidden
     * @private
     */
    private _hiddenFormGroupValues;
    /**
     * @hidden
     * An RxJS Subject that will kill the data stream upon component’s destruction (for unsubscribing)
     */
    private readonly _destroyRef;
    /** @hidden */
    constructor(_wizardGeneratorService: WizardGeneratorService, _formGeneratorService: FormGeneratorService);
    /**
     * @hidden
     */
    ngOnInit(): Promise<void>;
    /**
     * @hidden
     */
    ngOnDestroy(): void;
    /** @hidden */
    ngOnChanges(changes: SimpleChanges): Promise<void>;
    /**
     * @description Adds created form instance to the object of the forms.
     * @param form Form instance
     * @param key Form ID from @see item
     */
    onFormCreated(form: DynamicFormGroup, key: string): Promise<void>;
    /**
     * @description Adds component to the service for further usage.
     */
    addComponentToParent(): Promise<void>;
    /**
     * @description Callback function when form has been submitted.
     * @param result Form submission result.
     * @param index Form index in the step.
     */
    onFormSubmitted(result: SubmitFormEventResult, index: string): void;
    /**
     * Returns visible forms in the step.
     */
    getVisibleForms(): WizardStepForms;
    /**
     * @description Clears previously submitted form values and re-submit them again.
     * @returns Subject, which will return forms value.
     */
    submitForms(skipIfUntouched?: boolean): Subject<WizardStepSubmittedForms | null>;
    /**
     * Triggers form value revalidation and checks if field in form should be visible.
     */
    updateFormsState(): Promise<void>;
    /**
     * Refreshes step form group visibility.
     */
    refreshFormsVisibility(): Promise<void>;
    /**
     * @hidden
     * @description Keeps track on dependency fields for other steps and refreshes the view when they changed.
     * @param form
     * @param key
     */
    private _trackDependencyFieldsChanges;
    static ɵfac: i0.ɵɵFactoryDeclaration<WizardGeneratorStepComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<WizardGeneratorStepComponent, "fdp-wizard-generator-step", never, { "item": { "alias": "item"; "required": false; }; "stepStatus": { "alias": "stepStatus"; "required": false; }; "unifiedLayout": { "alias": "unifiedLayout"; "required": false; }; }, { "formsSubmitted": "formsSubmitted"; "formsCreated": "formsCreated"; }, never, never, true, never>;
}
