import { ENTER, SPACE, TAB, DOWN_ARROW, UP_ARROW } from '@angular/cdk/keycodes';
import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Directive, EventEmitter, inject, ElementRef, HostListener, Input, ViewChild, Output, Optional, Inject, forwardRef, ChangeDetectionStrategy, Component, NgModule, ViewEncapsulation, ContentChildren, ContentChild } from '@angular/core';
import { KeyUtil, RepeatDirective } from '@fundamental-ngx/cdk/utils';
import { AsyncPipe, NgTemplateOutlet, NgClass } from '@angular/common';
import { FD_LIST_UNREAD_INDICATOR, ListItemComponent, ListLinkDirective, ListTitleDirective, ListSecondaryDirective, ListGroupHeaderDirective, ListComponent as ListComponent$1, ListThumbnailDirective } from '@fundamental-ngx/core/list';
import { CheckboxComponent } from '@fundamental-ngx/core/checkbox';
import { RadioButtonComponent } from '@fundamental-ngx/core/radio';
import { BaseComponent, isPresent, CollectionBaseInput, isDataSource, isBlank, ArrayListDataSource, ObservableListDataSource } from '@fundamental-ngx/platform/shared';
import { merge } from 'lodash-es';
import { RouterLink } from '@angular/router';
import * as i1 from '@angular/cdk/a11y';
import { FocusKeyManager } from '@angular/cdk/a11y';
import { SelectionModel } from '@angular/cdk/collections';
import { FD_FORM_FIELD_CONTROL } from '@fundamental-ngx/cdk/forms';
import * as i2 from 'rxjs';
import { Observable, BehaviorSubject, map, of, startWith, observeOn, asyncScheduler, isObservable, switchMap, filter, firstValueFrom } from 'rxjs';
import { tap, delay } from 'rxjs/operators';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { BusyIndicatorComponent } from '@fundamental-ngx/core/busy-indicator';
import { InfiniteScrollDirective } from '@fundamental-ngx/core/infinite-scroll';
import { SkeletonComponent } from '@fundamental-ngx/core/skeleton';
import { TranslationResolver, FD_LANGUAGE, FdTranslatePipe } from '@fundamental-ngx/i18n';
import { ContentDensityModule } from '@fundamental-ngx/core/content-density';
import { ObjectAttributeComponent } from '@fundamental-ngx/core/object-attribute';
import * as i1$1 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import { AvatarComponent } from '@fundamental-ngx/core/avatar';
import { ButtonComponent } from '@fundamental-ngx/core/button';
import { FormItemComponent } from '@fundamental-ngx/core/form';
import { ObjectIdentifierComponent } from '@fundamental-ngx/core/object-identifier';
import { ObjectNumberComponent } from '@fundamental-ngx/core/object-number';
import { IconComponent } from '@fundamental-ngx/core/icon';
import { ObjectStatusComponent } from '@fundamental-ngx/platform/object-status';

const FdpListComponent = new InjectionToken('List Component');

/**
 * Default options for platform List
 */
class ListConfig {
    constructor() {
        /**
         * Content Density of element. 'cozy' | 'compact'
         */
        this.contentDensity = 'cozy';
        /**
         * Maps data providers
         */
        this.providers = new Map();
    }
    /**
     * Create Provider factory function
     */
    static createProviderFactory(obj) {
        const useFactory = () => Object.assign(new ListConfig(), obj);
        return useFactory;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ListConfig, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ListConfig, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ListConfig, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }] });

const IS_ACTIVE_CLASS = 'is-active';
let nextListItemId = 0;
class ListIconConfig {
    constructor() {
        /** user's custom classes */
        this.class = '';
        /**
         * The icon font
         * Options include: 'SAP-icons', 'BusinessSuiteInAppSymbols' and 'SAP-icons-TNT'
         */
        this.font = 'SAP-icons';
    }
}
class ListAvatarConfig {
    constructor() {
        /** @hidden */
        this.class = '';
        /** @hidden */
        this.ariaLabel = null;
        /** @hidden */
        this.ariaLabelledby = null;
        /** @hidden */
        this.label = null;
        /** @hidden */
        this.size = 's';
        /** @hidden */
        this.glyph = null;
        /** @hidden */
        this.zoomGlyph = null;
        /** @hidden */
        this.circle = false;
        /** @hidden */
        this.transparent = false;
        /** @hidden */
        this.contain = false;
        /** @hidden */
        this.placeholder = false;
        /** @hidden */
        this.tile = false;
        /** @hidden */
        this.border = false;
        /** @hidden */
        this.colorAccent = null;
        /** @hidden */
        this.random = false;
        /** @hidden */
        this.clickable = false;
        /** @hidden */
        this.image = null;
        /** @hidden */
        this.alterIcon = null;
        /** @hidden */
        this.backupImage = null;
    }
}
var LIST_ITEM_TYPE;
(function (LIST_ITEM_TYPE) {
    LIST_ITEM_TYPE["ITEM"] = "item";
    LIST_ITEM_TYPE["GROUP"] = "group";
    LIST_ITEM_TYPE["FOOTER"] = "footer";
    LIST_ITEM_TYPE["HEADER"] = "header";
})(LIST_ITEM_TYPE || (LIST_ITEM_TYPE = {}));
class ModifyItemEvent {
}
// eslint-disable-next-line @angular-eslint/directive-class-suffix
class ListItemDef {
    /** @hidden */
    constructor(/** @docs-private */ templateRef) {
        this.templateRef = templateRef;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ListItemDef, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.7", type: ListItemDef, isStandalone: true, selector: "[fdpItemDef]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ListItemDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdpItemDef]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.TemplateRef }] });
/**
 * This class contains common properties used across list Item components.
 * this can be extended to reduce the code duplication across list Item components.
 */
class BaseListItem extends BaseComponent {
    /** Avatar component properties. @see AvatarComponent for more details */
    set avatar(value) {
        if (!value) {
            return;
        }
        value = typeof value === 'string' ? { image: value } : value;
        this._avatarConfig = merge(new ListAvatarConfig(), value);
    }
    get avatar() {
        return this._avatarConfig;
    }
    /**
     * List item icon configuration.
     */
    set icon(value) {
        this._iconConfig = merge(new ListIconConfig(), value);
    }
    get icon() {
        return this._iconConfig;
    }
    /**
     * Whether to display unread notification circle.
     */
    get displayUnreadNotification() {
        return !!this._list?.unreadIndicator;
    }
    /** By default selection mode is 'none' */
    set selectionMode(value) {
        this._selectionMode = value;
        this._setAttrRole();
    }
    get selectionMode() {
        return this._selectionMode;
    }
    /**
     * @hidden
     * Whether listitem has row level selection enabled
     */
    set rowSelection(value) {
        this._rowSelection = value;
        this._setAttrRole();
    }
    get rowSelection() {
        return this._rowSelection;
    }
    /** @hidden */
    get _selectedAttr() {
        return !this.rowSelection && this.selectionMode === 'none' ? null : this._selected;
    }
    /** @hidden */
    get _listItemRole() {
        return this.role || this._defaultRole;
    }
    /** @hidden */
    constructor(itemEl, _listConfig, _list) {
        super();
        this.itemEl = itemEl;
        this._listConfig = _listConfig;
        this._list = _list;
        /** ID of the list item */
        this.id = `fdp-list-item-${nextListItemId++}`;
        /** To invert the status of secondary text */
        this.inverted = false;
        /** By default selection mode is 'active' */
        this.listType = 'active';
        /**
         * Whether Navigation mode is included to list component
         * for all the items
         */
        this.navigated = false;
        /**
         * Whether Navigation mode is included to list component
         * only a subset of the list items are navigable
         * you should indicate those by displaying a navigation arrow
         */
        this.navigationIndicator = false;
        /**
         * event emitter for selected item
         * seprate PR for custom event
         */
        this.itemSelected = new EventEmitter();
        /**
         * Event emitted for selected item through the checkbox.
         */
        this.itemCheckboxSelected = new EventEmitter();
        /** Event sent when delete, details or any other action buttons are clicked */
        this.buttonClicked = new EventEmitter();
        /** @hidden */
        this._type = LIST_ITEM_TYPE.ITEM;
        /**
         * @hidden
         * Whether By line mode is included to list component, by which
         * list item will accomdate the data in 2 column
         */
        this._hasByLine = false;
        /**
         * @hidden
         * Whether listitem is selected binded to template
         */
        this._selected = false;
        /** @hidden */
        this._rowSelection = false;
        /** @hidden */
        this._defaultRole = 'listitem';
        /** @hidden */
        this._listComponent = inject(FdpListComponent);
        /** @hidden */
        this._avatarConfig = new ListAvatarConfig();
        /** @hidden */
        this._iconConfig = new ListIconConfig();
        /** @hidden */
        this._selectionMode = 'none';
    }
    /** Selection value */
    set selectionValue(value) {
        this._selected = false;
        this._selectionValue = value;
        if (this._selectionValue !== undefined && this.selectionValue !== null) {
            this._selected = this.value === this._selectionValue;
        }
    }
    get selectionValue() {
        return this._selectionValue;
    }
    /**
     * @hidden
     * On item click event will be emitted
     */
    _onItemClick() {
        if (this.rowSelection && this.selectionMode === 'multi') {
            this._selected = !this._selected;
        }
        const event = new ModifyItemEvent();
        event.source = this;
        this._focused = !this._focused;
        this.itemSelected.emit(event);
        this.markForCheck();
    }
    /** @hidden */
    _handleKeyboardEvent(event) {
        if (!KeyUtil.isKeyCode(event, [ENTER, SPACE])) {
            return;
        }
        if (this.checkboxComponent || this.radioButtonComponent) {
            this._onKeyboardClick(event);
        }
        this.anchor?.nativeElement.click();
        if (this.rowSelection) {
            this._selected = !this._selected;
        }
        const $event = new ModifyItemEvent();
        $event.source = this;
        this.itemSelected.emit($event);
        this.markForCheck();
    }
    /**
     * @hidden
     * Handler for mouse events
     */
    _onClick(event) {
        if (this.checkboxComponent && !this.anchor) {
            if (!this.checkboxComponent.elementRef.nativeElement.contains(event.target)) {
                // clicking on the checkbox is not suppressed
                // so we should only process clicks if clicked on the list-item, not checkbox itself
                this.checkboxComponent.nextValue();
            }
            this.radioButtonComponent?.valueChange(event);
        }
        this.markForCheck();
        const $event = new ModifyItemEvent();
        $event.source = this;
        this.itemSelected.emit($event);
    }
    /**
     * @hidden
     * helps to avoid multi rows active class with navigation
     */
    _onBlur(event) {
        if (isPresent(this.anchor) && !KeyUtil.isKeyCode(event, [ENTER, SPACE])) {
            this.anchor.nativeElement.classList.remove(IS_ACTIVE_CLASS);
        }
    }
    /** @hidden */
    ngOnDestroy() {
        super.ngOnDestroy();
        this.itemSelected.complete();
    }
    /** @hidden */
    ngAfterViewInit() {
        this._listComponent._setupListItem(this);
    }
    /**
     * @hidden
     * To detect changes from parent-listbox to list item
     * for example single, multi option selection those details
     * will be deducted in list item
     */
    ngAfterViewChecked() {
        const currentItem = this.itemEl.nativeElement.querySelector('.fd-list__item');
        if (!currentItem) {
            return;
        }
        const parentNode = currentItem.parentNode instanceof HTMLElement && currentItem.parentNode;
        if (parentNode) {
            parentNode.removeAttribute('title');
            parentNode.removeAttribute('aria-label');
        }
        this.detectChanges();
    }
    /**
     * @hidden
     * Created focus on list item on mouseclick,
     * Up,down arrow press
     */
    focus() {
        this.listItem.nativeElement.focus();
    }
    /**
     * Programmatically set selected state of the list item.
     * @param selected Whether the list item is selected
     */
    setSelected(selected) {
        if (selected === this._selected) {
            return;
        }
        const event = new ModifyItemEvent();
        event.source = this;
        this._selected = selected;
        this.detectChanges();
    }
    /**
     * @hidden
     * on keydown append active styles on actionable item
     */
    _onKeyDown(event) {
        if (isPresent(this.anchor) && KeyUtil.isKeyCode(event, [ENTER, SPACE])) {
            this.anchor.nativeElement.classList.add(IS_ACTIVE_CLASS);
        }
    }
    /**
     * @hidden
     * on keyup remove active styles from actionable item
     */
    _onKeyUp(event) {
        if (isPresent(this.anchor) && KeyUtil.isKeyCode(event, [ENTER, SPACE])) {
            this.anchor.nativeElement.classList.remove(IS_ACTIVE_CLASS);
        }
    }
    /** @hidden */
    _onCheckboxModelChange() {
        const event = new ModifyItemEvent();
        event.source = this;
        this.itemCheckboxSelected.emit(event);
    }
    /**
     * @hidden
     * Handles action button click
     */
    _onActionButtonClick(action) {
        const event = new ModifyItemEvent();
        event.source = this;
        event.action = action;
        this.buttonClicked.emit(event);
    }
    /**
     * @hidden
     * Handles action button click on key press
     */
    _onKeyButtonClick(event, action) {
        if (KeyUtil.isKeyCode(event, [ENTER, SPACE])) {
            this._onActionButtonClick(action);
        }
    }
    /** @hidden */
    _isAdvancedText(text) {
        return typeof text !== 'string' && !!text.text;
    }
    /** @hidden */
    _onKeyboardClick(event) {
        this.checkboxComponent?.nextValue();
        this.radioButtonComponent?.valueChange(event);
        this.markForCheck();
        const $event = new ModifyItemEvent();
        $event.source = this;
        this.itemSelected.emit($event);
    }
    /** @hidden */
    _setAttrRole() {
        this._defaultRole =
            this.rowSelection || this.selectionMode === 'single' || this.selectionMode === 'multi'
                ? 'option'
                : 'listitem';
        this.markForCheck();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: BaseListItem, deps: [{ token: i0.ElementRef }, { token: ListConfig }, { token: FD_LIST_UNREAD_INDICATOR, optional: true }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.7", type: BaseListItem, isStandalone: true, inputs: { id: "id", ariaLevel: "ariaLevel", ariaPosinset: "ariaPosinset", avatar: "avatar", counter: "counter", description: "description", inverted: "inverted", noDataText: "noDataText", statusType: "statusType", secondary: "secondary", secondaryWrap: "secondaryWrap", title: "title", link: "link", titleWrap: "titleWrap", icon: "icon", unRead: "unRead", value: "value", selectionMode: "selectionMode", listType: "listType", navigated: "navigated", navigationIndicator: "navigationIndicator", role: "role", selectionValue: "selectionValue" }, outputs: { itemSelected: "itemSelected", itemCheckboxSelected: "itemCheckboxSelected", buttonClicked: "buttonClicked" }, host: { listeners: { "click": "_onClick($event)", "keydown": "_handleKeyboardEvent($event)", "focusout": "_onBlur($event)" } }, viewQueries: [{ propertyName: "listItem", first: true, predicate: ["listItem"], descendants: true, read: ElementRef }, { propertyName: "anchor", first: true, predicate: ["linkElement"], descendants: true, read: ElementRef }, { propertyName: "edit", first: true, predicate: ["edit"], descendants: true, read: ElementRef }, { propertyName: "delete", first: true, predicate: ["delete"], descendants: true, read: ElementRef }, { propertyName: "checkboxComponent", first: true, predicate: CheckboxComponent, descendants: true }, { propertyName: "radioButtonComponent", first: true, predicate: RadioButtonComponent, descendants: true }], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: BaseListItem, decorators: [{
            type: Directive
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: ListConfig }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [FD_LIST_UNREAD_INDICATOR]
                }] }], propDecorators: { id: [{
                type: Input
            }], ariaLevel: [{
                type: Input
            }], ariaPosinset: [{
                type: Input
            }], avatar: [{
                type: Input
            }], counter: [{
                type: Input
            }], description: [{
                type: Input
            }], inverted: [{
                type: Input
            }], noDataText: [{
                type: Input
            }], statusType: [{
                type: Input
            }], secondary: [{
                type: Input
            }], secondaryWrap: [{
                type: Input
            }], title: [{
                type: Input
            }], link: [{
                type: Input
            }], titleWrap: [{
                type: Input
            }], icon: [{
                type: Input
            }], unRead: [{
                type: Input
            }], value: [{
                type: Input
            }], selectionMode: [{
                type: Input
            }], listType: [{
                type: Input
            }], navigated: [{
                type: Input
            }], navigationIndicator: [{
                type: Input
            }], role: [{
                type: Input
            }], itemSelected: [{
                type: Output
            }], itemCheckboxSelected: [{
                type: Output
            }], buttonClicked: [{
                type: Output
            }], listItem: [{
                type: ViewChild,
                args: ['listItem', { read: ElementRef }]
            }], anchor: [{
                type: ViewChild,
                args: ['linkElement', { read: ElementRef }]
            }], edit: [{
                type: ViewChild,
                args: ['edit', { read: ElementRef }]
            }], delete: [{
                type: ViewChild,
                args: ['delete', { read: ElementRef }]
            }], checkboxComponent: [{
                type: ViewChild,
                args: [CheckboxComponent]
            }], radioButtonComponent: [{
                type: ViewChild,
                args: [RadioButtonComponent]
            }], selectionValue: [{
                type: Input
            }], _onItemClick: [{
                type: HostListener,
                args: ['click']
            }], _handleKeyboardEvent: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }], _onClick: [{
                type: HostListener,
                args: ['click', ['$event']]
            }], _onBlur: [{
                type: HostListener,
                args: ['focusout', ['$event']]
            }] } });

class ActionChangeEvent {
}
class ActionListItemComponent extends BaseListItem {
    constructor() {
        super(...arguments);
        /** Event sent when action in clicked */
        this.actionClicked = new EventEmitter();
    }
    /**
     * @hidden
     * Handles action click
     */
    _onActionClick() {
        const event = new ActionChangeEvent();
        event.source = this;
        this.actionClicked.emit(event);
    }
    /**
     * @hidden
     * on keydown append active styles on actionable item
     */
    _onKeyDown(event) {
        if (KeyUtil.isKeyCode(event, [ENTER, SPACE])) {
            this.button.nativeElement.classList.add(IS_ACTIVE_CLASS);
        }
    }
    /**
     * @hidden
     * on keyup remove active styles from actionable item
     */
    _onKeyUp(event) {
        if (KeyUtil.isKeyCode(event, [ENTER, SPACE])) {
            this.button.nativeElement.classList.remove(IS_ACTIVE_CLASS);
            this._onActionClick();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ActionListItemComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: ActionListItemComponent, isStandalone: true, selector: "fdp-action-list-item", outputs: { actionClicked: "actionClicked" }, host: { attributes: { "role": "none" } }, providers: [{ provide: BaseListItem, useExisting: forwardRef(() => ActionListItemComponent) }], viewQueries: [{ propertyName: "button", first: true, predicate: ["action"], descendants: true, read: ElementRef }], usesInheritance: true, ngImport: i0, template: "<div\n    #listItem\n    fd-list-item\n    class=\"fd-list__item--action\"\n    [id]=\"id\"\n    [tabindex]=\"-1\"\n    (keydown)=\"_onKeyDown($event)\"\n    (keyup)=\"_onKeyUp($event)\"\n    [attr.aria-label]=\"ariaLabel\"\n    [attr.aria-level]=\"ariaLevel\"\n    [attr.aria-posinset]=\"ariaPosinset\"\n    [attr.aria-setsize]=\"ariaSetSize | async\"\n    [ariaRole]=\"_listItemRole\"\n    [attr.aria-selected]=\"_selectedAttr\"\n>\n    <button #action class=\"fd-list__title\" [attr.aria-label]=\"title\" [attr.title]=\"title\" (click)=\"_onActionClick()\">\n        {{ title }}\n    </button>\n</div>\n", dependencies: [{ kind: "component", type: ListItemComponent, selector: "[fdListItem] ,[fd-list-item]", inputs: ["selected", "noData", "action", "interactive", "growing", "counter", "unread", "byline", "ariaRole", "id", "preventClick"], outputs: ["keyDown"] }, { kind: "pipe", type: AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ActionListItemComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fdp-action-list-item', providers: [{ provide: BaseListItem, useExisting: forwardRef(() => ActionListItemComponent) }], changeDetection: ChangeDetectionStrategy.OnPush, host: {
                        role: 'none'
                    }, imports: [ListItemComponent, AsyncPipe], template: "<div\n    #listItem\n    fd-list-item\n    class=\"fd-list__item--action\"\n    [id]=\"id\"\n    [tabindex]=\"-1\"\n    (keydown)=\"_onKeyDown($event)\"\n    (keyup)=\"_onKeyUp($event)\"\n    [attr.aria-label]=\"ariaLabel\"\n    [attr.aria-level]=\"ariaLevel\"\n    [attr.aria-posinset]=\"ariaPosinset\"\n    [attr.aria-setsize]=\"ariaSetSize | async\"\n    [ariaRole]=\"_listItemRole\"\n    [attr.aria-selected]=\"_selectedAttr\"\n>\n    <button #action class=\"fd-list__title\" [attr.aria-label]=\"title\" [attr.title]=\"title\" (click)=\"_onActionClick()\">\n        {{ title }}\n    </button>\n</div>\n" }]
        }], propDecorators: { button: [{
                type: ViewChild,
                args: ['action', { read: ElementRef }]
            }], actionClicked: [{
                type: Output
            }] } });

class ActionListItemModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ActionListItemModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.0.7", ngImport: i0, type: ActionListItemModule, imports: [ActionListItemComponent], exports: [ActionListItemComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ActionListItemModule, imports: [ActionListItemComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ActionListItemModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [ActionListItemComponent],
                    exports: [ActionListItemComponent]
                }]
        }] });

class DisplayListItemComponent extends BaseListItem {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DisplayListItemComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.0.7", type: DisplayListItemComponent, isStandalone: true, selector: "fdp-display-list-item", host: { attributes: { "role": "none" } }, providers: [{ provide: BaseListItem, useExisting: forwardRef(() => DisplayListItemComponent) }], usesInheritance: true, ngImport: i0, template: "<!--  list item navigation with Arrow-->\n@if (navigationIndicator || (navigated && !(noDataText !== null && noDataText !== undefined))) {\n    <div\n        #listItem\n        fd-list-item\n        [id]=\"id\"\n        [selected]=\"_selected\"\n        [tabindex]=\"-1\"\n        (keydown)=\"_onKeyDown($event)\"\n        (keyup)=\"_onKeyUp($event)\"\n        class=\"fd-list__item--link\"\n        [class.fd-list__item--inactive]=\"listType === 'inactive'\"\n        [attr.aria-label]=\"ariaLabel\"\n        [attr.aria-level]=\"ariaLevel\"\n        [attr.aria-posinset]=\"ariaPosinset\"\n        [attr.aria-setsize]=\"ariaSetSize | async\"\n        [ariaRole]=\"_listItemRole\"\n        [attr.aria-selected]=\"_selectedAttr\"\n    >\n        <a\n            #linkElement\n            fd-list-link\n            [routerLink]=\"link\"\n            [navigationIndicator]=\"navigationIndicator\"\n            [navigated]=\"navigated\"\n        >\n            <ng-template [ngTemplateOutlet]=\"commonTemplate\"></ng-template>\n        </a>\n    </div>\n}\n<!--  list item without navigation and used for simple list display-->\n@if (!navigationIndicator && !navigated && !(noDataText !== null && noDataText !== undefined)) {\n    <div\n        #listItem\n        fd-list-item\n        [id]=\"id\"\n        [selected]=\"_selected\"\n        (keydown)=\"_onKeyDown($event)\"\n        [tabindex]=\"-1\"\n        (keyup)=\"_onKeyUp($event)\"\n        [attr.aria-label]=\"ariaLabel\"\n        [attr.aria-level]=\"ariaLevel\"\n        [attr.aria-posinset]=\"ariaPosinset\"\n        [attr.aria-setsize]=\"ariaSetSize | async\"\n        [class.fd-list__item--inactive]=\"listType === 'inactive'\"\n        [ariaRole]=\"_listItemRole\"\n        [attr.aria-selected]=\"_selectedAttr\"\n    >\n        <ng-template [ngTemplateOutlet]=\"commonTemplate\"></ng-template>\n    </div>\n}\n<ng-template #commonTemplate>\n    @if (title) {\n        <span fd-list-title [attr.aria-label]=\"title\" [attr.nowrap]=\"titleWrap\" [attr.title]=\"title\">{{ title }}</span>\n    }\n    @if (secondary) {\n        <ng-template\n            [ngTemplateOutlet]=\"_isAdvancedText(secondary) ? advancedSecondary : simpleSecondary\"\n            [ngTemplateOutletContext]=\"{ $implicit: secondary }\"\n        ></ng-template>\n    }\n</ng-template>\n<ng-template #simpleSecondary let-secondary>\n    <span fd-list-secondary [attr.aria-label]=\"secondary\" [attr.title]=\"secondary\" [attr.nowrap]=\"secondaryWrap\">\n        {{ secondary }}\n    </span>\n</ng-template>\n<ng-template #advancedSecondary let-secondary>\n    <span\n        fd-list-secondary\n        [attr.aria-label]=\"secondary.ariaLabel ?? secondary.text\"\n        [attr.title]=\"secondary.title ?? secondary.text\"\n        [attr.nowrap]=\"secondaryWrap\"\n    >\n        {{ secondary.text }}\n    </span>\n</ng-template>\n", dependencies: [{ kind: "component", type: ListItemComponent, selector: "[fdListItem] ,[fd-list-item]", inputs: ["selected", "noData", "action", "interactive", "growing", "counter", "unread", "byline", "ariaRole", "id", "preventClick"], outputs: ["keyDown"] }, { kind: "directive", type: ListLinkDirective, selector: "[fd-list-link], [fdListLink]", inputs: ["navigationIndicator", "navigated", "focusable"] }, { kind: "directive", type: RouterLink, selector: "[routerLink]", inputs: ["target", "queryParams", "fragment", "queryParamsHandling", "state", "info", "relativeTo", "preserveFragment", "skipLocationChange", "replaceUrl", "routerLink"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: ListTitleDirective, selector: "[fd-list-title], [fdListTitle]", inputs: ["wrap"] }, { kind: "directive", type: ListSecondaryDirective, selector: "[fd-list-secondary], [fdListSecondary]", inputs: ["type"] }, { kind: "pipe", type: AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DisplayListItemComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fdp-display-list-item', providers: [{ provide: BaseListItem, useExisting: forwardRef(() => DisplayListItemComponent) }], changeDetection: ChangeDetectionStrategy.OnPush, host: {
                        role: 'none'
                    }, imports: [
                        ListItemComponent,
                        ListLinkDirective,
                        RouterLink,
                        NgTemplateOutlet,
                        ListTitleDirective,
                        NgClass,
                        ListSecondaryDirective,
                        AsyncPipe
                    ], template: "<!--  list item navigation with Arrow-->\n@if (navigationIndicator || (navigated && !(noDataText !== null && noDataText !== undefined))) {\n    <div\n        #listItem\n        fd-list-item\n        [id]=\"id\"\n        [selected]=\"_selected\"\n        [tabindex]=\"-1\"\n        (keydown)=\"_onKeyDown($event)\"\n        (keyup)=\"_onKeyUp($event)\"\n        class=\"fd-list__item--link\"\n        [class.fd-list__item--inactive]=\"listType === 'inactive'\"\n        [attr.aria-label]=\"ariaLabel\"\n        [attr.aria-level]=\"ariaLevel\"\n        [attr.aria-posinset]=\"ariaPosinset\"\n        [attr.aria-setsize]=\"ariaSetSize | async\"\n        [ariaRole]=\"_listItemRole\"\n        [attr.aria-selected]=\"_selectedAttr\"\n    >\n        <a\n            #linkElement\n            fd-list-link\n            [routerLink]=\"link\"\n            [navigationIndicator]=\"navigationIndicator\"\n            [navigated]=\"navigated\"\n        >\n            <ng-template [ngTemplateOutlet]=\"commonTemplate\"></ng-template>\n        </a>\n    </div>\n}\n<!--  list item without navigation and used for simple list display-->\n@if (!navigationIndicator && !navigated && !(noDataText !== null && noDataText !== undefined)) {\n    <div\n        #listItem\n        fd-list-item\n        [id]=\"id\"\n        [selected]=\"_selected\"\n        (keydown)=\"_onKeyDown($event)\"\n        [tabindex]=\"-1\"\n        (keyup)=\"_onKeyUp($event)\"\n        [attr.aria-label]=\"ariaLabel\"\n        [attr.aria-level]=\"ariaLevel\"\n        [attr.aria-posinset]=\"ariaPosinset\"\n        [attr.aria-setsize]=\"ariaSetSize | async\"\n        [class.fd-list__item--inactive]=\"listType === 'inactive'\"\n        [ariaRole]=\"_listItemRole\"\n        [attr.aria-selected]=\"_selectedAttr\"\n    >\n        <ng-template [ngTemplateOutlet]=\"commonTemplate\"></ng-template>\n    </div>\n}\n<ng-template #commonTemplate>\n    @if (title) {\n        <span fd-list-title [attr.aria-label]=\"title\" [attr.nowrap]=\"titleWrap\" [attr.title]=\"title\">{{ title }}</span>\n    }\n    @if (secondary) {\n        <ng-template\n            [ngTemplateOutlet]=\"_isAdvancedText(secondary) ? advancedSecondary : simpleSecondary\"\n            [ngTemplateOutletContext]=\"{ $implicit: secondary }\"\n        ></ng-template>\n    }\n</ng-template>\n<ng-template #simpleSecondary let-secondary>\n    <span fd-list-secondary [attr.aria-label]=\"secondary\" [attr.title]=\"secondary\" [attr.nowrap]=\"secondaryWrap\">\n        {{ secondary }}\n    </span>\n</ng-template>\n<ng-template #advancedSecondary let-secondary>\n    <span\n        fd-list-secondary\n        [attr.aria-label]=\"secondary.ariaLabel ?? secondary.text\"\n        [attr.title]=\"secondary.title ?? secondary.text\"\n        [attr.nowrap]=\"secondaryWrap\"\n    >\n        {{ secondary.text }}\n    </span>\n</ng-template>\n" }]
        }] });

class DisplayListItemModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DisplayListItemModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.0.7", ngImport: i0, type: DisplayListItemModule, imports: [DisplayListItemComponent], exports: [DisplayListItemComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DisplayListItemModule, imports: [DisplayListItemComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: DisplayListItemModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [DisplayListItemComponent],
                    exports: [DisplayListItemComponent]
                }]
        }] });

class FreeContentListItemComponent extends BaseListItem {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: FreeContentListItemComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: FreeContentListItemComponent, isStandalone: true, selector: "fdp-free-content-list-item, li[fdp-free-content-list-item]", host: { attributes: { "role": "listitem" } }, providers: [{ provide: BaseListItem, useExisting: forwardRef(() => FreeContentListItemComponent) }], usesInheritance: true, ngImport: i0, template: "<div\n    #listItem\n    [class.fd-list__item--unread]=\"unRead\"\n    fd-list-item\n    [id]=\"id\"\n    [selected]=\"_selected\"\n    [tabindex]=\"-1\"\n    (click)=\"_onItemClick()\"\n    (keydown)=\"_onKeyDown($event)\"\n    (keyup)=\"_onKeyUp($event)\"\n    class=\"fd-list__item--link\"\n    [class.fd-list__item--inactive]=\"listType === 'inactive'\"\n    [attr.aria-label]=\"ariaLabel\"\n    [attr.aria-describedby]=\"ariaDescribedBy\"\n    [attr.aria-level]=\"ariaLevel\"\n    [attr.aria-posinset]=\"ariaPosinset\"\n    [attr.aria-setsize]=\"ariaSetSize | async\"\n    [ariaRole]=\"_listItemRole\"\n    [attr.aria-selected]=\"_selectedAttr\"\n>\n    <ng-content></ng-content>\n</div>\n", styles: [""], dependencies: [{ kind: "component", type: ListItemComponent, selector: "[fdListItem] ,[fd-list-item]", inputs: ["selected", "noData", "action", "interactive", "growing", "counter", "unread", "byline", "ariaRole", "id", "preventClick"], outputs: ["keyDown"] }, { kind: "pipe", type: AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: FreeContentListItemComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fdp-free-content-list-item, li[fdp-free-content-list-item]', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [{ provide: BaseListItem, useExisting: forwardRef(() => FreeContentListItemComponent) }], host: {
                        role: 'listitem'
                    }, imports: [ListItemComponent, AsyncPipe], template: "<div\n    #listItem\n    [class.fd-list__item--unread]=\"unRead\"\n    fd-list-item\n    [id]=\"id\"\n    [selected]=\"_selected\"\n    [tabindex]=\"-1\"\n    (click)=\"_onItemClick()\"\n    (keydown)=\"_onKeyDown($event)\"\n    (keyup)=\"_onKeyUp($event)\"\n    class=\"fd-list__item--link\"\n    [class.fd-list__item--inactive]=\"listType === 'inactive'\"\n    [attr.aria-label]=\"ariaLabel\"\n    [attr.aria-describedby]=\"ariaDescribedBy\"\n    [attr.aria-level]=\"ariaLevel\"\n    [attr.aria-posinset]=\"ariaPosinset\"\n    [attr.aria-setsize]=\"ariaSetSize | async\"\n    [ariaRole]=\"_listItemRole\"\n    [attr.aria-selected]=\"_selectedAttr\"\n>\n    <ng-content></ng-content>\n</div>\n" }]
        }] });

class ListFooterComponent extends BaseComponent {
    constructor() {
        super(...arguments);
        /** @hidden */
        this._type = LIST_ITEM_TYPE.FOOTER;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ListFooterComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: ListFooterComponent, isStandalone: true, selector: "fdp-list-footer", host: { attributes: { "role": "none" } }, usesInheritance: true, ngImport: i0, template: `<div #listFooter class="fd-list__footer" [attr.id]="id" role="option"><ng-content></ng-content></div>`, isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ListFooterComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fdp-list-footer',
                    template: `<div #listFooter class="fd-list__footer" [attr.id]="id" role="option"><ng-content></ng-content></div>`,
                    standalone: true,
                    host: {
                        role: 'none'
                    }
                }]
        }] });

let nextListGrpHeaderId = 0;
class ListGroupHeaderComponent extends BaseListItem {
    constructor() {
        super(...arguments);
        /** @hidden */
        this._type = LIST_ITEM_TYPE.HEADER;
    }
    /**
     * @hidden
     * Initialization of the list header component
     */
    ngOnInit() {
        this.id = `fdp-list-${nextListGrpHeaderId++}`;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ListGroupHeaderComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: ListGroupHeaderComponent, isStandalone: true, selector: "fdp-list-group-header", inputs: { groupHeaderTitle: "groupHeaderTitle" }, host: { attributes: { "role": "none" } }, providers: [{ provide: BaseListItem, useExisting: forwardRef(() => ListGroupHeaderComponent) }], usesInheritance: true, ngImport: i0, template: ` <div
        #listItem
        fd-list-group-header
        [attr.aria-labelledby]="ariaLabelledBy"
        [attr.aria-label]="ariaLabel"
        [attr.id]="id"
        role="group"
        [tabindex]="0"
    >
        <span fd-list-title>{{ groupHeaderTitle }}</span>
        <ng-content></ng-content>
    </div>`, isInline: true, dependencies: [{ kind: "directive", type: ListGroupHeaderDirective, selector: "[fdListGroupHeader], [fd-list-group-header]", inputs: ["nativeElementId"], outputs: ["keyDown"] }, { kind: "directive", type: ListTitleDirective, selector: "[fd-list-title], [fdListTitle]", inputs: ["wrap"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ListGroupHeaderComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'fdp-list-group-header',
                    template: ` <div
        #listItem
        fd-list-group-header
        [attr.aria-labelledby]="ariaLabelledBy"
        [attr.aria-label]="ariaLabel"
        [attr.id]="id"
        role="group"
        [tabindex]="0"
    >
        <span fd-list-title>{{ groupHeaderTitle }}</span>
        <ng-content></ng-content>
    </div>`,
                    providers: [{ provide: BaseListItem, useExisting: forwardRef(() => ListGroupHeaderComponent) }],
                    host: {
                        role: 'none'
                    },
                    imports: [ListGroupHeaderDirective, ListTitleDirective]
                }]
        }], propDecorators: { groupHeaderTitle: [{
                type: Input
            }] } });

class LoadMoreContentDirective {
    /** @hidden */
    constructor(templateRef) {
        this.templateRef = templateRef;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: LoadMoreContentDirective, deps: [{ token: i0.TemplateRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.7", type: LoadMoreContentDirective, isStandalone: true, selector: "[fdpListLoadMoreContent]", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: LoadMoreContentDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fdpListLoadMoreContent]',
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i0.TemplateRef }] });

class SelectionChangeEvent {
}
let nextListId = 0;
/**
 * The List component represents a container for list item types.
 * It is used to display a list features.
 */
class ListComponent extends CollectionBaseInput {
    /** setter and getter for radio button and checkbox. */
    set value(value) {
        super.setValue(value);
    }
    get value() {
        return super.getValue();
    }
    /** setter and getter for row level Selection. */
    set rowSelection(value) {
        this._rowSelection = value;
        if (this._rowSelection) {
            this.selection = true;
            this._ulElement?.classList.add('fd-list--selection-row');
            if (this.navigated && this.hasObject) {
                this._ulElement?.classList.remove('fd-list--selection-row');
            }
        }
    }
    get rowSelection() {
        return this._rowSelection;
    }
    /** Datasource for suggestion list. */
    set dataSource(value) {
        if (value) {
            this._initializeDS(value);
        }
    }
    get dataSource() {
        return this._dataSource;
    }
    /** setter and getter for _navigated. */
    set navigated(value) {
        this._navigated = value;
        const classList = ['fd-list--navigation'];
        if (this.hasObject) {
            classList.push('fd-list--navigation-object');
        }
        this._ulElement?.classList.add(...classList);
    }
    get navigated() {
        return this._navigated;
    }
    /** setter and getter for _navigationIndicator. */
    set navigationIndicator(value) {
        this._navigationIndicator = value;
        this._ulElement?.classList.add('fd-list--navigation-indication');
    }
    get navigationIndicator() {
        return this._navigationIndicator;
    }
    /** setter and getter for hasByLine. */
    set hasByLine(value) {
        this._hasByLine = value;
        this._ulElement?.classList.add('fd-list--byline');
    }
    get hasByLine() {
        return this._hasByLine;
    }
    /** setter and getter for hasObject. */
    set hasObject(value) {
        this._hasObject = value;
        this._ulElement?.classList.add('fd-object-list');
    }
    get hasObject() {
        return this._hasObject;
    }
    /** @hidden */
    get _ulElement() {
        return this.elementRef.nativeElement.querySelector('.fd-list');
    }
    /** @hidden */
    constructor(_liveAnnouncer, _language$) {
        super();
        this._liveAnnouncer = _liveAnnouncer;
        this._language$ = _language$;
        /** Label used on announce message of data was loaded for screen readers. */
        this.loadingLabel = '';
        /** Items to be loaded at once. Intinity (no limit) by default. */
        this.itemSize = Infinity;
        /** define the role to custom requirement. */
        this.role = 'list';
        /** ListType 'inactive' | 'active' | 'navigation' | 'detail' */
        this.listType = 'active';
        /** Whether list component has removed borders. */
        this.noBorder = false;
        /** Eenables selection styles. */
        this.selection = false;
        /**
         * The type of the selection. Types include:
         * 'none'| 'multi' | 'single'|'delete'.
         * Leave empty for default ().'
         * Default value is set to 'none'.
         */
        this.selectionMode = 'none';
        /** Whether to display unread notification indicator. */
        this.unreadIndicator = false;
        /** Whether to intercept tab key navigation. */
        this.interceptTabKey = true;
        /** Event thrown, when selected item is changed */
        this.selectedItemChange = new EventEmitter();
        /**
         * @hidden
         * To display loading symbol
         */
        this._loading = false;
        /** @hidden
         * To differentiate between first loading when skeletons be shown and subsequent loadings when busy indicator be shown
         */
        this._firstLoadingDone = false;
        /** @hidden */
        this._items = [];
        /** @hidden */
        this._ariaSetSize = new Observable();
        /**
         * @hidden
         * Verfies partial navigation enabled
         */
        this._partialNavigation = false;
        /** @hidden */
        this._translationResolver = new TranslationResolver();
        /**
         * @hidden
         * Whether list component has multiselection
         * binding in tempate to append class
         */
        this._multiSelect = false;
        /** @hidden To store */
        this._tempItems = [];
        /** @hidden */
        this._startIndex = 0;
        /** @hidden */
        this._lastIndex = this.itemSize;
        /** @hidden */
        this._dsItems = [];
        /** @hidden */
        this._afterViewInit$ = new BehaviorSubject(false);
        this._init();
    }
    /**
     * @hidden
     * on Update navgiation styles for non navigated items
     * event:any to avoid code duplication
     * seprate PR for custom event
     */
    _updateNavigation(event) {
        let selectedItemId = '0';
        const element = event.target instanceof HTMLElement ? event.target : null;
        const parent = element?.closest('.fd-list__item');
        if (isPresent(parent)) {
            selectedItemId = parent?.getAttribute('id');
        }
        this.listItems.forEach((item, index) => {
            item.anchor?.nativeElement.classList.remove('is-navigated');
            if (item._focused) {
                this._keyManager?.updateActiveItem(index);
            }
        });
        const el = event.target instanceof HTMLElement && event.target;
        if (!el) {
            return;
        }
        const linkElement = el.querySelector('a');
        if (el.tagName.toLowerCase() === 'a') {
            el.classList.add('is-navigated');
        }
        else if (el.classList.contains('fd-list__item') && !!linkElement) {
            linkElement.classList.add('is-navigated');
        }
        // TODO: selection management should be completely changed https://github.com/SAP/fundamental-ngx/issues/8008
        if (this.rowSelection) {
            this._handleRowSelect(selectedItemId);
        }
        else if (this.selectionMode === 'single') {
            this._handleSingleSelect(event, selectedItemId);
        }
        else if (this.selectionMode === 'multi') {
            this._handleMultiSelect(selectedItemId);
        }
    }
    /** Get context for load more button */
    getLoadMoreContentContext() {
        const $implicit = {
            loadTitle: this.loadTitle,
            loading: this._loading,
            loadingLabel: (() => {
                if (this._loading) {
                    return this._language$.pipe(map((language) => this._translationResolver.resolve(language, 'platformList.loadingAriaLabel')));
                }
                return of(this.loadingLabel);
            })(),
            lastChunk: {
                start: this._startIndex,
                end: this._lastIndex
            },
            total: this._dsItems.length
        };
        return {
            $implicit,
            ...$implicit
        };
    }
    /**
     * @hidden
     * Initialization of the lis component with selection mode
     */
    ngOnInit() {
        this._setItems();
        this.stateChanges.next(this._items);
        this.id = `fdp-list-${nextListId++}`;
        // using selection Model for multiselect
        if (this.selectionMode === 'multi') {
            this._multiSelect = true;
            this.ariaMultiselectable = true;
        }
        else {
            this._multiSelect = false;
        }
        this._selectionModel = new SelectionModel(this._multiSelect, this.selectedItems);
        this._selectionModel.changed.pipe(takeUntilDestroyed(this._destroyed)).subscribe(() => {
            this.selectedItems = this._selectionModel.selected;
            const event = new SelectionChangeEvent();
            event.selectedItems = this.selectedItems;
            this.stateChanges.next(event);
            this.selectedItemChange.emit(event);
        });
    }
    /**
     * @hidden
     * Keyboard manager on list items, set values when passed via array
     */
    ngAfterViewInit() {
        this._afterViewInit$.next(true);
        this._keyManager = new FocusKeyManager(this.listItems).withWrap();
        this._subscriptions.add(this.listItems.changes
            .pipe(startWith(this.listItems), observeOn(asyncScheduler))
            .subscribe(() => this._updateListItems()));
        const indicator = this.elementRef.nativeElement.querySelector('fd-busy-indicator');
        indicator?.setAttribute('aria-label', '');
    }
    /** @hidden */
    ngOnDestroy() {
        super.ngOnDestroy();
        if (isDataSource(this.dataSource)) {
            this.dataSource.close();
        }
        this._dsSubscription?.unsubscribe();
        this._keyManager?.destroy();
    }
    /**
     * @hidden
     * handline keyboard operations
     * in template on list and list items
     */
    _handleKeyDown(event) {
        if (!this._keyManager) {
            return;
        }
        if (KeyUtil.isKeyCode(event, TAB) && !this.interceptTabKey) {
            return;
        }
        event.stopImmediatePropagation();
        if (KeyUtil.isKeyCode(event, DOWN_ARROW) || KeyUtil.isKeyCode(event, UP_ARROW)) {
            return false;
        }
        else if (KeyUtil.isKeyCode(event, ENTER) || KeyUtil.isKeyCode(event, SPACE)) {
            this._updateNavigation(event);
            return false;
        }
    }
    /** @hidden */
    _setCurrentActiveItemIndex(activeItemIndex) {
        this._keyManager?.setActiveItem(activeItemIndex);
    }
    /**
     * @hidden
     * binded in template on scroll
     */
    _scrollHandler() {
        if (!this._loading && this.loadOnScroll) {
            this._getMoreData();
        }
    }
    /**
     * @hidden
     * show more on enter or space press
     */
    _loadOnKeyPress(event) {
        if (KeyUtil.isKeyCode(event, [ENTER, SPACE])) {
            this._getMoreData();
        }
    }
    /**
     * @hidden
     * Handles lazy loading data
     * used in template
     * onscroll and on more button click
     */
    _getMoreData() {
        this._loading = true;
        of(this._loadNewItems())
            .pipe(tap(async (data) => {
            if (isBlank(data)) {
                console.error('===Invalid Response received===');
            }
            this.loadingLabel = this._translationResolver.resolve(this._language, 'platformList.loadingAriaLabel');
            await this._liveAnnouncer.announce(this.loadingLabel, 'assertive');
        }), delay(this.delayTime), takeUntilDestroyed(this._destroyed))
            .subscribe((result) => {
            if (isPresent(result)) {
                for (let i = this._items.length, j = 0; j < result.length; ++i, ++j) {
                    this._items[i] = result[j];
                }
            }
            this._loading = false;
            this.stateChanges.next(this._items);
            this.markForCheck();
        });
    }
    /**
     * @hidden
     * used in tempate to get Selected items from a list
     * event:any to avoid code duplication
     */
    _onSelectionChanged(event) {
        this._updateNavigation(event);
    }
    /** @hidden */
    _setupListItem(item) {
        item.selectionMode = this.selectionMode;
        item.rowSelection = this.rowSelection;
        item._hasByLine = this.hasByLine;
        item.itemSelected.subscribe(() => {
            this._keyManager?.setActiveItem(this.listItems.toArray().indexOf(item));
        });
        this.stateChanges.next(item);
    }
    /** @hidden */
    _selectItem(item) {
        this._selectionModel.select(item);
        this.stateChanges.next(item);
    }
    /** @hidden */
    _setItems() {
        if (this._dsItems.length !== null && this.itemSize !== 0) {
            this._startIndex = 0;
            this._lastIndex = this.itemSize;
            this._items = this._dsItems.slice(this._startIndex, this._lastIndex);
        }
        else {
            this._items = this._dsItems;
        }
        this.stateChanges.next(this._items);
    }
    /** @hidden */
    _initializeDS(ds) {
        this._dsItems = [];
        if (isDataSource(this.dataSource)) {
            this.dataSource.close();
            if (this._dsSubscription) {
                this._dsSubscription.unsubscribe();
                this._dsSubscription = null;
            }
        }
        // Convert ListDataSource<T> | Observable<T[]> | T[] as DataSource
        this._dataSource = this._openDataStream(ds);
    }
    /** @hidden */
    _toDataStream(source) {
        if (isDataSource(source)) {
            return source;
        }
        if (Array.isArray(source)) {
            // default implementation to work on top of arrays
            return new ArrayListDataSource(source);
        }
        if (isObservable(source)) {
            return new ObservableListDataSource(source);
        }
        return undefined;
    }
    /** @hidden */
    _openDataStream(ds) {
        const initDataSource = this._toDataStream(ds);
        if (initDataSource === undefined) {
            throw new Error(`[dataSource] source did not match an array, Observable, or DataSource`);
        }
        /**
         * This is single point of data entry to the component. We dont want to set data on different
         * places. If any new data comes in either you do a search and you want to pass initial data
         * its here.
         */
        this._dsSubscription = initDataSource
            .open()
            .pipe(
        // Set new items when component is fully initiated and all child components are available.
        this._waitForViewInit(), takeUntilDestroyed(this._destroyed))
            .subscribe((data) => {
            this._dsItems = data || [];
            this.stateChanges.next(this._dsItems);
            this._setItems();
            // Trigger change detection when queue is empty.
            setTimeout(() => {
                this.detectChanges();
            });
        });
        this._dsSubscription.add(initDataSource.onDataRequested().subscribe(() => (this._loading = true)));
        this._dsSubscription.add(initDataSource.onDataReceived().subscribe(() => {
            this._loading = false;
            this._firstLoadingDone = true;
        }));
        const matchParams = new Map();
        matchParams.set('query', '*');
        matchParams.set('limit', this.itemSize);
        // initial data fetch
        initDataSource.match(matchParams);
        return initDataSource;
    }
    /** @hidden */
    _loadNewItems() {
        this._startIndex = this._startIndex + this.itemSize;
        this._lastIndex = this._lastIndex + this.itemSize;
        this._tempItems = this._dsItems.slice(this._startIndex, this._lastIndex);
        return this._tempItems;
    }
    /**
     * @hidden
     * List item with radio button styles, check, uncheckupdates
     * event:any to avoid code duplication
     */
    _handleSingleSelect(event, selectedItemId) {
        const parent = event.target instanceof HTMLElement && event.target.closest('.fd-list__item');
        const radio = parent ? parent.querySelector('input') : null;
        this._selectedvalue = radio ? radio.value : null;
        this.listItems.forEach((item) => {
            if (isPresent(item.radioButtonComponent)) {
                item._selected = false;
                item.listItem.nativeElement.setAttribute('aria-checked', 'false');
            }
            this.stateChanges.next(item);
        });
        this._selectionModel.clear();
        this.listItems.forEach((item) => {
            item.selectionValue = this._selectedvalue;
            const { nativeElement } = item.listItem;
            if (nativeElement.getAttribute('id') === selectedItemId) {
                nativeElement.setAttribute('_selected', 'true');
                nativeElement.setAttribute('aria-checked', 'true');
                this._selectItem(item);
            }
        });
    }
    /** @hidden */
    _handleRowSelect(selectedItemId) {
        // handles mutli select on row level without checkbox
        if (this.selectionMode === 'multi') {
            this.listItems.forEach((item) => {
                if (item._selected) {
                    this._selectionModel.select(item);
                }
                else {
                    this._selectionModel.deselect(item);
                }
                this.stateChanges.next(item);
            });
        }
        // handles single select on row level without radiobutton
        if (this.selectionMode === 'single') {
            this.listItems.forEach((item) => {
                if (!item.anchor) {
                    return;
                }
                const { nativeElement } = item.listItem;
                nativeElement.setAttribute('_selected', 'false');
                nativeElement.setAttribute('aria-selected', 'false');
                nativeElement.classList.remove('is-selected');
                item.anchor.nativeElement.classList.remove('is-selected');
                this.stateChanges.next(item);
            });
            this._selectionModel.clear();
            this.listItems.forEach((item) => {
                const { nativeElement } = item.listItem;
                if (nativeElement.getAttribute('id') !== selectedItemId) {
                    return;
                }
                nativeElement.setAttribute('_selected', 'true');
                item.anchor?.nativeElement.classList.add('is-selected');
                this._selectItem(item);
            });
            selectedItemId = '0';
        }
    }
    /**
     * @hidden
     * List item with checkbox styles,check,uncheckupdates
     * event:any to avoid code duplication
     */
    _handleMultiSelect(selectedItemId) {
        this.listItems.forEach((item) => {
            const { nativeElement } = item.listItem;
            if (nativeElement.getAttribute('id') !== selectedItemId) {
                return;
            }
            const select = nativeElement.getAttribute('_selected');
            nativeElement.setAttribute('_selected', `${!select}`);
            if (item._selected) {
                nativeElement.setAttribute('aria-selected', 'true');
                this._selectionModel.select(item);
            }
            else {
                nativeElement.setAttribute('aria-selected', 'false');
                this._selectionModel.deselect(item);
            }
            this.stateChanges.next(item);
        });
    }
    /**
     * @hidden
     * Setting values from list to list items
     * example:
     * Does list item has navigation,
     * should show arrows,
     * will it be compact mode,
     * should be in which selection mode
     * set values when passed via datasource
     */
    _updateListItems() {
        if (this.listItems.length !== 0) {
            this.listItems.first.listItem.nativeElement.setAttribute('tabindex', '0');
        }
        this._ariaSetSize = this.ariaSetsize
            ? of(this.ariaSetsize)
            : this._dataSource && this._dataSource.dataProvider?.getTotalItems
                ? this._dataSource.dataProvider.getTotalItems()
                : of(this.listItems.length);
        this._partialNavigation = this.listItems.some((item) => item.navigationIndicator || item.listType === 'detail');
        let currentGroup = null;
        let currentGroupItemIds = [];
        // Since we cannot use index from the iteration due to possible group item existence, we need to track it manually.
        let itemIndex = 0;
        this.listItems.forEach((item) => {
            if (!this._partialNavigation) {
                item.navigated = this.navigated;
                item.navigationIndicator = this.navigationIndicator;
                item.listType = this.listType;
            }
            if (item._type === LIST_ITEM_TYPE.HEADER) {
                currentGroup?.listItem.nativeElement.setAttribute('aria-owns', currentGroupItemIds.join(' '));
                currentGroupItemIds = [];
                currentGroup = item;
                return;
            }
            if (item._type !== LIST_ITEM_TYPE.ITEM) {
                return;
            }
            item.ariaSetSize = this._ariaSetSize;
            item.ariaPosinset = ++itemIndex;
            if (currentGroup) {
                currentGroupItemIds.push(item.listItem.nativeElement.id);
            }
            if (item === this.listItems.last) {
                currentGroup?.listItem.nativeElement.setAttribute('aria-owns', currentGroupItemIds.join(' '));
            }
        });
        this.markForCheck();
    }
    /** @hidden */
    _waitForViewInit() {
        return (source) => source.pipe(switchMap((src) => this._afterViewInit$.pipe(filter((afterViewInit) => afterViewInit), map(() => src))));
    }
    /** @hidden */
    async _init() {
        this._language = await firstValueFrom(this._language$);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ListComponent, deps: [{ token: i1.LiveAnnouncer }, { token: FD_LANGUAGE }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.0.7", type: ListComponent, isStandalone: true, selector: "fdp-list", inputs: { selectedItems: "selectedItems", ariaSetsize: "ariaSetsize", ariaMultiselectable: "ariaMultiselectable", loadTitle: "loadTitle", loadingLabel: "loadingLabel", delayTime: "delayTime", itemSize: "itemSize", loadMore: "loadMore", loadOnScroll: "loadOnScroll", role: "role", listType: "listType", maxHeight: "maxHeight", noBorder: "noBorder", scrollOffsetPercentage: "scrollOffsetPercentage", selection: "selection", selectionMode: "selectionMode", value: "value", rowSelection: "rowSelection", dataSource: "dataSource", navigated: "navigated", navigationIndicator: "navigationIndicator", hasByLine: "hasByLine", hasObject: "hasObject", unreadIndicator: "unreadIndicator", interceptTabKey: "interceptTabKey" }, outputs: { selectedItemChange: "selectedItemChange" }, host: { listeners: { "click": "_updateNavigation($event)" }, properties: { "attr.tabindex": "-1" } }, providers: [
            { provide: FD_FORM_FIELD_CONTROL, useExisting: ListComponent, multi: true },
            { provide: FdpListComponent, useExisting: ListComponent },
            {
                provide: FD_LIST_UNREAD_INDICATOR,
                useExisting: ListComponent
            }
        ], queries: [{ propertyName: "listItemDef", first: true, predicate: i0.forwardRef(() => ListItemDef), descendants: true }, { propertyName: "loadMoreContent", first: true, predicate: LoadMoreContentDirective, descendants: true }, { propertyName: "listItems", predicate: i0.forwardRef(() => BaseListItem), descendants: true }], viewQueries: [{ propertyName: "anchor", first: true, predicate: ["link"], descendants: true, read: ElementRef }], usesInheritance: true, ngImport: i0, template: "<ng-content select=\"fd-toolbar\"></ng-content>\n<div\n    fd-list\n    [attr.id]=\"id\"\n    [noBorder]=\"noBorder\"\n    [selection]=\"selection\"\n    [byline]=\"hasByLine\"\n    [class.fd-list--navigation]=\"navigated || navigationIndicator\"\n    [navigationIndicator]=\"navigationIndicator\"\n    [style.outline]=\"'none'\"\n    (keydown)=\"_keyManager?.onKeydown($event); _handleKeyDown($event)\"\n    (change)=\"_onSelectionChanged($event)\"\n    [attr.aria-setsize]=\"_ariaSetSize | async\"\n    [attr.aria-label]=\"ariaLabel\"\n    [attr.aria-labelledby]=\"ariaLabelledBy\"\n    [attr.aria-multiselectable]=\"ariaMultiselectable\"\n    [role]=\"role\"\n    [unreadIndicator]=\"unreadIndicator\"\n>\n    @if (loadMore && loadOnScroll) {\n        <fd-busy-indicator\n            size=\"l\"\n            class=\"fd-busy-indicator-custom fd-list__item--growing\"\n            [block]=\"true\"\n            [loading]=\"_loading && _firstLoadingDone\"\n            role=\"alert\"\n            [attr.aria-busy]=\"_loading\"\n            [attr.aria-label]=\"_loading ? ('platformList.loadingAriaLabel' | fdTranslate) : null\"\n        >\n            <div\n                fd-list\n                fdInfiniteScroll\n                class=\"fd-list__infinite-scroll\"\n                [style.max-height]=\"maxHeight\"\n                (onScrollAction)=\"_scrollHandler()\"\n                [scrollPercent]=\"scrollOffsetPercentage\"\n                [role]=\"role\"\n            >\n                @if (_items.length !== 0) {\n                    @for (item of _items; track item; let i = $index) {\n                        <ng-template\n                            [ngTemplateOutlet]=\"listItemDef.templateRef\"\n                            [ngTemplateOutletContext]=\"{ $implicit: item }\"\n                        >\n                        </ng-template>\n                    }\n                } @else {\n                    @if (!listItems.length && !_firstLoadingDone) {\n                        @if (!hasByLine) {\n                            <li fd-list-item *fdkRepeat=\"3\">\n                                <fd-skeleton\n                                    [style.margin]=\"'auto 0'\"\n                                    type=\"text\"\n                                    textLines=\"1\"\n                                    width=\"40%\"\n                                ></fd-skeleton>\n                            </li>\n                        } @else {\n                            <li fd-list-item *fdkRepeat=\"3\">\n                                <fd-skeleton width=\"100%\" height=\"48px\" [style.margin]=\"'auto 0'\">\n                                    <svg:rect x=\"0\" y=\"0\" width=\"48\" height=\"48\" rx=\"4\" />\n                                    <svg:rect x=\"60\" y=\"0\" width=\"40%\" height=\"12\" rx=\"4\" />\n                                    <svg:rect x=\"60\" y=\"20\" width=\"30%\" height=\"8\" rx=\"4\" />\n                                </fd-skeleton>\n                            </li>\n                        }\n                    }\n                    <ng-content></ng-content>\n                }\n            </div>\n        </fd-busy-indicator>\n    }\n    @if (!loadOnScroll) {\n        @if (_items.length !== 0) {\n            @for (item of _items; track item; let i = $index) {\n                <ng-template\n                    [ngTemplateOutlet]=\"listItemDef.templateRef\"\n                    [ngTemplateOutletContext]=\"{ $implicit: item }\"\n                >\n                </ng-template>\n            }\n        } @else {\n            @if (!listItems.length && !_firstLoadingDone) {\n                @if (!hasByLine) {\n                    <li fd-list-item *fdkRepeat=\"3\">\n                        <fd-skeleton [style.margin]=\"'auto 0'\" type=\"text\" textLines=\"1\" width=\"40%\"></fd-skeleton>\n                    </li>\n                } @else {\n                    <li fd-list-item *fdkRepeat=\"3\">\n                        <fd-skeleton width=\"100%\" height=\"48px\" [style.margin]=\"'auto 0'\">\n                            <svg:rect x=\"0\" y=\"0\" width=\"48\" height=\"48\" rx=\"4\" />\n                            <svg:rect x=\"60\" y=\"0\" width=\"40%\" height=\"12\" rx=\"4\" />\n                            <svg:rect x=\"60\" y=\"20\" width=\"30%\" height=\"8\" rx=\"4\" />\n                        </fd-skeleton>\n                    </li>\n                }\n            }\n            <ng-content></ng-content>\n        }\n        @if (loadMore && !loadOnScroll && _firstLoadingDone) {\n            <li\n                #listItem\n                (click)=\"_getMoreData()\"\n                fd-list-item\n                (keydown)=\"_loadOnKeyPress($event)\"\n                [class.fd-list__item--custom-content]=\"loadMoreContent\"\n                class=\"fd-list__item fd-list__item--growing fd-list__item--action\"\n                [tabindex]=\"0\"\n                role=\"button\"\n            >\n                <ng-template [ngTemplateOutlet]=\"loadMoreElementContent\"></ng-template>\n            </li>\n        }\n    }\n    <ng-template #loadMoreElementContent>\n        @if (loadMoreContent) {\n            <div class=\"fd-list__title\">\n                <ng-template\n                    [ngTemplateOutlet]=\"loadMoreContent.templateRef\"\n                    [ngTemplateOutletContext]=\"getLoadMoreContentContext()\"\n                >\n                </ng-template>\n            </div>\n        } @else {\n            <button class=\"fd-list__title\">\n                <fd-busy-indicator\n                    size=\"m\"\n                    class=\"fd-busy-indicator-custom\"\n                    [block]=\"true\"\n                    [loading]=\"_loading\"\n                    role=\"alert\"\n                    [attr.aria-label]=\"_loading ? ('platformList.loadingAriaLabel' | fdTranslate) : loadTitle\"\n                >\n                </fd-busy-indicator>\n                {{ loadTitle }}\n                <ng-content select=\"#load\"></ng-content>\n            </button>\n        }\n    </ng-template>\n</div>\n", styles: [".fd-list{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;list-style:none;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative;width:100%}.fd-list:after,.fd-list:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__footer,.fd-list__group-header,.fd-list__item{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;padding-block:0;padding-inline:.9375rem}.fd-list__footer:after,.fd-list__footer:before,.fd-list__group-header:after,.fd-list__group-header:before,.fd-list__item:after,.fd-list__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__item{background:var(--fdList_Item_Background_Color);border-bottom:var(--sapList_BorderWidth) solid var(--fdList_Item_Border_Color);height:var(--fdList_Item_Height);position:relative}.fd-list__item.is-focus,.fd-list__item:focus{outline:none;pointer-events:all}.fd-list__item.is-focus:before,.fd-list__item:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem .125rem .0625rem;pointer-events:none;position:absolute}.fd-list__item.is-focus.is-active:before,.fd-list__item.is-focus:active:before,.fd-list__item:focus.is-active:before,.fd-list__item:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-list__item--unread .fd-list__title{font-weight:700}.fd-list__item--no-data .fd-list__title{text-align:center}.fd-list__item--interactive.is-hover,.fd-list__item--interactive:hover,.fd-list__item--interractive.is-hover,.fd-list__item--interractive:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__item--interactive.is-selected,.fd-list__item--interactive[aria-selected=true],.fd-list__item--interractive.is-selected,.fd-list__item--interractive[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item--interactive.is-selected .fd-list__link,.fd-list__item--interactive[aria-selected=true] .fd-list__link,.fd-list__item--interractive.is-selected .fd-list__link,.fd-list__item--interractive[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item--interactive.is-selected .fd-list__link.is-active,.fd-list__item--interactive.is-selected .fd-list__link:active,.fd-list__item--interactive[aria-selected=true] .fd-list__link.is-active,.fd-list__item--interactive[aria-selected=true] .fd-list__link:active,.fd-list__item--interractive.is-selected .fd-list__link.is-active,.fd-list__item--interractive.is-selected .fd-list__link:active,.fd-list__item--interractive[aria-selected=true] .fd-list__link.is-active,.fd-list__item--interractive[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item--interactive.is-selected.is-hover,.fd-list__item--interactive.is-selected:hover,.fd-list__item--interactive[aria-selected=true].is-hover,.fd-list__item--interactive[aria-selected=true]:hover,.fd-list__item--interractive.is-selected.is-hover,.fd-list__item--interractive.is-selected:hover,.fd-list__item--interractive[aria-selected=true].is-hover,.fd-list__item--interractive[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__item--interactive.is-active,.fd-list__item--interactive.is-active.is-hover,.fd-list__item--interactive.is-active.is-selected,.fd-list__item--interactive.is-active.is-selected.is-hover,.fd-list__item--interactive.is-active.is-selected:hover,.fd-list__item--interactive.is-active:hover,.fd-list__item--interactive.is-active[aria-selected=true],.fd-list__item--interactive.is-active[aria-selected=true].is-hover,.fd-list__item--interactive.is-active[aria-selected=true]:hover,.fd-list__item--interactive:active,.fd-list__item--interactive:active.is-hover,.fd-list__item--interactive:active.is-selected,.fd-list__item--interactive:active.is-selected.is-hover,.fd-list__item--interactive:active.is-selected:hover,.fd-list__item--interactive:active:hover,.fd-list__item--interactive:active[aria-selected=true],.fd-list__item--interactive:active[aria-selected=true].is-hover,.fd-list__item--interactive:active[aria-selected=true]:hover,.fd-list__item--interractive.is-active,.fd-list__item--interractive.is-active.is-hover,.fd-list__item--interractive.is-active.is-selected,.fd-list__item--interractive.is-active.is-selected.is-hover,.fd-list__item--interractive.is-active.is-selected:hover,.fd-list__item--interractive.is-active:hover,.fd-list__item--interractive.is-active[aria-selected=true],.fd-list__item--interractive.is-active[aria-selected=true].is-hover,.fd-list__item--interractive.is-active[aria-selected=true]:hover,.fd-list__item--interractive:active,.fd-list__item--interractive:active.is-hover,.fd-list__item--interractive:active.is-selected,.fd-list__item--interractive:active.is-selected.is-hover,.fd-list__item--interractive:active.is-selected:hover,.fd-list__item--interractive:active:hover,.fd-list__item--interractive:active[aria-selected=true],.fd-list__item--interractive:active[aria-selected=true].is-hover,.fd-list__item--interractive:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__item--interactive.is-active,.fd-list__item--interactive.is-active .fd-list__byline,.fd-list__item--interactive.is-active .fd-list__byline-left,.fd-list__item--interactive.is-active .fd-list__byline-right,.fd-list__item--interactive.is-active .fd-list__byline-right--critical,.fd-list__item--interactive.is-active .fd-list__byline-right--informative,.fd-list__item--interactive.is-active .fd-list__byline-right--negative,.fd-list__item--interactive.is-active .fd-list__byline-right--neutral,.fd-list__item--interactive.is-active .fd-list__byline-right--positive,.fd-list__item--interactive.is-active .fd-list__content,.fd-list__item--interactive.is-active .fd-list__icon,.fd-list__item--interactive.is-active .fd-list__secondary,.fd-list__item--interactive.is-active .fd-list__thumbnail,.fd-list__item--interactive.is-active .fd-list__title,.fd-list__item--interactive.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--interactive:active,.fd-list__item--interactive:active .fd-list__byline,.fd-list__item--interactive:active .fd-list__byline-left,.fd-list__item--interactive:active .fd-list__byline-right,.fd-list__item--interactive:active .fd-list__byline-right--critical,.fd-list__item--interactive:active .fd-list__byline-right--informative,.fd-list__item--interactive:active .fd-list__byline-right--negative,.fd-list__item--interactive:active .fd-list__byline-right--neutral,.fd-list__item--interactive:active .fd-list__byline-right--positive,.fd-list__item--interactive:active .fd-list__content,.fd-list__item--interactive:active .fd-list__icon,.fd-list__item--interactive:active .fd-list__secondary,.fd-list__item--interactive:active .fd-list__thumbnail,.fd-list__item--interactive:active .fd-list__title,.fd-list__item--interactive:active.fd-list__link--navigation-indicator:after,.fd-list__item--interractive.is-active,.fd-list__item--interractive.is-active .fd-list__byline,.fd-list__item--interractive.is-active .fd-list__byline-left,.fd-list__item--interractive.is-active .fd-list__byline-right,.fd-list__item--interractive.is-active .fd-list__byline-right--critical,.fd-list__item--interractive.is-active .fd-list__byline-right--informative,.fd-list__item--interractive.is-active .fd-list__byline-right--negative,.fd-list__item--interractive.is-active .fd-list__byline-right--neutral,.fd-list__item--interractive.is-active .fd-list__byline-right--positive,.fd-list__item--interractive.is-active .fd-list__content,.fd-list__item--interractive.is-active .fd-list__icon,.fd-list__item--interractive.is-active .fd-list__secondary,.fd-list__item--interractive.is-active .fd-list__thumbnail,.fd-list__item--interractive.is-active .fd-list__title,.fd-list__item--interractive.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--interractive:active,.fd-list__item--interractive:active .fd-list__byline,.fd-list__item--interractive:active .fd-list__byline-left,.fd-list__item--interractive:active .fd-list__byline-right,.fd-list__item--interractive:active .fd-list__byline-right--critical,.fd-list__item--interractive:active .fd-list__byline-right--informative,.fd-list__item--interractive:active .fd-list__byline-right--negative,.fd-list__item--interractive:active .fd-list__byline-right--neutral,.fd-list__item--interractive:active .fd-list__byline-right--positive,.fd-list__item--interractive:active .fd-list__content,.fd-list__item--interractive:active .fd-list__icon,.fd-list__item--interractive:active .fd-list__secondary,.fd-list__item--interractive:active .fd-list__thumbnail,.fd-list__item--interractive:active .fd-list__title,.fd-list__item--interractive:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__item--action{border-bottom:var(--fdList_Item_Action_Border);font-size:var(--sapFontSize);padding-block:0;padding-inline:0;text-align:center;--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list__item--action:first-child{border-top:var(--fdList_Item_Action_Border)}.fd-list__item--action .fd-list__title{background:transparent;border:var(--fdList_Item_Action_Button_Border);border-radius:var(--fdList_Item_Action_Button_Border_Radius);color:var(--sapButton_TextColor);cursor:pointer;height:var(--fdList_Item_Action_Button_Size);margin-block:var(--fdList_Item_Action_Button_Spacing);margin-inline:var(--fdList_Item_Action_Button_Spacing);padding-block:0;padding-inline:.9375rem;pointer-events:all;width:100%}.fd-list__item--action .fd-list__title.is-hover,.fd-list__item--action .fd-list__title:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__item--action .fd-list__title.is-selected,.fd-list__item--action .fd-list__title[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item--action .fd-list__title.is-selected .fd-list__link,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item--action .fd-list__title.is-selected .fd-list__link.is-active,.fd-list__item--action .fd-list__title.is-selected .fd-list__link:active,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link.is-active,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item--action .fd-list__title.is-selected.is-hover,.fd-list__item--action .fd-list__title.is-selected:hover,.fd-list__item--action .fd-list__title[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__item--action .fd-list__title.is-active,.fd-list__item--action .fd-list__title.is-active.is-hover,.fd-list__item--action .fd-list__title.is-active.is-selected,.fd-list__item--action .fd-list__title.is-active.is-selected.is-hover,.fd-list__item--action .fd-list__title.is-active.is-selected:hover,.fd-list__item--action .fd-list__title.is-active:hover,.fd-list__item--action .fd-list__title.is-active[aria-selected=true],.fd-list__item--action .fd-list__title.is-active[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title.is-active[aria-selected=true]:hover,.fd-list__item--action .fd-list__title:active,.fd-list__item--action .fd-list__title:active.is-hover,.fd-list__item--action .fd-list__title:active.is-selected,.fd-list__item--action .fd-list__title:active.is-selected.is-hover,.fd-list__item--action .fd-list__title:active.is-selected:hover,.fd-list__item--action .fd-list__title:active:hover,.fd-list__item--action .fd-list__title:active[aria-selected=true],.fd-list__item--action .fd-list__title:active[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__item--action .fd-list__title.is-active,.fd-list__item--action .fd-list__title.is-active .fd-list__byline,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-left,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--critical,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--informative,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--negative,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--neutral,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--positive,.fd-list__item--action .fd-list__title.is-active .fd-list__content,.fd-list__item--action .fd-list__title.is-active .fd-list__icon,.fd-list__item--action .fd-list__title.is-active .fd-list__secondary,.fd-list__item--action .fd-list__title.is-active .fd-list__thumbnail,.fd-list__item--action .fd-list__title.is-active .fd-list__title,.fd-list__item--action .fd-list__title.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--action .fd-list__title:active,.fd-list__item--action .fd-list__title:active .fd-list__byline,.fd-list__item--action .fd-list__title:active .fd-list__byline-left,.fd-list__item--action .fd-list__title:active .fd-list__byline-right,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--critical,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--informative,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--negative,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--neutral,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--positive,.fd-list__item--action .fd-list__title:active .fd-list__content,.fd-list__item--action .fd-list__title:active .fd-list__icon,.fd-list__item--action .fd-list__title:active .fd-list__secondary,.fd-list__item--action .fd-list__title:active .fd-list__thumbnail,.fd-list__item--action .fd-list__title:active .fd-list__title,.fd-list__item--action .fd-list__title:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__item--action .fd-list__title.is-focus,.fd-list__item--action .fd-list__title:focus{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.125rem}.fd-list__item--action .fd-list__title.is-focus.is-active,.fd-list__item--action .fd-list__title.is-focus:active,.fd-list__item--action .fd-list__title:focus.is-active,.fd-list__item--action .fd-list__title:focus:active{outline-color:var(--fdList_Active_Outline_Color)}.fd-list__item--action .fd-list__title::-moz-focus-inner{border:0}.fd-list__item--growing{--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list__item--growing .fd-list__title{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;gap:.5rem}.fd-list__item--growing .fd-list__title-text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:inherit;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;font-weight:var(--fdList_Growing_Font_Weight);forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;text-shadow:inherit;white-space:nowrap}.fd-list__item--growing .fd-list__title-text:after,.fd-list__item--growing .fd-list__title-text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__item--inactive,.fd-list__item--inactive .fd-list__secondary,.fd-list__item--inactive .fd-list__title{pointer-events:none}.fd-list__item.is-selected,.fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item.is-selected .fd-list__link,.fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item.is-selected .fd-list__link.is-active,.fd-list__item.is-selected .fd-list__link:active,.fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item.is-selected.is-hover,.fd-list__item.is-selected:hover,.fd-list__item[aria-selected=true].is-hover,.fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__secondary,.fd-list__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdList_Item_Text_Color);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;pointer-events:none;pointer-events:all;text-overflow:ellipsis;white-space:nowrap}.fd-list__secondary:after,.fd-list__secondary:before,.fd-list__title:after,.fd-list__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__title{-webkit-box-flex:3;-ms-flex:3 3 10%;flex:3 3 10%;font-size:var(--fdList_Item_Text_Font_Size);min-height:var(--fdList_Item_Text_Font_Size)}.fd-list__title:last-child:first-child{-ms-flex-preferred-size:auto;flex-basis:auto}.fd-list__title .fd-list__title-text{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-list__title~.fd-list__icon{-webkit-margin-end:-1rem;margin-inline-end:-1rem}.fd-list__secondary{color:var(--fdList_Status_Text_Color);font-size:var(--sapFontSize);max-width:40%;text-align:right;-webkit-padding-start:1rem;padding-inline-start:1rem}.fd-list__secondary--positive{--fdList_Status_Text_Color:var(--sapPositiveTextColor)}.fd-list__secondary--critical{--fdList_Status_Text_Color:var(--sapCriticalTextColor)}.fd-list__secondary--negative{--fdList_Status_Text_Color:var(--sapNegativeTextColor)}.fd-list__secondary--informative{--fdList_Status_Text_Color:var(--sapInformativeTextColor)}.fd-list__secondary[dir=rtl],[dir=rtl] .fd-list__secondary{text-align:left}.fd-list__icon [class*=sap-icon],.fd-list__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;pointer-events:none;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_NonInteractiveIconColor);font-size:var(--fdList_Item_Icon_Font_Size);width:2.75rem;-webkit-box-flex:0;-ms-flex:0 0 auto;flex:0 0 auto}.fd-list__icon [class*=sap-icon]:first-child,.fd-list__icon[class*=sap-icon]:first-child{-webkit-margin-start:-1rem;margin-inline-start:-1rem}.fd-list__link{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;--fdList_Item_Border_Color:transparent;background:var(--fdList_Item_Background_Color);border-bottom:var(--sapList_BorderWidth) solid var(--fdList_Item_Border_Color);cursor:pointer;height:100%;padding-block:0;padding-inline:.9375rem;text-decoration:none;width:100%}.fd-list__link:after,.fd-list__link:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__link.is-focus,.fd-list__link:focus{outline:none;pointer-events:all}.fd-list__link.is-focus:before,.fd-list__link:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem;pointer-events:none;position:absolute}.fd-list__link.is-focus.is-active:before,.fd-list__link.is-focus:active:before,.fd-list__link:focus.is-active:before,.fd-list__link:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-list__link.is-hover,.fd-list__link:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__link.is-selected,.fd-list__link[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__link.is-selected .fd-list__link,.fd-list__link[aria-selected=true] .fd-list__link{background:inherit}.fd-list__link.is-selected .fd-list__link.is-active,.fd-list__link.is-selected .fd-list__link:active,.fd-list__link[aria-selected=true] .fd-list__link.is-active,.fd-list__link[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__link.is-selected.is-hover,.fd-list__link.is-selected:hover,.fd-list__link[aria-selected=true].is-hover,.fd-list__link[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__link.is-active,.fd-list__link.is-active.is-hover,.fd-list__link.is-active.is-selected,.fd-list__link.is-active.is-selected.is-hover,.fd-list__link.is-active.is-selected:hover,.fd-list__link.is-active:hover,.fd-list__link.is-active[aria-selected=true],.fd-list__link.is-active[aria-selected=true].is-hover,.fd-list__link.is-active[aria-selected=true]:hover,.fd-list__link:active,.fd-list__link:active.is-hover,.fd-list__link:active.is-selected,.fd-list__link:active.is-selected.is-hover,.fd-list__link:active.is-selected:hover,.fd-list__link:active:hover,.fd-list__link:active[aria-selected=true],.fd-list__link:active[aria-selected=true].is-hover,.fd-list__link:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__link.is-active,.fd-list__link.is-active .fd-list__byline,.fd-list__link.is-active .fd-list__byline-left,.fd-list__link.is-active .fd-list__byline-right,.fd-list__link.is-active .fd-list__byline-right--critical,.fd-list__link.is-active .fd-list__byline-right--informative,.fd-list__link.is-active .fd-list__byline-right--negative,.fd-list__link.is-active .fd-list__byline-right--neutral,.fd-list__link.is-active .fd-list__byline-right--positive,.fd-list__link.is-active .fd-list__content,.fd-list__link.is-active .fd-list__icon,.fd-list__link.is-active .fd-list__secondary,.fd-list__link.is-active .fd-list__thumbnail,.fd-list__link.is-active .fd-list__title,.fd-list__link.is-active.fd-list__link--navigation-indicator:after,.fd-list__link:active,.fd-list__link:active .fd-list__byline,.fd-list__link:active .fd-list__byline-left,.fd-list__link:active .fd-list__byline-right,.fd-list__link:active .fd-list__byline-right--critical,.fd-list__link:active .fd-list__byline-right--informative,.fd-list__link:active .fd-list__byline-right--negative,.fd-list__link:active .fd-list__byline-right--neutral,.fd-list__link:active .fd-list__byline-right--positive,.fd-list__link:active .fd-list__content,.fd-list__link:active .fd-list__icon,.fd-list__link:active .fd-list__secondary,.fd-list__link:active .fd-list__thumbnail,.fd-list__link:active .fd-list__title,.fd-list__link:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__group-header{background:var(--sapList_GroupHeaderBackground);border-bottom:var(--sapList_BorderWidth) solid var(--sapList_GroupHeaderBorderColor);height:var(--sapElement_LineHeight);-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}.fd-list__group-header .fd-list__title{color:var(--sapList_TableGroupHeaderTextColor);font-family:var(--sapFontHeaderFamily);font-size:var(--sapFontHeader6Size);font-weight:700;line-height:2rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list__footer{background:var(--sapList_FooterBackground);color:var(--sapList_FooterTextColor);font-size:var(--sapFontSize);height:2rem}.fd-list__footer--right{-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end}.fd-list__footer--left{-webkit-box-pack:start;-ms-flex-pack:start;justify-content:flex-start}.fd-list__bold{font-weight:700}.fd-list__message{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:2rem;left:0;line-height:normal;line-height:2rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;position:absolute;text-overflow:ellipsis;top:0;white-space:nowrap;width:100%;-webkit-padding-start:.5rem;background-color:var(--fdList_Message_Background_Color);font-size:var(--sapFontSmallSize);padding-inline-start:.5rem}.fd-list__message:after,.fd-list__message:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__message--error{--fdList_Message_Background_Color:var(--sapErrorBackground)}.fd-list__message--warning{--fdList_Message_Background_Color:var(--sapWarningBackground)}.fd-list__message--success{--fdList_Message_Background_Color:var(--sapSuccessBackground)}.fd-list__message--information{--fdList_Message_Background_Color:var(--sapInformationBackground)}.fd-list .fd-list__button{-webkit-margin-start:var(--fdList_Button_Spacing);margin-inline-start:var(--fdList_Button_Spacing);-ms-flex-item-align:center;align-self:center}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view),.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view),[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view),[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view){--fdList_Item_Icon_Font_Size:1rem;--fdList_Item_Text_Font_Size:var(--sapFontSize);--fdList_Item_Height:var(--sapElement_Compact_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing{--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action{--fdList_Item_Height:var(--sapElement_Compact_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title{height:var(--fdList_Item_Action_Button_Size_Compact)}.fd-list--no-border .fd-list__group-header,.fd-list--no-border .fd-list__item{border-bottom:0;border-top:0}.fd-list--no-border .fd-list__item.is-selected,.fd-list--no-border .fd-list__item[aria-selected=true]{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-list--has-message{-webkit-padding-before:2rem;padding-block-start:2rem}.fd-list__infinite-scroll{outline:none;overflow:scroll}.fd-list--dropdown.is-focus,.fd-list--dropdown:focus{outline:none;z-index:5}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header){display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:auto;min-height:2.5rem;padding-block:0;padding-inline:.9375rem}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link{background:inherit}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link.is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link:active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link.is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true],.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true]:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true],.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-left,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--critical,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--informative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--negative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--neutral,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--positive,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__content,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__icon,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__secondary,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__thumbnail,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__title,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.fd-list__link--navigation-indicator:after,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-left,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--critical,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--informative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--negative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--neutral,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--positive,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__content,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__icon,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__secondary,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__thumbnail,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__title,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list--dropdown[class*=-compact] .fd-list__item:not(.fd-list__group-header),.fd-list--dropdown[class*=-condensed] .fd-list__item:not(.fd-list__group-header),[class*=-compact] .fd-list--dropdown:not([class*=-cozy]) .fd-list__item:not(.fd-list__group-header),[class*=-condensed] .fd-list--dropdown:not([class*=-cozy]) .fd-list__item:not(.fd-list__group-header){height:auto;min-height:2rem;padding-block:0;padding-inline:.9375rem}.fd-list--multi-input .fd-list__item{height:auto;padding-block:0;padding-inline:0 1rem}.fd-list--multi-input .fd-list__item.is-hover,.fd-list--multi-input .fd-list__item:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list--multi-input .fd-list__item.is-selected,.fd-list--multi-input .fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--multi-input .fd-list__item.is-selected .fd-list__link,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list--multi-input .fd-list__item.is-selected .fd-list__link.is-active,.fd-list--multi-input .fd-list__item.is-selected .fd-list__link:active,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--multi-input .fd-list__item.is-selected.is-hover,.fd-list--multi-input .fd-list__item.is-selected:hover,.fd-list--multi-input .fd-list__item[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--multi-input .fd-list__item.is-active,.fd-list--multi-input .fd-list__item.is-active.is-hover,.fd-list--multi-input .fd-list__item.is-active.is-selected,.fd-list--multi-input .fd-list__item.is-active.is-selected.is-hover,.fd-list--multi-input .fd-list__item.is-active.is-selected:hover,.fd-list--multi-input .fd-list__item.is-active:hover,.fd-list--multi-input .fd-list__item.is-active[aria-selected=true],.fd-list--multi-input .fd-list__item.is-active[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item.is-active[aria-selected=true]:hover,.fd-list--multi-input .fd-list__item:active,.fd-list--multi-input .fd-list__item:active.is-hover,.fd-list--multi-input .fd-list__item:active.is-selected,.fd-list--multi-input .fd-list__item:active.is-selected.is-hover,.fd-list--multi-input .fd-list__item:active.is-selected:hover,.fd-list--multi-input .fd-list__item:active:hover,.fd-list--multi-input .fd-list__item:active[aria-selected=true],.fd-list--multi-input .fd-list__item:active[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list--multi-input .fd-list__item.is-active,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-left,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--critical,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--informative,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--negative,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--neutral,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--positive,.fd-list--multi-input .fd-list__item.is-active .fd-list__content,.fd-list--multi-input .fd-list__item.is-active .fd-list__icon,.fd-list--multi-input .fd-list__item.is-active .fd-list__secondary,.fd-list--multi-input .fd-list__item.is-active .fd-list__thumbnail,.fd-list--multi-input .fd-list__item.is-active .fd-list__title,.fd-list--multi-input .fd-list__item.is-active.fd-list__link--navigation-indicator:after,.fd-list--multi-input .fd-list__item:active,.fd-list--multi-input .fd-list__item:active .fd-list__byline,.fd-list--multi-input .fd-list__item:active .fd-list__byline-left,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--critical,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--informative,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--negative,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--neutral,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--positive,.fd-list--multi-input .fd-list__item:active .fd-list__content,.fd-list--multi-input .fd-list__item:active .fd-list__icon,.fd-list--multi-input .fd-list__item:active .fd-list__secondary,.fd-list--multi-input .fd-list__item:active .fd-list__thumbnail,.fd-list--multi-input .fd-list__item:active .fd-list__title,.fd-list--multi-input .fd-list__item:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list--multi-input .fd-list__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:inherit;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;position:relative;text-overflow:ellipsis;width:100%;-webkit-margin-end:0;margin-inline-end:0}.fd-list--multi-input .fd-list__label:after,.fd-list--multi-input .fd-list__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--multi-input .fd-list__label:before{margin-block:-.1875rem -.1875rem}.fd-list--multi-input .fd-list__input.is-focus,.fd-list--multi-input .fd-list__input:focus{-webkit-box-shadow:none;box-shadow:none;z-index:5}.fd-list--multi-input .fd-list__input.is-focus+.fd-list__label:after,.fd-list--multi-input .fd-list__input:focus+.fd-list__label:after{inset:.0625rem}.fd-list--multi-input .fd-list__footer{height:auto;text-align:right;-webkit-box-pack:end;-ms-flex-pack:end;background-color:var(--sapList_Background);justify-content:flex-end;line-height:1rem}.fd-list--multi-input .fd-list__footer,.fd-list--multi-input .fd-list__label{padding-block:.75rem;padding-inline:.9375rem}.fd-list--multi-input[class*=-compact] .fd-list__item,.fd-list--multi-input[class*=-condensed] .fd-list__item,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__item,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__item{height:auto;padding-block:0;padding-inline:0}.fd-list--multi-input[class*=-compact] .fd-list__label:before,.fd-list--multi-input[class*=-condensed] .fd-list__label:before,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label:before,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label:before{-webkit-margin-start:0;margin-inline-start:0;margin-top:0;-webkit-margin-after:0;margin-block-end:0}.fd-list--multi-input[class*=-compact] .fd-list__footer,.fd-list--multi-input[class*=-compact] .fd-list__label,.fd-list--multi-input[class*=-condensed] .fd-list__footer,.fd-list--multi-input[class*=-condensed] .fd-list__label,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__footer,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__footer,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label{padding-block:.5rem;padding-inline:.9375rem}.fd-list--dropdown,.fd-list--multi-input{display:block;max-width:40rem;min-width:5rem}.fd-list--dropdown .fd-list__item,.fd-list--multi-input .fd-list__item{border:none;cursor:pointer}.fd-list--dropdown .fd-list__item.is-selected,.fd-list--dropdown .fd-list__item[aria-selected=true],.fd-list--multi-input .fd-list__item.is-selected,.fd-list--multi-input .fd-list__item[aria-selected=true]{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-list--dropdown .fd-list__secondary,.fd-list--dropdown .fd-list__title,.fd-list--multi-input .fd-list__secondary,.fd-list--multi-input .fd-list__title{font-size:var(--sapFontSize);white-space:normal;-webkit-box-flex:1;-ms-flex:auto;flex:auto;width:auto}.fd-list--dropdown .fd-list__secondary--no-wrap,.fd-list--dropdown .fd-list__title--no-wrap,.fd-list--multi-input .fd-list__secondary--no-wrap,.fd-list--multi-input .fd-list__title--no-wrap{white-space:nowrap}.fd-list--dropdown .fd-list__secondary,.fd-list--multi-input .fd-list__secondary{display:block}.fd-list--dropdown .fd-list__title,.fd-list--multi-input .fd-list__title{max-width:24rem}.fd-list--dropdown .fd-list__title:first-child:last-child,.fd-list--multi-input .fd-list__title:first-child:last-child{max-width:40rem}.fd-list--dropdown .fd-list__secondary,.fd-list--multi-input .fd-list__secondary{max-width:16rem}.fd-list--dropdown.fd-list--mobile,.fd-list--multi-input.fd-list--mobile{max-width:100%}.fd-list--dropdown .fd-list__icon,.fd-list--multi-input .fd-list__icon{line-height:1rem}.fd-list--dropdown.fd-list--large-dropdown,.fd-list--multi-input.fd-list--large-dropdown{max-width:62rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__title,.fd-list--multi-input.fd-list--large-dropdown .fd-list__title{max-width:37.2rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__title:first-child:last-child,.fd-list--multi-input.fd-list--large-dropdown .fd-list__title:first-child:last-child{max-width:62rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__secondary,.fd-list--multi-input.fd-list--large-dropdown .fd-list__secondary{max-width:24.8rem}.fd-list--dropdown.fd-list--large-dropdown.fd-list--mobile,.fd-list--multi-input.fd-list--large-dropdown.fd-list--mobile{max-width:100%}.fd-list--byline .fd-list__item{height:auto;min-height:5rem;padding-block:.9375rem;padding-inline:1rem;width:100%;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.fd-list--byline .fd-list__item.is-focus,.fd-list--byline .fd-list__item:focus{pointer-events:all;z-index:5}.fd-list--byline .fd-list__item .fd-list__item-counter{-ms-flex-align:center;-ms-flex-item-align:center;align-self:center;-webkit-box-pack:end;-ms-flex-pack:end;height:100%;justify-content:flex-end;min-width:2rem}.fd-list--byline .fd-list__item .fd-list__item-counter,.fd-list--byline .fd-list__thumbnail{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;align-items:center}.fd-list--byline .fd-list__thumbnail{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;pointer-events:none;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-ms-flex-align:center;-webkit-margin-end:.75rem;border-radius:.25rem;color:var(--sapContent_NonInteractiveIconColor);font-size:2rem;height:3rem;margin-inline-end:.75rem;max-height:3rem;max-width:3rem;min-height:3rem;min-width:3rem;width:3rem}.fd-list--byline .fd-list__thumbnail:after,.fd-list--byline .fd-list__thumbnail:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__thumbnail [class*=sap-icon],.fd-list--byline .fd-list__thumbnail[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;line-height:1}.fd-list--byline .fd-list__thumbnail>svg{height:100%}.fd-list--byline .fd-list__notification{color:var(--sapAccentColor6);font-size:.375rem;left:1rem;position:absolute;top:50%;-webkit-transform:translateY(-50%);transform:translateY(-50%)}.fd-list--byline .fd-list__notification[dir=rtl],[dir=rtl] .fd-list--byline .fd-list__notification{left:auto;right:1rem}.fd-list--byline .fd-list__notification+.fd-list__link .fd-list__content .fd-list__title,.fd-list--byline .fd-list__notification~.fd-list__content .fd-list__title{font-weight:700}.fd-list--byline .fd-list__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;pointer-events:none;-ms-flex-line-pack:justify;align-content:space-between;height:100%;min-height:3rem;min-width:3rem;-webkit-box-flex:1;-ms-flex:1 1 auto;flex:1 1 auto;padding-block:.125rem;padding-inline:0}.fd-list--byline .fd-list__content:after,.fd-list--byline .fd-list__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__title{font-size:var(--sapFontLargeSize);min-height:1rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list--byline .fd-list__byline{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-list--byline .fd-list__byline:after,.fd-list--byline .fd-list__byline:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline--2-col{display:-webkit-box;display:-ms-flexbox;display:flex;pointer-events:all}.fd-list--byline .fd-list__byline--wrap .fd-list__byline-left,.fd-list--byline .fd-list__byline--wrap .fd-list__byline-right{display:inline;padding-block:0;padding-inline:0;white-space:normal;width:100%}.fd-list--byline .fd-list__byline--wrap .fd-list__byline-right{float:right;width:auto}.fd-list--byline .fd-list__link--more{pointer-events:all;text-transform:capitalize}.fd-list--byline .fd-list__byline--wrap,.fd-list--byline .fd-list__title--wrap{white-space:normal}.fd-list--byline .fd-list__byline-left{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;width:60%;-ms-flex-item-align:end;align-self:flex-end;-webkit-padding-end:.5rem;padding-inline-end:.5rem}.fd-list--byline .fd-list__byline-left:after,.fd-list--byline .fd-list__byline-left:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline-right{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-align:right;text-overflow:ellipsis;white-space:nowrap;width:40%;-ms-flex-item-align:end;align-self:flex-end;-webkit-padding-start:.5rem;padding-inline-start:.5rem}.fd-list--byline .fd-list__byline-right:after,.fd-list--byline .fd-list__byline-right:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline-right[dir=rtl],[dir=rtl] .fd-list--byline .fd-list__byline-right{text-align:left}.fd-list--byline .fd-list__byline-right--neutral{color:var(--sapNeutralTextColor)}.fd-list--byline .fd-list__byline-right--positive{color:var(--sapPositiveTextColor)}.fd-list--byline .fd-list__byline-right--critical{color:var(--sapCriticalTextColor)}.fd-list--byline .fd-list__byline-right--negative{color:var(--sapNegativeTextColor)}.fd-list--byline .fd-list__byline-right--informative{color:var(--sapInformativeTextColor)}.fd-list--byline.fd-list--unread-indicator .fd-list__item{padding-inline:2.125rem 1rem}.fd-list--byline[class*=-compact] .fd-list__title,.fd-list--byline[class*=-condensed] .fd-list__title,[class*=-compact] .fd-list--byline:not([class*=-cozy]) .fd-list__title,[class*=-condensed] .fd-list--byline:not([class*=-cozy]) .fd-list__title{font-size:var(--sapFontSize)}.fd-list--byline.fd-list--no-border .fd-list__item{height:100%;max-height:5rem;padding-block:.5rem}.fd-list--byline.fd-list--no-border .fd-list__item:first-child{-webkit-padding-before:.9375rem;padding-block-start:.9375rem}.fd-list--byline.fd-list--no-border .fd-list__item:last-child{-webkit-padding-after:.9375rem;padding-block-end:.9375rem}.fd-list--message-view{--fdListNavigationIndicatorFontSize:.75rem;--fdList_Item_Height:calc(2.75rem + var(--sapList_BorderWidth));--fdList_Message_View_Item_Byline_Height:calc(3.325rem + var(--sapList_BorderWidth));--fdList_Message_View_Title_Size:var(--sapFontHeader5Size)}.fd-list--message-view .fd-list__item{height:auto}.fd-list--message-view .fd-list__item--byline{--fdList_Item_Height:var(--fdList_Message_View_Item_Byline_Height)}.fd-list--message-view .fd-list__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-flex:1;-ms-flex:1 1 auto;flex:1 1 auto;overflow:hidden;pointer-events:none;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__content:after,.fd-list--message-view .fd-list__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--message-view .fd-list__title{color:var(--sapGroup_TitleTextColor);font-family:var(--sapFontHeaderFamily);font-size:var(--fdList_Message_View_Title_Size);font-weight:var(--sapFontHeaderWeight,normal);overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__subtitle{-webkit-padding-before:.25rem;color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);overflow:hidden;padding-block-start:.25rem;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__link{padding-block:.5rem}.fd-list--message-view .fd-list__link.is-active .fd-list__subtitle,.fd-list--message-view .fd-list__link.is-active .fd-list__title,.fd-list--message-view .fd-list__link.is-active .fd-object-status .fd-object-status__icon,.fd-list--message-view .fd-list__link:active .fd-list__subtitle,.fd-list--message-view .fd-list__link:active .fd-list__title,.fd-list--message-view .fd-list__link:active .fd-object-status .fd-object-status__icon{color:var(--sapList_Active_TextColor)}.fd-list--message-view[class*=-compact],.fd-list--message-view[class*=-condensed],[class*=-compact] .fd-list--message-view:not([class*=-cozy]),[class*=-condensed] .fd-list--message-view:not([class*=-cozy]){--fdList_Message_View_Item_Height:calc(2rem + var(--sapList_BorderWidth));--fdList_Message_View_Title_Size:var(--sapFontHeader6Size);--fdList_Message_View_Item_Byline_Height:calc(3.25rem + var(--sapList_BorderWidth))}.fd-list--navigation .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-icon-tab-bar__list .fd-list__link{gap:.25rem}.fd-list--navigation .fd-list__link{padding-inline:var(--fdList_Navigation_Link_Padding_Left,.9375rem) var(--fdList_Navigation_Link_Padding_Right,.9375rem)}.fd-list--navigation.fd-list--unread-indicator{--fdList_Navigation_Link_Padding_Left:2.125rem;--fdList_Navigation_Link_Padding_Right:.9375rem}.fd-list--navigation.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:.9375rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--selection{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:.9375rem}.fd-list--navigation.fd-list--selection .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--selection.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--selection.fd-list--navigation-indication .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline,.fd-list--navigation.fd-list--byline.fd-list--compact{--fdList_Navigation_Link_Padding_Left:1rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--compact .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline .fd-list__link,.fd-list--navigation.fd-list--byline.fd-list--compact .fd-list__link{padding-block:.9375rem}.fd-list--navigation.fd-list--byline.fd-list--compact.fd-list--unread-indicator,.fd-list--navigation.fd-list--byline.fd-list--unread-indicator{--fdList_Navigation_Link_Padding_Left:2.125rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:.9375rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--byline.fd-list--selection{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-compact],.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-condensed],[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]),[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]){--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-compact] .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-condensed] .fd-list__item--link,[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]) .fd-list__item--link,[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]) .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication[class*=-compact],.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication[class*=-condensed],[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication:not([class*=-cozy]),[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication:not([class*=-cozy]){--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--navigation-object{--fdList_Navigation_Link_Padding_Left:1rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--navigation-object .fd-list__item--link,.fd-list--navigation.fd-list--navigation-object[dir=rtl] .fd-list__item--link,[dir=rtl] .fd-list--navigation.fd-list--navigation-object .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--navigation-object .fd-list__link{padding-block:1rem}.fd-list--navigation-indication .fd-list:after{content:\"\";min-width:1.5rem}.fd-list--navigation-indication fd-list__item.fd-list__item--link{-webkit-padding-end:0;padding-inline-end:0}.fd-list--navigation-indication fd-list__item.fd-list__item--link:after{content:none}.fd-list--navigation-indication .fd-list__link:after{content:\"\";min-width:2.5rem}.fd-list--navigation-indication .fd-list__link--navigation-indicator:after{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_NonInteractiveIconColor);content:\"\\e1ed\";font-family:SAP-icons;font-size:var(--fdListNavigationIndicatorFontSize,var(--sapFontLargeSize));height:100%;text-decoration:none;text-transform:none}.fd-list--navigation-indication .fd-list__link--navigation-indicator[dir=rtl]:after,[dir=rtl] .fd-list--navigation-indication .fd-list__link--navigation-indicator:after{content:\"\\e1ee\"}.fd-list--navigation-indication .fd-list__icon:last-child,.fd-list--navigation-indication .fd-list__icon[dir=rtl]:last-child,[dir=rtl] .fd-list--navigation-indication .fd-list__icon:last-child{margin-block:0;margin-inline:0}.fd-list--navigation-indication .is-navigated{-webkit-box-shadow:inset -.1875rem 0 0 0 var(--sapList_SelectionBorderColor);box-shadow:inset -.1875rem 0 0 0 var(--sapList_SelectionBorderColor)}.fd-list--navigation-indication .is-navigated[dir=rtl],[dir=rtl] .fd-list--navigation-indication .is-navigated{-webkit-box-shadow:inset .1875rem 0 0 0 var(--sapList_SelectionBorderColor);box-shadow:inset .1875rem 0 0 0 var(--sapList_SelectionBorderColor)}.fd-list--selection .fd-list__item{cursor:pointer;padding-inline:2.75rem .9375rem}.fd-list--selection .fd-list__item.is-hover,.fd-list--selection .fd-list__item:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background)}.fd-list--selection .fd-list__item.is-selected,.fd-list--selection .fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--selection .fd-list__item.is-selected .fd-list__link,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list--selection .fd-list__item.is-selected .fd-list__link.is-active,.fd-list--selection .fd-list__item.is-selected .fd-list__link:active,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--selection .fd-list__item.is-selected.is-hover,.fd-list--selection .fd-list__item.is-selected:hover,.fd-list--selection .fd-list__item[aria-selected=true].is-hover,.fd-list--selection .fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--selection .fd-list__form-item{left:0;position:absolute;top:0;z-index:5}.fd-list--selection .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection .fd-list__form-item{left:auto;right:0}.fd-list--selection[class*=-compact] .fd-list__form-item,.fd-list--selection[class*=-condensed] .fd-list__form-item,[class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item,[class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item{left:.375rem}.fd-list--selection[class*=-compact] .fd-list__form-item[dir=rtl],.fd-list--selection[class*=-condensed] .fd-list__form-item[dir=rtl],[class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection[class*=-compact] .fd-list__form-item,[dir=rtl] .fd-list--selection[class*=-condensed] .fd-list__form-item,[dir=rtl] [class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item,[dir=rtl] [class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item{left:auto;right:.375rem}.fd-list--selection.fd-list--byline .fd-list__item{padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline .fd-list__form-item{top:.3125rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__item,.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__item,[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__item,[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__item{padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item,.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item,[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item,[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item{left:.375rem;top:.5rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item[dir=rtl],.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item[dir=rtl],[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item,[dir=rtl] .fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item,[dir=rtl] [class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item,[dir=rtl] [class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item{left:auto;right:.375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item{padding-block:.5rem;padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:first-child{-webkit-padding-before:.9375rem;padding-block-start:.9375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:last-child{-webkit-padding-after:.9375rem;padding-block-end:.9375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item{top:0}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item label,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item label{-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item label:after,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item label:after{top:.375rem}.fd-list--selection.fd-list--selection-row .fd-list__item{-webkit-padding-start:1rem;padding-inline-start:1rem}:root{--fdList_Item_Background_Color:var(--sapList_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor);--fdList_Item_Text_Font_Size:var(--sapFontLargeSize);--fdList_Item_Icon_Font_Size:1.125rem;--fdList_Item_Height:var(--sapElement_LineHeight);--fdList_Status_Text_Color:var(--sapNeutralTextColor);--fdList_Message_Background_Color:var(--sapNeutralBackground)}.fd-list__item-counter{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-margin-start:1rem;color:var(--sapContent_MarkerTextColor);margin-inline-start:1rem}.fd-list__item-counter:after,.fd-list__item-counter:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__item--custom-content{height:fit-content!important;min-height:var(--fdList_Item_Action_Height)}\n/*! Bundled license information:\n\nfundamental-styles/dist/list.css:\n  (*!\n   * Fundamental Library Styles v0.38.0\n   * Copyright (c) 2024 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "component", type: ListComponent$1, selector: "[fd-list], [fdList]", inputs: ["dropdownMode", "multiInputMode", "mobileMode", "hasMessage", "noBorder", "navigationIndicator", "selection", "keyboardSupport", "byline", "unreadIndicator", "role"], outputs: ["focusEscapeList"] }, { kind: "component", type: BusyIndicatorComponent, selector: "fd-busy-indicator", inputs: ["loading", "size", "block", "ariaLabel", "title", "label", "ariaLive"] }, { kind: "directive", type: InfiniteScrollDirective, selector: "[fdInfiniteScroll]", inputs: ["scrollPercent", "scrollOffset"], outputs: ["onScrollAction"] }, { kind: "component", type: ListItemComponent, selector: "[fdListItem] ,[fd-list-item]", inputs: ["selected", "noData", "action", "interactive", "growing", "counter", "unread", "byline", "ariaRole", "id", "preventClick"], outputs: ["keyDown"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: RepeatDirective, selector: "[fdkRepeat]", inputs: ["fdkRepeat"] }, { kind: "component", type: SkeletonComponent, selector: "fd-skeleton", inputs: ["animated", "type", "textLines", "width", "height"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }, { kind: "pipe", type: AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ListComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fdp-list', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [
                        { provide: FD_FORM_FIELD_CONTROL, useExisting: ListComponent, multi: true },
                        { provide: FdpListComponent, useExisting: ListComponent },
                        {
                            provide: FD_LIST_UNREAD_INDICATOR,
                            useExisting: ListComponent
                        }
                    ], host: {
                        '[attr.tabindex]': '-1'
                    }, imports: [
                        ListComponent$1,
                        BusyIndicatorComponent,
                        InfiniteScrollDirective,
                        ListItemComponent,
                        NgTemplateOutlet,
                        RepeatDirective,
                        SkeletonComponent,
                        FdTranslatePipe,
                        AsyncPipe
                    ], template: "<ng-content select=\"fd-toolbar\"></ng-content>\n<div\n    fd-list\n    [attr.id]=\"id\"\n    [noBorder]=\"noBorder\"\n    [selection]=\"selection\"\n    [byline]=\"hasByLine\"\n    [class.fd-list--navigation]=\"navigated || navigationIndicator\"\n    [navigationIndicator]=\"navigationIndicator\"\n    [style.outline]=\"'none'\"\n    (keydown)=\"_keyManager?.onKeydown($event); _handleKeyDown($event)\"\n    (change)=\"_onSelectionChanged($event)\"\n    [attr.aria-setsize]=\"_ariaSetSize | async\"\n    [attr.aria-label]=\"ariaLabel\"\n    [attr.aria-labelledby]=\"ariaLabelledBy\"\n    [attr.aria-multiselectable]=\"ariaMultiselectable\"\n    [role]=\"role\"\n    [unreadIndicator]=\"unreadIndicator\"\n>\n    @if (loadMore && loadOnScroll) {\n        <fd-busy-indicator\n            size=\"l\"\n            class=\"fd-busy-indicator-custom fd-list__item--growing\"\n            [block]=\"true\"\n            [loading]=\"_loading && _firstLoadingDone\"\n            role=\"alert\"\n            [attr.aria-busy]=\"_loading\"\n            [attr.aria-label]=\"_loading ? ('platformList.loadingAriaLabel' | fdTranslate) : null\"\n        >\n            <div\n                fd-list\n                fdInfiniteScroll\n                class=\"fd-list__infinite-scroll\"\n                [style.max-height]=\"maxHeight\"\n                (onScrollAction)=\"_scrollHandler()\"\n                [scrollPercent]=\"scrollOffsetPercentage\"\n                [role]=\"role\"\n            >\n                @if (_items.length !== 0) {\n                    @for (item of _items; track item; let i = $index) {\n                        <ng-template\n                            [ngTemplateOutlet]=\"listItemDef.templateRef\"\n                            [ngTemplateOutletContext]=\"{ $implicit: item }\"\n                        >\n                        </ng-template>\n                    }\n                } @else {\n                    @if (!listItems.length && !_firstLoadingDone) {\n                        @if (!hasByLine) {\n                            <li fd-list-item *fdkRepeat=\"3\">\n                                <fd-skeleton\n                                    [style.margin]=\"'auto 0'\"\n                                    type=\"text\"\n                                    textLines=\"1\"\n                                    width=\"40%\"\n                                ></fd-skeleton>\n                            </li>\n                        } @else {\n                            <li fd-list-item *fdkRepeat=\"3\">\n                                <fd-skeleton width=\"100%\" height=\"48px\" [style.margin]=\"'auto 0'\">\n                                    <svg:rect x=\"0\" y=\"0\" width=\"48\" height=\"48\" rx=\"4\" />\n                                    <svg:rect x=\"60\" y=\"0\" width=\"40%\" height=\"12\" rx=\"4\" />\n                                    <svg:rect x=\"60\" y=\"20\" width=\"30%\" height=\"8\" rx=\"4\" />\n                                </fd-skeleton>\n                            </li>\n                        }\n                    }\n                    <ng-content></ng-content>\n                }\n            </div>\n        </fd-busy-indicator>\n    }\n    @if (!loadOnScroll) {\n        @if (_items.length !== 0) {\n            @for (item of _items; track item; let i = $index) {\n                <ng-template\n                    [ngTemplateOutlet]=\"listItemDef.templateRef\"\n                    [ngTemplateOutletContext]=\"{ $implicit: item }\"\n                >\n                </ng-template>\n            }\n        } @else {\n            @if (!listItems.length && !_firstLoadingDone) {\n                @if (!hasByLine) {\n                    <li fd-list-item *fdkRepeat=\"3\">\n                        <fd-skeleton [style.margin]=\"'auto 0'\" type=\"text\" textLines=\"1\" width=\"40%\"></fd-skeleton>\n                    </li>\n                } @else {\n                    <li fd-list-item *fdkRepeat=\"3\">\n                        <fd-skeleton width=\"100%\" height=\"48px\" [style.margin]=\"'auto 0'\">\n                            <svg:rect x=\"0\" y=\"0\" width=\"48\" height=\"48\" rx=\"4\" />\n                            <svg:rect x=\"60\" y=\"0\" width=\"40%\" height=\"12\" rx=\"4\" />\n                            <svg:rect x=\"60\" y=\"20\" width=\"30%\" height=\"8\" rx=\"4\" />\n                        </fd-skeleton>\n                    </li>\n                }\n            }\n            <ng-content></ng-content>\n        }\n        @if (loadMore && !loadOnScroll && _firstLoadingDone) {\n            <li\n                #listItem\n                (click)=\"_getMoreData()\"\n                fd-list-item\n                (keydown)=\"_loadOnKeyPress($event)\"\n                [class.fd-list__item--custom-content]=\"loadMoreContent\"\n                class=\"fd-list__item fd-list__item--growing fd-list__item--action\"\n                [tabindex]=\"0\"\n                role=\"button\"\n            >\n                <ng-template [ngTemplateOutlet]=\"loadMoreElementContent\"></ng-template>\n            </li>\n        }\n    }\n    <ng-template #loadMoreElementContent>\n        @if (loadMoreContent) {\n            <div class=\"fd-list__title\">\n                <ng-template\n                    [ngTemplateOutlet]=\"loadMoreContent.templateRef\"\n                    [ngTemplateOutletContext]=\"getLoadMoreContentContext()\"\n                >\n                </ng-template>\n            </div>\n        } @else {\n            <button class=\"fd-list__title\">\n                <fd-busy-indicator\n                    size=\"m\"\n                    class=\"fd-busy-indicator-custom\"\n                    [block]=\"true\"\n                    [loading]=\"_loading\"\n                    role=\"alert\"\n                    [attr.aria-label]=\"_loading ? ('platformList.loadingAriaLabel' | fdTranslate) : loadTitle\"\n                >\n                </fd-busy-indicator>\n                {{ loadTitle }}\n                <ng-content select=\"#load\"></ng-content>\n            </button>\n        }\n    </ng-template>\n</div>\n", styles: [".fd-list{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;list-style:none;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative;width:100%}.fd-list:after,.fd-list:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__footer,.fd-list__group-header,.fd-list__item{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;padding-block:0;padding-inline:.9375rem}.fd-list__footer:after,.fd-list__footer:before,.fd-list__group-header:after,.fd-list__group-header:before,.fd-list__item:after,.fd-list__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__item{background:var(--fdList_Item_Background_Color);border-bottom:var(--sapList_BorderWidth) solid var(--fdList_Item_Border_Color);height:var(--fdList_Item_Height);position:relative}.fd-list__item.is-focus,.fd-list__item:focus{outline:none;pointer-events:all}.fd-list__item.is-focus:before,.fd-list__item:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem .125rem .0625rem;pointer-events:none;position:absolute}.fd-list__item.is-focus.is-active:before,.fd-list__item.is-focus:active:before,.fd-list__item:focus.is-active:before,.fd-list__item:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-list__item--unread .fd-list__title{font-weight:700}.fd-list__item--no-data .fd-list__title{text-align:center}.fd-list__item--interactive.is-hover,.fd-list__item--interactive:hover,.fd-list__item--interractive.is-hover,.fd-list__item--interractive:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__item--interactive.is-selected,.fd-list__item--interactive[aria-selected=true],.fd-list__item--interractive.is-selected,.fd-list__item--interractive[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item--interactive.is-selected .fd-list__link,.fd-list__item--interactive[aria-selected=true] .fd-list__link,.fd-list__item--interractive.is-selected .fd-list__link,.fd-list__item--interractive[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item--interactive.is-selected .fd-list__link.is-active,.fd-list__item--interactive.is-selected .fd-list__link:active,.fd-list__item--interactive[aria-selected=true] .fd-list__link.is-active,.fd-list__item--interactive[aria-selected=true] .fd-list__link:active,.fd-list__item--interractive.is-selected .fd-list__link.is-active,.fd-list__item--interractive.is-selected .fd-list__link:active,.fd-list__item--interractive[aria-selected=true] .fd-list__link.is-active,.fd-list__item--interractive[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item--interactive.is-selected.is-hover,.fd-list__item--interactive.is-selected:hover,.fd-list__item--interactive[aria-selected=true].is-hover,.fd-list__item--interactive[aria-selected=true]:hover,.fd-list__item--interractive.is-selected.is-hover,.fd-list__item--interractive.is-selected:hover,.fd-list__item--interractive[aria-selected=true].is-hover,.fd-list__item--interractive[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__item--interactive.is-active,.fd-list__item--interactive.is-active.is-hover,.fd-list__item--interactive.is-active.is-selected,.fd-list__item--interactive.is-active.is-selected.is-hover,.fd-list__item--interactive.is-active.is-selected:hover,.fd-list__item--interactive.is-active:hover,.fd-list__item--interactive.is-active[aria-selected=true],.fd-list__item--interactive.is-active[aria-selected=true].is-hover,.fd-list__item--interactive.is-active[aria-selected=true]:hover,.fd-list__item--interactive:active,.fd-list__item--interactive:active.is-hover,.fd-list__item--interactive:active.is-selected,.fd-list__item--interactive:active.is-selected.is-hover,.fd-list__item--interactive:active.is-selected:hover,.fd-list__item--interactive:active:hover,.fd-list__item--interactive:active[aria-selected=true],.fd-list__item--interactive:active[aria-selected=true].is-hover,.fd-list__item--interactive:active[aria-selected=true]:hover,.fd-list__item--interractive.is-active,.fd-list__item--interractive.is-active.is-hover,.fd-list__item--interractive.is-active.is-selected,.fd-list__item--interractive.is-active.is-selected.is-hover,.fd-list__item--interractive.is-active.is-selected:hover,.fd-list__item--interractive.is-active:hover,.fd-list__item--interractive.is-active[aria-selected=true],.fd-list__item--interractive.is-active[aria-selected=true].is-hover,.fd-list__item--interractive.is-active[aria-selected=true]:hover,.fd-list__item--interractive:active,.fd-list__item--interractive:active.is-hover,.fd-list__item--interractive:active.is-selected,.fd-list__item--interractive:active.is-selected.is-hover,.fd-list__item--interractive:active.is-selected:hover,.fd-list__item--interractive:active:hover,.fd-list__item--interractive:active[aria-selected=true],.fd-list__item--interractive:active[aria-selected=true].is-hover,.fd-list__item--interractive:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__item--interactive.is-active,.fd-list__item--interactive.is-active .fd-list__byline,.fd-list__item--interactive.is-active .fd-list__byline-left,.fd-list__item--interactive.is-active .fd-list__byline-right,.fd-list__item--interactive.is-active .fd-list__byline-right--critical,.fd-list__item--interactive.is-active .fd-list__byline-right--informative,.fd-list__item--interactive.is-active .fd-list__byline-right--negative,.fd-list__item--interactive.is-active .fd-list__byline-right--neutral,.fd-list__item--interactive.is-active .fd-list__byline-right--positive,.fd-list__item--interactive.is-active .fd-list__content,.fd-list__item--interactive.is-active .fd-list__icon,.fd-list__item--interactive.is-active .fd-list__secondary,.fd-list__item--interactive.is-active .fd-list__thumbnail,.fd-list__item--interactive.is-active .fd-list__title,.fd-list__item--interactive.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--interactive:active,.fd-list__item--interactive:active .fd-list__byline,.fd-list__item--interactive:active .fd-list__byline-left,.fd-list__item--interactive:active .fd-list__byline-right,.fd-list__item--interactive:active .fd-list__byline-right--critical,.fd-list__item--interactive:active .fd-list__byline-right--informative,.fd-list__item--interactive:active .fd-list__byline-right--negative,.fd-list__item--interactive:active .fd-list__byline-right--neutral,.fd-list__item--interactive:active .fd-list__byline-right--positive,.fd-list__item--interactive:active .fd-list__content,.fd-list__item--interactive:active .fd-list__icon,.fd-list__item--interactive:active .fd-list__secondary,.fd-list__item--interactive:active .fd-list__thumbnail,.fd-list__item--interactive:active .fd-list__title,.fd-list__item--interactive:active.fd-list__link--navigation-indicator:after,.fd-list__item--interractive.is-active,.fd-list__item--interractive.is-active .fd-list__byline,.fd-list__item--interractive.is-active .fd-list__byline-left,.fd-list__item--interractive.is-active .fd-list__byline-right,.fd-list__item--interractive.is-active .fd-list__byline-right--critical,.fd-list__item--interractive.is-active .fd-list__byline-right--informative,.fd-list__item--interractive.is-active .fd-list__byline-right--negative,.fd-list__item--interractive.is-active .fd-list__byline-right--neutral,.fd-list__item--interractive.is-active .fd-list__byline-right--positive,.fd-list__item--interractive.is-active .fd-list__content,.fd-list__item--interractive.is-active .fd-list__icon,.fd-list__item--interractive.is-active .fd-list__secondary,.fd-list__item--interractive.is-active .fd-list__thumbnail,.fd-list__item--interractive.is-active .fd-list__title,.fd-list__item--interractive.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--interractive:active,.fd-list__item--interractive:active .fd-list__byline,.fd-list__item--interractive:active .fd-list__byline-left,.fd-list__item--interractive:active .fd-list__byline-right,.fd-list__item--interractive:active .fd-list__byline-right--critical,.fd-list__item--interractive:active .fd-list__byline-right--informative,.fd-list__item--interractive:active .fd-list__byline-right--negative,.fd-list__item--interractive:active .fd-list__byline-right--neutral,.fd-list__item--interractive:active .fd-list__byline-right--positive,.fd-list__item--interractive:active .fd-list__content,.fd-list__item--interractive:active .fd-list__icon,.fd-list__item--interractive:active .fd-list__secondary,.fd-list__item--interractive:active .fd-list__thumbnail,.fd-list__item--interractive:active .fd-list__title,.fd-list__item--interractive:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__item--action{border-bottom:var(--fdList_Item_Action_Border);font-size:var(--sapFontSize);padding-block:0;padding-inline:0;text-align:center;--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list__item--action:first-child{border-top:var(--fdList_Item_Action_Border)}.fd-list__item--action .fd-list__title{background:transparent;border:var(--fdList_Item_Action_Button_Border);border-radius:var(--fdList_Item_Action_Button_Border_Radius);color:var(--sapButton_TextColor);cursor:pointer;height:var(--fdList_Item_Action_Button_Size);margin-block:var(--fdList_Item_Action_Button_Spacing);margin-inline:var(--fdList_Item_Action_Button_Spacing);padding-block:0;padding-inline:.9375rem;pointer-events:all;width:100%}.fd-list__item--action .fd-list__title.is-hover,.fd-list__item--action .fd-list__title:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__item--action .fd-list__title.is-selected,.fd-list__item--action .fd-list__title[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item--action .fd-list__title.is-selected .fd-list__link,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item--action .fd-list__title.is-selected .fd-list__link.is-active,.fd-list__item--action .fd-list__title.is-selected .fd-list__link:active,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link.is-active,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item--action .fd-list__title.is-selected.is-hover,.fd-list__item--action .fd-list__title.is-selected:hover,.fd-list__item--action .fd-list__title[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__item--action .fd-list__title.is-active,.fd-list__item--action .fd-list__title.is-active.is-hover,.fd-list__item--action .fd-list__title.is-active.is-selected,.fd-list__item--action .fd-list__title.is-active.is-selected.is-hover,.fd-list__item--action .fd-list__title.is-active.is-selected:hover,.fd-list__item--action .fd-list__title.is-active:hover,.fd-list__item--action .fd-list__title.is-active[aria-selected=true],.fd-list__item--action .fd-list__title.is-active[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title.is-active[aria-selected=true]:hover,.fd-list__item--action .fd-list__title:active,.fd-list__item--action .fd-list__title:active.is-hover,.fd-list__item--action .fd-list__title:active.is-selected,.fd-list__item--action .fd-list__title:active.is-selected.is-hover,.fd-list__item--action .fd-list__title:active.is-selected:hover,.fd-list__item--action .fd-list__title:active:hover,.fd-list__item--action .fd-list__title:active[aria-selected=true],.fd-list__item--action .fd-list__title:active[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__item--action .fd-list__title.is-active,.fd-list__item--action .fd-list__title.is-active .fd-list__byline,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-left,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--critical,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--informative,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--negative,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--neutral,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--positive,.fd-list__item--action .fd-list__title.is-active .fd-list__content,.fd-list__item--action .fd-list__title.is-active .fd-list__icon,.fd-list__item--action .fd-list__title.is-active .fd-list__secondary,.fd-list__item--action .fd-list__title.is-active .fd-list__thumbnail,.fd-list__item--action .fd-list__title.is-active .fd-list__title,.fd-list__item--action .fd-list__title.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--action .fd-list__title:active,.fd-list__item--action .fd-list__title:active .fd-list__byline,.fd-list__item--action .fd-list__title:active .fd-list__byline-left,.fd-list__item--action .fd-list__title:active .fd-list__byline-right,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--critical,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--informative,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--negative,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--neutral,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--positive,.fd-list__item--action .fd-list__title:active .fd-list__content,.fd-list__item--action .fd-list__title:active .fd-list__icon,.fd-list__item--action .fd-list__title:active .fd-list__secondary,.fd-list__item--action .fd-list__title:active .fd-list__thumbnail,.fd-list__item--action .fd-list__title:active .fd-list__title,.fd-list__item--action .fd-list__title:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__item--action .fd-list__title.is-focus,.fd-list__item--action .fd-list__title:focus{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.125rem}.fd-list__item--action .fd-list__title.is-focus.is-active,.fd-list__item--action .fd-list__title.is-focus:active,.fd-list__item--action .fd-list__title:focus.is-active,.fd-list__item--action .fd-list__title:focus:active{outline-color:var(--fdList_Active_Outline_Color)}.fd-list__item--action .fd-list__title::-moz-focus-inner{border:0}.fd-list__item--growing{--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list__item--growing .fd-list__title{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;gap:.5rem}.fd-list__item--growing .fd-list__title-text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:inherit;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;font-weight:var(--fdList_Growing_Font_Weight);forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;text-shadow:inherit;white-space:nowrap}.fd-list__item--growing .fd-list__title-text:after,.fd-list__item--growing .fd-list__title-text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__item--inactive,.fd-list__item--inactive .fd-list__secondary,.fd-list__item--inactive .fd-list__title{pointer-events:none}.fd-list__item.is-selected,.fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item.is-selected .fd-list__link,.fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item.is-selected .fd-list__link.is-active,.fd-list__item.is-selected .fd-list__link:active,.fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item.is-selected.is-hover,.fd-list__item.is-selected:hover,.fd-list__item[aria-selected=true].is-hover,.fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__secondary,.fd-list__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdList_Item_Text_Color);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;pointer-events:none;pointer-events:all;text-overflow:ellipsis;white-space:nowrap}.fd-list__secondary:after,.fd-list__secondary:before,.fd-list__title:after,.fd-list__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__title{-webkit-box-flex:3;-ms-flex:3 3 10%;flex:3 3 10%;font-size:var(--fdList_Item_Text_Font_Size);min-height:var(--fdList_Item_Text_Font_Size)}.fd-list__title:last-child:first-child{-ms-flex-preferred-size:auto;flex-basis:auto}.fd-list__title .fd-list__title-text{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-list__title~.fd-list__icon{-webkit-margin-end:-1rem;margin-inline-end:-1rem}.fd-list__secondary{color:var(--fdList_Status_Text_Color);font-size:var(--sapFontSize);max-width:40%;text-align:right;-webkit-padding-start:1rem;padding-inline-start:1rem}.fd-list__secondary--positive{--fdList_Status_Text_Color:var(--sapPositiveTextColor)}.fd-list__secondary--critical{--fdList_Status_Text_Color:var(--sapCriticalTextColor)}.fd-list__secondary--negative{--fdList_Status_Text_Color:var(--sapNegativeTextColor)}.fd-list__secondary--informative{--fdList_Status_Text_Color:var(--sapInformativeTextColor)}.fd-list__secondary[dir=rtl],[dir=rtl] .fd-list__secondary{text-align:left}.fd-list__icon [class*=sap-icon],.fd-list__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;pointer-events:none;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_NonInteractiveIconColor);font-size:var(--fdList_Item_Icon_Font_Size);width:2.75rem;-webkit-box-flex:0;-ms-flex:0 0 auto;flex:0 0 auto}.fd-list__icon [class*=sap-icon]:first-child,.fd-list__icon[class*=sap-icon]:first-child{-webkit-margin-start:-1rem;margin-inline-start:-1rem}.fd-list__link{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;--fdList_Item_Border_Color:transparent;background:var(--fdList_Item_Background_Color);border-bottom:var(--sapList_BorderWidth) solid var(--fdList_Item_Border_Color);cursor:pointer;height:100%;padding-block:0;padding-inline:.9375rem;text-decoration:none;width:100%}.fd-list__link:after,.fd-list__link:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__link.is-focus,.fd-list__link:focus{outline:none;pointer-events:all}.fd-list__link.is-focus:before,.fd-list__link:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem;pointer-events:none;position:absolute}.fd-list__link.is-focus.is-active:before,.fd-list__link.is-focus:active:before,.fd-list__link:focus.is-active:before,.fd-list__link:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-list__link.is-hover,.fd-list__link:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__link.is-selected,.fd-list__link[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__link.is-selected .fd-list__link,.fd-list__link[aria-selected=true] .fd-list__link{background:inherit}.fd-list__link.is-selected .fd-list__link.is-active,.fd-list__link.is-selected .fd-list__link:active,.fd-list__link[aria-selected=true] .fd-list__link.is-active,.fd-list__link[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__link.is-selected.is-hover,.fd-list__link.is-selected:hover,.fd-list__link[aria-selected=true].is-hover,.fd-list__link[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__link.is-active,.fd-list__link.is-active.is-hover,.fd-list__link.is-active.is-selected,.fd-list__link.is-active.is-selected.is-hover,.fd-list__link.is-active.is-selected:hover,.fd-list__link.is-active:hover,.fd-list__link.is-active[aria-selected=true],.fd-list__link.is-active[aria-selected=true].is-hover,.fd-list__link.is-active[aria-selected=true]:hover,.fd-list__link:active,.fd-list__link:active.is-hover,.fd-list__link:active.is-selected,.fd-list__link:active.is-selected.is-hover,.fd-list__link:active.is-selected:hover,.fd-list__link:active:hover,.fd-list__link:active[aria-selected=true],.fd-list__link:active[aria-selected=true].is-hover,.fd-list__link:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__link.is-active,.fd-list__link.is-active .fd-list__byline,.fd-list__link.is-active .fd-list__byline-left,.fd-list__link.is-active .fd-list__byline-right,.fd-list__link.is-active .fd-list__byline-right--critical,.fd-list__link.is-active .fd-list__byline-right--informative,.fd-list__link.is-active .fd-list__byline-right--negative,.fd-list__link.is-active .fd-list__byline-right--neutral,.fd-list__link.is-active .fd-list__byline-right--positive,.fd-list__link.is-active .fd-list__content,.fd-list__link.is-active .fd-list__icon,.fd-list__link.is-active .fd-list__secondary,.fd-list__link.is-active .fd-list__thumbnail,.fd-list__link.is-active .fd-list__title,.fd-list__link.is-active.fd-list__link--navigation-indicator:after,.fd-list__link:active,.fd-list__link:active .fd-list__byline,.fd-list__link:active .fd-list__byline-left,.fd-list__link:active .fd-list__byline-right,.fd-list__link:active .fd-list__byline-right--critical,.fd-list__link:active .fd-list__byline-right--informative,.fd-list__link:active .fd-list__byline-right--negative,.fd-list__link:active .fd-list__byline-right--neutral,.fd-list__link:active .fd-list__byline-right--positive,.fd-list__link:active .fd-list__content,.fd-list__link:active .fd-list__icon,.fd-list__link:active .fd-list__secondary,.fd-list__link:active .fd-list__thumbnail,.fd-list__link:active .fd-list__title,.fd-list__link:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__group-header{background:var(--sapList_GroupHeaderBackground);border-bottom:var(--sapList_BorderWidth) solid var(--sapList_GroupHeaderBorderColor);height:var(--sapElement_LineHeight);-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}.fd-list__group-header .fd-list__title{color:var(--sapList_TableGroupHeaderTextColor);font-family:var(--sapFontHeaderFamily);font-size:var(--sapFontHeader6Size);font-weight:700;line-height:2rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list__footer{background:var(--sapList_FooterBackground);color:var(--sapList_FooterTextColor);font-size:var(--sapFontSize);height:2rem}.fd-list__footer--right{-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end}.fd-list__footer--left{-webkit-box-pack:start;-ms-flex-pack:start;justify-content:flex-start}.fd-list__bold{font-weight:700}.fd-list__message{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:2rem;left:0;line-height:normal;line-height:2rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;position:absolute;text-overflow:ellipsis;top:0;white-space:nowrap;width:100%;-webkit-padding-start:.5rem;background-color:var(--fdList_Message_Background_Color);font-size:var(--sapFontSmallSize);padding-inline-start:.5rem}.fd-list__message:after,.fd-list__message:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__message--error{--fdList_Message_Background_Color:var(--sapErrorBackground)}.fd-list__message--warning{--fdList_Message_Background_Color:var(--sapWarningBackground)}.fd-list__message--success{--fdList_Message_Background_Color:var(--sapSuccessBackground)}.fd-list__message--information{--fdList_Message_Background_Color:var(--sapInformationBackground)}.fd-list .fd-list__button{-webkit-margin-start:var(--fdList_Button_Spacing);margin-inline-start:var(--fdList_Button_Spacing);-ms-flex-item-align:center;align-self:center}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view),.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view),[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view),[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view){--fdList_Item_Icon_Font_Size:1rem;--fdList_Item_Text_Font_Size:var(--sapFontSize);--fdList_Item_Height:var(--sapElement_Compact_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing{--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action{--fdList_Item_Height:var(--sapElement_Compact_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title{height:var(--fdList_Item_Action_Button_Size_Compact)}.fd-list--no-border .fd-list__group-header,.fd-list--no-border .fd-list__item{border-bottom:0;border-top:0}.fd-list--no-border .fd-list__item.is-selected,.fd-list--no-border .fd-list__item[aria-selected=true]{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-list--has-message{-webkit-padding-before:2rem;padding-block-start:2rem}.fd-list__infinite-scroll{outline:none;overflow:scroll}.fd-list--dropdown.is-focus,.fd-list--dropdown:focus{outline:none;z-index:5}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header){display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:auto;min-height:2.5rem;padding-block:0;padding-inline:.9375rem}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link{background:inherit}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link.is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link:active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link.is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true],.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true]:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true],.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-left,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--critical,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--informative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--negative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--neutral,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--positive,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__content,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__icon,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__secondary,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__thumbnail,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__title,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.fd-list__link--navigation-indicator:after,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-left,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--critical,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--informative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--negative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--neutral,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--positive,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__content,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__icon,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__secondary,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__thumbnail,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__title,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list--dropdown[class*=-compact] .fd-list__item:not(.fd-list__group-header),.fd-list--dropdown[class*=-condensed] .fd-list__item:not(.fd-list__group-header),[class*=-compact] .fd-list--dropdown:not([class*=-cozy]) .fd-list__item:not(.fd-list__group-header),[class*=-condensed] .fd-list--dropdown:not([class*=-cozy]) .fd-list__item:not(.fd-list__group-header){height:auto;min-height:2rem;padding-block:0;padding-inline:.9375rem}.fd-list--multi-input .fd-list__item{height:auto;padding-block:0;padding-inline:0 1rem}.fd-list--multi-input .fd-list__item.is-hover,.fd-list--multi-input .fd-list__item:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list--multi-input .fd-list__item.is-selected,.fd-list--multi-input .fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--multi-input .fd-list__item.is-selected .fd-list__link,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list--multi-input .fd-list__item.is-selected .fd-list__link.is-active,.fd-list--multi-input .fd-list__item.is-selected .fd-list__link:active,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--multi-input .fd-list__item.is-selected.is-hover,.fd-list--multi-input .fd-list__item.is-selected:hover,.fd-list--multi-input .fd-list__item[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--multi-input .fd-list__item.is-active,.fd-list--multi-input .fd-list__item.is-active.is-hover,.fd-list--multi-input .fd-list__item.is-active.is-selected,.fd-list--multi-input .fd-list__item.is-active.is-selected.is-hover,.fd-list--multi-input .fd-list__item.is-active.is-selected:hover,.fd-list--multi-input .fd-list__item.is-active:hover,.fd-list--multi-input .fd-list__item.is-active[aria-selected=true],.fd-list--multi-input .fd-list__item.is-active[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item.is-active[aria-selected=true]:hover,.fd-list--multi-input .fd-list__item:active,.fd-list--multi-input .fd-list__item:active.is-hover,.fd-list--multi-input .fd-list__item:active.is-selected,.fd-list--multi-input .fd-list__item:active.is-selected.is-hover,.fd-list--multi-input .fd-list__item:active.is-selected:hover,.fd-list--multi-input .fd-list__item:active:hover,.fd-list--multi-input .fd-list__item:active[aria-selected=true],.fd-list--multi-input .fd-list__item:active[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list--multi-input .fd-list__item.is-active,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-left,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--critical,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--informative,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--negative,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--neutral,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--positive,.fd-list--multi-input .fd-list__item.is-active .fd-list__content,.fd-list--multi-input .fd-list__item.is-active .fd-list__icon,.fd-list--multi-input .fd-list__item.is-active .fd-list__secondary,.fd-list--multi-input .fd-list__item.is-active .fd-list__thumbnail,.fd-list--multi-input .fd-list__item.is-active .fd-list__title,.fd-list--multi-input .fd-list__item.is-active.fd-list__link--navigation-indicator:after,.fd-list--multi-input .fd-list__item:active,.fd-list--multi-input .fd-list__item:active .fd-list__byline,.fd-list--multi-input .fd-list__item:active .fd-list__byline-left,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--critical,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--informative,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--negative,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--neutral,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--positive,.fd-list--multi-input .fd-list__item:active .fd-list__content,.fd-list--multi-input .fd-list__item:active .fd-list__icon,.fd-list--multi-input .fd-list__item:active .fd-list__secondary,.fd-list--multi-input .fd-list__item:active .fd-list__thumbnail,.fd-list--multi-input .fd-list__item:active .fd-list__title,.fd-list--multi-input .fd-list__item:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list--multi-input .fd-list__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:inherit;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;position:relative;text-overflow:ellipsis;width:100%;-webkit-margin-end:0;margin-inline-end:0}.fd-list--multi-input .fd-list__label:after,.fd-list--multi-input .fd-list__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--multi-input .fd-list__label:before{margin-block:-.1875rem -.1875rem}.fd-list--multi-input .fd-list__input.is-focus,.fd-list--multi-input .fd-list__input:focus{-webkit-box-shadow:none;box-shadow:none;z-index:5}.fd-list--multi-input .fd-list__input.is-focus+.fd-list__label:after,.fd-list--multi-input .fd-list__input:focus+.fd-list__label:after{inset:.0625rem}.fd-list--multi-input .fd-list__footer{height:auto;text-align:right;-webkit-box-pack:end;-ms-flex-pack:end;background-color:var(--sapList_Background);justify-content:flex-end;line-height:1rem}.fd-list--multi-input .fd-list__footer,.fd-list--multi-input .fd-list__label{padding-block:.75rem;padding-inline:.9375rem}.fd-list--multi-input[class*=-compact] .fd-list__item,.fd-list--multi-input[class*=-condensed] .fd-list__item,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__item,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__item{height:auto;padding-block:0;padding-inline:0}.fd-list--multi-input[class*=-compact] .fd-list__label:before,.fd-list--multi-input[class*=-condensed] .fd-list__label:before,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label:before,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label:before{-webkit-margin-start:0;margin-inline-start:0;margin-top:0;-webkit-margin-after:0;margin-block-end:0}.fd-list--multi-input[class*=-compact] .fd-list__footer,.fd-list--multi-input[class*=-compact] .fd-list__label,.fd-list--multi-input[class*=-condensed] .fd-list__footer,.fd-list--multi-input[class*=-condensed] .fd-list__label,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__footer,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__footer,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label{padding-block:.5rem;padding-inline:.9375rem}.fd-list--dropdown,.fd-list--multi-input{display:block;max-width:40rem;min-width:5rem}.fd-list--dropdown .fd-list__item,.fd-list--multi-input .fd-list__item{border:none;cursor:pointer}.fd-list--dropdown .fd-list__item.is-selected,.fd-list--dropdown .fd-list__item[aria-selected=true],.fd-list--multi-input .fd-list__item.is-selected,.fd-list--multi-input .fd-list__item[aria-selected=true]{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-list--dropdown .fd-list__secondary,.fd-list--dropdown .fd-list__title,.fd-list--multi-input .fd-list__secondary,.fd-list--multi-input .fd-list__title{font-size:var(--sapFontSize);white-space:normal;-webkit-box-flex:1;-ms-flex:auto;flex:auto;width:auto}.fd-list--dropdown .fd-list__secondary--no-wrap,.fd-list--dropdown .fd-list__title--no-wrap,.fd-list--multi-input .fd-list__secondary--no-wrap,.fd-list--multi-input .fd-list__title--no-wrap{white-space:nowrap}.fd-list--dropdown .fd-list__secondary,.fd-list--multi-input .fd-list__secondary{display:block}.fd-list--dropdown .fd-list__title,.fd-list--multi-input .fd-list__title{max-width:24rem}.fd-list--dropdown .fd-list__title:first-child:last-child,.fd-list--multi-input .fd-list__title:first-child:last-child{max-width:40rem}.fd-list--dropdown .fd-list__secondary,.fd-list--multi-input .fd-list__secondary{max-width:16rem}.fd-list--dropdown.fd-list--mobile,.fd-list--multi-input.fd-list--mobile{max-width:100%}.fd-list--dropdown .fd-list__icon,.fd-list--multi-input .fd-list__icon{line-height:1rem}.fd-list--dropdown.fd-list--large-dropdown,.fd-list--multi-input.fd-list--large-dropdown{max-width:62rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__title,.fd-list--multi-input.fd-list--large-dropdown .fd-list__title{max-width:37.2rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__title:first-child:last-child,.fd-list--multi-input.fd-list--large-dropdown .fd-list__title:first-child:last-child{max-width:62rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__secondary,.fd-list--multi-input.fd-list--large-dropdown .fd-list__secondary{max-width:24.8rem}.fd-list--dropdown.fd-list--large-dropdown.fd-list--mobile,.fd-list--multi-input.fd-list--large-dropdown.fd-list--mobile{max-width:100%}.fd-list--byline .fd-list__item{height:auto;min-height:5rem;padding-block:.9375rem;padding-inline:1rem;width:100%;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.fd-list--byline .fd-list__item.is-focus,.fd-list--byline .fd-list__item:focus{pointer-events:all;z-index:5}.fd-list--byline .fd-list__item .fd-list__item-counter{-ms-flex-align:center;-ms-flex-item-align:center;align-self:center;-webkit-box-pack:end;-ms-flex-pack:end;height:100%;justify-content:flex-end;min-width:2rem}.fd-list--byline .fd-list__item .fd-list__item-counter,.fd-list--byline .fd-list__thumbnail{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;align-items:center}.fd-list--byline .fd-list__thumbnail{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;pointer-events:none;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-ms-flex-align:center;-webkit-margin-end:.75rem;border-radius:.25rem;color:var(--sapContent_NonInteractiveIconColor);font-size:2rem;height:3rem;margin-inline-end:.75rem;max-height:3rem;max-width:3rem;min-height:3rem;min-width:3rem;width:3rem}.fd-list--byline .fd-list__thumbnail:after,.fd-list--byline .fd-list__thumbnail:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__thumbnail [class*=sap-icon],.fd-list--byline .fd-list__thumbnail[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;line-height:1}.fd-list--byline .fd-list__thumbnail>svg{height:100%}.fd-list--byline .fd-list__notification{color:var(--sapAccentColor6);font-size:.375rem;left:1rem;position:absolute;top:50%;-webkit-transform:translateY(-50%);transform:translateY(-50%)}.fd-list--byline .fd-list__notification[dir=rtl],[dir=rtl] .fd-list--byline .fd-list__notification{left:auto;right:1rem}.fd-list--byline .fd-list__notification+.fd-list__link .fd-list__content .fd-list__title,.fd-list--byline .fd-list__notification~.fd-list__content .fd-list__title{font-weight:700}.fd-list--byline .fd-list__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;pointer-events:none;-ms-flex-line-pack:justify;align-content:space-between;height:100%;min-height:3rem;min-width:3rem;-webkit-box-flex:1;-ms-flex:1 1 auto;flex:1 1 auto;padding-block:.125rem;padding-inline:0}.fd-list--byline .fd-list__content:after,.fd-list--byline .fd-list__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__title{font-size:var(--sapFontLargeSize);min-height:1rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list--byline .fd-list__byline{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-list--byline .fd-list__byline:after,.fd-list--byline .fd-list__byline:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline--2-col{display:-webkit-box;display:-ms-flexbox;display:flex;pointer-events:all}.fd-list--byline .fd-list__byline--wrap .fd-list__byline-left,.fd-list--byline .fd-list__byline--wrap .fd-list__byline-right{display:inline;padding-block:0;padding-inline:0;white-space:normal;width:100%}.fd-list--byline .fd-list__byline--wrap .fd-list__byline-right{float:right;width:auto}.fd-list--byline .fd-list__link--more{pointer-events:all;text-transform:capitalize}.fd-list--byline .fd-list__byline--wrap,.fd-list--byline .fd-list__title--wrap{white-space:normal}.fd-list--byline .fd-list__byline-left{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;width:60%;-ms-flex-item-align:end;align-self:flex-end;-webkit-padding-end:.5rem;padding-inline-end:.5rem}.fd-list--byline .fd-list__byline-left:after,.fd-list--byline .fd-list__byline-left:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline-right{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-align:right;text-overflow:ellipsis;white-space:nowrap;width:40%;-ms-flex-item-align:end;align-self:flex-end;-webkit-padding-start:.5rem;padding-inline-start:.5rem}.fd-list--byline .fd-list__byline-right:after,.fd-list--byline .fd-list__byline-right:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline-right[dir=rtl],[dir=rtl] .fd-list--byline .fd-list__byline-right{text-align:left}.fd-list--byline .fd-list__byline-right--neutral{color:var(--sapNeutralTextColor)}.fd-list--byline .fd-list__byline-right--positive{color:var(--sapPositiveTextColor)}.fd-list--byline .fd-list__byline-right--critical{color:var(--sapCriticalTextColor)}.fd-list--byline .fd-list__byline-right--negative{color:var(--sapNegativeTextColor)}.fd-list--byline .fd-list__byline-right--informative{color:var(--sapInformativeTextColor)}.fd-list--byline.fd-list--unread-indicator .fd-list__item{padding-inline:2.125rem 1rem}.fd-list--byline[class*=-compact] .fd-list__title,.fd-list--byline[class*=-condensed] .fd-list__title,[class*=-compact] .fd-list--byline:not([class*=-cozy]) .fd-list__title,[class*=-condensed] .fd-list--byline:not([class*=-cozy]) .fd-list__title{font-size:var(--sapFontSize)}.fd-list--byline.fd-list--no-border .fd-list__item{height:100%;max-height:5rem;padding-block:.5rem}.fd-list--byline.fd-list--no-border .fd-list__item:first-child{-webkit-padding-before:.9375rem;padding-block-start:.9375rem}.fd-list--byline.fd-list--no-border .fd-list__item:last-child{-webkit-padding-after:.9375rem;padding-block-end:.9375rem}.fd-list--message-view{--fdListNavigationIndicatorFontSize:.75rem;--fdList_Item_Height:calc(2.75rem + var(--sapList_BorderWidth));--fdList_Message_View_Item_Byline_Height:calc(3.325rem + var(--sapList_BorderWidth));--fdList_Message_View_Title_Size:var(--sapFontHeader5Size)}.fd-list--message-view .fd-list__item{height:auto}.fd-list--message-view .fd-list__item--byline{--fdList_Item_Height:var(--fdList_Message_View_Item_Byline_Height)}.fd-list--message-view .fd-list__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-flex:1;-ms-flex:1 1 auto;flex:1 1 auto;overflow:hidden;pointer-events:none;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__content:after,.fd-list--message-view .fd-list__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--message-view .fd-list__title{color:var(--sapGroup_TitleTextColor);font-family:var(--sapFontHeaderFamily);font-size:var(--fdList_Message_View_Title_Size);font-weight:var(--sapFontHeaderWeight,normal);overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__subtitle{-webkit-padding-before:.25rem;color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);overflow:hidden;padding-block-start:.25rem;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__link{padding-block:.5rem}.fd-list--message-view .fd-list__link.is-active .fd-list__subtitle,.fd-list--message-view .fd-list__link.is-active .fd-list__title,.fd-list--message-view .fd-list__link.is-active .fd-object-status .fd-object-status__icon,.fd-list--message-view .fd-list__link:active .fd-list__subtitle,.fd-list--message-view .fd-list__link:active .fd-list__title,.fd-list--message-view .fd-list__link:active .fd-object-status .fd-object-status__icon{color:var(--sapList_Active_TextColor)}.fd-list--message-view[class*=-compact],.fd-list--message-view[class*=-condensed],[class*=-compact] .fd-list--message-view:not([class*=-cozy]),[class*=-condensed] .fd-list--message-view:not([class*=-cozy]){--fdList_Message_View_Item_Height:calc(2rem + var(--sapList_BorderWidth));--fdList_Message_View_Title_Size:var(--sapFontHeader6Size);--fdList_Message_View_Item_Byline_Height:calc(3.25rem + var(--sapList_BorderWidth))}.fd-list--navigation .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-icon-tab-bar__list .fd-list__link{gap:.25rem}.fd-list--navigation .fd-list__link{padding-inline:var(--fdList_Navigation_Link_Padding_Left,.9375rem) var(--fdList_Navigation_Link_Padding_Right,.9375rem)}.fd-list--navigation.fd-list--unread-indicator{--fdList_Navigation_Link_Padding_Left:2.125rem;--fdList_Navigation_Link_Padding_Right:.9375rem}.fd-list--navigation.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:.9375rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--selection{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:.9375rem}.fd-list--navigation.fd-list--selection .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--selection.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--selection.fd-list--navigation-indication .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline,.fd-list--navigation.fd-list--byline.fd-list--compact{--fdList_Navigation_Link_Padding_Left:1rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--compact .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline .fd-list__link,.fd-list--navigation.fd-list--byline.fd-list--compact .fd-list__link{padding-block:.9375rem}.fd-list--navigation.fd-list--byline.fd-list--compact.fd-list--unread-indicator,.fd-list--navigation.fd-list--byline.fd-list--unread-indicator{--fdList_Navigation_Link_Padding_Left:2.125rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:.9375rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--byline.fd-list--selection{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-compact],.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-condensed],[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]),[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]){--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-compact] .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-condensed] .fd-list__item--link,[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]) .fd-list__item--link,[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]) .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication[class*=-compact],.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication[class*=-condensed],[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication:not([class*=-cozy]),[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication:not([class*=-cozy]){--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--navigation-object{--fdList_Navigation_Link_Padding_Left:1rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--navigation-object .fd-list__item--link,.fd-list--navigation.fd-list--navigation-object[dir=rtl] .fd-list__item--link,[dir=rtl] .fd-list--navigation.fd-list--navigation-object .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--navigation-object .fd-list__link{padding-block:1rem}.fd-list--navigation-indication .fd-list:after{content:\"\";min-width:1.5rem}.fd-list--navigation-indication fd-list__item.fd-list__item--link{-webkit-padding-end:0;padding-inline-end:0}.fd-list--navigation-indication fd-list__item.fd-list__item--link:after{content:none}.fd-list--navigation-indication .fd-list__link:after{content:\"\";min-width:2.5rem}.fd-list--navigation-indication .fd-list__link--navigation-indicator:after{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_NonInteractiveIconColor);content:\"\\e1ed\";font-family:SAP-icons;font-size:var(--fdListNavigationIndicatorFontSize,var(--sapFontLargeSize));height:100%;text-decoration:none;text-transform:none}.fd-list--navigation-indication .fd-list__link--navigation-indicator[dir=rtl]:after,[dir=rtl] .fd-list--navigation-indication .fd-list__link--navigation-indicator:after{content:\"\\e1ee\"}.fd-list--navigation-indication .fd-list__icon:last-child,.fd-list--navigation-indication .fd-list__icon[dir=rtl]:last-child,[dir=rtl] .fd-list--navigation-indication .fd-list__icon:last-child{margin-block:0;margin-inline:0}.fd-list--navigation-indication .is-navigated{-webkit-box-shadow:inset -.1875rem 0 0 0 var(--sapList_SelectionBorderColor);box-shadow:inset -.1875rem 0 0 0 var(--sapList_SelectionBorderColor)}.fd-list--navigation-indication .is-navigated[dir=rtl],[dir=rtl] .fd-list--navigation-indication .is-navigated{-webkit-box-shadow:inset .1875rem 0 0 0 var(--sapList_SelectionBorderColor);box-shadow:inset .1875rem 0 0 0 var(--sapList_SelectionBorderColor)}.fd-list--selection .fd-list__item{cursor:pointer;padding-inline:2.75rem .9375rem}.fd-list--selection .fd-list__item.is-hover,.fd-list--selection .fd-list__item:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background)}.fd-list--selection .fd-list__item.is-selected,.fd-list--selection .fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--selection .fd-list__item.is-selected .fd-list__link,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list--selection .fd-list__item.is-selected .fd-list__link.is-active,.fd-list--selection .fd-list__item.is-selected .fd-list__link:active,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--selection .fd-list__item.is-selected.is-hover,.fd-list--selection .fd-list__item.is-selected:hover,.fd-list--selection .fd-list__item[aria-selected=true].is-hover,.fd-list--selection .fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--selection .fd-list__form-item{left:0;position:absolute;top:0;z-index:5}.fd-list--selection .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection .fd-list__form-item{left:auto;right:0}.fd-list--selection[class*=-compact] .fd-list__form-item,.fd-list--selection[class*=-condensed] .fd-list__form-item,[class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item,[class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item{left:.375rem}.fd-list--selection[class*=-compact] .fd-list__form-item[dir=rtl],.fd-list--selection[class*=-condensed] .fd-list__form-item[dir=rtl],[class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection[class*=-compact] .fd-list__form-item,[dir=rtl] .fd-list--selection[class*=-condensed] .fd-list__form-item,[dir=rtl] [class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item,[dir=rtl] [class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item{left:auto;right:.375rem}.fd-list--selection.fd-list--byline .fd-list__item{padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline .fd-list__form-item{top:.3125rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__item,.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__item,[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__item,[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__item{padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item,.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item,[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item,[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item{left:.375rem;top:.5rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item[dir=rtl],.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item[dir=rtl],[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item,[dir=rtl] .fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item,[dir=rtl] [class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item,[dir=rtl] [class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item{left:auto;right:.375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item{padding-block:.5rem;padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:first-child{-webkit-padding-before:.9375rem;padding-block-start:.9375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:last-child{-webkit-padding-after:.9375rem;padding-block-end:.9375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item{top:0}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item label,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item label{-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item label:after,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item label:after{top:.375rem}.fd-list--selection.fd-list--selection-row .fd-list__item{-webkit-padding-start:1rem;padding-inline-start:1rem}:root{--fdList_Item_Background_Color:var(--sapList_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor);--fdList_Item_Text_Font_Size:var(--sapFontLargeSize);--fdList_Item_Icon_Font_Size:1.125rem;--fdList_Item_Height:var(--sapElement_LineHeight);--fdList_Status_Text_Color:var(--sapNeutralTextColor);--fdList_Message_Background_Color:var(--sapNeutralBackground)}.fd-list__item-counter{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-margin-start:1rem;color:var(--sapContent_MarkerTextColor);margin-inline-start:1rem}.fd-list__item-counter:after,.fd-list__item-counter:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__item--custom-content{height:fit-content!important;min-height:var(--fdList_Item_Action_Height)}\n/*! Bundled license information:\n\nfundamental-styles/dist/list.css:\n  (*!\n   * Fundamental Library Styles v0.38.0\n   * Copyright (c) 2024 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], ctorParameters: () => [{ type: i1.LiveAnnouncer }, { type: i2.Observable, decorators: [{
                    type: Inject,
                    args: [FD_LANGUAGE]
                }] }], propDecorators: { selectedItems: [{
                type: Input
            }], ariaSetsize: [{
                type: Input
            }], ariaMultiselectable: [{
                type: Input
            }], loadTitle: [{
                type: Input
            }], loadingLabel: [{
                type: Input
            }], delayTime: [{
                type: Input
            }], itemSize: [{
                type: Input
            }], loadMore: [{
                type: Input
            }], loadOnScroll: [{
                type: Input
            }], role: [{
                type: Input
            }], listType: [{
                type: Input
            }], maxHeight: [{
                type: Input
            }], noBorder: [{
                type: Input
            }], scrollOffsetPercentage: [{
                type: Input
            }], selection: [{
                type: Input
            }], selectionMode: [{
                type: Input
            }], value: [{
                type: Input
            }], rowSelection: [{
                type: Input
            }], dataSource: [{
                type: Input
            }], navigated: [{
                type: Input
            }], navigationIndicator: [{
                type: Input
            }], hasByLine: [{
                type: Input
            }], hasObject: [{
                type: Input
            }], unreadIndicator: [{
                type: Input
            }], interceptTabKey: [{
                type: Input
            }], selectedItemChange: [{
                type: Output
            }], anchor: [{
                type: ViewChild,
                args: ['link', { read: ElementRef }]
            }], listItemDef: [{
                type: ContentChild,
                args: [forwardRef(() => ListItemDef)]
            }], loadMoreContent: [{
                type: ContentChild,
                args: [LoadMoreContentDirective]
            }], listItems: [{
                type: ContentChildren,
                args: [forwardRef(() => BaseListItem), { descendants: true }]
            }], _updateNavigation: [{
                type: HostListener,
                args: ['click', ['$event']]
            }] } });

class ObjectListItemRowComponent {
    constructor() {
        /** object attribute is a link */
        this.islink = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ObjectListItemRowComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.7", type: ObjectListItemRowComponent, isStandalone: true, selector: "fdp-object-list-item-row", inputs: { attributeLabel: "attributeLabel", linkedText: "linkedText", islink: "islink" }, ngImport: i0, template: ` <div class="fd-object-list__row">
        <div class="fd-object-list__row-left">
            <fd-object-attribute
                class="fd-object-list__object-attribute"
                [islink]="islink"
                [label]="attributeLabel"
                [linkText]="linkedText"
            >
                <ng-content select=".attribute"></ng-content>
            </fd-object-attribute>
        </div>
        <div class="fd-object-list__row-right">
            <ng-content></ng-content>
        </div>
    </div>`, isInline: true, styles: [".fd-list{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;list-style:none;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative;width:100%}.fd-list:after,.fd-list:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__footer,.fd-list__group-header,.fd-list__item{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;padding-block:0;padding-inline:.9375rem}.fd-list__footer:after,.fd-list__footer:before,.fd-list__group-header:after,.fd-list__group-header:before,.fd-list__item:after,.fd-list__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__item{background:var(--fdList_Item_Background_Color);border-bottom:var(--sapList_BorderWidth) solid var(--fdList_Item_Border_Color);height:var(--fdList_Item_Height);position:relative}.fd-list__item.is-focus,.fd-list__item:focus{outline:none;pointer-events:all}.fd-list__item.is-focus:before,.fd-list__item:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem .125rem .0625rem;pointer-events:none;position:absolute}.fd-list__item.is-focus.is-active:before,.fd-list__item.is-focus:active:before,.fd-list__item:focus.is-active:before,.fd-list__item:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-list__item--unread .fd-list__title{font-weight:700}.fd-list__item--no-data .fd-list__title{text-align:center}.fd-list__item--interactive.is-hover,.fd-list__item--interactive:hover,.fd-list__item--interractive.is-hover,.fd-list__item--interractive:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__item--interactive.is-selected,.fd-list__item--interactive[aria-selected=true],.fd-list__item--interractive.is-selected,.fd-list__item--interractive[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item--interactive.is-selected .fd-list__link,.fd-list__item--interactive[aria-selected=true] .fd-list__link,.fd-list__item--interractive.is-selected .fd-list__link,.fd-list__item--interractive[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item--interactive.is-selected .fd-list__link.is-active,.fd-list__item--interactive.is-selected .fd-list__link:active,.fd-list__item--interactive[aria-selected=true] .fd-list__link.is-active,.fd-list__item--interactive[aria-selected=true] .fd-list__link:active,.fd-list__item--interractive.is-selected .fd-list__link.is-active,.fd-list__item--interractive.is-selected .fd-list__link:active,.fd-list__item--interractive[aria-selected=true] .fd-list__link.is-active,.fd-list__item--interractive[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item--interactive.is-selected.is-hover,.fd-list__item--interactive.is-selected:hover,.fd-list__item--interactive[aria-selected=true].is-hover,.fd-list__item--interactive[aria-selected=true]:hover,.fd-list__item--interractive.is-selected.is-hover,.fd-list__item--interractive.is-selected:hover,.fd-list__item--interractive[aria-selected=true].is-hover,.fd-list__item--interractive[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__item--interactive.is-active,.fd-list__item--interactive.is-active.is-hover,.fd-list__item--interactive.is-active.is-selected,.fd-list__item--interactive.is-active.is-selected.is-hover,.fd-list__item--interactive.is-active.is-selected:hover,.fd-list__item--interactive.is-active:hover,.fd-list__item--interactive.is-active[aria-selected=true],.fd-list__item--interactive.is-active[aria-selected=true].is-hover,.fd-list__item--interactive.is-active[aria-selected=true]:hover,.fd-list__item--interactive:active,.fd-list__item--interactive:active.is-hover,.fd-list__item--interactive:active.is-selected,.fd-list__item--interactive:active.is-selected.is-hover,.fd-list__item--interactive:active.is-selected:hover,.fd-list__item--interactive:active:hover,.fd-list__item--interactive:active[aria-selected=true],.fd-list__item--interactive:active[aria-selected=true].is-hover,.fd-list__item--interactive:active[aria-selected=true]:hover,.fd-list__item--interractive.is-active,.fd-list__item--interractive.is-active.is-hover,.fd-list__item--interractive.is-active.is-selected,.fd-list__item--interractive.is-active.is-selected.is-hover,.fd-list__item--interractive.is-active.is-selected:hover,.fd-list__item--interractive.is-active:hover,.fd-list__item--interractive.is-active[aria-selected=true],.fd-list__item--interractive.is-active[aria-selected=true].is-hover,.fd-list__item--interractive.is-active[aria-selected=true]:hover,.fd-list__item--interractive:active,.fd-list__item--interractive:active.is-hover,.fd-list__item--interractive:active.is-selected,.fd-list__item--interractive:active.is-selected.is-hover,.fd-list__item--interractive:active.is-selected:hover,.fd-list__item--interractive:active:hover,.fd-list__item--interractive:active[aria-selected=true],.fd-list__item--interractive:active[aria-selected=true].is-hover,.fd-list__item--interractive:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__item--interactive.is-active,.fd-list__item--interactive.is-active .fd-list__byline,.fd-list__item--interactive.is-active .fd-list__byline-left,.fd-list__item--interactive.is-active .fd-list__byline-right,.fd-list__item--interactive.is-active .fd-list__byline-right--critical,.fd-list__item--interactive.is-active .fd-list__byline-right--informative,.fd-list__item--interactive.is-active .fd-list__byline-right--negative,.fd-list__item--interactive.is-active .fd-list__byline-right--neutral,.fd-list__item--interactive.is-active .fd-list__byline-right--positive,.fd-list__item--interactive.is-active .fd-list__content,.fd-list__item--interactive.is-active .fd-list__icon,.fd-list__item--interactive.is-active .fd-list__secondary,.fd-list__item--interactive.is-active .fd-list__thumbnail,.fd-list__item--interactive.is-active .fd-list__title,.fd-list__item--interactive.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--interactive:active,.fd-list__item--interactive:active .fd-list__byline,.fd-list__item--interactive:active .fd-list__byline-left,.fd-list__item--interactive:active .fd-list__byline-right,.fd-list__item--interactive:active .fd-list__byline-right--critical,.fd-list__item--interactive:active .fd-list__byline-right--informative,.fd-list__item--interactive:active .fd-list__byline-right--negative,.fd-list__item--interactive:active .fd-list__byline-right--neutral,.fd-list__item--interactive:active .fd-list__byline-right--positive,.fd-list__item--interactive:active .fd-list__content,.fd-list__item--interactive:active .fd-list__icon,.fd-list__item--interactive:active .fd-list__secondary,.fd-list__item--interactive:active .fd-list__thumbnail,.fd-list__item--interactive:active .fd-list__title,.fd-list__item--interactive:active.fd-list__link--navigation-indicator:after,.fd-list__item--interractive.is-active,.fd-list__item--interractive.is-active .fd-list__byline,.fd-list__item--interractive.is-active .fd-list__byline-left,.fd-list__item--interractive.is-active .fd-list__byline-right,.fd-list__item--interractive.is-active .fd-list__byline-right--critical,.fd-list__item--interractive.is-active .fd-list__byline-right--informative,.fd-list__item--interractive.is-active .fd-list__byline-right--negative,.fd-list__item--interractive.is-active .fd-list__byline-right--neutral,.fd-list__item--interractive.is-active .fd-list__byline-right--positive,.fd-list__item--interractive.is-active .fd-list__content,.fd-list__item--interractive.is-active .fd-list__icon,.fd-list__item--interractive.is-active .fd-list__secondary,.fd-list__item--interractive.is-active .fd-list__thumbnail,.fd-list__item--interractive.is-active .fd-list__title,.fd-list__item--interractive.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--interractive:active,.fd-list__item--interractive:active .fd-list__byline,.fd-list__item--interractive:active .fd-list__byline-left,.fd-list__item--interractive:active .fd-list__byline-right,.fd-list__item--interractive:active .fd-list__byline-right--critical,.fd-list__item--interractive:active .fd-list__byline-right--informative,.fd-list__item--interractive:active .fd-list__byline-right--negative,.fd-list__item--interractive:active .fd-list__byline-right--neutral,.fd-list__item--interractive:active .fd-list__byline-right--positive,.fd-list__item--interractive:active .fd-list__content,.fd-list__item--interractive:active .fd-list__icon,.fd-list__item--interractive:active .fd-list__secondary,.fd-list__item--interractive:active .fd-list__thumbnail,.fd-list__item--interractive:active .fd-list__title,.fd-list__item--interractive:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__item--action{border-bottom:var(--fdList_Item_Action_Border);font-size:var(--sapFontSize);padding-block:0;padding-inline:0;text-align:center;--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list__item--action:first-child{border-top:var(--fdList_Item_Action_Border)}.fd-list__item--action .fd-list__title{background:transparent;border:var(--fdList_Item_Action_Button_Border);border-radius:var(--fdList_Item_Action_Button_Border_Radius);color:var(--sapButton_TextColor);cursor:pointer;height:var(--fdList_Item_Action_Button_Size);margin-block:var(--fdList_Item_Action_Button_Spacing);margin-inline:var(--fdList_Item_Action_Button_Spacing);padding-block:0;padding-inline:.9375rem;pointer-events:all;width:100%}.fd-list__item--action .fd-list__title.is-hover,.fd-list__item--action .fd-list__title:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__item--action .fd-list__title.is-selected,.fd-list__item--action .fd-list__title[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item--action .fd-list__title.is-selected .fd-list__link,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item--action .fd-list__title.is-selected .fd-list__link.is-active,.fd-list__item--action .fd-list__title.is-selected .fd-list__link:active,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link.is-active,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item--action .fd-list__title.is-selected.is-hover,.fd-list__item--action .fd-list__title.is-selected:hover,.fd-list__item--action .fd-list__title[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__item--action .fd-list__title.is-active,.fd-list__item--action .fd-list__title.is-active.is-hover,.fd-list__item--action .fd-list__title.is-active.is-selected,.fd-list__item--action .fd-list__title.is-active.is-selected.is-hover,.fd-list__item--action .fd-list__title.is-active.is-selected:hover,.fd-list__item--action .fd-list__title.is-active:hover,.fd-list__item--action .fd-list__title.is-active[aria-selected=true],.fd-list__item--action .fd-list__title.is-active[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title.is-active[aria-selected=true]:hover,.fd-list__item--action .fd-list__title:active,.fd-list__item--action .fd-list__title:active.is-hover,.fd-list__item--action .fd-list__title:active.is-selected,.fd-list__item--action .fd-list__title:active.is-selected.is-hover,.fd-list__item--action .fd-list__title:active.is-selected:hover,.fd-list__item--action .fd-list__title:active:hover,.fd-list__item--action .fd-list__title:active[aria-selected=true],.fd-list__item--action .fd-list__title:active[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__item--action .fd-list__title.is-active,.fd-list__item--action .fd-list__title.is-active .fd-list__byline,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-left,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--critical,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--informative,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--negative,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--neutral,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--positive,.fd-list__item--action .fd-list__title.is-active .fd-list__content,.fd-list__item--action .fd-list__title.is-active .fd-list__icon,.fd-list__item--action .fd-list__title.is-active .fd-list__secondary,.fd-list__item--action .fd-list__title.is-active .fd-list__thumbnail,.fd-list__item--action .fd-list__title.is-active .fd-list__title,.fd-list__item--action .fd-list__title.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--action .fd-list__title:active,.fd-list__item--action .fd-list__title:active .fd-list__byline,.fd-list__item--action .fd-list__title:active .fd-list__byline-left,.fd-list__item--action .fd-list__title:active .fd-list__byline-right,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--critical,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--informative,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--negative,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--neutral,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--positive,.fd-list__item--action .fd-list__title:active .fd-list__content,.fd-list__item--action .fd-list__title:active .fd-list__icon,.fd-list__item--action .fd-list__title:active .fd-list__secondary,.fd-list__item--action .fd-list__title:active .fd-list__thumbnail,.fd-list__item--action .fd-list__title:active .fd-list__title,.fd-list__item--action .fd-list__title:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__item--action .fd-list__title.is-focus,.fd-list__item--action .fd-list__title:focus{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.125rem}.fd-list__item--action .fd-list__title.is-focus.is-active,.fd-list__item--action .fd-list__title.is-focus:active,.fd-list__item--action .fd-list__title:focus.is-active,.fd-list__item--action .fd-list__title:focus:active{outline-color:var(--fdList_Active_Outline_Color)}.fd-list__item--action .fd-list__title::-moz-focus-inner{border:0}.fd-list__item--growing{--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list__item--growing .fd-list__title{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;gap:.5rem}.fd-list__item--growing .fd-list__title-text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:inherit;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;font-weight:var(--fdList_Growing_Font_Weight);forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;text-shadow:inherit;white-space:nowrap}.fd-list__item--growing .fd-list__title-text:after,.fd-list__item--growing .fd-list__title-text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__item--inactive,.fd-list__item--inactive .fd-list__secondary,.fd-list__item--inactive .fd-list__title{pointer-events:none}.fd-list__item.is-selected,.fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item.is-selected .fd-list__link,.fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item.is-selected .fd-list__link.is-active,.fd-list__item.is-selected .fd-list__link:active,.fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item.is-selected.is-hover,.fd-list__item.is-selected:hover,.fd-list__item[aria-selected=true].is-hover,.fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__secondary,.fd-list__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdList_Item_Text_Color);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;pointer-events:none;pointer-events:all;text-overflow:ellipsis;white-space:nowrap}.fd-list__secondary:after,.fd-list__secondary:before,.fd-list__title:after,.fd-list__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__title{-webkit-box-flex:3;-ms-flex:3 3 10%;flex:3 3 10%;font-size:var(--fdList_Item_Text_Font_Size);min-height:var(--fdList_Item_Text_Font_Size)}.fd-list__title:last-child:first-child{-ms-flex-preferred-size:auto;flex-basis:auto}.fd-list__title .fd-list__title-text{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-list__title~.fd-list__icon{-webkit-margin-end:-1rem;margin-inline-end:-1rem}.fd-list__secondary{color:var(--fdList_Status_Text_Color);font-size:var(--sapFontSize);max-width:40%;text-align:right;-webkit-padding-start:1rem;padding-inline-start:1rem}.fd-list__secondary--positive{--fdList_Status_Text_Color:var(--sapPositiveTextColor)}.fd-list__secondary--critical{--fdList_Status_Text_Color:var(--sapCriticalTextColor)}.fd-list__secondary--negative{--fdList_Status_Text_Color:var(--sapNegativeTextColor)}.fd-list__secondary--informative{--fdList_Status_Text_Color:var(--sapInformativeTextColor)}.fd-list__secondary[dir=rtl],[dir=rtl] .fd-list__secondary{text-align:left}.fd-list__icon [class*=sap-icon],.fd-list__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;pointer-events:none;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_NonInteractiveIconColor);font-size:var(--fdList_Item_Icon_Font_Size);width:2.75rem;-webkit-box-flex:0;-ms-flex:0 0 auto;flex:0 0 auto}.fd-list__icon [class*=sap-icon]:first-child,.fd-list__icon[class*=sap-icon]:first-child{-webkit-margin-start:-1rem;margin-inline-start:-1rem}.fd-list__link{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;--fdList_Item_Border_Color:transparent;background:var(--fdList_Item_Background_Color);border-bottom:var(--sapList_BorderWidth) solid var(--fdList_Item_Border_Color);cursor:pointer;height:100%;padding-block:0;padding-inline:.9375rem;text-decoration:none;width:100%}.fd-list__link:after,.fd-list__link:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__link.is-focus,.fd-list__link:focus{outline:none;pointer-events:all}.fd-list__link.is-focus:before,.fd-list__link:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem;pointer-events:none;position:absolute}.fd-list__link.is-focus.is-active:before,.fd-list__link.is-focus:active:before,.fd-list__link:focus.is-active:before,.fd-list__link:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-list__link.is-hover,.fd-list__link:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__link.is-selected,.fd-list__link[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__link.is-selected .fd-list__link,.fd-list__link[aria-selected=true] .fd-list__link{background:inherit}.fd-list__link.is-selected .fd-list__link.is-active,.fd-list__link.is-selected .fd-list__link:active,.fd-list__link[aria-selected=true] .fd-list__link.is-active,.fd-list__link[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__link.is-selected.is-hover,.fd-list__link.is-selected:hover,.fd-list__link[aria-selected=true].is-hover,.fd-list__link[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__link.is-active,.fd-list__link.is-active.is-hover,.fd-list__link.is-active.is-selected,.fd-list__link.is-active.is-selected.is-hover,.fd-list__link.is-active.is-selected:hover,.fd-list__link.is-active:hover,.fd-list__link.is-active[aria-selected=true],.fd-list__link.is-active[aria-selected=true].is-hover,.fd-list__link.is-active[aria-selected=true]:hover,.fd-list__link:active,.fd-list__link:active.is-hover,.fd-list__link:active.is-selected,.fd-list__link:active.is-selected.is-hover,.fd-list__link:active.is-selected:hover,.fd-list__link:active:hover,.fd-list__link:active[aria-selected=true],.fd-list__link:active[aria-selected=true].is-hover,.fd-list__link:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__link.is-active,.fd-list__link.is-active .fd-list__byline,.fd-list__link.is-active .fd-list__byline-left,.fd-list__link.is-active .fd-list__byline-right,.fd-list__link.is-active .fd-list__byline-right--critical,.fd-list__link.is-active .fd-list__byline-right--informative,.fd-list__link.is-active .fd-list__byline-right--negative,.fd-list__link.is-active .fd-list__byline-right--neutral,.fd-list__link.is-active .fd-list__byline-right--positive,.fd-list__link.is-active .fd-list__content,.fd-list__link.is-active .fd-list__icon,.fd-list__link.is-active .fd-list__secondary,.fd-list__link.is-active .fd-list__thumbnail,.fd-list__link.is-active .fd-list__title,.fd-list__link.is-active.fd-list__link--navigation-indicator:after,.fd-list__link:active,.fd-list__link:active .fd-list__byline,.fd-list__link:active .fd-list__byline-left,.fd-list__link:active .fd-list__byline-right,.fd-list__link:active .fd-list__byline-right--critical,.fd-list__link:active .fd-list__byline-right--informative,.fd-list__link:active .fd-list__byline-right--negative,.fd-list__link:active .fd-list__byline-right--neutral,.fd-list__link:active .fd-list__byline-right--positive,.fd-list__link:active .fd-list__content,.fd-list__link:active .fd-list__icon,.fd-list__link:active .fd-list__secondary,.fd-list__link:active .fd-list__thumbnail,.fd-list__link:active .fd-list__title,.fd-list__link:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__group-header{background:var(--sapList_GroupHeaderBackground);border-bottom:var(--sapList_BorderWidth) solid var(--sapList_GroupHeaderBorderColor);height:var(--sapElement_LineHeight);-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}.fd-list__group-header .fd-list__title{color:var(--sapList_TableGroupHeaderTextColor);font-family:var(--sapFontHeaderFamily);font-size:var(--sapFontHeader6Size);font-weight:700;line-height:2rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list__footer{background:var(--sapList_FooterBackground);color:var(--sapList_FooterTextColor);font-size:var(--sapFontSize);height:2rem}.fd-list__footer--right{-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end}.fd-list__footer--left{-webkit-box-pack:start;-ms-flex-pack:start;justify-content:flex-start}.fd-list__bold{font-weight:700}.fd-list__message{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:2rem;left:0;line-height:normal;line-height:2rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;position:absolute;text-overflow:ellipsis;top:0;white-space:nowrap;width:100%;-webkit-padding-start:.5rem;background-color:var(--fdList_Message_Background_Color);font-size:var(--sapFontSmallSize);padding-inline-start:.5rem}.fd-list__message:after,.fd-list__message:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__message--error{--fdList_Message_Background_Color:var(--sapErrorBackground)}.fd-list__message--warning{--fdList_Message_Background_Color:var(--sapWarningBackground)}.fd-list__message--success{--fdList_Message_Background_Color:var(--sapSuccessBackground)}.fd-list__message--information{--fdList_Message_Background_Color:var(--sapInformationBackground)}.fd-list .fd-list__button{-webkit-margin-start:var(--fdList_Button_Spacing);margin-inline-start:var(--fdList_Button_Spacing);-ms-flex-item-align:center;align-self:center}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view),.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view),[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view),[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view){--fdList_Item_Icon_Font_Size:1rem;--fdList_Item_Text_Font_Size:var(--sapFontSize);--fdList_Item_Height:var(--sapElement_Compact_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing{--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action{--fdList_Item_Height:var(--sapElement_Compact_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title{height:var(--fdList_Item_Action_Button_Size_Compact)}.fd-list--no-border .fd-list__group-header,.fd-list--no-border .fd-list__item{border-bottom:0;border-top:0}.fd-list--no-border .fd-list__item.is-selected,.fd-list--no-border .fd-list__item[aria-selected=true]{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-list--has-message{-webkit-padding-before:2rem;padding-block-start:2rem}.fd-list__infinite-scroll{outline:none;overflow:scroll}.fd-list--dropdown.is-focus,.fd-list--dropdown:focus{outline:none;z-index:5}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header){display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:auto;min-height:2.5rem;padding-block:0;padding-inline:.9375rem}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link{background:inherit}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link.is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link:active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link.is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true],.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true]:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true],.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-left,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--critical,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--informative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--negative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--neutral,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--positive,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__content,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__icon,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__secondary,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__thumbnail,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__title,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.fd-list__link--navigation-indicator:after,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-left,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--critical,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--informative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--negative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--neutral,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--positive,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__content,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__icon,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__secondary,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__thumbnail,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__title,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list--dropdown[class*=-compact] .fd-list__item:not(.fd-list__group-header),.fd-list--dropdown[class*=-condensed] .fd-list__item:not(.fd-list__group-header),[class*=-compact] .fd-list--dropdown:not([class*=-cozy]) .fd-list__item:not(.fd-list__group-header),[class*=-condensed] .fd-list--dropdown:not([class*=-cozy]) .fd-list__item:not(.fd-list__group-header){height:auto;min-height:2rem;padding-block:0;padding-inline:.9375rem}.fd-list--multi-input .fd-list__item{height:auto;padding-block:0;padding-inline:0 1rem}.fd-list--multi-input .fd-list__item.is-hover,.fd-list--multi-input .fd-list__item:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list--multi-input .fd-list__item.is-selected,.fd-list--multi-input .fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--multi-input .fd-list__item.is-selected .fd-list__link,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list--multi-input .fd-list__item.is-selected .fd-list__link.is-active,.fd-list--multi-input .fd-list__item.is-selected .fd-list__link:active,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--multi-input .fd-list__item.is-selected.is-hover,.fd-list--multi-input .fd-list__item.is-selected:hover,.fd-list--multi-input .fd-list__item[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--multi-input .fd-list__item.is-active,.fd-list--multi-input .fd-list__item.is-active.is-hover,.fd-list--multi-input .fd-list__item.is-active.is-selected,.fd-list--multi-input .fd-list__item.is-active.is-selected.is-hover,.fd-list--multi-input .fd-list__item.is-active.is-selected:hover,.fd-list--multi-input .fd-list__item.is-active:hover,.fd-list--multi-input .fd-list__item.is-active[aria-selected=true],.fd-list--multi-input .fd-list__item.is-active[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item.is-active[aria-selected=true]:hover,.fd-list--multi-input .fd-list__item:active,.fd-list--multi-input .fd-list__item:active.is-hover,.fd-list--multi-input .fd-list__item:active.is-selected,.fd-list--multi-input .fd-list__item:active.is-selected.is-hover,.fd-list--multi-input .fd-list__item:active.is-selected:hover,.fd-list--multi-input .fd-list__item:active:hover,.fd-list--multi-input .fd-list__item:active[aria-selected=true],.fd-list--multi-input .fd-list__item:active[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list--multi-input .fd-list__item.is-active,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-left,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--critical,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--informative,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--negative,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--neutral,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--positive,.fd-list--multi-input .fd-list__item.is-active .fd-list__content,.fd-list--multi-input .fd-list__item.is-active .fd-list__icon,.fd-list--multi-input .fd-list__item.is-active .fd-list__secondary,.fd-list--multi-input .fd-list__item.is-active .fd-list__thumbnail,.fd-list--multi-input .fd-list__item.is-active .fd-list__title,.fd-list--multi-input .fd-list__item.is-active.fd-list__link--navigation-indicator:after,.fd-list--multi-input .fd-list__item:active,.fd-list--multi-input .fd-list__item:active .fd-list__byline,.fd-list--multi-input .fd-list__item:active .fd-list__byline-left,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--critical,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--informative,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--negative,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--neutral,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--positive,.fd-list--multi-input .fd-list__item:active .fd-list__content,.fd-list--multi-input .fd-list__item:active .fd-list__icon,.fd-list--multi-input .fd-list__item:active .fd-list__secondary,.fd-list--multi-input .fd-list__item:active .fd-list__thumbnail,.fd-list--multi-input .fd-list__item:active .fd-list__title,.fd-list--multi-input .fd-list__item:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list--multi-input .fd-list__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:inherit;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;position:relative;text-overflow:ellipsis;width:100%;-webkit-margin-end:0;margin-inline-end:0}.fd-list--multi-input .fd-list__label:after,.fd-list--multi-input .fd-list__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--multi-input .fd-list__label:before{margin-block:-.1875rem -.1875rem}.fd-list--multi-input .fd-list__input.is-focus,.fd-list--multi-input .fd-list__input:focus{-webkit-box-shadow:none;box-shadow:none;z-index:5}.fd-list--multi-input .fd-list__input.is-focus+.fd-list__label:after,.fd-list--multi-input .fd-list__input:focus+.fd-list__label:after{inset:.0625rem}.fd-list--multi-input .fd-list__footer{height:auto;text-align:right;-webkit-box-pack:end;-ms-flex-pack:end;background-color:var(--sapList_Background);justify-content:flex-end;line-height:1rem}.fd-list--multi-input .fd-list__footer,.fd-list--multi-input .fd-list__label{padding-block:.75rem;padding-inline:.9375rem}.fd-list--multi-input[class*=-compact] .fd-list__item,.fd-list--multi-input[class*=-condensed] .fd-list__item,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__item,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__item{height:auto;padding-block:0;padding-inline:0}.fd-list--multi-input[class*=-compact] .fd-list__label:before,.fd-list--multi-input[class*=-condensed] .fd-list__label:before,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label:before,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label:before{-webkit-margin-start:0;margin-inline-start:0;margin-top:0;-webkit-margin-after:0;margin-block-end:0}.fd-list--multi-input[class*=-compact] .fd-list__footer,.fd-list--multi-input[class*=-compact] .fd-list__label,.fd-list--multi-input[class*=-condensed] .fd-list__footer,.fd-list--multi-input[class*=-condensed] .fd-list__label,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__footer,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__footer,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label{padding-block:.5rem;padding-inline:.9375rem}.fd-list--dropdown,.fd-list--multi-input{display:block;max-width:40rem;min-width:5rem}.fd-list--dropdown .fd-list__item,.fd-list--multi-input .fd-list__item{border:none;cursor:pointer}.fd-list--dropdown .fd-list__item.is-selected,.fd-list--dropdown .fd-list__item[aria-selected=true],.fd-list--multi-input .fd-list__item.is-selected,.fd-list--multi-input .fd-list__item[aria-selected=true]{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-list--dropdown .fd-list__secondary,.fd-list--dropdown .fd-list__title,.fd-list--multi-input .fd-list__secondary,.fd-list--multi-input .fd-list__title{font-size:var(--sapFontSize);white-space:normal;-webkit-box-flex:1;-ms-flex:auto;flex:auto;width:auto}.fd-list--dropdown .fd-list__secondary--no-wrap,.fd-list--dropdown .fd-list__title--no-wrap,.fd-list--multi-input .fd-list__secondary--no-wrap,.fd-list--multi-input .fd-list__title--no-wrap{white-space:nowrap}.fd-list--dropdown .fd-list__secondary,.fd-list--multi-input .fd-list__secondary{display:block}.fd-list--dropdown .fd-list__title,.fd-list--multi-input .fd-list__title{max-width:24rem}.fd-list--dropdown .fd-list__title:first-child:last-child,.fd-list--multi-input .fd-list__title:first-child:last-child{max-width:40rem}.fd-list--dropdown .fd-list__secondary,.fd-list--multi-input .fd-list__secondary{max-width:16rem}.fd-list--dropdown.fd-list--mobile,.fd-list--multi-input.fd-list--mobile{max-width:100%}.fd-list--dropdown .fd-list__icon,.fd-list--multi-input .fd-list__icon{line-height:1rem}.fd-list--dropdown.fd-list--large-dropdown,.fd-list--multi-input.fd-list--large-dropdown{max-width:62rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__title,.fd-list--multi-input.fd-list--large-dropdown .fd-list__title{max-width:37.2rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__title:first-child:last-child,.fd-list--multi-input.fd-list--large-dropdown .fd-list__title:first-child:last-child{max-width:62rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__secondary,.fd-list--multi-input.fd-list--large-dropdown .fd-list__secondary{max-width:24.8rem}.fd-list--dropdown.fd-list--large-dropdown.fd-list--mobile,.fd-list--multi-input.fd-list--large-dropdown.fd-list--mobile{max-width:100%}.fd-list--byline .fd-list__item{height:auto;min-height:5rem;padding-block:.9375rem;padding-inline:1rem;width:100%;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.fd-list--byline .fd-list__item.is-focus,.fd-list--byline .fd-list__item:focus{pointer-events:all;z-index:5}.fd-list--byline .fd-list__item .fd-list__item-counter{-ms-flex-align:center;-ms-flex-item-align:center;align-self:center;-webkit-box-pack:end;-ms-flex-pack:end;height:100%;justify-content:flex-end;min-width:2rem}.fd-list--byline .fd-list__item .fd-list__item-counter,.fd-list--byline .fd-list__thumbnail{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;align-items:center}.fd-list--byline .fd-list__thumbnail{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;pointer-events:none;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-ms-flex-align:center;-webkit-margin-end:.75rem;border-radius:.25rem;color:var(--sapContent_NonInteractiveIconColor);font-size:2rem;height:3rem;margin-inline-end:.75rem;max-height:3rem;max-width:3rem;min-height:3rem;min-width:3rem;width:3rem}.fd-list--byline .fd-list__thumbnail:after,.fd-list--byline .fd-list__thumbnail:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__thumbnail [class*=sap-icon],.fd-list--byline .fd-list__thumbnail[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;line-height:1}.fd-list--byline .fd-list__thumbnail>svg{height:100%}.fd-list--byline .fd-list__notification{color:var(--sapAccentColor6);font-size:.375rem;left:1rem;position:absolute;top:50%;-webkit-transform:translateY(-50%);transform:translateY(-50%)}.fd-list--byline .fd-list__notification[dir=rtl],[dir=rtl] .fd-list--byline .fd-list__notification{left:auto;right:1rem}.fd-list--byline .fd-list__notification+.fd-list__link .fd-list__content .fd-list__title,.fd-list--byline .fd-list__notification~.fd-list__content .fd-list__title{font-weight:700}.fd-list--byline .fd-list__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;pointer-events:none;-ms-flex-line-pack:justify;align-content:space-between;height:100%;min-height:3rem;min-width:3rem;-webkit-box-flex:1;-ms-flex:1 1 auto;flex:1 1 auto;padding-block:.125rem;padding-inline:0}.fd-list--byline .fd-list__content:after,.fd-list--byline .fd-list__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__title{font-size:var(--sapFontLargeSize);min-height:1rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list--byline .fd-list__byline{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-list--byline .fd-list__byline:after,.fd-list--byline .fd-list__byline:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline--2-col{display:-webkit-box;display:-ms-flexbox;display:flex;pointer-events:all}.fd-list--byline .fd-list__byline--wrap .fd-list__byline-left,.fd-list--byline .fd-list__byline--wrap .fd-list__byline-right{display:inline;padding-block:0;padding-inline:0;white-space:normal;width:100%}.fd-list--byline .fd-list__byline--wrap .fd-list__byline-right{float:right;width:auto}.fd-list--byline .fd-list__link--more{pointer-events:all;text-transform:capitalize}.fd-list--byline .fd-list__byline--wrap,.fd-list--byline .fd-list__title--wrap{white-space:normal}.fd-list--byline .fd-list__byline-left{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;width:60%;-ms-flex-item-align:end;align-self:flex-end;-webkit-padding-end:.5rem;padding-inline-end:.5rem}.fd-list--byline .fd-list__byline-left:after,.fd-list--byline .fd-list__byline-left:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline-right{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-align:right;text-overflow:ellipsis;white-space:nowrap;width:40%;-ms-flex-item-align:end;align-self:flex-end;-webkit-padding-start:.5rem;padding-inline-start:.5rem}.fd-list--byline .fd-list__byline-right:after,.fd-list--byline .fd-list__byline-right:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline-right[dir=rtl],[dir=rtl] .fd-list--byline .fd-list__byline-right{text-align:left}.fd-list--byline .fd-list__byline-right--neutral{color:var(--sapNeutralTextColor)}.fd-list--byline .fd-list__byline-right--positive{color:var(--sapPositiveTextColor)}.fd-list--byline .fd-list__byline-right--critical{color:var(--sapCriticalTextColor)}.fd-list--byline .fd-list__byline-right--negative{color:var(--sapNegativeTextColor)}.fd-list--byline .fd-list__byline-right--informative{color:var(--sapInformativeTextColor)}.fd-list--byline.fd-list--unread-indicator .fd-list__item{padding-inline:2.125rem 1rem}.fd-list--byline[class*=-compact] .fd-list__title,.fd-list--byline[class*=-condensed] .fd-list__title,[class*=-compact] .fd-list--byline:not([class*=-cozy]) .fd-list__title,[class*=-condensed] .fd-list--byline:not([class*=-cozy]) .fd-list__title{font-size:var(--sapFontSize)}.fd-list--byline.fd-list--no-border .fd-list__item{height:100%;max-height:5rem;padding-block:.5rem}.fd-list--byline.fd-list--no-border .fd-list__item:first-child{-webkit-padding-before:.9375rem;padding-block-start:.9375rem}.fd-list--byline.fd-list--no-border .fd-list__item:last-child{-webkit-padding-after:.9375rem;padding-block-end:.9375rem}.fd-list--message-view{--fdListNavigationIndicatorFontSize:.75rem;--fdList_Item_Height:calc(2.75rem + var(--sapList_BorderWidth));--fdList_Message_View_Item_Byline_Height:calc(3.325rem + var(--sapList_BorderWidth));--fdList_Message_View_Title_Size:var(--sapFontHeader5Size)}.fd-list--message-view .fd-list__item{height:auto}.fd-list--message-view .fd-list__item--byline{--fdList_Item_Height:var(--fdList_Message_View_Item_Byline_Height)}.fd-list--message-view .fd-list__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-flex:1;-ms-flex:1 1 auto;flex:1 1 auto;overflow:hidden;pointer-events:none;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__content:after,.fd-list--message-view .fd-list__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--message-view .fd-list__title{color:var(--sapGroup_TitleTextColor);font-family:var(--sapFontHeaderFamily);font-size:var(--fdList_Message_View_Title_Size);font-weight:var(--sapFontHeaderWeight,normal);overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__subtitle{-webkit-padding-before:.25rem;color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);overflow:hidden;padding-block-start:.25rem;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__link{padding-block:.5rem}.fd-list--message-view .fd-list__link.is-active .fd-list__subtitle,.fd-list--message-view .fd-list__link.is-active .fd-list__title,.fd-list--message-view .fd-list__link.is-active .fd-object-status .fd-object-status__icon,.fd-list--message-view .fd-list__link:active .fd-list__subtitle,.fd-list--message-view .fd-list__link:active .fd-list__title,.fd-list--message-view .fd-list__link:active .fd-object-status .fd-object-status__icon{color:var(--sapList_Active_TextColor)}.fd-list--message-view[class*=-compact],.fd-list--message-view[class*=-condensed],[class*=-compact] .fd-list--message-view:not([class*=-cozy]),[class*=-condensed] .fd-list--message-view:not([class*=-cozy]){--fdList_Message_View_Item_Height:calc(2rem + var(--sapList_BorderWidth));--fdList_Message_View_Title_Size:var(--sapFontHeader6Size);--fdList_Message_View_Item_Byline_Height:calc(3.25rem + var(--sapList_BorderWidth))}.fd-list--navigation .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-icon-tab-bar__list .fd-list__link{gap:.25rem}.fd-list--navigation .fd-list__link{padding-inline:var(--fdList_Navigation_Link_Padding_Left,.9375rem) var(--fdList_Navigation_Link_Padding_Right,.9375rem)}.fd-list--navigation.fd-list--unread-indicator{--fdList_Navigation_Link_Padding_Left:2.125rem;--fdList_Navigation_Link_Padding_Right:.9375rem}.fd-list--navigation.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:.9375rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--selection{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:.9375rem}.fd-list--navigation.fd-list--selection .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--selection.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--selection.fd-list--navigation-indication .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline,.fd-list--navigation.fd-list--byline.fd-list--compact{--fdList_Navigation_Link_Padding_Left:1rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--compact .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline .fd-list__link,.fd-list--navigation.fd-list--byline.fd-list--compact .fd-list__link{padding-block:.9375rem}.fd-list--navigation.fd-list--byline.fd-list--compact.fd-list--unread-indicator,.fd-list--navigation.fd-list--byline.fd-list--unread-indicator{--fdList_Navigation_Link_Padding_Left:2.125rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:.9375rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--byline.fd-list--selection{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-compact],.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-condensed],[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]),[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]){--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-compact] .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-condensed] .fd-list__item--link,[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]) .fd-list__item--link,[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]) .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication[class*=-compact],.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication[class*=-condensed],[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication:not([class*=-cozy]),[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication:not([class*=-cozy]){--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--navigation-object{--fdList_Navigation_Link_Padding_Left:1rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--navigation-object .fd-list__item--link,.fd-list--navigation.fd-list--navigation-object[dir=rtl] .fd-list__item--link,[dir=rtl] .fd-list--navigation.fd-list--navigation-object .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--navigation-object .fd-list__link{padding-block:1rem}.fd-list--navigation-indication .fd-list:after{content:\"\";min-width:1.5rem}.fd-list--navigation-indication fd-list__item.fd-list__item--link{-webkit-padding-end:0;padding-inline-end:0}.fd-list--navigation-indication fd-list__item.fd-list__item--link:after{content:none}.fd-list--navigation-indication .fd-list__link:after{content:\"\";min-width:2.5rem}.fd-list--navigation-indication .fd-list__link--navigation-indicator:after{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_NonInteractiveIconColor);content:\"\\e1ed\";font-family:SAP-icons;font-size:var(--fdListNavigationIndicatorFontSize,var(--sapFontLargeSize));height:100%;text-decoration:none;text-transform:none}.fd-list--navigation-indication .fd-list__link--navigation-indicator[dir=rtl]:after,[dir=rtl] .fd-list--navigation-indication .fd-list__link--navigation-indicator:after{content:\"\\e1ee\"}.fd-list--navigation-indication .fd-list__icon:last-child,.fd-list--navigation-indication .fd-list__icon[dir=rtl]:last-child,[dir=rtl] .fd-list--navigation-indication .fd-list__icon:last-child{margin-block:0;margin-inline:0}.fd-list--navigation-indication .is-navigated{-webkit-box-shadow:inset -.1875rem 0 0 0 var(--sapList_SelectionBorderColor);box-shadow:inset -.1875rem 0 0 0 var(--sapList_SelectionBorderColor)}.fd-list--navigation-indication .is-navigated[dir=rtl],[dir=rtl] .fd-list--navigation-indication .is-navigated{-webkit-box-shadow:inset .1875rem 0 0 0 var(--sapList_SelectionBorderColor);box-shadow:inset .1875rem 0 0 0 var(--sapList_SelectionBorderColor)}.fd-list--selection .fd-list__item{cursor:pointer;padding-inline:2.75rem .9375rem}.fd-list--selection .fd-list__item.is-hover,.fd-list--selection .fd-list__item:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background)}.fd-list--selection .fd-list__item.is-selected,.fd-list--selection .fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--selection .fd-list__item.is-selected .fd-list__link,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list--selection .fd-list__item.is-selected .fd-list__link.is-active,.fd-list--selection .fd-list__item.is-selected .fd-list__link:active,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--selection .fd-list__item.is-selected.is-hover,.fd-list--selection .fd-list__item.is-selected:hover,.fd-list--selection .fd-list__item[aria-selected=true].is-hover,.fd-list--selection .fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--selection .fd-list__form-item{left:0;position:absolute;top:0;z-index:5}.fd-list--selection .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection .fd-list__form-item{left:auto;right:0}.fd-list--selection[class*=-compact] .fd-list__form-item,.fd-list--selection[class*=-condensed] .fd-list__form-item,[class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item,[class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item{left:.375rem}.fd-list--selection[class*=-compact] .fd-list__form-item[dir=rtl],.fd-list--selection[class*=-condensed] .fd-list__form-item[dir=rtl],[class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection[class*=-compact] .fd-list__form-item,[dir=rtl] .fd-list--selection[class*=-condensed] .fd-list__form-item,[dir=rtl] [class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item,[dir=rtl] [class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item{left:auto;right:.375rem}.fd-list--selection.fd-list--byline .fd-list__item{padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline .fd-list__form-item{top:.3125rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__item,.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__item,[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__item,[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__item{padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item,.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item,[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item,[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item{left:.375rem;top:.5rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item[dir=rtl],.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item[dir=rtl],[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item,[dir=rtl] .fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item,[dir=rtl] [class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item,[dir=rtl] [class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item{left:auto;right:.375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item{padding-block:.5rem;padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:first-child{-webkit-padding-before:.9375rem;padding-block-start:.9375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:last-child{-webkit-padding-after:.9375rem;padding-block-end:.9375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item{top:0}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item label,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item label{-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item label:after,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item label:after{top:.375rem}.fd-list--selection.fd-list--selection-row .fd-list__item{-webkit-padding-start:1rem;padding-inline-start:1rem}:root{--fdList_Item_Background_Color:var(--sapList_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor);--fdList_Item_Text_Font_Size:var(--sapFontLargeSize);--fdList_Item_Icon_Font_Size:1.125rem;--fdList_Item_Height:var(--sapElement_LineHeight);--fdList_Status_Text_Color:var(--sapNeutralTextColor);--fdList_Message_Background_Color:var(--sapNeutralBackground)}.fd-list__item-counter{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-margin-start:1rem;color:var(--sapContent_MarkerTextColor);margin-inline-start:1rem}.fd-list__item-counter:after,.fd-list__item-counter:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list .fd-object-list__item{padding-block:1rem;--fdList_Item_Height:100%}.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-avatar,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-identifier__title,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-list__intro,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-list__object-attribute,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-marker__icon,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-marker__text,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-number__text,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-number__unit,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-status__icon,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-status__text,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-avatar,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-identifier__title,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-list__intro,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-list__object-attribute,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-marker__icon,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-marker__text,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-number__text,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-number__unit,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-status__icon,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-status__text{color:var(--sapList_Active_TextColor);text-shadow:none}.fd-object-list__intro{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;max-width:100%;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;width:100%;-webkit-padding-after:.75rem;color:var(--sapContent_LabelColor);padding-block-end:.75rem}.fd-object-list__intro:after,.fd-object-list__intro:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;height:100%;width:100%}.fd-object-list__container:after,.fd-object-list__container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.75rem}.fd-object-list__header:after,.fd-object-list__header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__header-left{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-align:left;width:60%}.fd-object-list__header-left:after,.fd-object-list__header-left:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__header-left[dir=rtl],[dir=rtl] .fd-object-list__header-left{text-align:right}.fd-object-list__header-right{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-align:right;width:40%;-webkit-margin-start:.25rem;margin-inline-start:.25rem}.fd-object-list__header-right:after,.fd-object-list__header-right:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__header-right[dir=rtl],[dir=rtl] .fd-object-list__header-right{text-align:left}.fd-object-list__row{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.5rem;-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-object-list__row:after,.fd-object-list__row:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__row-left,.fd-object-list__row-right{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-box-align:center;-ms-flex-align:center;align-items:center;line-height:1;width:50%}.fd-object-list__row-left:after,.fd-object-list__row-left:before,.fd-object-list__row-right:after,.fd-object-list__row-right:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__row-left:only-child,.fd-object-list__row-right:only-child{width:100%}.fd-object-list__row-right{-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end}.fd-object-list__row-right .fd-object-status__text{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-object-list__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;margin-top:.25rem;padding-block:0;padding-inline:0}.fd-object-list__content:after,.fd-object-list__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__object-number .fd-object-number__text{display:block;font-size:var(--fdObject_List_Number_Font_Size)}.fd-object-list__object-number .fd-object-number__text:after{content:none}.fd-object-list__object-identifier .fd-object-identifier__title{display:-webkit-box;-webkit-line-clamp:2;-webkit-box-orient:vertical;color:var(--sapGroup_TitleTextColor);font-size:var(--fdObject_List_Title_Font_Size);font-weight:var(--fdObject_List_Title_Font_Weight);line-height:1.5;overflow:hidden;text-overflow:ellipsis;white-space:normal}.fd-object-list__object-attribute{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-object-list__object-attribute:after,.fd-object-list__object-attribute:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__row{align-items:normal}\n/*! Bundled license information:\n\nfundamental-styles/dist/object-list.css:\n  (*!\n   * Fundamental Library Styles v0.38.0\n   * Copyright (c) 2024 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "component", type: ObjectAttributeComponent, selector: "fd-object-attribute, fdp-object-attribute", inputs: ["label", "linkText", "islink", "disabled"], outputs: ["objectAttributeclick"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ObjectListItemRowComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fdp-object-list-item-row', template: ` <div class="fd-object-list__row">
        <div class="fd-object-list__row-left">
            <fd-object-attribute
                class="fd-object-list__object-attribute"
                [islink]="islink"
                [label]="attributeLabel"
                [linkText]="linkedText"
            >
                <ng-content select=".attribute"></ng-content>
            </fd-object-attribute>
        </div>
        <div class="fd-object-list__row-right">
            <ng-content></ng-content>
        </div>
    </div>`, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, imports: [ObjectAttributeComponent], styles: [".fd-list{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;list-style:none;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative;width:100%}.fd-list:after,.fd-list:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__footer,.fd-list__group-header,.fd-list__item{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;padding-block:0;padding-inline:.9375rem}.fd-list__footer:after,.fd-list__footer:before,.fd-list__group-header:after,.fd-list__group-header:before,.fd-list__item:after,.fd-list__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__item{background:var(--fdList_Item_Background_Color);border-bottom:var(--sapList_BorderWidth) solid var(--fdList_Item_Border_Color);height:var(--fdList_Item_Height);position:relative}.fd-list__item.is-focus,.fd-list__item:focus{outline:none;pointer-events:all}.fd-list__item.is-focus:before,.fd-list__item:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem .125rem .0625rem;pointer-events:none;position:absolute}.fd-list__item.is-focus.is-active:before,.fd-list__item.is-focus:active:before,.fd-list__item:focus.is-active:before,.fd-list__item:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-list__item--unread .fd-list__title{font-weight:700}.fd-list__item--no-data .fd-list__title{text-align:center}.fd-list__item--interactive.is-hover,.fd-list__item--interactive:hover,.fd-list__item--interractive.is-hover,.fd-list__item--interractive:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__item--interactive.is-selected,.fd-list__item--interactive[aria-selected=true],.fd-list__item--interractive.is-selected,.fd-list__item--interractive[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item--interactive.is-selected .fd-list__link,.fd-list__item--interactive[aria-selected=true] .fd-list__link,.fd-list__item--interractive.is-selected .fd-list__link,.fd-list__item--interractive[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item--interactive.is-selected .fd-list__link.is-active,.fd-list__item--interactive.is-selected .fd-list__link:active,.fd-list__item--interactive[aria-selected=true] .fd-list__link.is-active,.fd-list__item--interactive[aria-selected=true] .fd-list__link:active,.fd-list__item--interractive.is-selected .fd-list__link.is-active,.fd-list__item--interractive.is-selected .fd-list__link:active,.fd-list__item--interractive[aria-selected=true] .fd-list__link.is-active,.fd-list__item--interractive[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item--interactive.is-selected.is-hover,.fd-list__item--interactive.is-selected:hover,.fd-list__item--interactive[aria-selected=true].is-hover,.fd-list__item--interactive[aria-selected=true]:hover,.fd-list__item--interractive.is-selected.is-hover,.fd-list__item--interractive.is-selected:hover,.fd-list__item--interractive[aria-selected=true].is-hover,.fd-list__item--interractive[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__item--interactive.is-active,.fd-list__item--interactive.is-active.is-hover,.fd-list__item--interactive.is-active.is-selected,.fd-list__item--interactive.is-active.is-selected.is-hover,.fd-list__item--interactive.is-active.is-selected:hover,.fd-list__item--interactive.is-active:hover,.fd-list__item--interactive.is-active[aria-selected=true],.fd-list__item--interactive.is-active[aria-selected=true].is-hover,.fd-list__item--interactive.is-active[aria-selected=true]:hover,.fd-list__item--interactive:active,.fd-list__item--interactive:active.is-hover,.fd-list__item--interactive:active.is-selected,.fd-list__item--interactive:active.is-selected.is-hover,.fd-list__item--interactive:active.is-selected:hover,.fd-list__item--interactive:active:hover,.fd-list__item--interactive:active[aria-selected=true],.fd-list__item--interactive:active[aria-selected=true].is-hover,.fd-list__item--interactive:active[aria-selected=true]:hover,.fd-list__item--interractive.is-active,.fd-list__item--interractive.is-active.is-hover,.fd-list__item--interractive.is-active.is-selected,.fd-list__item--interractive.is-active.is-selected.is-hover,.fd-list__item--interractive.is-active.is-selected:hover,.fd-list__item--interractive.is-active:hover,.fd-list__item--interractive.is-active[aria-selected=true],.fd-list__item--interractive.is-active[aria-selected=true].is-hover,.fd-list__item--interractive.is-active[aria-selected=true]:hover,.fd-list__item--interractive:active,.fd-list__item--interractive:active.is-hover,.fd-list__item--interractive:active.is-selected,.fd-list__item--interractive:active.is-selected.is-hover,.fd-list__item--interractive:active.is-selected:hover,.fd-list__item--interractive:active:hover,.fd-list__item--interractive:active[aria-selected=true],.fd-list__item--interractive:active[aria-selected=true].is-hover,.fd-list__item--interractive:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__item--interactive.is-active,.fd-list__item--interactive.is-active .fd-list__byline,.fd-list__item--interactive.is-active .fd-list__byline-left,.fd-list__item--interactive.is-active .fd-list__byline-right,.fd-list__item--interactive.is-active .fd-list__byline-right--critical,.fd-list__item--interactive.is-active .fd-list__byline-right--informative,.fd-list__item--interactive.is-active .fd-list__byline-right--negative,.fd-list__item--interactive.is-active .fd-list__byline-right--neutral,.fd-list__item--interactive.is-active .fd-list__byline-right--positive,.fd-list__item--interactive.is-active .fd-list__content,.fd-list__item--interactive.is-active .fd-list__icon,.fd-list__item--interactive.is-active .fd-list__secondary,.fd-list__item--interactive.is-active .fd-list__thumbnail,.fd-list__item--interactive.is-active .fd-list__title,.fd-list__item--interactive.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--interactive:active,.fd-list__item--interactive:active .fd-list__byline,.fd-list__item--interactive:active .fd-list__byline-left,.fd-list__item--interactive:active .fd-list__byline-right,.fd-list__item--interactive:active .fd-list__byline-right--critical,.fd-list__item--interactive:active .fd-list__byline-right--informative,.fd-list__item--interactive:active .fd-list__byline-right--negative,.fd-list__item--interactive:active .fd-list__byline-right--neutral,.fd-list__item--interactive:active .fd-list__byline-right--positive,.fd-list__item--interactive:active .fd-list__content,.fd-list__item--interactive:active .fd-list__icon,.fd-list__item--interactive:active .fd-list__secondary,.fd-list__item--interactive:active .fd-list__thumbnail,.fd-list__item--interactive:active .fd-list__title,.fd-list__item--interactive:active.fd-list__link--navigation-indicator:after,.fd-list__item--interractive.is-active,.fd-list__item--interractive.is-active .fd-list__byline,.fd-list__item--interractive.is-active .fd-list__byline-left,.fd-list__item--interractive.is-active .fd-list__byline-right,.fd-list__item--interractive.is-active .fd-list__byline-right--critical,.fd-list__item--interractive.is-active .fd-list__byline-right--informative,.fd-list__item--interractive.is-active .fd-list__byline-right--negative,.fd-list__item--interractive.is-active .fd-list__byline-right--neutral,.fd-list__item--interractive.is-active .fd-list__byline-right--positive,.fd-list__item--interractive.is-active .fd-list__content,.fd-list__item--interractive.is-active .fd-list__icon,.fd-list__item--interractive.is-active .fd-list__secondary,.fd-list__item--interractive.is-active .fd-list__thumbnail,.fd-list__item--interractive.is-active .fd-list__title,.fd-list__item--interractive.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--interractive:active,.fd-list__item--interractive:active .fd-list__byline,.fd-list__item--interractive:active .fd-list__byline-left,.fd-list__item--interractive:active .fd-list__byline-right,.fd-list__item--interractive:active .fd-list__byline-right--critical,.fd-list__item--interractive:active .fd-list__byline-right--informative,.fd-list__item--interractive:active .fd-list__byline-right--negative,.fd-list__item--interractive:active .fd-list__byline-right--neutral,.fd-list__item--interractive:active .fd-list__byline-right--positive,.fd-list__item--interractive:active .fd-list__content,.fd-list__item--interractive:active .fd-list__icon,.fd-list__item--interractive:active .fd-list__secondary,.fd-list__item--interractive:active .fd-list__thumbnail,.fd-list__item--interractive:active .fd-list__title,.fd-list__item--interractive:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__item--action{border-bottom:var(--fdList_Item_Action_Border);font-size:var(--sapFontSize);padding-block:0;padding-inline:0;text-align:center;--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list__item--action:first-child{border-top:var(--fdList_Item_Action_Border)}.fd-list__item--action .fd-list__title{background:transparent;border:var(--fdList_Item_Action_Button_Border);border-radius:var(--fdList_Item_Action_Button_Border_Radius);color:var(--sapButton_TextColor);cursor:pointer;height:var(--fdList_Item_Action_Button_Size);margin-block:var(--fdList_Item_Action_Button_Spacing);margin-inline:var(--fdList_Item_Action_Button_Spacing);padding-block:0;padding-inline:.9375rem;pointer-events:all;width:100%}.fd-list__item--action .fd-list__title.is-hover,.fd-list__item--action .fd-list__title:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__item--action .fd-list__title.is-selected,.fd-list__item--action .fd-list__title[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item--action .fd-list__title.is-selected .fd-list__link,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item--action .fd-list__title.is-selected .fd-list__link.is-active,.fd-list__item--action .fd-list__title.is-selected .fd-list__link:active,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link.is-active,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item--action .fd-list__title.is-selected.is-hover,.fd-list__item--action .fd-list__title.is-selected:hover,.fd-list__item--action .fd-list__title[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__item--action .fd-list__title.is-active,.fd-list__item--action .fd-list__title.is-active.is-hover,.fd-list__item--action .fd-list__title.is-active.is-selected,.fd-list__item--action .fd-list__title.is-active.is-selected.is-hover,.fd-list__item--action .fd-list__title.is-active.is-selected:hover,.fd-list__item--action .fd-list__title.is-active:hover,.fd-list__item--action .fd-list__title.is-active[aria-selected=true],.fd-list__item--action .fd-list__title.is-active[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title.is-active[aria-selected=true]:hover,.fd-list__item--action .fd-list__title:active,.fd-list__item--action .fd-list__title:active.is-hover,.fd-list__item--action .fd-list__title:active.is-selected,.fd-list__item--action .fd-list__title:active.is-selected.is-hover,.fd-list__item--action .fd-list__title:active.is-selected:hover,.fd-list__item--action .fd-list__title:active:hover,.fd-list__item--action .fd-list__title:active[aria-selected=true],.fd-list__item--action .fd-list__title:active[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__item--action .fd-list__title.is-active,.fd-list__item--action .fd-list__title.is-active .fd-list__byline,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-left,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--critical,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--informative,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--negative,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--neutral,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--positive,.fd-list__item--action .fd-list__title.is-active .fd-list__content,.fd-list__item--action .fd-list__title.is-active .fd-list__icon,.fd-list__item--action .fd-list__title.is-active .fd-list__secondary,.fd-list__item--action .fd-list__title.is-active .fd-list__thumbnail,.fd-list__item--action .fd-list__title.is-active .fd-list__title,.fd-list__item--action .fd-list__title.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--action .fd-list__title:active,.fd-list__item--action .fd-list__title:active .fd-list__byline,.fd-list__item--action .fd-list__title:active .fd-list__byline-left,.fd-list__item--action .fd-list__title:active .fd-list__byline-right,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--critical,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--informative,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--negative,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--neutral,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--positive,.fd-list__item--action .fd-list__title:active .fd-list__content,.fd-list__item--action .fd-list__title:active .fd-list__icon,.fd-list__item--action .fd-list__title:active .fd-list__secondary,.fd-list__item--action .fd-list__title:active .fd-list__thumbnail,.fd-list__item--action .fd-list__title:active .fd-list__title,.fd-list__item--action .fd-list__title:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__item--action .fd-list__title.is-focus,.fd-list__item--action .fd-list__title:focus{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.125rem}.fd-list__item--action .fd-list__title.is-focus.is-active,.fd-list__item--action .fd-list__title.is-focus:active,.fd-list__item--action .fd-list__title:focus.is-active,.fd-list__item--action .fd-list__title:focus:active{outline-color:var(--fdList_Active_Outline_Color)}.fd-list__item--action .fd-list__title::-moz-focus-inner{border:0}.fd-list__item--growing{--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list__item--growing .fd-list__title{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;gap:.5rem}.fd-list__item--growing .fd-list__title-text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:inherit;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;font-weight:var(--fdList_Growing_Font_Weight);forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;text-shadow:inherit;white-space:nowrap}.fd-list__item--growing .fd-list__title-text:after,.fd-list__item--growing .fd-list__title-text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__item--inactive,.fd-list__item--inactive .fd-list__secondary,.fd-list__item--inactive .fd-list__title{pointer-events:none}.fd-list__item.is-selected,.fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item.is-selected .fd-list__link,.fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item.is-selected .fd-list__link.is-active,.fd-list__item.is-selected .fd-list__link:active,.fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item.is-selected.is-hover,.fd-list__item.is-selected:hover,.fd-list__item[aria-selected=true].is-hover,.fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__secondary,.fd-list__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdList_Item_Text_Color);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;pointer-events:none;pointer-events:all;text-overflow:ellipsis;white-space:nowrap}.fd-list__secondary:after,.fd-list__secondary:before,.fd-list__title:after,.fd-list__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__title{-webkit-box-flex:3;-ms-flex:3 3 10%;flex:3 3 10%;font-size:var(--fdList_Item_Text_Font_Size);min-height:var(--fdList_Item_Text_Font_Size)}.fd-list__title:last-child:first-child{-ms-flex-preferred-size:auto;flex-basis:auto}.fd-list__title .fd-list__title-text{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-list__title~.fd-list__icon{-webkit-margin-end:-1rem;margin-inline-end:-1rem}.fd-list__secondary{color:var(--fdList_Status_Text_Color);font-size:var(--sapFontSize);max-width:40%;text-align:right;-webkit-padding-start:1rem;padding-inline-start:1rem}.fd-list__secondary--positive{--fdList_Status_Text_Color:var(--sapPositiveTextColor)}.fd-list__secondary--critical{--fdList_Status_Text_Color:var(--sapCriticalTextColor)}.fd-list__secondary--negative{--fdList_Status_Text_Color:var(--sapNegativeTextColor)}.fd-list__secondary--informative{--fdList_Status_Text_Color:var(--sapInformativeTextColor)}.fd-list__secondary[dir=rtl],[dir=rtl] .fd-list__secondary{text-align:left}.fd-list__icon [class*=sap-icon],.fd-list__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;pointer-events:none;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_NonInteractiveIconColor);font-size:var(--fdList_Item_Icon_Font_Size);width:2.75rem;-webkit-box-flex:0;-ms-flex:0 0 auto;flex:0 0 auto}.fd-list__icon [class*=sap-icon]:first-child,.fd-list__icon[class*=sap-icon]:first-child{-webkit-margin-start:-1rem;margin-inline-start:-1rem}.fd-list__link{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;--fdList_Item_Border_Color:transparent;background:var(--fdList_Item_Background_Color);border-bottom:var(--sapList_BorderWidth) solid var(--fdList_Item_Border_Color);cursor:pointer;height:100%;padding-block:0;padding-inline:.9375rem;text-decoration:none;width:100%}.fd-list__link:after,.fd-list__link:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__link.is-focus,.fd-list__link:focus{outline:none;pointer-events:all}.fd-list__link.is-focus:before,.fd-list__link:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem;pointer-events:none;position:absolute}.fd-list__link.is-focus.is-active:before,.fd-list__link.is-focus:active:before,.fd-list__link:focus.is-active:before,.fd-list__link:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-list__link.is-hover,.fd-list__link:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__link.is-selected,.fd-list__link[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__link.is-selected .fd-list__link,.fd-list__link[aria-selected=true] .fd-list__link{background:inherit}.fd-list__link.is-selected .fd-list__link.is-active,.fd-list__link.is-selected .fd-list__link:active,.fd-list__link[aria-selected=true] .fd-list__link.is-active,.fd-list__link[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__link.is-selected.is-hover,.fd-list__link.is-selected:hover,.fd-list__link[aria-selected=true].is-hover,.fd-list__link[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__link.is-active,.fd-list__link.is-active.is-hover,.fd-list__link.is-active.is-selected,.fd-list__link.is-active.is-selected.is-hover,.fd-list__link.is-active.is-selected:hover,.fd-list__link.is-active:hover,.fd-list__link.is-active[aria-selected=true],.fd-list__link.is-active[aria-selected=true].is-hover,.fd-list__link.is-active[aria-selected=true]:hover,.fd-list__link:active,.fd-list__link:active.is-hover,.fd-list__link:active.is-selected,.fd-list__link:active.is-selected.is-hover,.fd-list__link:active.is-selected:hover,.fd-list__link:active:hover,.fd-list__link:active[aria-selected=true],.fd-list__link:active[aria-selected=true].is-hover,.fd-list__link:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__link.is-active,.fd-list__link.is-active .fd-list__byline,.fd-list__link.is-active .fd-list__byline-left,.fd-list__link.is-active .fd-list__byline-right,.fd-list__link.is-active .fd-list__byline-right--critical,.fd-list__link.is-active .fd-list__byline-right--informative,.fd-list__link.is-active .fd-list__byline-right--negative,.fd-list__link.is-active .fd-list__byline-right--neutral,.fd-list__link.is-active .fd-list__byline-right--positive,.fd-list__link.is-active .fd-list__content,.fd-list__link.is-active .fd-list__icon,.fd-list__link.is-active .fd-list__secondary,.fd-list__link.is-active .fd-list__thumbnail,.fd-list__link.is-active .fd-list__title,.fd-list__link.is-active.fd-list__link--navigation-indicator:after,.fd-list__link:active,.fd-list__link:active .fd-list__byline,.fd-list__link:active .fd-list__byline-left,.fd-list__link:active .fd-list__byline-right,.fd-list__link:active .fd-list__byline-right--critical,.fd-list__link:active .fd-list__byline-right--informative,.fd-list__link:active .fd-list__byline-right--negative,.fd-list__link:active .fd-list__byline-right--neutral,.fd-list__link:active .fd-list__byline-right--positive,.fd-list__link:active .fd-list__content,.fd-list__link:active .fd-list__icon,.fd-list__link:active .fd-list__secondary,.fd-list__link:active .fd-list__thumbnail,.fd-list__link:active .fd-list__title,.fd-list__link:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__group-header{background:var(--sapList_GroupHeaderBackground);border-bottom:var(--sapList_BorderWidth) solid var(--sapList_GroupHeaderBorderColor);height:var(--sapElement_LineHeight);-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}.fd-list__group-header .fd-list__title{color:var(--sapList_TableGroupHeaderTextColor);font-family:var(--sapFontHeaderFamily);font-size:var(--sapFontHeader6Size);font-weight:700;line-height:2rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list__footer{background:var(--sapList_FooterBackground);color:var(--sapList_FooterTextColor);font-size:var(--sapFontSize);height:2rem}.fd-list__footer--right{-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end}.fd-list__footer--left{-webkit-box-pack:start;-ms-flex-pack:start;justify-content:flex-start}.fd-list__bold{font-weight:700}.fd-list__message{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:2rem;left:0;line-height:normal;line-height:2rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;position:absolute;text-overflow:ellipsis;top:0;white-space:nowrap;width:100%;-webkit-padding-start:.5rem;background-color:var(--fdList_Message_Background_Color);font-size:var(--sapFontSmallSize);padding-inline-start:.5rem}.fd-list__message:after,.fd-list__message:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__message--error{--fdList_Message_Background_Color:var(--sapErrorBackground)}.fd-list__message--warning{--fdList_Message_Background_Color:var(--sapWarningBackground)}.fd-list__message--success{--fdList_Message_Background_Color:var(--sapSuccessBackground)}.fd-list__message--information{--fdList_Message_Background_Color:var(--sapInformationBackground)}.fd-list .fd-list__button{-webkit-margin-start:var(--fdList_Button_Spacing);margin-inline-start:var(--fdList_Button_Spacing);-ms-flex-item-align:center;align-self:center}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view),.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view),[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view),[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view){--fdList_Item_Icon_Font_Size:1rem;--fdList_Item_Text_Font_Size:var(--sapFontSize);--fdList_Item_Height:var(--sapElement_Compact_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing{--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action{--fdList_Item_Height:var(--sapElement_Compact_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title{height:var(--fdList_Item_Action_Button_Size_Compact)}.fd-list--no-border .fd-list__group-header,.fd-list--no-border .fd-list__item{border-bottom:0;border-top:0}.fd-list--no-border .fd-list__item.is-selected,.fd-list--no-border .fd-list__item[aria-selected=true]{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-list--has-message{-webkit-padding-before:2rem;padding-block-start:2rem}.fd-list__infinite-scroll{outline:none;overflow:scroll}.fd-list--dropdown.is-focus,.fd-list--dropdown:focus{outline:none;z-index:5}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header){display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:auto;min-height:2.5rem;padding-block:0;padding-inline:.9375rem}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link{background:inherit}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link.is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link:active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link.is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true],.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true]:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true],.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-left,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--critical,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--informative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--negative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--neutral,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--positive,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__content,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__icon,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__secondary,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__thumbnail,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__title,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.fd-list__link--navigation-indicator:after,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-left,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--critical,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--informative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--negative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--neutral,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--positive,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__content,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__icon,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__secondary,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__thumbnail,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__title,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list--dropdown[class*=-compact] .fd-list__item:not(.fd-list__group-header),.fd-list--dropdown[class*=-condensed] .fd-list__item:not(.fd-list__group-header),[class*=-compact] .fd-list--dropdown:not([class*=-cozy]) .fd-list__item:not(.fd-list__group-header),[class*=-condensed] .fd-list--dropdown:not([class*=-cozy]) .fd-list__item:not(.fd-list__group-header){height:auto;min-height:2rem;padding-block:0;padding-inline:.9375rem}.fd-list--multi-input .fd-list__item{height:auto;padding-block:0;padding-inline:0 1rem}.fd-list--multi-input .fd-list__item.is-hover,.fd-list--multi-input .fd-list__item:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list--multi-input .fd-list__item.is-selected,.fd-list--multi-input .fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--multi-input .fd-list__item.is-selected .fd-list__link,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list--multi-input .fd-list__item.is-selected .fd-list__link.is-active,.fd-list--multi-input .fd-list__item.is-selected .fd-list__link:active,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--multi-input .fd-list__item.is-selected.is-hover,.fd-list--multi-input .fd-list__item.is-selected:hover,.fd-list--multi-input .fd-list__item[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--multi-input .fd-list__item.is-active,.fd-list--multi-input .fd-list__item.is-active.is-hover,.fd-list--multi-input .fd-list__item.is-active.is-selected,.fd-list--multi-input .fd-list__item.is-active.is-selected.is-hover,.fd-list--multi-input .fd-list__item.is-active.is-selected:hover,.fd-list--multi-input .fd-list__item.is-active:hover,.fd-list--multi-input .fd-list__item.is-active[aria-selected=true],.fd-list--multi-input .fd-list__item.is-active[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item.is-active[aria-selected=true]:hover,.fd-list--multi-input .fd-list__item:active,.fd-list--multi-input .fd-list__item:active.is-hover,.fd-list--multi-input .fd-list__item:active.is-selected,.fd-list--multi-input .fd-list__item:active.is-selected.is-hover,.fd-list--multi-input .fd-list__item:active.is-selected:hover,.fd-list--multi-input .fd-list__item:active:hover,.fd-list--multi-input .fd-list__item:active[aria-selected=true],.fd-list--multi-input .fd-list__item:active[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list--multi-input .fd-list__item.is-active,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-left,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--critical,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--informative,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--negative,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--neutral,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--positive,.fd-list--multi-input .fd-list__item.is-active .fd-list__content,.fd-list--multi-input .fd-list__item.is-active .fd-list__icon,.fd-list--multi-input .fd-list__item.is-active .fd-list__secondary,.fd-list--multi-input .fd-list__item.is-active .fd-list__thumbnail,.fd-list--multi-input .fd-list__item.is-active .fd-list__title,.fd-list--multi-input .fd-list__item.is-active.fd-list__link--navigation-indicator:after,.fd-list--multi-input .fd-list__item:active,.fd-list--multi-input .fd-list__item:active .fd-list__byline,.fd-list--multi-input .fd-list__item:active .fd-list__byline-left,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--critical,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--informative,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--negative,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--neutral,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--positive,.fd-list--multi-input .fd-list__item:active .fd-list__content,.fd-list--multi-input .fd-list__item:active .fd-list__icon,.fd-list--multi-input .fd-list__item:active .fd-list__secondary,.fd-list--multi-input .fd-list__item:active .fd-list__thumbnail,.fd-list--multi-input .fd-list__item:active .fd-list__title,.fd-list--multi-input .fd-list__item:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list--multi-input .fd-list__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:inherit;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;position:relative;text-overflow:ellipsis;width:100%;-webkit-margin-end:0;margin-inline-end:0}.fd-list--multi-input .fd-list__label:after,.fd-list--multi-input .fd-list__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--multi-input .fd-list__label:before{margin-block:-.1875rem -.1875rem}.fd-list--multi-input .fd-list__input.is-focus,.fd-list--multi-input .fd-list__input:focus{-webkit-box-shadow:none;box-shadow:none;z-index:5}.fd-list--multi-input .fd-list__input.is-focus+.fd-list__label:after,.fd-list--multi-input .fd-list__input:focus+.fd-list__label:after{inset:.0625rem}.fd-list--multi-input .fd-list__footer{height:auto;text-align:right;-webkit-box-pack:end;-ms-flex-pack:end;background-color:var(--sapList_Background);justify-content:flex-end;line-height:1rem}.fd-list--multi-input .fd-list__footer,.fd-list--multi-input .fd-list__label{padding-block:.75rem;padding-inline:.9375rem}.fd-list--multi-input[class*=-compact] .fd-list__item,.fd-list--multi-input[class*=-condensed] .fd-list__item,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__item,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__item{height:auto;padding-block:0;padding-inline:0}.fd-list--multi-input[class*=-compact] .fd-list__label:before,.fd-list--multi-input[class*=-condensed] .fd-list__label:before,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label:before,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label:before{-webkit-margin-start:0;margin-inline-start:0;margin-top:0;-webkit-margin-after:0;margin-block-end:0}.fd-list--multi-input[class*=-compact] .fd-list__footer,.fd-list--multi-input[class*=-compact] .fd-list__label,.fd-list--multi-input[class*=-condensed] .fd-list__footer,.fd-list--multi-input[class*=-condensed] .fd-list__label,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__footer,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__footer,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label{padding-block:.5rem;padding-inline:.9375rem}.fd-list--dropdown,.fd-list--multi-input{display:block;max-width:40rem;min-width:5rem}.fd-list--dropdown .fd-list__item,.fd-list--multi-input .fd-list__item{border:none;cursor:pointer}.fd-list--dropdown .fd-list__item.is-selected,.fd-list--dropdown .fd-list__item[aria-selected=true],.fd-list--multi-input .fd-list__item.is-selected,.fd-list--multi-input .fd-list__item[aria-selected=true]{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-list--dropdown .fd-list__secondary,.fd-list--dropdown .fd-list__title,.fd-list--multi-input .fd-list__secondary,.fd-list--multi-input .fd-list__title{font-size:var(--sapFontSize);white-space:normal;-webkit-box-flex:1;-ms-flex:auto;flex:auto;width:auto}.fd-list--dropdown .fd-list__secondary--no-wrap,.fd-list--dropdown .fd-list__title--no-wrap,.fd-list--multi-input .fd-list__secondary--no-wrap,.fd-list--multi-input .fd-list__title--no-wrap{white-space:nowrap}.fd-list--dropdown .fd-list__secondary,.fd-list--multi-input .fd-list__secondary{display:block}.fd-list--dropdown .fd-list__title,.fd-list--multi-input .fd-list__title{max-width:24rem}.fd-list--dropdown .fd-list__title:first-child:last-child,.fd-list--multi-input .fd-list__title:first-child:last-child{max-width:40rem}.fd-list--dropdown .fd-list__secondary,.fd-list--multi-input .fd-list__secondary{max-width:16rem}.fd-list--dropdown.fd-list--mobile,.fd-list--multi-input.fd-list--mobile{max-width:100%}.fd-list--dropdown .fd-list__icon,.fd-list--multi-input .fd-list__icon{line-height:1rem}.fd-list--dropdown.fd-list--large-dropdown,.fd-list--multi-input.fd-list--large-dropdown{max-width:62rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__title,.fd-list--multi-input.fd-list--large-dropdown .fd-list__title{max-width:37.2rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__title:first-child:last-child,.fd-list--multi-input.fd-list--large-dropdown .fd-list__title:first-child:last-child{max-width:62rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__secondary,.fd-list--multi-input.fd-list--large-dropdown .fd-list__secondary{max-width:24.8rem}.fd-list--dropdown.fd-list--large-dropdown.fd-list--mobile,.fd-list--multi-input.fd-list--large-dropdown.fd-list--mobile{max-width:100%}.fd-list--byline .fd-list__item{height:auto;min-height:5rem;padding-block:.9375rem;padding-inline:1rem;width:100%;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.fd-list--byline .fd-list__item.is-focus,.fd-list--byline .fd-list__item:focus{pointer-events:all;z-index:5}.fd-list--byline .fd-list__item .fd-list__item-counter{-ms-flex-align:center;-ms-flex-item-align:center;align-self:center;-webkit-box-pack:end;-ms-flex-pack:end;height:100%;justify-content:flex-end;min-width:2rem}.fd-list--byline .fd-list__item .fd-list__item-counter,.fd-list--byline .fd-list__thumbnail{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;align-items:center}.fd-list--byline .fd-list__thumbnail{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;pointer-events:none;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-ms-flex-align:center;-webkit-margin-end:.75rem;border-radius:.25rem;color:var(--sapContent_NonInteractiveIconColor);font-size:2rem;height:3rem;margin-inline-end:.75rem;max-height:3rem;max-width:3rem;min-height:3rem;min-width:3rem;width:3rem}.fd-list--byline .fd-list__thumbnail:after,.fd-list--byline .fd-list__thumbnail:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__thumbnail [class*=sap-icon],.fd-list--byline .fd-list__thumbnail[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;line-height:1}.fd-list--byline .fd-list__thumbnail>svg{height:100%}.fd-list--byline .fd-list__notification{color:var(--sapAccentColor6);font-size:.375rem;left:1rem;position:absolute;top:50%;-webkit-transform:translateY(-50%);transform:translateY(-50%)}.fd-list--byline .fd-list__notification[dir=rtl],[dir=rtl] .fd-list--byline .fd-list__notification{left:auto;right:1rem}.fd-list--byline .fd-list__notification+.fd-list__link .fd-list__content .fd-list__title,.fd-list--byline .fd-list__notification~.fd-list__content .fd-list__title{font-weight:700}.fd-list--byline .fd-list__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;pointer-events:none;-ms-flex-line-pack:justify;align-content:space-between;height:100%;min-height:3rem;min-width:3rem;-webkit-box-flex:1;-ms-flex:1 1 auto;flex:1 1 auto;padding-block:.125rem;padding-inline:0}.fd-list--byline .fd-list__content:after,.fd-list--byline .fd-list__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__title{font-size:var(--sapFontLargeSize);min-height:1rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list--byline .fd-list__byline{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-list--byline .fd-list__byline:after,.fd-list--byline .fd-list__byline:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline--2-col{display:-webkit-box;display:-ms-flexbox;display:flex;pointer-events:all}.fd-list--byline .fd-list__byline--wrap .fd-list__byline-left,.fd-list--byline .fd-list__byline--wrap .fd-list__byline-right{display:inline;padding-block:0;padding-inline:0;white-space:normal;width:100%}.fd-list--byline .fd-list__byline--wrap .fd-list__byline-right{float:right;width:auto}.fd-list--byline .fd-list__link--more{pointer-events:all;text-transform:capitalize}.fd-list--byline .fd-list__byline--wrap,.fd-list--byline .fd-list__title--wrap{white-space:normal}.fd-list--byline .fd-list__byline-left{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;width:60%;-ms-flex-item-align:end;align-self:flex-end;-webkit-padding-end:.5rem;padding-inline-end:.5rem}.fd-list--byline .fd-list__byline-left:after,.fd-list--byline .fd-list__byline-left:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline-right{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-align:right;text-overflow:ellipsis;white-space:nowrap;width:40%;-ms-flex-item-align:end;align-self:flex-end;-webkit-padding-start:.5rem;padding-inline-start:.5rem}.fd-list--byline .fd-list__byline-right:after,.fd-list--byline .fd-list__byline-right:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline-right[dir=rtl],[dir=rtl] .fd-list--byline .fd-list__byline-right{text-align:left}.fd-list--byline .fd-list__byline-right--neutral{color:var(--sapNeutralTextColor)}.fd-list--byline .fd-list__byline-right--positive{color:var(--sapPositiveTextColor)}.fd-list--byline .fd-list__byline-right--critical{color:var(--sapCriticalTextColor)}.fd-list--byline .fd-list__byline-right--negative{color:var(--sapNegativeTextColor)}.fd-list--byline .fd-list__byline-right--informative{color:var(--sapInformativeTextColor)}.fd-list--byline.fd-list--unread-indicator .fd-list__item{padding-inline:2.125rem 1rem}.fd-list--byline[class*=-compact] .fd-list__title,.fd-list--byline[class*=-condensed] .fd-list__title,[class*=-compact] .fd-list--byline:not([class*=-cozy]) .fd-list__title,[class*=-condensed] .fd-list--byline:not([class*=-cozy]) .fd-list__title{font-size:var(--sapFontSize)}.fd-list--byline.fd-list--no-border .fd-list__item{height:100%;max-height:5rem;padding-block:.5rem}.fd-list--byline.fd-list--no-border .fd-list__item:first-child{-webkit-padding-before:.9375rem;padding-block-start:.9375rem}.fd-list--byline.fd-list--no-border .fd-list__item:last-child{-webkit-padding-after:.9375rem;padding-block-end:.9375rem}.fd-list--message-view{--fdListNavigationIndicatorFontSize:.75rem;--fdList_Item_Height:calc(2.75rem + var(--sapList_BorderWidth));--fdList_Message_View_Item_Byline_Height:calc(3.325rem + var(--sapList_BorderWidth));--fdList_Message_View_Title_Size:var(--sapFontHeader5Size)}.fd-list--message-view .fd-list__item{height:auto}.fd-list--message-view .fd-list__item--byline{--fdList_Item_Height:var(--fdList_Message_View_Item_Byline_Height)}.fd-list--message-view .fd-list__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-flex:1;-ms-flex:1 1 auto;flex:1 1 auto;overflow:hidden;pointer-events:none;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__content:after,.fd-list--message-view .fd-list__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--message-view .fd-list__title{color:var(--sapGroup_TitleTextColor);font-family:var(--sapFontHeaderFamily);font-size:var(--fdList_Message_View_Title_Size);font-weight:var(--sapFontHeaderWeight,normal);overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__subtitle{-webkit-padding-before:.25rem;color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);overflow:hidden;padding-block-start:.25rem;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__link{padding-block:.5rem}.fd-list--message-view .fd-list__link.is-active .fd-list__subtitle,.fd-list--message-view .fd-list__link.is-active .fd-list__title,.fd-list--message-view .fd-list__link.is-active .fd-object-status .fd-object-status__icon,.fd-list--message-view .fd-list__link:active .fd-list__subtitle,.fd-list--message-view .fd-list__link:active .fd-list__title,.fd-list--message-view .fd-list__link:active .fd-object-status .fd-object-status__icon{color:var(--sapList_Active_TextColor)}.fd-list--message-view[class*=-compact],.fd-list--message-view[class*=-condensed],[class*=-compact] .fd-list--message-view:not([class*=-cozy]),[class*=-condensed] .fd-list--message-view:not([class*=-cozy]){--fdList_Message_View_Item_Height:calc(2rem + var(--sapList_BorderWidth));--fdList_Message_View_Title_Size:var(--sapFontHeader6Size);--fdList_Message_View_Item_Byline_Height:calc(3.25rem + var(--sapList_BorderWidth))}.fd-list--navigation .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-icon-tab-bar__list .fd-list__link{gap:.25rem}.fd-list--navigation .fd-list__link{padding-inline:var(--fdList_Navigation_Link_Padding_Left,.9375rem) var(--fdList_Navigation_Link_Padding_Right,.9375rem)}.fd-list--navigation.fd-list--unread-indicator{--fdList_Navigation_Link_Padding_Left:2.125rem;--fdList_Navigation_Link_Padding_Right:.9375rem}.fd-list--navigation.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:.9375rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--selection{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:.9375rem}.fd-list--navigation.fd-list--selection .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--selection.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--selection.fd-list--navigation-indication .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline,.fd-list--navigation.fd-list--byline.fd-list--compact{--fdList_Navigation_Link_Padding_Left:1rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--compact .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline .fd-list__link,.fd-list--navigation.fd-list--byline.fd-list--compact .fd-list__link{padding-block:.9375rem}.fd-list--navigation.fd-list--byline.fd-list--compact.fd-list--unread-indicator,.fd-list--navigation.fd-list--byline.fd-list--unread-indicator{--fdList_Navigation_Link_Padding_Left:2.125rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:.9375rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--byline.fd-list--selection{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-compact],.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-condensed],[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]),[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]){--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-compact] .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-condensed] .fd-list__item--link,[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]) .fd-list__item--link,[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]) .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication[class*=-compact],.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication[class*=-condensed],[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication:not([class*=-cozy]),[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication:not([class*=-cozy]){--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--navigation-object{--fdList_Navigation_Link_Padding_Left:1rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--navigation-object .fd-list__item--link,.fd-list--navigation.fd-list--navigation-object[dir=rtl] .fd-list__item--link,[dir=rtl] .fd-list--navigation.fd-list--navigation-object .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--navigation-object .fd-list__link{padding-block:1rem}.fd-list--navigation-indication .fd-list:after{content:\"\";min-width:1.5rem}.fd-list--navigation-indication fd-list__item.fd-list__item--link{-webkit-padding-end:0;padding-inline-end:0}.fd-list--navigation-indication fd-list__item.fd-list__item--link:after{content:none}.fd-list--navigation-indication .fd-list__link:after{content:\"\";min-width:2.5rem}.fd-list--navigation-indication .fd-list__link--navigation-indicator:after{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_NonInteractiveIconColor);content:\"\\e1ed\";font-family:SAP-icons;font-size:var(--fdListNavigationIndicatorFontSize,var(--sapFontLargeSize));height:100%;text-decoration:none;text-transform:none}.fd-list--navigation-indication .fd-list__link--navigation-indicator[dir=rtl]:after,[dir=rtl] .fd-list--navigation-indication .fd-list__link--navigation-indicator:after{content:\"\\e1ee\"}.fd-list--navigation-indication .fd-list__icon:last-child,.fd-list--navigation-indication .fd-list__icon[dir=rtl]:last-child,[dir=rtl] .fd-list--navigation-indication .fd-list__icon:last-child{margin-block:0;margin-inline:0}.fd-list--navigation-indication .is-navigated{-webkit-box-shadow:inset -.1875rem 0 0 0 var(--sapList_SelectionBorderColor);box-shadow:inset -.1875rem 0 0 0 var(--sapList_SelectionBorderColor)}.fd-list--navigation-indication .is-navigated[dir=rtl],[dir=rtl] .fd-list--navigation-indication .is-navigated{-webkit-box-shadow:inset .1875rem 0 0 0 var(--sapList_SelectionBorderColor);box-shadow:inset .1875rem 0 0 0 var(--sapList_SelectionBorderColor)}.fd-list--selection .fd-list__item{cursor:pointer;padding-inline:2.75rem .9375rem}.fd-list--selection .fd-list__item.is-hover,.fd-list--selection .fd-list__item:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background)}.fd-list--selection .fd-list__item.is-selected,.fd-list--selection .fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--selection .fd-list__item.is-selected .fd-list__link,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list--selection .fd-list__item.is-selected .fd-list__link.is-active,.fd-list--selection .fd-list__item.is-selected .fd-list__link:active,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--selection .fd-list__item.is-selected.is-hover,.fd-list--selection .fd-list__item.is-selected:hover,.fd-list--selection .fd-list__item[aria-selected=true].is-hover,.fd-list--selection .fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--selection .fd-list__form-item{left:0;position:absolute;top:0;z-index:5}.fd-list--selection .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection .fd-list__form-item{left:auto;right:0}.fd-list--selection[class*=-compact] .fd-list__form-item,.fd-list--selection[class*=-condensed] .fd-list__form-item,[class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item,[class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item{left:.375rem}.fd-list--selection[class*=-compact] .fd-list__form-item[dir=rtl],.fd-list--selection[class*=-condensed] .fd-list__form-item[dir=rtl],[class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection[class*=-compact] .fd-list__form-item,[dir=rtl] .fd-list--selection[class*=-condensed] .fd-list__form-item,[dir=rtl] [class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item,[dir=rtl] [class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item{left:auto;right:.375rem}.fd-list--selection.fd-list--byline .fd-list__item{padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline .fd-list__form-item{top:.3125rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__item,.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__item,[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__item,[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__item{padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item,.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item,[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item,[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item{left:.375rem;top:.5rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item[dir=rtl],.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item[dir=rtl],[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item,[dir=rtl] .fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item,[dir=rtl] [class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item,[dir=rtl] [class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item{left:auto;right:.375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item{padding-block:.5rem;padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:first-child{-webkit-padding-before:.9375rem;padding-block-start:.9375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:last-child{-webkit-padding-after:.9375rem;padding-block-end:.9375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item{top:0}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item label,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item label{-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item label:after,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item label:after{top:.375rem}.fd-list--selection.fd-list--selection-row .fd-list__item{-webkit-padding-start:1rem;padding-inline-start:1rem}:root{--fdList_Item_Background_Color:var(--sapList_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor);--fdList_Item_Text_Font_Size:var(--sapFontLargeSize);--fdList_Item_Icon_Font_Size:1.125rem;--fdList_Item_Height:var(--sapElement_LineHeight);--fdList_Status_Text_Color:var(--sapNeutralTextColor);--fdList_Message_Background_Color:var(--sapNeutralBackground)}.fd-list__item-counter{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-margin-start:1rem;color:var(--sapContent_MarkerTextColor);margin-inline-start:1rem}.fd-list__item-counter:after,.fd-list__item-counter:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list .fd-object-list__item{padding-block:1rem;--fdList_Item_Height:100%}.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-avatar,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-identifier__title,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-list__intro,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-list__object-attribute,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-marker__icon,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-marker__text,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-number__text,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-number__unit,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-status__icon,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-status__text,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-avatar,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-identifier__title,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-list__intro,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-list__object-attribute,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-marker__icon,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-marker__text,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-number__text,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-number__unit,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-status__icon,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-status__text{color:var(--sapList_Active_TextColor);text-shadow:none}.fd-object-list__intro{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;max-width:100%;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;width:100%;-webkit-padding-after:.75rem;color:var(--sapContent_LabelColor);padding-block-end:.75rem}.fd-object-list__intro:after,.fd-object-list__intro:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;height:100%;width:100%}.fd-object-list__container:after,.fd-object-list__container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.75rem}.fd-object-list__header:after,.fd-object-list__header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__header-left{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-align:left;width:60%}.fd-object-list__header-left:after,.fd-object-list__header-left:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__header-left[dir=rtl],[dir=rtl] .fd-object-list__header-left{text-align:right}.fd-object-list__header-right{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-align:right;width:40%;-webkit-margin-start:.25rem;margin-inline-start:.25rem}.fd-object-list__header-right:after,.fd-object-list__header-right:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__header-right[dir=rtl],[dir=rtl] .fd-object-list__header-right{text-align:left}.fd-object-list__row{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.5rem;-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-object-list__row:after,.fd-object-list__row:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__row-left,.fd-object-list__row-right{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-box-align:center;-ms-flex-align:center;align-items:center;line-height:1;width:50%}.fd-object-list__row-left:after,.fd-object-list__row-left:before,.fd-object-list__row-right:after,.fd-object-list__row-right:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__row-left:only-child,.fd-object-list__row-right:only-child{width:100%}.fd-object-list__row-right{-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end}.fd-object-list__row-right .fd-object-status__text{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-object-list__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;margin-top:.25rem;padding-block:0;padding-inline:0}.fd-object-list__content:after,.fd-object-list__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__object-number .fd-object-number__text{display:block;font-size:var(--fdObject_List_Number_Font_Size)}.fd-object-list__object-number .fd-object-number__text:after{content:none}.fd-object-list__object-identifier .fd-object-identifier__title{display:-webkit-box;-webkit-line-clamp:2;-webkit-box-orient:vertical;color:var(--sapGroup_TitleTextColor);font-size:var(--fdObject_List_Title_Font_Size);font-weight:var(--fdObject_List_Title_Font_Weight);line-height:1.5;overflow:hidden;text-overflow:ellipsis;white-space:normal}.fd-object-list__object-attribute{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-object-list__object-attribute:after,.fd-object-list__object-attribute:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__row{align-items:normal}\n/*! Bundled license information:\n\nfundamental-styles/dist/object-list.css:\n  (*!\n   * Fundamental Library Styles v0.38.0\n   * Copyright (c) 2024 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], propDecorators: { attributeLabel: [{
                type: Input
            }], linkedText: [{
                type: Input
            }], islink: [{
                type: Input
            }] } });

class ObjectListItemComponent extends BaseListItem {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ObjectListItemComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.0.7", type: ObjectListItemComponent, isStandalone: true, selector: "fdp-object-list-item", inputs: { introductionText: "introductionText", amount: "amount", currency: "currency", decimal: "decimal", numberStatus: "numberStatus", label: "label", glyph: "glyph", circle: "circle", placeholder: "placeholder", tile: "tile", colorAccent: "colorAccent", image: "image", transparent: "transparent" }, host: { attributes: { "role": "none" } }, providers: [{ provide: BaseListItem, useExisting: forwardRef(() => ObjectListItemComponent) }], queries: [{ propertyName: "children", predicate: ObjectListItemRowComponent }], usesInheritance: true, ngImport: i0, template: "<!--  list item navigation with Arrow-->\n@if (navigationIndicator || (navigated && !(noDataText !== null && noDataText !== undefined))) {\n    <div\n        #listItem\n        fd-list-item\n        [id]=\"id\"\n        [selected]=\"_selected\"\n        [tabindex]=\"-1\"\n        (click)=\"_onItemClick()\"\n        (keydown)=\"_onKeyDown($event)\"\n        (keyup)=\"_onKeyUp($event)\"\n        class=\"fd-object-list__item fd-list__item--link\"\n        [class.fd-list__item--inactive]=\"listType === 'inactive'\"\n        [attr.aria-label]=\"ariaLabel\"\n        [attr.aria-level]=\"ariaLevel\"\n        [attr.aria-posinset]=\"ariaPosinset\"\n        [attr.aria-setsize]=\"ariaSetSize | async\"\n        [ariaRole]=\"_listItemRole\"\n        [attr.aria-selected]=\"_selectedAttr\"\n    >\n        <ng-template [ngTemplateOutlet]=\"selectionTemplate\"> </ng-template>\n        <a\n            #linkElement\n            fd-list-link\n            [routerLink]=\"link\"\n            [attr.href]=\"link\"\n            [attr.aria-label]=\"title\"\n            [navigationIndicator]=\"navigationIndicator\"\n            [navigated]=\"navigated\"\n            tabindex=\"-1\"\n        >\n            <ng-template [ngTemplateOutlet]=\"objectTemplate\"></ng-template>\n        </a>\n    </div>\n}\n<!--  list item without navigation and used for simple list display-->\n@if (!navigationIndicator && !navigated && !(noDataText !== null && noDataText !== undefined)) {\n    <div\n        #listItem\n        fd-list-item\n        [id]=\"id\"\n        [selected]=\"_selected\"\n        (keydown)=\"_onKeyDown($event)\"\n        [tabindex]=\"-1\"\n        class=\"fd-object-list__item\"\n        (keyup)=\"_onKeyUp($event)\"\n        [attr.aria-label]=\"ariaLabel\"\n        [attr.aria-level]=\"ariaLevel\"\n        [attr.aria-posinset]=\"ariaPosinset\"\n        [attr.aria-setsize]=\"ariaSetSize | async\"\n        [class.fd-list__item--inactive]=\"listType === 'inactive'\"\n        (click)=\"_onItemClick()\"\n        [ariaRole]=\"role\"\n        [attr.aria-selected]=\"_selectedAttr\"\n    >\n        <ng-template [ngTemplateOutlet]=\"selectionTemplate\"></ng-template>\n        <ng-template [ngTemplateOutlet]=\"objectTemplate\"></ng-template>\n    </div>\n}\n@if (noDataText !== null && noDataText !== undefined) {\n    <div\n        #listItem\n        fd-list-item\n        [id]=\"id\"\n        [tabindex]=\"0\"\n        [attr.aria-label]=\"ariaLabel\"\n        class=\"fd-object-list__item\"\n        [attr.aria-level]=\"ariaLevel\"\n        [attr.aria-posinset]=\"ariaPosinset\"\n        [attr.aria-setsize]=\"ariaSetSize | async\"\n    >\n        <span fd-list-title [attr.aria-label]=\"noDataText\" [attr.title]=\"noDataText\">{{ noDataText }}</span>\n    </div>\n}\n<ng-template #objectTemplate>\n    <div class=\"fd-object-list__container\">\n        <!--Optional text-->\n        @if (introductionText) {\n            <div class=\"fd-object-list__intro\">{{ introductionText }}</div>\n        }\n        <!--header content-->\n        <div class=\"fd-object-list__header\">\n            @if (avatar.label || avatar.image || avatar.glyph || avatar.zoomGlyph) {\n                <fd-avatar\n                    [size]=\"avatar.size\"\n                    [glyph]=\"avatar.glyph\"\n                    [zoomGlyph]=\"avatar.zoomGlyph\"\n                    [label]=\"avatar.label\"\n                    [circle]=\"avatar.circle\"\n                    [placeholder]=\"avatar.placeholder\"\n                    [tile]=\"avatar.tile\"\n                    [colorAccent]=\"avatar.colorAccent\"\n                    [image]=\"avatar.image\"\n                    [transparent]=\"avatar.transparent\"\n                    [random]=\"avatar.random\"\n                    [class]=\"avatar.class\"\n                    [ariaLabel]=\"avatar.ariaLabel\"\n                    [ariaLabelledby]=\"avatar.ariaLabelledby\"\n                    [contain]=\"avatar.contain\"\n                    [border]=\"avatar.border\"\n                    [alterIcon]=\"avatar.alterIcon\"\n                    [backupImage]=\"avatar.backupImage\"\n                    [clickable]=\"avatar.clickable\"\n                ></fd-avatar>\n            }\n            <!--left side header content-->\n            <div class=\"fd-object-list__header-left\">\n                <fd-object-identifier class=\"fd-object-list__object-identifier\">{{ title }}</fd-object-identifier>\n            </div>\n            <!--right side header content-->\n            <div class=\"fd-object-list__header-right\">\n                <fd-object-number\n                    class=\"fd-object-list__object-number\"\n                    [number]=\"amount\"\n                    [unit]=\"currency\"\n                    [status]=\"numberStatus\"\n                    [decimal]=\"decimal\"\n                >\n                </fd-object-number>\n            </div>\n        </div>\n        <!--body content-->\n        <div class=\"fd-object-list__content\">\n            <ng-content select=\"fdp-object-list-item-row\"></ng-content>\n        </div>\n    </div>\n    <ng-template [ngTemplateOutlet]=\"actionsTemplate\"></ng-template>\n</ng-template>\n<ng-template #selectionTemplate>\n    @if ((selectionMode === 'multi' || selectionMode === 'single') && !rowSelection) {\n        <div fd-form-item class=\"fd-list__form-item\">\n            @if (selectionMode === 'multi') {\n                <fd-checkbox role=\"checkbox\" [(ngModel)]=\"_selected\" tabIndexValue=\"-1\"> </fd-checkbox>\n            }\n            @if (selectionMode === 'single') {\n                <fd-radio-button [value]=\"value\" [name]=\"name\" role=\"radio\" [(ngModel)]=\"selectionValue\">\n                </fd-radio-button>\n            }\n        </div>\n    }\n</ng-template>\n<ng-template #actionsTemplate>\n    <ng-content select=\"#secondaryAction\"></ng-content>\n    @if (listType === 'detail') {\n        <button\n            fd-button\n            role=\"button\"\n            fdType=\"transparent\"\n            glyph=\"edit\"\n            title=\"detail\"\n            [attr.aria-label]=\"'platformObjectListItem.detailsActionAriaLabel' | fdTranslate\"\n            (keydown)=\"_onKeyButtonClick($event, 'edit')\"\n            (click)=\"_onActionButtonClick('edit')\"\n            [attr.id]=\"'detail-' + id\"\n        ></button>\n    }\n    @if (selectionMode === 'delete') {\n        <button\n            fd-button\n            role=\"button\"\n            [attr.aria-label]=\"'platformObjectListItem.deleteActionAriaLabel' | fdTranslate\"\n            title=\"delete\"\n            fdType=\"transparent\"\n            glyph=\"decline\"\n            (keydown)=\"_onKeyButtonClick($event, 'delete')\"\n            (click)=\"_onActionButtonClick('delete')\"\n            [attr.id]=\"'delete-' + id\"\n        ></button>\n    }\n</ng-template>\n", styles: [".fd-list{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;list-style:none;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative;width:100%}.fd-list:after,.fd-list:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__footer,.fd-list__group-header,.fd-list__item{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;padding-block:0;padding-inline:.9375rem}.fd-list__footer:after,.fd-list__footer:before,.fd-list__group-header:after,.fd-list__group-header:before,.fd-list__item:after,.fd-list__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__item{background:var(--fdList_Item_Background_Color);border-bottom:var(--sapList_BorderWidth) solid var(--fdList_Item_Border_Color);height:var(--fdList_Item_Height);position:relative}.fd-list__item.is-focus,.fd-list__item:focus{outline:none;pointer-events:all}.fd-list__item.is-focus:before,.fd-list__item:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem .125rem .0625rem;pointer-events:none;position:absolute}.fd-list__item.is-focus.is-active:before,.fd-list__item.is-focus:active:before,.fd-list__item:focus.is-active:before,.fd-list__item:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-list__item--unread .fd-list__title{font-weight:700}.fd-list__item--no-data .fd-list__title{text-align:center}.fd-list__item--interactive.is-hover,.fd-list__item--interactive:hover,.fd-list__item--interractive.is-hover,.fd-list__item--interractive:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__item--interactive.is-selected,.fd-list__item--interactive[aria-selected=true],.fd-list__item--interractive.is-selected,.fd-list__item--interractive[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item--interactive.is-selected .fd-list__link,.fd-list__item--interactive[aria-selected=true] .fd-list__link,.fd-list__item--interractive.is-selected .fd-list__link,.fd-list__item--interractive[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item--interactive.is-selected .fd-list__link.is-active,.fd-list__item--interactive.is-selected .fd-list__link:active,.fd-list__item--interactive[aria-selected=true] .fd-list__link.is-active,.fd-list__item--interactive[aria-selected=true] .fd-list__link:active,.fd-list__item--interractive.is-selected .fd-list__link.is-active,.fd-list__item--interractive.is-selected .fd-list__link:active,.fd-list__item--interractive[aria-selected=true] .fd-list__link.is-active,.fd-list__item--interractive[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item--interactive.is-selected.is-hover,.fd-list__item--interactive.is-selected:hover,.fd-list__item--interactive[aria-selected=true].is-hover,.fd-list__item--interactive[aria-selected=true]:hover,.fd-list__item--interractive.is-selected.is-hover,.fd-list__item--interractive.is-selected:hover,.fd-list__item--interractive[aria-selected=true].is-hover,.fd-list__item--interractive[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__item--interactive.is-active,.fd-list__item--interactive.is-active.is-hover,.fd-list__item--interactive.is-active.is-selected,.fd-list__item--interactive.is-active.is-selected.is-hover,.fd-list__item--interactive.is-active.is-selected:hover,.fd-list__item--interactive.is-active:hover,.fd-list__item--interactive.is-active[aria-selected=true],.fd-list__item--interactive.is-active[aria-selected=true].is-hover,.fd-list__item--interactive.is-active[aria-selected=true]:hover,.fd-list__item--interactive:active,.fd-list__item--interactive:active.is-hover,.fd-list__item--interactive:active.is-selected,.fd-list__item--interactive:active.is-selected.is-hover,.fd-list__item--interactive:active.is-selected:hover,.fd-list__item--interactive:active:hover,.fd-list__item--interactive:active[aria-selected=true],.fd-list__item--interactive:active[aria-selected=true].is-hover,.fd-list__item--interactive:active[aria-selected=true]:hover,.fd-list__item--interractive.is-active,.fd-list__item--interractive.is-active.is-hover,.fd-list__item--interractive.is-active.is-selected,.fd-list__item--interractive.is-active.is-selected.is-hover,.fd-list__item--interractive.is-active.is-selected:hover,.fd-list__item--interractive.is-active:hover,.fd-list__item--interractive.is-active[aria-selected=true],.fd-list__item--interractive.is-active[aria-selected=true].is-hover,.fd-list__item--interractive.is-active[aria-selected=true]:hover,.fd-list__item--interractive:active,.fd-list__item--interractive:active.is-hover,.fd-list__item--interractive:active.is-selected,.fd-list__item--interractive:active.is-selected.is-hover,.fd-list__item--interractive:active.is-selected:hover,.fd-list__item--interractive:active:hover,.fd-list__item--interractive:active[aria-selected=true],.fd-list__item--interractive:active[aria-selected=true].is-hover,.fd-list__item--interractive:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__item--interactive.is-active,.fd-list__item--interactive.is-active .fd-list__byline,.fd-list__item--interactive.is-active .fd-list__byline-left,.fd-list__item--interactive.is-active .fd-list__byline-right,.fd-list__item--interactive.is-active .fd-list__byline-right--critical,.fd-list__item--interactive.is-active .fd-list__byline-right--informative,.fd-list__item--interactive.is-active .fd-list__byline-right--negative,.fd-list__item--interactive.is-active .fd-list__byline-right--neutral,.fd-list__item--interactive.is-active .fd-list__byline-right--positive,.fd-list__item--interactive.is-active .fd-list__content,.fd-list__item--interactive.is-active .fd-list__icon,.fd-list__item--interactive.is-active .fd-list__secondary,.fd-list__item--interactive.is-active .fd-list__thumbnail,.fd-list__item--interactive.is-active .fd-list__title,.fd-list__item--interactive.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--interactive:active,.fd-list__item--interactive:active .fd-list__byline,.fd-list__item--interactive:active .fd-list__byline-left,.fd-list__item--interactive:active .fd-list__byline-right,.fd-list__item--interactive:active .fd-list__byline-right--critical,.fd-list__item--interactive:active .fd-list__byline-right--informative,.fd-list__item--interactive:active .fd-list__byline-right--negative,.fd-list__item--interactive:active .fd-list__byline-right--neutral,.fd-list__item--interactive:active .fd-list__byline-right--positive,.fd-list__item--interactive:active .fd-list__content,.fd-list__item--interactive:active .fd-list__icon,.fd-list__item--interactive:active .fd-list__secondary,.fd-list__item--interactive:active .fd-list__thumbnail,.fd-list__item--interactive:active .fd-list__title,.fd-list__item--interactive:active.fd-list__link--navigation-indicator:after,.fd-list__item--interractive.is-active,.fd-list__item--interractive.is-active .fd-list__byline,.fd-list__item--interractive.is-active .fd-list__byline-left,.fd-list__item--interractive.is-active .fd-list__byline-right,.fd-list__item--interractive.is-active .fd-list__byline-right--critical,.fd-list__item--interractive.is-active .fd-list__byline-right--informative,.fd-list__item--interractive.is-active .fd-list__byline-right--negative,.fd-list__item--interractive.is-active .fd-list__byline-right--neutral,.fd-list__item--interractive.is-active .fd-list__byline-right--positive,.fd-list__item--interractive.is-active .fd-list__content,.fd-list__item--interractive.is-active .fd-list__icon,.fd-list__item--interractive.is-active .fd-list__secondary,.fd-list__item--interractive.is-active .fd-list__thumbnail,.fd-list__item--interractive.is-active .fd-list__title,.fd-list__item--interractive.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--interractive:active,.fd-list__item--interractive:active .fd-list__byline,.fd-list__item--interractive:active .fd-list__byline-left,.fd-list__item--interractive:active .fd-list__byline-right,.fd-list__item--interractive:active .fd-list__byline-right--critical,.fd-list__item--interractive:active .fd-list__byline-right--informative,.fd-list__item--interractive:active .fd-list__byline-right--negative,.fd-list__item--interractive:active .fd-list__byline-right--neutral,.fd-list__item--interractive:active .fd-list__byline-right--positive,.fd-list__item--interractive:active .fd-list__content,.fd-list__item--interractive:active .fd-list__icon,.fd-list__item--interractive:active .fd-list__secondary,.fd-list__item--interractive:active .fd-list__thumbnail,.fd-list__item--interractive:active .fd-list__title,.fd-list__item--interractive:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__item--action{border-bottom:var(--fdList_Item_Action_Border);font-size:var(--sapFontSize);padding-block:0;padding-inline:0;text-align:center;--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list__item--action:first-child{border-top:var(--fdList_Item_Action_Border)}.fd-list__item--action .fd-list__title{background:transparent;border:var(--fdList_Item_Action_Button_Border);border-radius:var(--fdList_Item_Action_Button_Border_Radius);color:var(--sapButton_TextColor);cursor:pointer;height:var(--fdList_Item_Action_Button_Size);margin-block:var(--fdList_Item_Action_Button_Spacing);margin-inline:var(--fdList_Item_Action_Button_Spacing);padding-block:0;padding-inline:.9375rem;pointer-events:all;width:100%}.fd-list__item--action .fd-list__title.is-hover,.fd-list__item--action .fd-list__title:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__item--action .fd-list__title.is-selected,.fd-list__item--action .fd-list__title[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item--action .fd-list__title.is-selected .fd-list__link,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item--action .fd-list__title.is-selected .fd-list__link.is-active,.fd-list__item--action .fd-list__title.is-selected .fd-list__link:active,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link.is-active,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item--action .fd-list__title.is-selected.is-hover,.fd-list__item--action .fd-list__title.is-selected:hover,.fd-list__item--action .fd-list__title[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__item--action .fd-list__title.is-active,.fd-list__item--action .fd-list__title.is-active.is-hover,.fd-list__item--action .fd-list__title.is-active.is-selected,.fd-list__item--action .fd-list__title.is-active.is-selected.is-hover,.fd-list__item--action .fd-list__title.is-active.is-selected:hover,.fd-list__item--action .fd-list__title.is-active:hover,.fd-list__item--action .fd-list__title.is-active[aria-selected=true],.fd-list__item--action .fd-list__title.is-active[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title.is-active[aria-selected=true]:hover,.fd-list__item--action .fd-list__title:active,.fd-list__item--action .fd-list__title:active.is-hover,.fd-list__item--action .fd-list__title:active.is-selected,.fd-list__item--action .fd-list__title:active.is-selected.is-hover,.fd-list__item--action .fd-list__title:active.is-selected:hover,.fd-list__item--action .fd-list__title:active:hover,.fd-list__item--action .fd-list__title:active[aria-selected=true],.fd-list__item--action .fd-list__title:active[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__item--action .fd-list__title.is-active,.fd-list__item--action .fd-list__title.is-active .fd-list__byline,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-left,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--critical,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--informative,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--negative,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--neutral,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--positive,.fd-list__item--action .fd-list__title.is-active .fd-list__content,.fd-list__item--action .fd-list__title.is-active .fd-list__icon,.fd-list__item--action .fd-list__title.is-active .fd-list__secondary,.fd-list__item--action .fd-list__title.is-active .fd-list__thumbnail,.fd-list__item--action .fd-list__title.is-active .fd-list__title,.fd-list__item--action .fd-list__title.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--action .fd-list__title:active,.fd-list__item--action .fd-list__title:active .fd-list__byline,.fd-list__item--action .fd-list__title:active .fd-list__byline-left,.fd-list__item--action .fd-list__title:active .fd-list__byline-right,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--critical,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--informative,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--negative,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--neutral,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--positive,.fd-list__item--action .fd-list__title:active .fd-list__content,.fd-list__item--action .fd-list__title:active .fd-list__icon,.fd-list__item--action .fd-list__title:active .fd-list__secondary,.fd-list__item--action .fd-list__title:active .fd-list__thumbnail,.fd-list__item--action .fd-list__title:active .fd-list__title,.fd-list__item--action .fd-list__title:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__item--action .fd-list__title.is-focus,.fd-list__item--action .fd-list__title:focus{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.125rem}.fd-list__item--action .fd-list__title.is-focus.is-active,.fd-list__item--action .fd-list__title.is-focus:active,.fd-list__item--action .fd-list__title:focus.is-active,.fd-list__item--action .fd-list__title:focus:active{outline-color:var(--fdList_Active_Outline_Color)}.fd-list__item--action .fd-list__title::-moz-focus-inner{border:0}.fd-list__item--growing{--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list__item--growing .fd-list__title{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;gap:.5rem}.fd-list__item--growing .fd-list__title-text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:inherit;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;font-weight:var(--fdList_Growing_Font_Weight);forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;text-shadow:inherit;white-space:nowrap}.fd-list__item--growing .fd-list__title-text:after,.fd-list__item--growing .fd-list__title-text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__item--inactive,.fd-list__item--inactive .fd-list__secondary,.fd-list__item--inactive .fd-list__title{pointer-events:none}.fd-list__item.is-selected,.fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item.is-selected .fd-list__link,.fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item.is-selected .fd-list__link.is-active,.fd-list__item.is-selected .fd-list__link:active,.fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item.is-selected.is-hover,.fd-list__item.is-selected:hover,.fd-list__item[aria-selected=true].is-hover,.fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__secondary,.fd-list__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdList_Item_Text_Color);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;pointer-events:none;pointer-events:all;text-overflow:ellipsis;white-space:nowrap}.fd-list__secondary:after,.fd-list__secondary:before,.fd-list__title:after,.fd-list__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__title{-webkit-box-flex:3;-ms-flex:3 3 10%;flex:3 3 10%;font-size:var(--fdList_Item_Text_Font_Size);min-height:var(--fdList_Item_Text_Font_Size)}.fd-list__title:last-child:first-child{-ms-flex-preferred-size:auto;flex-basis:auto}.fd-list__title .fd-list__title-text{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-list__title~.fd-list__icon{-webkit-margin-end:-1rem;margin-inline-end:-1rem}.fd-list__secondary{color:var(--fdList_Status_Text_Color);font-size:var(--sapFontSize);max-width:40%;text-align:right;-webkit-padding-start:1rem;padding-inline-start:1rem}.fd-list__secondary--positive{--fdList_Status_Text_Color:var(--sapPositiveTextColor)}.fd-list__secondary--critical{--fdList_Status_Text_Color:var(--sapCriticalTextColor)}.fd-list__secondary--negative{--fdList_Status_Text_Color:var(--sapNegativeTextColor)}.fd-list__secondary--informative{--fdList_Status_Text_Color:var(--sapInformativeTextColor)}.fd-list__secondary[dir=rtl],[dir=rtl] .fd-list__secondary{text-align:left}.fd-list__icon [class*=sap-icon],.fd-list__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;pointer-events:none;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_NonInteractiveIconColor);font-size:var(--fdList_Item_Icon_Font_Size);width:2.75rem;-webkit-box-flex:0;-ms-flex:0 0 auto;flex:0 0 auto}.fd-list__icon [class*=sap-icon]:first-child,.fd-list__icon[class*=sap-icon]:first-child{-webkit-margin-start:-1rem;margin-inline-start:-1rem}.fd-list__link{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;--fdList_Item_Border_Color:transparent;background:var(--fdList_Item_Background_Color);border-bottom:var(--sapList_BorderWidth) solid var(--fdList_Item_Border_Color);cursor:pointer;height:100%;padding-block:0;padding-inline:.9375rem;text-decoration:none;width:100%}.fd-list__link:after,.fd-list__link:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__link.is-focus,.fd-list__link:focus{outline:none;pointer-events:all}.fd-list__link.is-focus:before,.fd-list__link:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem;pointer-events:none;position:absolute}.fd-list__link.is-focus.is-active:before,.fd-list__link.is-focus:active:before,.fd-list__link:focus.is-active:before,.fd-list__link:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-list__link.is-hover,.fd-list__link:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__link.is-selected,.fd-list__link[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__link.is-selected .fd-list__link,.fd-list__link[aria-selected=true] .fd-list__link{background:inherit}.fd-list__link.is-selected .fd-list__link.is-active,.fd-list__link.is-selected .fd-list__link:active,.fd-list__link[aria-selected=true] .fd-list__link.is-active,.fd-list__link[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__link.is-selected.is-hover,.fd-list__link.is-selected:hover,.fd-list__link[aria-selected=true].is-hover,.fd-list__link[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__link.is-active,.fd-list__link.is-active.is-hover,.fd-list__link.is-active.is-selected,.fd-list__link.is-active.is-selected.is-hover,.fd-list__link.is-active.is-selected:hover,.fd-list__link.is-active:hover,.fd-list__link.is-active[aria-selected=true],.fd-list__link.is-active[aria-selected=true].is-hover,.fd-list__link.is-active[aria-selected=true]:hover,.fd-list__link:active,.fd-list__link:active.is-hover,.fd-list__link:active.is-selected,.fd-list__link:active.is-selected.is-hover,.fd-list__link:active.is-selected:hover,.fd-list__link:active:hover,.fd-list__link:active[aria-selected=true],.fd-list__link:active[aria-selected=true].is-hover,.fd-list__link:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__link.is-active,.fd-list__link.is-active .fd-list__byline,.fd-list__link.is-active .fd-list__byline-left,.fd-list__link.is-active .fd-list__byline-right,.fd-list__link.is-active .fd-list__byline-right--critical,.fd-list__link.is-active .fd-list__byline-right--informative,.fd-list__link.is-active .fd-list__byline-right--negative,.fd-list__link.is-active .fd-list__byline-right--neutral,.fd-list__link.is-active .fd-list__byline-right--positive,.fd-list__link.is-active .fd-list__content,.fd-list__link.is-active .fd-list__icon,.fd-list__link.is-active .fd-list__secondary,.fd-list__link.is-active .fd-list__thumbnail,.fd-list__link.is-active .fd-list__title,.fd-list__link.is-active.fd-list__link--navigation-indicator:after,.fd-list__link:active,.fd-list__link:active .fd-list__byline,.fd-list__link:active .fd-list__byline-left,.fd-list__link:active .fd-list__byline-right,.fd-list__link:active .fd-list__byline-right--critical,.fd-list__link:active .fd-list__byline-right--informative,.fd-list__link:active .fd-list__byline-right--negative,.fd-list__link:active .fd-list__byline-right--neutral,.fd-list__link:active .fd-list__byline-right--positive,.fd-list__link:active .fd-list__content,.fd-list__link:active .fd-list__icon,.fd-list__link:active .fd-list__secondary,.fd-list__link:active .fd-list__thumbnail,.fd-list__link:active .fd-list__title,.fd-list__link:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__group-header{background:var(--sapList_GroupHeaderBackground);border-bottom:var(--sapList_BorderWidth) solid var(--sapList_GroupHeaderBorderColor);height:var(--sapElement_LineHeight);-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}.fd-list__group-header .fd-list__title{color:var(--sapList_TableGroupHeaderTextColor);font-family:var(--sapFontHeaderFamily);font-size:var(--sapFontHeader6Size);font-weight:700;line-height:2rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list__footer{background:var(--sapList_FooterBackground);color:var(--sapList_FooterTextColor);font-size:var(--sapFontSize);height:2rem}.fd-list__footer--right{-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end}.fd-list__footer--left{-webkit-box-pack:start;-ms-flex-pack:start;justify-content:flex-start}.fd-list__bold{font-weight:700}.fd-list__message{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:2rem;left:0;line-height:normal;line-height:2rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;position:absolute;text-overflow:ellipsis;top:0;white-space:nowrap;width:100%;-webkit-padding-start:.5rem;background-color:var(--fdList_Message_Background_Color);font-size:var(--sapFontSmallSize);padding-inline-start:.5rem}.fd-list__message:after,.fd-list__message:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__message--error{--fdList_Message_Background_Color:var(--sapErrorBackground)}.fd-list__message--warning{--fdList_Message_Background_Color:var(--sapWarningBackground)}.fd-list__message--success{--fdList_Message_Background_Color:var(--sapSuccessBackground)}.fd-list__message--information{--fdList_Message_Background_Color:var(--sapInformationBackground)}.fd-list .fd-list__button{-webkit-margin-start:var(--fdList_Button_Spacing);margin-inline-start:var(--fdList_Button_Spacing);-ms-flex-item-align:center;align-self:center}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view),.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view),[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view),[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view){--fdList_Item_Icon_Font_Size:1rem;--fdList_Item_Text_Font_Size:var(--sapFontSize);--fdList_Item_Height:var(--sapElement_Compact_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing{--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action{--fdList_Item_Height:var(--sapElement_Compact_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title{height:var(--fdList_Item_Action_Button_Size_Compact)}.fd-list--no-border .fd-list__group-header,.fd-list--no-border .fd-list__item{border-bottom:0;border-top:0}.fd-list--no-border .fd-list__item.is-selected,.fd-list--no-border .fd-list__item[aria-selected=true]{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-list--has-message{-webkit-padding-before:2rem;padding-block-start:2rem}.fd-list__infinite-scroll{outline:none;overflow:scroll}.fd-list--dropdown.is-focus,.fd-list--dropdown:focus{outline:none;z-index:5}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header){display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:auto;min-height:2.5rem;padding-block:0;padding-inline:.9375rem}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link{background:inherit}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link.is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link:active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link.is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true],.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true]:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true],.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-left,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--critical,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--informative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--negative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--neutral,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--positive,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__content,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__icon,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__secondary,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__thumbnail,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__title,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.fd-list__link--navigation-indicator:after,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-left,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--critical,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--informative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--negative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--neutral,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--positive,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__content,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__icon,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__secondary,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__thumbnail,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__title,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list--dropdown[class*=-compact] .fd-list__item:not(.fd-list__group-header),.fd-list--dropdown[class*=-condensed] .fd-list__item:not(.fd-list__group-header),[class*=-compact] .fd-list--dropdown:not([class*=-cozy]) .fd-list__item:not(.fd-list__group-header),[class*=-condensed] .fd-list--dropdown:not([class*=-cozy]) .fd-list__item:not(.fd-list__group-header){height:auto;min-height:2rem;padding-block:0;padding-inline:.9375rem}.fd-list--multi-input .fd-list__item{height:auto;padding-block:0;padding-inline:0 1rem}.fd-list--multi-input .fd-list__item.is-hover,.fd-list--multi-input .fd-list__item:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list--multi-input .fd-list__item.is-selected,.fd-list--multi-input .fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--multi-input .fd-list__item.is-selected .fd-list__link,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list--multi-input .fd-list__item.is-selected .fd-list__link.is-active,.fd-list--multi-input .fd-list__item.is-selected .fd-list__link:active,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--multi-input .fd-list__item.is-selected.is-hover,.fd-list--multi-input .fd-list__item.is-selected:hover,.fd-list--multi-input .fd-list__item[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--multi-input .fd-list__item.is-active,.fd-list--multi-input .fd-list__item.is-active.is-hover,.fd-list--multi-input .fd-list__item.is-active.is-selected,.fd-list--multi-input .fd-list__item.is-active.is-selected.is-hover,.fd-list--multi-input .fd-list__item.is-active.is-selected:hover,.fd-list--multi-input .fd-list__item.is-active:hover,.fd-list--multi-input .fd-list__item.is-active[aria-selected=true],.fd-list--multi-input .fd-list__item.is-active[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item.is-active[aria-selected=true]:hover,.fd-list--multi-input .fd-list__item:active,.fd-list--multi-input .fd-list__item:active.is-hover,.fd-list--multi-input .fd-list__item:active.is-selected,.fd-list--multi-input .fd-list__item:active.is-selected.is-hover,.fd-list--multi-input .fd-list__item:active.is-selected:hover,.fd-list--multi-input .fd-list__item:active:hover,.fd-list--multi-input .fd-list__item:active[aria-selected=true],.fd-list--multi-input .fd-list__item:active[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list--multi-input .fd-list__item.is-active,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-left,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--critical,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--informative,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--negative,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--neutral,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--positive,.fd-list--multi-input .fd-list__item.is-active .fd-list__content,.fd-list--multi-input .fd-list__item.is-active .fd-list__icon,.fd-list--multi-input .fd-list__item.is-active .fd-list__secondary,.fd-list--multi-input .fd-list__item.is-active .fd-list__thumbnail,.fd-list--multi-input .fd-list__item.is-active .fd-list__title,.fd-list--multi-input .fd-list__item.is-active.fd-list__link--navigation-indicator:after,.fd-list--multi-input .fd-list__item:active,.fd-list--multi-input .fd-list__item:active .fd-list__byline,.fd-list--multi-input .fd-list__item:active .fd-list__byline-left,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--critical,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--informative,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--negative,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--neutral,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--positive,.fd-list--multi-input .fd-list__item:active .fd-list__content,.fd-list--multi-input .fd-list__item:active .fd-list__icon,.fd-list--multi-input .fd-list__item:active .fd-list__secondary,.fd-list--multi-input .fd-list__item:active .fd-list__thumbnail,.fd-list--multi-input .fd-list__item:active .fd-list__title,.fd-list--multi-input .fd-list__item:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list--multi-input .fd-list__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:inherit;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;position:relative;text-overflow:ellipsis;width:100%;-webkit-margin-end:0;margin-inline-end:0}.fd-list--multi-input .fd-list__label:after,.fd-list--multi-input .fd-list__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--multi-input .fd-list__label:before{margin-block:-.1875rem -.1875rem}.fd-list--multi-input .fd-list__input.is-focus,.fd-list--multi-input .fd-list__input:focus{-webkit-box-shadow:none;box-shadow:none;z-index:5}.fd-list--multi-input .fd-list__input.is-focus+.fd-list__label:after,.fd-list--multi-input .fd-list__input:focus+.fd-list__label:after{inset:.0625rem}.fd-list--multi-input .fd-list__footer{height:auto;text-align:right;-webkit-box-pack:end;-ms-flex-pack:end;background-color:var(--sapList_Background);justify-content:flex-end;line-height:1rem}.fd-list--multi-input .fd-list__footer,.fd-list--multi-input .fd-list__label{padding-block:.75rem;padding-inline:.9375rem}.fd-list--multi-input[class*=-compact] .fd-list__item,.fd-list--multi-input[class*=-condensed] .fd-list__item,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__item,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__item{height:auto;padding-block:0;padding-inline:0}.fd-list--multi-input[class*=-compact] .fd-list__label:before,.fd-list--multi-input[class*=-condensed] .fd-list__label:before,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label:before,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label:before{-webkit-margin-start:0;margin-inline-start:0;margin-top:0;-webkit-margin-after:0;margin-block-end:0}.fd-list--multi-input[class*=-compact] .fd-list__footer,.fd-list--multi-input[class*=-compact] .fd-list__label,.fd-list--multi-input[class*=-condensed] .fd-list__footer,.fd-list--multi-input[class*=-condensed] .fd-list__label,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__footer,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__footer,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label{padding-block:.5rem;padding-inline:.9375rem}.fd-list--dropdown,.fd-list--multi-input{display:block;max-width:40rem;min-width:5rem}.fd-list--dropdown .fd-list__item,.fd-list--multi-input .fd-list__item{border:none;cursor:pointer}.fd-list--dropdown .fd-list__item.is-selected,.fd-list--dropdown .fd-list__item[aria-selected=true],.fd-list--multi-input .fd-list__item.is-selected,.fd-list--multi-input .fd-list__item[aria-selected=true]{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-list--dropdown .fd-list__secondary,.fd-list--dropdown .fd-list__title,.fd-list--multi-input .fd-list__secondary,.fd-list--multi-input .fd-list__title{font-size:var(--sapFontSize);white-space:normal;-webkit-box-flex:1;-ms-flex:auto;flex:auto;width:auto}.fd-list--dropdown .fd-list__secondary--no-wrap,.fd-list--dropdown .fd-list__title--no-wrap,.fd-list--multi-input .fd-list__secondary--no-wrap,.fd-list--multi-input .fd-list__title--no-wrap{white-space:nowrap}.fd-list--dropdown .fd-list__secondary,.fd-list--multi-input .fd-list__secondary{display:block}.fd-list--dropdown .fd-list__title,.fd-list--multi-input .fd-list__title{max-width:24rem}.fd-list--dropdown .fd-list__title:first-child:last-child,.fd-list--multi-input .fd-list__title:first-child:last-child{max-width:40rem}.fd-list--dropdown .fd-list__secondary,.fd-list--multi-input .fd-list__secondary{max-width:16rem}.fd-list--dropdown.fd-list--mobile,.fd-list--multi-input.fd-list--mobile{max-width:100%}.fd-list--dropdown .fd-list__icon,.fd-list--multi-input .fd-list__icon{line-height:1rem}.fd-list--dropdown.fd-list--large-dropdown,.fd-list--multi-input.fd-list--large-dropdown{max-width:62rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__title,.fd-list--multi-input.fd-list--large-dropdown .fd-list__title{max-width:37.2rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__title:first-child:last-child,.fd-list--multi-input.fd-list--large-dropdown .fd-list__title:first-child:last-child{max-width:62rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__secondary,.fd-list--multi-input.fd-list--large-dropdown .fd-list__secondary{max-width:24.8rem}.fd-list--dropdown.fd-list--large-dropdown.fd-list--mobile,.fd-list--multi-input.fd-list--large-dropdown.fd-list--mobile{max-width:100%}.fd-list--byline .fd-list__item{height:auto;min-height:5rem;padding-block:.9375rem;padding-inline:1rem;width:100%;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.fd-list--byline .fd-list__item.is-focus,.fd-list--byline .fd-list__item:focus{pointer-events:all;z-index:5}.fd-list--byline .fd-list__item .fd-list__item-counter{-ms-flex-align:center;-ms-flex-item-align:center;align-self:center;-webkit-box-pack:end;-ms-flex-pack:end;height:100%;justify-content:flex-end;min-width:2rem}.fd-list--byline .fd-list__item .fd-list__item-counter,.fd-list--byline .fd-list__thumbnail{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;align-items:center}.fd-list--byline .fd-list__thumbnail{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;pointer-events:none;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-ms-flex-align:center;-webkit-margin-end:.75rem;border-radius:.25rem;color:var(--sapContent_NonInteractiveIconColor);font-size:2rem;height:3rem;margin-inline-end:.75rem;max-height:3rem;max-width:3rem;min-height:3rem;min-width:3rem;width:3rem}.fd-list--byline .fd-list__thumbnail:after,.fd-list--byline .fd-list__thumbnail:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__thumbnail [class*=sap-icon],.fd-list--byline .fd-list__thumbnail[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;line-height:1}.fd-list--byline .fd-list__thumbnail>svg{height:100%}.fd-list--byline .fd-list__notification{color:var(--sapAccentColor6);font-size:.375rem;left:1rem;position:absolute;top:50%;-webkit-transform:translateY(-50%);transform:translateY(-50%)}.fd-list--byline .fd-list__notification[dir=rtl],[dir=rtl] .fd-list--byline .fd-list__notification{left:auto;right:1rem}.fd-list--byline .fd-list__notification+.fd-list__link .fd-list__content .fd-list__title,.fd-list--byline .fd-list__notification~.fd-list__content .fd-list__title{font-weight:700}.fd-list--byline .fd-list__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;pointer-events:none;-ms-flex-line-pack:justify;align-content:space-between;height:100%;min-height:3rem;min-width:3rem;-webkit-box-flex:1;-ms-flex:1 1 auto;flex:1 1 auto;padding-block:.125rem;padding-inline:0}.fd-list--byline .fd-list__content:after,.fd-list--byline .fd-list__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__title{font-size:var(--sapFontLargeSize);min-height:1rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list--byline .fd-list__byline{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-list--byline .fd-list__byline:after,.fd-list--byline .fd-list__byline:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline--2-col{display:-webkit-box;display:-ms-flexbox;display:flex;pointer-events:all}.fd-list--byline .fd-list__byline--wrap .fd-list__byline-left,.fd-list--byline .fd-list__byline--wrap .fd-list__byline-right{display:inline;padding-block:0;padding-inline:0;white-space:normal;width:100%}.fd-list--byline .fd-list__byline--wrap .fd-list__byline-right{float:right;width:auto}.fd-list--byline .fd-list__link--more{pointer-events:all;text-transform:capitalize}.fd-list--byline .fd-list__byline--wrap,.fd-list--byline .fd-list__title--wrap{white-space:normal}.fd-list--byline .fd-list__byline-left{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;width:60%;-ms-flex-item-align:end;align-self:flex-end;-webkit-padding-end:.5rem;padding-inline-end:.5rem}.fd-list--byline .fd-list__byline-left:after,.fd-list--byline .fd-list__byline-left:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline-right{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-align:right;text-overflow:ellipsis;white-space:nowrap;width:40%;-ms-flex-item-align:end;align-self:flex-end;-webkit-padding-start:.5rem;padding-inline-start:.5rem}.fd-list--byline .fd-list__byline-right:after,.fd-list--byline .fd-list__byline-right:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline-right[dir=rtl],[dir=rtl] .fd-list--byline .fd-list__byline-right{text-align:left}.fd-list--byline .fd-list__byline-right--neutral{color:var(--sapNeutralTextColor)}.fd-list--byline .fd-list__byline-right--positive{color:var(--sapPositiveTextColor)}.fd-list--byline .fd-list__byline-right--critical{color:var(--sapCriticalTextColor)}.fd-list--byline .fd-list__byline-right--negative{color:var(--sapNegativeTextColor)}.fd-list--byline .fd-list__byline-right--informative{color:var(--sapInformativeTextColor)}.fd-list--byline.fd-list--unread-indicator .fd-list__item{padding-inline:2.125rem 1rem}.fd-list--byline[class*=-compact] .fd-list__title,.fd-list--byline[class*=-condensed] .fd-list__title,[class*=-compact] .fd-list--byline:not([class*=-cozy]) .fd-list__title,[class*=-condensed] .fd-list--byline:not([class*=-cozy]) .fd-list__title{font-size:var(--sapFontSize)}.fd-list--byline.fd-list--no-border .fd-list__item{height:100%;max-height:5rem;padding-block:.5rem}.fd-list--byline.fd-list--no-border .fd-list__item:first-child{-webkit-padding-before:.9375rem;padding-block-start:.9375rem}.fd-list--byline.fd-list--no-border .fd-list__item:last-child{-webkit-padding-after:.9375rem;padding-block-end:.9375rem}.fd-list--message-view{--fdListNavigationIndicatorFontSize:.75rem;--fdList_Item_Height:calc(2.75rem + var(--sapList_BorderWidth));--fdList_Message_View_Item_Byline_Height:calc(3.325rem + var(--sapList_BorderWidth));--fdList_Message_View_Title_Size:var(--sapFontHeader5Size)}.fd-list--message-view .fd-list__item{height:auto}.fd-list--message-view .fd-list__item--byline{--fdList_Item_Height:var(--fdList_Message_View_Item_Byline_Height)}.fd-list--message-view .fd-list__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-flex:1;-ms-flex:1 1 auto;flex:1 1 auto;overflow:hidden;pointer-events:none;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__content:after,.fd-list--message-view .fd-list__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--message-view .fd-list__title{color:var(--sapGroup_TitleTextColor);font-family:var(--sapFontHeaderFamily);font-size:var(--fdList_Message_View_Title_Size);font-weight:var(--sapFontHeaderWeight,normal);overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__subtitle{-webkit-padding-before:.25rem;color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);overflow:hidden;padding-block-start:.25rem;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__link{padding-block:.5rem}.fd-list--message-view .fd-list__link.is-active .fd-list__subtitle,.fd-list--message-view .fd-list__link.is-active .fd-list__title,.fd-list--message-view .fd-list__link.is-active .fd-object-status .fd-object-status__icon,.fd-list--message-view .fd-list__link:active .fd-list__subtitle,.fd-list--message-view .fd-list__link:active .fd-list__title,.fd-list--message-view .fd-list__link:active .fd-object-status .fd-object-status__icon{color:var(--sapList_Active_TextColor)}.fd-list--message-view[class*=-compact],.fd-list--message-view[class*=-condensed],[class*=-compact] .fd-list--message-view:not([class*=-cozy]),[class*=-condensed] .fd-list--message-view:not([class*=-cozy]){--fdList_Message_View_Item_Height:calc(2rem + var(--sapList_BorderWidth));--fdList_Message_View_Title_Size:var(--sapFontHeader6Size);--fdList_Message_View_Item_Byline_Height:calc(3.25rem + var(--sapList_BorderWidth))}.fd-list--navigation .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-icon-tab-bar__list .fd-list__link{gap:.25rem}.fd-list--navigation .fd-list__link{padding-inline:var(--fdList_Navigation_Link_Padding_Left,.9375rem) var(--fdList_Navigation_Link_Padding_Right,.9375rem)}.fd-list--navigation.fd-list--unread-indicator{--fdList_Navigation_Link_Padding_Left:2.125rem;--fdList_Navigation_Link_Padding_Right:.9375rem}.fd-list--navigation.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:.9375rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--selection{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:.9375rem}.fd-list--navigation.fd-list--selection .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--selection.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--selection.fd-list--navigation-indication .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline,.fd-list--navigation.fd-list--byline.fd-list--compact{--fdList_Navigation_Link_Padding_Left:1rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--compact .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline .fd-list__link,.fd-list--navigation.fd-list--byline.fd-list--compact .fd-list__link{padding-block:.9375rem}.fd-list--navigation.fd-list--byline.fd-list--compact.fd-list--unread-indicator,.fd-list--navigation.fd-list--byline.fd-list--unread-indicator{--fdList_Navigation_Link_Padding_Left:2.125rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:.9375rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--byline.fd-list--selection{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-compact],.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-condensed],[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]),[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]){--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-compact] .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-condensed] .fd-list__item--link,[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]) .fd-list__item--link,[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]) .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication[class*=-compact],.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication[class*=-condensed],[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication:not([class*=-cozy]),[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication:not([class*=-cozy]){--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--navigation-object{--fdList_Navigation_Link_Padding_Left:1rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--navigation-object .fd-list__item--link,.fd-list--navigation.fd-list--navigation-object[dir=rtl] .fd-list__item--link,[dir=rtl] .fd-list--navigation.fd-list--navigation-object .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--navigation-object .fd-list__link{padding-block:1rem}.fd-list--navigation-indication .fd-list:after{content:\"\";min-width:1.5rem}.fd-list--navigation-indication fd-list__item.fd-list__item--link{-webkit-padding-end:0;padding-inline-end:0}.fd-list--navigation-indication fd-list__item.fd-list__item--link:after{content:none}.fd-list--navigation-indication .fd-list__link:after{content:\"\";min-width:2.5rem}.fd-list--navigation-indication .fd-list__link--navigation-indicator:after{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_NonInteractiveIconColor);content:\"\\e1ed\";font-family:SAP-icons;font-size:var(--fdListNavigationIndicatorFontSize,var(--sapFontLargeSize));height:100%;text-decoration:none;text-transform:none}.fd-list--navigation-indication .fd-list__link--navigation-indicator[dir=rtl]:after,[dir=rtl] .fd-list--navigation-indication .fd-list__link--navigation-indicator:after{content:\"\\e1ee\"}.fd-list--navigation-indication .fd-list__icon:last-child,.fd-list--navigation-indication .fd-list__icon[dir=rtl]:last-child,[dir=rtl] .fd-list--navigation-indication .fd-list__icon:last-child{margin-block:0;margin-inline:0}.fd-list--navigation-indication .is-navigated{-webkit-box-shadow:inset -.1875rem 0 0 0 var(--sapList_SelectionBorderColor);box-shadow:inset -.1875rem 0 0 0 var(--sapList_SelectionBorderColor)}.fd-list--navigation-indication .is-navigated[dir=rtl],[dir=rtl] .fd-list--navigation-indication .is-navigated{-webkit-box-shadow:inset .1875rem 0 0 0 var(--sapList_SelectionBorderColor);box-shadow:inset .1875rem 0 0 0 var(--sapList_SelectionBorderColor)}.fd-list--selection .fd-list__item{cursor:pointer;padding-inline:2.75rem .9375rem}.fd-list--selection .fd-list__item.is-hover,.fd-list--selection .fd-list__item:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background)}.fd-list--selection .fd-list__item.is-selected,.fd-list--selection .fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--selection .fd-list__item.is-selected .fd-list__link,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list--selection .fd-list__item.is-selected .fd-list__link.is-active,.fd-list--selection .fd-list__item.is-selected .fd-list__link:active,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--selection .fd-list__item.is-selected.is-hover,.fd-list--selection .fd-list__item.is-selected:hover,.fd-list--selection .fd-list__item[aria-selected=true].is-hover,.fd-list--selection .fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--selection .fd-list__form-item{left:0;position:absolute;top:0;z-index:5}.fd-list--selection .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection .fd-list__form-item{left:auto;right:0}.fd-list--selection[class*=-compact] .fd-list__form-item,.fd-list--selection[class*=-condensed] .fd-list__form-item,[class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item,[class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item{left:.375rem}.fd-list--selection[class*=-compact] .fd-list__form-item[dir=rtl],.fd-list--selection[class*=-condensed] .fd-list__form-item[dir=rtl],[class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection[class*=-compact] .fd-list__form-item,[dir=rtl] .fd-list--selection[class*=-condensed] .fd-list__form-item,[dir=rtl] [class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item,[dir=rtl] [class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item{left:auto;right:.375rem}.fd-list--selection.fd-list--byline .fd-list__item{padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline .fd-list__form-item{top:.3125rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__item,.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__item,[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__item,[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__item{padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item,.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item,[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item,[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item{left:.375rem;top:.5rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item[dir=rtl],.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item[dir=rtl],[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item,[dir=rtl] .fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item,[dir=rtl] [class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item,[dir=rtl] [class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item{left:auto;right:.375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item{padding-block:.5rem;padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:first-child{-webkit-padding-before:.9375rem;padding-block-start:.9375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:last-child{-webkit-padding-after:.9375rem;padding-block-end:.9375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item{top:0}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item label,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item label{-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item label:after,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item label:after{top:.375rem}.fd-list--selection.fd-list--selection-row .fd-list__item{-webkit-padding-start:1rem;padding-inline-start:1rem}:root{--fdList_Item_Background_Color:var(--sapList_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor);--fdList_Item_Text_Font_Size:var(--sapFontLargeSize);--fdList_Item_Icon_Font_Size:1.125rem;--fdList_Item_Height:var(--sapElement_LineHeight);--fdList_Status_Text_Color:var(--sapNeutralTextColor);--fdList_Message_Background_Color:var(--sapNeutralBackground)}.fd-list__item-counter{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-margin-start:1rem;color:var(--sapContent_MarkerTextColor);margin-inline-start:1rem}.fd-list__item-counter:after,.fd-list__item-counter:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list .fd-object-list__item{padding-block:1rem;--fdList_Item_Height:100%}.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-avatar,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-identifier__title,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-list__intro,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-list__object-attribute,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-marker__icon,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-marker__text,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-number__text,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-number__unit,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-status__icon,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-status__text,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-avatar,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-identifier__title,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-list__intro,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-list__object-attribute,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-marker__icon,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-marker__text,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-number__text,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-number__unit,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-status__icon,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-status__text{color:var(--sapList_Active_TextColor);text-shadow:none}.fd-object-list__intro{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;max-width:100%;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;width:100%;-webkit-padding-after:.75rem;color:var(--sapContent_LabelColor);padding-block-end:.75rem}.fd-object-list__intro:after,.fd-object-list__intro:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;height:100%;width:100%}.fd-object-list__container:after,.fd-object-list__container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.75rem}.fd-object-list__header:after,.fd-object-list__header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__header-left{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-align:left;width:60%}.fd-object-list__header-left:after,.fd-object-list__header-left:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__header-left[dir=rtl],[dir=rtl] .fd-object-list__header-left{text-align:right}.fd-object-list__header-right{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-align:right;width:40%;-webkit-margin-start:.25rem;margin-inline-start:.25rem}.fd-object-list__header-right:after,.fd-object-list__header-right:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__header-right[dir=rtl],[dir=rtl] .fd-object-list__header-right{text-align:left}.fd-object-list__row{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.5rem;-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-object-list__row:after,.fd-object-list__row:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__row-left,.fd-object-list__row-right{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-box-align:center;-ms-flex-align:center;align-items:center;line-height:1;width:50%}.fd-object-list__row-left:after,.fd-object-list__row-left:before,.fd-object-list__row-right:after,.fd-object-list__row-right:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__row-left:only-child,.fd-object-list__row-right:only-child{width:100%}.fd-object-list__row-right{-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end}.fd-object-list__row-right .fd-object-status__text{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-object-list__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;margin-top:.25rem;padding-block:0;padding-inline:0}.fd-object-list__content:after,.fd-object-list__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__object-number .fd-object-number__text{display:block;font-size:var(--fdObject_List_Number_Font_Size)}.fd-object-list__object-number .fd-object-number__text:after{content:none}.fd-object-list__object-identifier .fd-object-identifier__title{display:-webkit-box;-webkit-line-clamp:2;-webkit-box-orient:vertical;color:var(--sapGroup_TitleTextColor);font-size:var(--fdObject_List_Title_Font_Size);font-weight:var(--fdObject_List_Title_Font_Weight);line-height:1.5;overflow:hidden;text-overflow:ellipsis;white-space:normal}.fd-object-list__object-attribute{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-object-list__object-attribute:after,.fd-object-list__object-attribute:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__row{align-items:normal}\n/*! Bundled license information:\n\nfundamental-styles/dist/object-list.css:\n  (*!\n   * Fundamental Library Styles v0.38.0\n   * Copyright (c) 2024 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"], dependencies: [{ kind: "component", type: ListItemComponent, selector: "[fdListItem] ,[fd-list-item]", inputs: ["selected", "noData", "action", "interactive", "growing", "counter", "unread", "byline", "ariaRole", "id", "preventClick"], outputs: ["keyDown"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: ListLinkDirective, selector: "[fd-list-link], [fdListLink]", inputs: ["navigationIndicator", "navigated", "focusable"] }, { kind: "directive", type: RouterLink, selector: "[routerLink]", inputs: ["target", "queryParams", "fragment", "queryParamsHandling", "state", "info", "relativeTo", "preserveFragment", "skipLocationChange", "replaceUrl", "routerLink"] }, { kind: "directive", type: ListTitleDirective, selector: "[fd-list-title], [fdListTitle]", inputs: ["wrap"] }, { kind: "component", type: AvatarComponent, selector: "fd-avatar", inputs: ["class", "id", "ariaLabel", "ariaLabelledby", "label", "size", "font", "glyph", "zoomGlyph", "circle", "transparent", "contain", "placeholder", "tile", "border", "colorAccent", "colorIndication", "random", "clickable", "valueState", "image", "alterIcon", "backupImage"], outputs: ["avatarClicked", "zoomGlyphClicked"] }, { kind: "component", type: ObjectIdentifierComponent, selector: "fd-object-identifier", inputs: ["description", "bold", "medium"] }, { kind: "component", type: ObjectNumberComponent, selector: "fd-object-number", inputs: ["number", "decimal", "unit", "emphasized", "large", "status", "class", "ariaLabelledBy", "ariaLabel"] }, { kind: "component", type: FormItemComponent, selector: "[fd-form-item]", inputs: ["isInline", "horizontal"] }, { kind: "component", type: CheckboxComponent, selector: "fd-checkbox", inputs: ["wrapLabel", "valignLabel", "ariaLabel", "role", "value", "ariaLabelledBy", "ariaDescribedBy", "title", "inputId", "state", "name", "label", "disabled", "readonly", "tristate", "tristateSelectable", "labelClass", "required", "displayOnly", "values", "standalone"], outputs: ["focusChange"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: RadioButtonComponent, selector: "fd-radio-button", inputs: ["ariaLabel", "ariaLabelledBy", "ariaDescribedBy", "title", "tabIndex", "state", "disabled", "readOnly", "selectedValue", "name", "id", "value", "required", "standalone", "wrapLabel", "valignLabel"] }, { kind: "component", type: ButtonComponent, selector: "button[fd-button], a[fd-button], span[fd-button]", inputs: ["class"], exportAs: ["fd-button"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }, { kind: "pipe", type: AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ObjectListItemComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fdp-object-list-item', encapsulation: ViewEncapsulation.None, providers: [{ provide: BaseListItem, useExisting: forwardRef(() => ObjectListItemComponent) }], changeDetection: ChangeDetectionStrategy.OnPush, host: {
                        role: 'none'
                    }, imports: [
                        ListItemComponent,
                        NgTemplateOutlet,
                        ListLinkDirective,
                        RouterLink,
                        ListTitleDirective,
                        AvatarComponent,
                        ObjectIdentifierComponent,
                        ObjectNumberComponent,
                        FormItemComponent,
                        CheckboxComponent,
                        FormsModule,
                        RadioButtonComponent,
                        ButtonComponent,
                        FdTranslatePipe,
                        AsyncPipe
                    ], template: "<!--  list item navigation with Arrow-->\n@if (navigationIndicator || (navigated && !(noDataText !== null && noDataText !== undefined))) {\n    <div\n        #listItem\n        fd-list-item\n        [id]=\"id\"\n        [selected]=\"_selected\"\n        [tabindex]=\"-1\"\n        (click)=\"_onItemClick()\"\n        (keydown)=\"_onKeyDown($event)\"\n        (keyup)=\"_onKeyUp($event)\"\n        class=\"fd-object-list__item fd-list__item--link\"\n        [class.fd-list__item--inactive]=\"listType === 'inactive'\"\n        [attr.aria-label]=\"ariaLabel\"\n        [attr.aria-level]=\"ariaLevel\"\n        [attr.aria-posinset]=\"ariaPosinset\"\n        [attr.aria-setsize]=\"ariaSetSize | async\"\n        [ariaRole]=\"_listItemRole\"\n        [attr.aria-selected]=\"_selectedAttr\"\n    >\n        <ng-template [ngTemplateOutlet]=\"selectionTemplate\"> </ng-template>\n        <a\n            #linkElement\n            fd-list-link\n            [routerLink]=\"link\"\n            [attr.href]=\"link\"\n            [attr.aria-label]=\"title\"\n            [navigationIndicator]=\"navigationIndicator\"\n            [navigated]=\"navigated\"\n            tabindex=\"-1\"\n        >\n            <ng-template [ngTemplateOutlet]=\"objectTemplate\"></ng-template>\n        </a>\n    </div>\n}\n<!--  list item without navigation and used for simple list display-->\n@if (!navigationIndicator && !navigated && !(noDataText !== null && noDataText !== undefined)) {\n    <div\n        #listItem\n        fd-list-item\n        [id]=\"id\"\n        [selected]=\"_selected\"\n        (keydown)=\"_onKeyDown($event)\"\n        [tabindex]=\"-1\"\n        class=\"fd-object-list__item\"\n        (keyup)=\"_onKeyUp($event)\"\n        [attr.aria-label]=\"ariaLabel\"\n        [attr.aria-level]=\"ariaLevel\"\n        [attr.aria-posinset]=\"ariaPosinset\"\n        [attr.aria-setsize]=\"ariaSetSize | async\"\n        [class.fd-list__item--inactive]=\"listType === 'inactive'\"\n        (click)=\"_onItemClick()\"\n        [ariaRole]=\"role\"\n        [attr.aria-selected]=\"_selectedAttr\"\n    >\n        <ng-template [ngTemplateOutlet]=\"selectionTemplate\"></ng-template>\n        <ng-template [ngTemplateOutlet]=\"objectTemplate\"></ng-template>\n    </div>\n}\n@if (noDataText !== null && noDataText !== undefined) {\n    <div\n        #listItem\n        fd-list-item\n        [id]=\"id\"\n        [tabindex]=\"0\"\n        [attr.aria-label]=\"ariaLabel\"\n        class=\"fd-object-list__item\"\n        [attr.aria-level]=\"ariaLevel\"\n        [attr.aria-posinset]=\"ariaPosinset\"\n        [attr.aria-setsize]=\"ariaSetSize | async\"\n    >\n        <span fd-list-title [attr.aria-label]=\"noDataText\" [attr.title]=\"noDataText\">{{ noDataText }}</span>\n    </div>\n}\n<ng-template #objectTemplate>\n    <div class=\"fd-object-list__container\">\n        <!--Optional text-->\n        @if (introductionText) {\n            <div class=\"fd-object-list__intro\">{{ introductionText }}</div>\n        }\n        <!--header content-->\n        <div class=\"fd-object-list__header\">\n            @if (avatar.label || avatar.image || avatar.glyph || avatar.zoomGlyph) {\n                <fd-avatar\n                    [size]=\"avatar.size\"\n                    [glyph]=\"avatar.glyph\"\n                    [zoomGlyph]=\"avatar.zoomGlyph\"\n                    [label]=\"avatar.label\"\n                    [circle]=\"avatar.circle\"\n                    [placeholder]=\"avatar.placeholder\"\n                    [tile]=\"avatar.tile\"\n                    [colorAccent]=\"avatar.colorAccent\"\n                    [image]=\"avatar.image\"\n                    [transparent]=\"avatar.transparent\"\n                    [random]=\"avatar.random\"\n                    [class]=\"avatar.class\"\n                    [ariaLabel]=\"avatar.ariaLabel\"\n                    [ariaLabelledby]=\"avatar.ariaLabelledby\"\n                    [contain]=\"avatar.contain\"\n                    [border]=\"avatar.border\"\n                    [alterIcon]=\"avatar.alterIcon\"\n                    [backupImage]=\"avatar.backupImage\"\n                    [clickable]=\"avatar.clickable\"\n                ></fd-avatar>\n            }\n            <!--left side header content-->\n            <div class=\"fd-object-list__header-left\">\n                <fd-object-identifier class=\"fd-object-list__object-identifier\">{{ title }}</fd-object-identifier>\n            </div>\n            <!--right side header content-->\n            <div class=\"fd-object-list__header-right\">\n                <fd-object-number\n                    class=\"fd-object-list__object-number\"\n                    [number]=\"amount\"\n                    [unit]=\"currency\"\n                    [status]=\"numberStatus\"\n                    [decimal]=\"decimal\"\n                >\n                </fd-object-number>\n            </div>\n        </div>\n        <!--body content-->\n        <div class=\"fd-object-list__content\">\n            <ng-content select=\"fdp-object-list-item-row\"></ng-content>\n        </div>\n    </div>\n    <ng-template [ngTemplateOutlet]=\"actionsTemplate\"></ng-template>\n</ng-template>\n<ng-template #selectionTemplate>\n    @if ((selectionMode === 'multi' || selectionMode === 'single') && !rowSelection) {\n        <div fd-form-item class=\"fd-list__form-item\">\n            @if (selectionMode === 'multi') {\n                <fd-checkbox role=\"checkbox\" [(ngModel)]=\"_selected\" tabIndexValue=\"-1\"> </fd-checkbox>\n            }\n            @if (selectionMode === 'single') {\n                <fd-radio-button [value]=\"value\" [name]=\"name\" role=\"radio\" [(ngModel)]=\"selectionValue\">\n                </fd-radio-button>\n            }\n        </div>\n    }\n</ng-template>\n<ng-template #actionsTemplate>\n    <ng-content select=\"#secondaryAction\"></ng-content>\n    @if (listType === 'detail') {\n        <button\n            fd-button\n            role=\"button\"\n            fdType=\"transparent\"\n            glyph=\"edit\"\n            title=\"detail\"\n            [attr.aria-label]=\"'platformObjectListItem.detailsActionAriaLabel' | fdTranslate\"\n            (keydown)=\"_onKeyButtonClick($event, 'edit')\"\n            (click)=\"_onActionButtonClick('edit')\"\n            [attr.id]=\"'detail-' + id\"\n        ></button>\n    }\n    @if (selectionMode === 'delete') {\n        <button\n            fd-button\n            role=\"button\"\n            [attr.aria-label]=\"'platformObjectListItem.deleteActionAriaLabel' | fdTranslate\"\n            title=\"delete\"\n            fdType=\"transparent\"\n            glyph=\"decline\"\n            (keydown)=\"_onKeyButtonClick($event, 'delete')\"\n            (click)=\"_onActionButtonClick('delete')\"\n            [attr.id]=\"'delete-' + id\"\n        ></button>\n    }\n</ng-template>\n", styles: [".fd-list{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;list-style:none;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;position:relative;width:100%}.fd-list:after,.fd-list:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__footer,.fd-list__group-header,.fd-list__item{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;padding-block:0;padding-inline:.9375rem}.fd-list__footer:after,.fd-list__footer:before,.fd-list__group-header:after,.fd-list__group-header:before,.fd-list__item:after,.fd-list__item:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__item{background:var(--fdList_Item_Background_Color);border-bottom:var(--sapList_BorderWidth) solid var(--fdList_Item_Border_Color);height:var(--fdList_Item_Height);position:relative}.fd-list__item.is-focus,.fd-list__item:focus{outline:none;pointer-events:all}.fd-list__item.is-focus:before,.fd-list__item:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem .125rem .0625rem;pointer-events:none;position:absolute}.fd-list__item.is-focus.is-active:before,.fd-list__item.is-focus:active:before,.fd-list__item:focus.is-active:before,.fd-list__item:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-list__item--unread .fd-list__title{font-weight:700}.fd-list__item--no-data .fd-list__title{text-align:center}.fd-list__item--interactive.is-hover,.fd-list__item--interactive:hover,.fd-list__item--interractive.is-hover,.fd-list__item--interractive:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__item--interactive.is-selected,.fd-list__item--interactive[aria-selected=true],.fd-list__item--interractive.is-selected,.fd-list__item--interractive[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item--interactive.is-selected .fd-list__link,.fd-list__item--interactive[aria-selected=true] .fd-list__link,.fd-list__item--interractive.is-selected .fd-list__link,.fd-list__item--interractive[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item--interactive.is-selected .fd-list__link.is-active,.fd-list__item--interactive.is-selected .fd-list__link:active,.fd-list__item--interactive[aria-selected=true] .fd-list__link.is-active,.fd-list__item--interactive[aria-selected=true] .fd-list__link:active,.fd-list__item--interractive.is-selected .fd-list__link.is-active,.fd-list__item--interractive.is-selected .fd-list__link:active,.fd-list__item--interractive[aria-selected=true] .fd-list__link.is-active,.fd-list__item--interractive[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item--interactive.is-selected.is-hover,.fd-list__item--interactive.is-selected:hover,.fd-list__item--interactive[aria-selected=true].is-hover,.fd-list__item--interactive[aria-selected=true]:hover,.fd-list__item--interractive.is-selected.is-hover,.fd-list__item--interractive.is-selected:hover,.fd-list__item--interractive[aria-selected=true].is-hover,.fd-list__item--interractive[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__item--interactive.is-active,.fd-list__item--interactive.is-active.is-hover,.fd-list__item--interactive.is-active.is-selected,.fd-list__item--interactive.is-active.is-selected.is-hover,.fd-list__item--interactive.is-active.is-selected:hover,.fd-list__item--interactive.is-active:hover,.fd-list__item--interactive.is-active[aria-selected=true],.fd-list__item--interactive.is-active[aria-selected=true].is-hover,.fd-list__item--interactive.is-active[aria-selected=true]:hover,.fd-list__item--interactive:active,.fd-list__item--interactive:active.is-hover,.fd-list__item--interactive:active.is-selected,.fd-list__item--interactive:active.is-selected.is-hover,.fd-list__item--interactive:active.is-selected:hover,.fd-list__item--interactive:active:hover,.fd-list__item--interactive:active[aria-selected=true],.fd-list__item--interactive:active[aria-selected=true].is-hover,.fd-list__item--interactive:active[aria-selected=true]:hover,.fd-list__item--interractive.is-active,.fd-list__item--interractive.is-active.is-hover,.fd-list__item--interractive.is-active.is-selected,.fd-list__item--interractive.is-active.is-selected.is-hover,.fd-list__item--interractive.is-active.is-selected:hover,.fd-list__item--interractive.is-active:hover,.fd-list__item--interractive.is-active[aria-selected=true],.fd-list__item--interractive.is-active[aria-selected=true].is-hover,.fd-list__item--interractive.is-active[aria-selected=true]:hover,.fd-list__item--interractive:active,.fd-list__item--interractive:active.is-hover,.fd-list__item--interractive:active.is-selected,.fd-list__item--interractive:active.is-selected.is-hover,.fd-list__item--interractive:active.is-selected:hover,.fd-list__item--interractive:active:hover,.fd-list__item--interractive:active[aria-selected=true],.fd-list__item--interractive:active[aria-selected=true].is-hover,.fd-list__item--interractive:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__item--interactive.is-active,.fd-list__item--interactive.is-active .fd-list__byline,.fd-list__item--interactive.is-active .fd-list__byline-left,.fd-list__item--interactive.is-active .fd-list__byline-right,.fd-list__item--interactive.is-active .fd-list__byline-right--critical,.fd-list__item--interactive.is-active .fd-list__byline-right--informative,.fd-list__item--interactive.is-active .fd-list__byline-right--negative,.fd-list__item--interactive.is-active .fd-list__byline-right--neutral,.fd-list__item--interactive.is-active .fd-list__byline-right--positive,.fd-list__item--interactive.is-active .fd-list__content,.fd-list__item--interactive.is-active .fd-list__icon,.fd-list__item--interactive.is-active .fd-list__secondary,.fd-list__item--interactive.is-active .fd-list__thumbnail,.fd-list__item--interactive.is-active .fd-list__title,.fd-list__item--interactive.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--interactive:active,.fd-list__item--interactive:active .fd-list__byline,.fd-list__item--interactive:active .fd-list__byline-left,.fd-list__item--interactive:active .fd-list__byline-right,.fd-list__item--interactive:active .fd-list__byline-right--critical,.fd-list__item--interactive:active .fd-list__byline-right--informative,.fd-list__item--interactive:active .fd-list__byline-right--negative,.fd-list__item--interactive:active .fd-list__byline-right--neutral,.fd-list__item--interactive:active .fd-list__byline-right--positive,.fd-list__item--interactive:active .fd-list__content,.fd-list__item--interactive:active .fd-list__icon,.fd-list__item--interactive:active .fd-list__secondary,.fd-list__item--interactive:active .fd-list__thumbnail,.fd-list__item--interactive:active .fd-list__title,.fd-list__item--interactive:active.fd-list__link--navigation-indicator:after,.fd-list__item--interractive.is-active,.fd-list__item--interractive.is-active .fd-list__byline,.fd-list__item--interractive.is-active .fd-list__byline-left,.fd-list__item--interractive.is-active .fd-list__byline-right,.fd-list__item--interractive.is-active .fd-list__byline-right--critical,.fd-list__item--interractive.is-active .fd-list__byline-right--informative,.fd-list__item--interractive.is-active .fd-list__byline-right--negative,.fd-list__item--interractive.is-active .fd-list__byline-right--neutral,.fd-list__item--interractive.is-active .fd-list__byline-right--positive,.fd-list__item--interractive.is-active .fd-list__content,.fd-list__item--interractive.is-active .fd-list__icon,.fd-list__item--interractive.is-active .fd-list__secondary,.fd-list__item--interractive.is-active .fd-list__thumbnail,.fd-list__item--interractive.is-active .fd-list__title,.fd-list__item--interractive.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--interractive:active,.fd-list__item--interractive:active .fd-list__byline,.fd-list__item--interractive:active .fd-list__byline-left,.fd-list__item--interractive:active .fd-list__byline-right,.fd-list__item--interractive:active .fd-list__byline-right--critical,.fd-list__item--interractive:active .fd-list__byline-right--informative,.fd-list__item--interractive:active .fd-list__byline-right--negative,.fd-list__item--interractive:active .fd-list__byline-right--neutral,.fd-list__item--interractive:active .fd-list__byline-right--positive,.fd-list__item--interractive:active .fd-list__content,.fd-list__item--interractive:active .fd-list__icon,.fd-list__item--interractive:active .fd-list__secondary,.fd-list__item--interractive:active .fd-list__thumbnail,.fd-list__item--interractive:active .fd-list__title,.fd-list__item--interractive:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__item--action{border-bottom:var(--fdList_Item_Action_Border);font-size:var(--sapFontSize);padding-block:0;padding-inline:0;text-align:center;--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list__item--action:first-child{border-top:var(--fdList_Item_Action_Border)}.fd-list__item--action .fd-list__title{background:transparent;border:var(--fdList_Item_Action_Button_Border);border-radius:var(--fdList_Item_Action_Button_Border_Radius);color:var(--sapButton_TextColor);cursor:pointer;height:var(--fdList_Item_Action_Button_Size);margin-block:var(--fdList_Item_Action_Button_Spacing);margin-inline:var(--fdList_Item_Action_Button_Spacing);padding-block:0;padding-inline:.9375rem;pointer-events:all;width:100%}.fd-list__item--action .fd-list__title.is-hover,.fd-list__item--action .fd-list__title:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__item--action .fd-list__title.is-selected,.fd-list__item--action .fd-list__title[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item--action .fd-list__title.is-selected .fd-list__link,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item--action .fd-list__title.is-selected .fd-list__link.is-active,.fd-list__item--action .fd-list__title.is-selected .fd-list__link:active,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link.is-active,.fd-list__item--action .fd-list__title[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item--action .fd-list__title.is-selected.is-hover,.fd-list__item--action .fd-list__title.is-selected:hover,.fd-list__item--action .fd-list__title[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__item--action .fd-list__title.is-active,.fd-list__item--action .fd-list__title.is-active.is-hover,.fd-list__item--action .fd-list__title.is-active.is-selected,.fd-list__item--action .fd-list__title.is-active.is-selected.is-hover,.fd-list__item--action .fd-list__title.is-active.is-selected:hover,.fd-list__item--action .fd-list__title.is-active:hover,.fd-list__item--action .fd-list__title.is-active[aria-selected=true],.fd-list__item--action .fd-list__title.is-active[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title.is-active[aria-selected=true]:hover,.fd-list__item--action .fd-list__title:active,.fd-list__item--action .fd-list__title:active.is-hover,.fd-list__item--action .fd-list__title:active.is-selected,.fd-list__item--action .fd-list__title:active.is-selected.is-hover,.fd-list__item--action .fd-list__title:active.is-selected:hover,.fd-list__item--action .fd-list__title:active:hover,.fd-list__item--action .fd-list__title:active[aria-selected=true],.fd-list__item--action .fd-list__title:active[aria-selected=true].is-hover,.fd-list__item--action .fd-list__title:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__item--action .fd-list__title.is-active,.fd-list__item--action .fd-list__title.is-active .fd-list__byline,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-left,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--critical,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--informative,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--negative,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--neutral,.fd-list__item--action .fd-list__title.is-active .fd-list__byline-right--positive,.fd-list__item--action .fd-list__title.is-active .fd-list__content,.fd-list__item--action .fd-list__title.is-active .fd-list__icon,.fd-list__item--action .fd-list__title.is-active .fd-list__secondary,.fd-list__item--action .fd-list__title.is-active .fd-list__thumbnail,.fd-list__item--action .fd-list__title.is-active .fd-list__title,.fd-list__item--action .fd-list__title.is-active.fd-list__link--navigation-indicator:after,.fd-list__item--action .fd-list__title:active,.fd-list__item--action .fd-list__title:active .fd-list__byline,.fd-list__item--action .fd-list__title:active .fd-list__byline-left,.fd-list__item--action .fd-list__title:active .fd-list__byline-right,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--critical,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--informative,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--negative,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--neutral,.fd-list__item--action .fd-list__title:active .fd-list__byline-right--positive,.fd-list__item--action .fd-list__title:active .fd-list__content,.fd-list__item--action .fd-list__title:active .fd-list__icon,.fd-list__item--action .fd-list__title:active .fd-list__secondary,.fd-list__item--action .fd-list__title:active .fd-list__thumbnail,.fd-list__item--action .fd-list__title:active .fd-list__title,.fd-list__item--action .fd-list__title:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__item--action .fd-list__title.is-focus,.fd-list__item--action .fd-list__title:focus{outline:var(--sapContent_FocusColor) var(--sapContent_FocusStyle) var(--sapContent_FocusWidth);outline-offset:-.125rem}.fd-list__item--action .fd-list__title.is-focus.is-active,.fd-list__item--action .fd-list__title.is-focus:active,.fd-list__item--action .fd-list__title:focus.is-active,.fd-list__item--action .fd-list__title:focus:active{outline-color:var(--fdList_Active_Outline_Color)}.fd-list__item--action .fd-list__title::-moz-focus-inner{border:0}.fd-list__item--growing{--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list__item--growing .fd-list__title{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;gap:.5rem}.fd-list__item--growing .fd-list__title-text{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:inherit;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;font-weight:var(--fdList_Growing_Font_Weight);forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;text-shadow:inherit;white-space:nowrap}.fd-list__item--growing .fd-list__title-text:after,.fd-list__item--growing .fd-list__title-text:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__item--inactive,.fd-list__item--inactive .fd-list__secondary,.fd-list__item--inactive .fd-list__title{pointer-events:none}.fd-list__item.is-selected,.fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__item.is-selected .fd-list__link,.fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list__item.is-selected .fd-list__link.is-active,.fd-list__item.is-selected .fd-list__link:active,.fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__item.is-selected.is-hover,.fd-list__item.is-selected:hover,.fd-list__item[aria-selected=true].is-hover,.fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__secondary,.fd-list__title{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--fdList_Item_Text_Color);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;pointer-events:none;pointer-events:all;text-overflow:ellipsis;white-space:nowrap}.fd-list__secondary:after,.fd-list__secondary:before,.fd-list__title:after,.fd-list__title:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__title{-webkit-box-flex:3;-ms-flex:3 3 10%;flex:3 3 10%;font-size:var(--fdList_Item_Text_Font_Size);min-height:var(--fdList_Item_Text_Font_Size)}.fd-list__title:last-child:first-child{-ms-flex-preferred-size:auto;flex-basis:auto}.fd-list__title .fd-list__title-text{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.fd-list__title~.fd-list__icon{-webkit-margin-end:-1rem;margin-inline-end:-1rem}.fd-list__secondary{color:var(--fdList_Status_Text_Color);font-size:var(--sapFontSize);max-width:40%;text-align:right;-webkit-padding-start:1rem;padding-inline-start:1rem}.fd-list__secondary--positive{--fdList_Status_Text_Color:var(--sapPositiveTextColor)}.fd-list__secondary--critical{--fdList_Status_Text_Color:var(--sapCriticalTextColor)}.fd-list__secondary--negative{--fdList_Status_Text_Color:var(--sapNegativeTextColor)}.fd-list__secondary--informative{--fdList_Status_Text_Color:var(--sapInformativeTextColor)}.fd-list__secondary[dir=rtl],[dir=rtl] .fd-list__secondary{text-align:left}.fd-list__icon [class*=sap-icon],.fd-list__icon[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;font-size:inherit;line-height:1;pointer-events:none;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_NonInteractiveIconColor);font-size:var(--fdList_Item_Icon_Font_Size);width:2.75rem;-webkit-box-flex:0;-ms-flex:0 0 auto;flex:0 0 auto}.fd-list__icon [class*=sap-icon]:first-child,.fd-list__icon[class*=sap-icon]:first-child{-webkit-margin-start:-1rem;margin-inline-start:-1rem}.fd-list__link{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-inline:0;-webkit-box-align:center;-ms-flex-align:center;align-items:center;--fdList_Item_Border_Color:transparent;background:var(--fdList_Item_Background_Color);border-bottom:var(--sapList_BorderWidth) solid var(--fdList_Item_Border_Color);cursor:pointer;height:100%;padding-block:0;padding-inline:.9375rem;text-decoration:none;width:100%}.fd-list__link:after,.fd-list__link:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__link.is-focus,.fd-list__link:focus{outline:none;pointer-events:all}.fd-list__link.is-focus:before,.fd-list__link:focus:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--sapContent_FocusColor);content:\"\";display:block;inset:.125rem;pointer-events:none;position:absolute}.fd-list__link.is-focus.is-active:before,.fd-list__link.is-focus:active:before,.fd-list__link:focus.is-active:before,.fd-list__link:focus:active:before{border:var(--sapContent_FocusWidth) var(--sapContent_FocusStyle) var(--fdList_Active_Outline_Color)}.fd-list__link.is-hover,.fd-list__link:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list__link.is-selected,.fd-list__link[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list__link.is-selected .fd-list__link,.fd-list__link[aria-selected=true] .fd-list__link{background:inherit}.fd-list__link.is-selected .fd-list__link.is-active,.fd-list__link.is-selected .fd-list__link:active,.fd-list__link[aria-selected=true] .fd-list__link.is-active,.fd-list__link[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list__link.is-selected.is-hover,.fd-list__link.is-selected:hover,.fd-list__link[aria-selected=true].is-hover,.fd-list__link[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list__link.is-active,.fd-list__link.is-active.is-hover,.fd-list__link.is-active.is-selected,.fd-list__link.is-active.is-selected.is-hover,.fd-list__link.is-active.is-selected:hover,.fd-list__link.is-active:hover,.fd-list__link.is-active[aria-selected=true],.fd-list__link.is-active[aria-selected=true].is-hover,.fd-list__link.is-active[aria-selected=true]:hover,.fd-list__link:active,.fd-list__link:active.is-hover,.fd-list__link:active.is-selected,.fd-list__link:active.is-selected.is-hover,.fd-list__link:active.is-selected:hover,.fd-list__link:active:hover,.fd-list__link:active[aria-selected=true],.fd-list__link:active[aria-selected=true].is-hover,.fd-list__link:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list__link.is-active,.fd-list__link.is-active .fd-list__byline,.fd-list__link.is-active .fd-list__byline-left,.fd-list__link.is-active .fd-list__byline-right,.fd-list__link.is-active .fd-list__byline-right--critical,.fd-list__link.is-active .fd-list__byline-right--informative,.fd-list__link.is-active .fd-list__byline-right--negative,.fd-list__link.is-active .fd-list__byline-right--neutral,.fd-list__link.is-active .fd-list__byline-right--positive,.fd-list__link.is-active .fd-list__content,.fd-list__link.is-active .fd-list__icon,.fd-list__link.is-active .fd-list__secondary,.fd-list__link.is-active .fd-list__thumbnail,.fd-list__link.is-active .fd-list__title,.fd-list__link.is-active.fd-list__link--navigation-indicator:after,.fd-list__link:active,.fd-list__link:active .fd-list__byline,.fd-list__link:active .fd-list__byline-left,.fd-list__link:active .fd-list__byline-right,.fd-list__link:active .fd-list__byline-right--critical,.fd-list__link:active .fd-list__byline-right--informative,.fd-list__link:active .fd-list__byline-right--negative,.fd-list__link:active .fd-list__byline-right--neutral,.fd-list__link:active .fd-list__byline-right--positive,.fd-list__link:active .fd-list__content,.fd-list__link:active .fd-list__icon,.fd-list__link:active .fd-list__secondary,.fd-list__link:active .fd-list__thumbnail,.fd-list__link:active .fd-list__title,.fd-list__link:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list__group-header{background:var(--sapList_GroupHeaderBackground);border-bottom:var(--sapList_BorderWidth) solid var(--sapList_GroupHeaderBorderColor);height:var(--sapElement_LineHeight);-webkit-box-align:end;-ms-flex-align:end;align-items:flex-end}.fd-list__group-header .fd-list__title{color:var(--sapList_TableGroupHeaderTextColor);font-family:var(--sapFontHeaderFamily);font-size:var(--sapFontHeader6Size);font-weight:700;line-height:2rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list__footer{background:var(--sapList_FooterBackground);color:var(--sapList_FooterTextColor);font-size:var(--sapFontSize);height:2rem}.fd-list__footer--right{-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end}.fd-list__footer--left{-webkit-box-pack:start;-ms-flex-pack:start;justify-content:flex-start}.fd-list__bold{font-weight:700}.fd-list__message{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;height:2rem;left:0;line-height:normal;line-height:2rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;position:absolute;text-overflow:ellipsis;top:0;white-space:nowrap;width:100%;-webkit-padding-start:.5rem;background-color:var(--fdList_Message_Background_Color);font-size:var(--sapFontSmallSize);padding-inline-start:.5rem}.fd-list__message:after,.fd-list__message:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list__message--error{--fdList_Message_Background_Color:var(--sapErrorBackground)}.fd-list__message--warning{--fdList_Message_Background_Color:var(--sapWarningBackground)}.fd-list__message--success{--fdList_Message_Background_Color:var(--sapSuccessBackground)}.fd-list__message--information{--fdList_Message_Background_Color:var(--sapInformationBackground)}.fd-list .fd-list__button{-webkit-margin-start:var(--fdList_Button_Spacing);margin-inline-start:var(--fdList_Button_Spacing);-ms-flex-item-align:center;align-self:center}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view),.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view),[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view),[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view){--fdList_Item_Icon_Font_Size:1rem;--fdList_Item_Text_Font_Size:var(--sapFontSize);--fdList_Item_Height:var(--sapElement_Compact_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item--growing{--fdList_Item_Height:var(--sapElement_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action{--fdList_Item_Height:var(--sapElement_Compact_LineHeight)}.fd-list[class*=-compact]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,.fd-list[class*=-condensed]:not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,[class*=-compact] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title,[class*=-condensed] .fd-list:not([class*=-cozy]):not(.fd-object-list):not(.fd-list--message-view) .fd-list__item.fd-list__item--action .fd-list__title{height:var(--fdList_Item_Action_Button_Size_Compact)}.fd-list--no-border .fd-list__group-header,.fd-list--no-border .fd-list__item{border-bottom:0;border-top:0}.fd-list--no-border .fd-list__item.is-selected,.fd-list--no-border .fd-list__item[aria-selected=true]{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-list--has-message{-webkit-padding-before:2rem;padding-block-start:2rem}.fd-list__infinite-scroll{outline:none;overflow:scroll}.fd-list--dropdown.is-focus,.fd-list--dropdown:focus{outline:none;z-index:5}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header){display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:auto;min-height:2.5rem;padding-block:0;padding-inline:.9375rem}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link{background:inherit}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link.is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected .fd-list__link:active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link.is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header)[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true],.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active[aria-selected=true]:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected.is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.is-selected:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active:hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true],.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true].is-hover,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-left,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--critical,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--informative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--negative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--neutral,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__byline-right--positive,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__content,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__icon,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__secondary,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__thumbnail,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active .fd-list__title,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header).is-active.fd-list__link--navigation-indicator:after,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-left,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--critical,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--informative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--negative,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--neutral,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__byline-right--positive,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__content,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__icon,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__secondary,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__thumbnail,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active .fd-list__title,.fd-list--dropdown .fd-list__item:not(.fd-list__group-header):active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list--dropdown[class*=-compact] .fd-list__item:not(.fd-list__group-header),.fd-list--dropdown[class*=-condensed] .fd-list__item:not(.fd-list__group-header),[class*=-compact] .fd-list--dropdown:not([class*=-cozy]) .fd-list__item:not(.fd-list__group-header),[class*=-condensed] .fd-list--dropdown:not([class*=-cozy]) .fd-list__item:not(.fd-list__group-header){height:auto;min-height:2rem;padding-block:0;padding-inline:.9375rem}.fd-list--multi-input .fd-list__item{height:auto;padding-block:0;padding-inline:0 1rem}.fd-list--multi-input .fd-list__item.is-hover,.fd-list--multi-input .fd-list__item:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor)}.fd-list--multi-input .fd-list__item.is-selected,.fd-list--multi-input .fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--multi-input .fd-list__item.is-selected .fd-list__link,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list--multi-input .fd-list__item.is-selected .fd-list__link.is-active,.fd-list--multi-input .fd-list__item.is-selected .fd-list__link:active,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list--multi-input .fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--multi-input .fd-list__item.is-selected.is-hover,.fd-list--multi-input .fd-list__item.is-selected:hover,.fd-list--multi-input .fd-list__item[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--multi-input .fd-list__item.is-active,.fd-list--multi-input .fd-list__item.is-active.is-hover,.fd-list--multi-input .fd-list__item.is-active.is-selected,.fd-list--multi-input .fd-list__item.is-active.is-selected.is-hover,.fd-list--multi-input .fd-list__item.is-active.is-selected:hover,.fd-list--multi-input .fd-list__item.is-active:hover,.fd-list--multi-input .fd-list__item.is-active[aria-selected=true],.fd-list--multi-input .fd-list__item.is-active[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item.is-active[aria-selected=true]:hover,.fd-list--multi-input .fd-list__item:active,.fd-list--multi-input .fd-list__item:active.is-hover,.fd-list--multi-input .fd-list__item:active.is-selected,.fd-list--multi-input .fd-list__item:active.is-selected.is-hover,.fd-list--multi-input .fd-list__item:active.is-selected:hover,.fd-list--multi-input .fd-list__item:active:hover,.fd-list--multi-input .fd-list__item:active[aria-selected=true],.fd-list--multi-input .fd-list__item:active[aria-selected=true].is-hover,.fd-list--multi-input .fd-list__item:active[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Active_Background);--fdList_Item_Text_Color:var(--sapList_Active_TextColor);--fdList_Item_Border_Color:var(--sapList_Active_Background)}.fd-list--multi-input .fd-list__item.is-active,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-left,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--critical,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--informative,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--negative,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--neutral,.fd-list--multi-input .fd-list__item.is-active .fd-list__byline-right--positive,.fd-list--multi-input .fd-list__item.is-active .fd-list__content,.fd-list--multi-input .fd-list__item.is-active .fd-list__icon,.fd-list--multi-input .fd-list__item.is-active .fd-list__secondary,.fd-list--multi-input .fd-list__item.is-active .fd-list__thumbnail,.fd-list--multi-input .fd-list__item.is-active .fd-list__title,.fd-list--multi-input .fd-list__item.is-active.fd-list__link--navigation-indicator:after,.fd-list--multi-input .fd-list__item:active,.fd-list--multi-input .fd-list__item:active .fd-list__byline,.fd-list--multi-input .fd-list__item:active .fd-list__byline-left,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--critical,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--informative,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--negative,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--neutral,.fd-list--multi-input .fd-list__item:active .fd-list__byline-right--positive,.fd-list--multi-input .fd-list__item:active .fd-list__content,.fd-list--multi-input .fd-list__item:active .fd-list__icon,.fd-list--multi-input .fd-list__item:active .fd-list__secondary,.fd-list--multi-input .fd-list__item:active .fd-list__thumbnail,.fd-list--multi-input .fd-list__item:active .fd-list__title,.fd-list--multi-input .fd-list__item:active.fd-list__link--navigation-indicator:after{text-shadow:none}.fd-list--multi-input .fd-list__label{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:inherit;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;position:relative;text-overflow:ellipsis;width:100%;-webkit-margin-end:0;margin-inline-end:0}.fd-list--multi-input .fd-list__label:after,.fd-list--multi-input .fd-list__label:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--multi-input .fd-list__label:before{margin-block:-.1875rem -.1875rem}.fd-list--multi-input .fd-list__input.is-focus,.fd-list--multi-input .fd-list__input:focus{-webkit-box-shadow:none;box-shadow:none;z-index:5}.fd-list--multi-input .fd-list__input.is-focus+.fd-list__label:after,.fd-list--multi-input .fd-list__input:focus+.fd-list__label:after{inset:.0625rem}.fd-list--multi-input .fd-list__footer{height:auto;text-align:right;-webkit-box-pack:end;-ms-flex-pack:end;background-color:var(--sapList_Background);justify-content:flex-end;line-height:1rem}.fd-list--multi-input .fd-list__footer,.fd-list--multi-input .fd-list__label{padding-block:.75rem;padding-inline:.9375rem}.fd-list--multi-input[class*=-compact] .fd-list__item,.fd-list--multi-input[class*=-condensed] .fd-list__item,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__item,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__item{height:auto;padding-block:0;padding-inline:0}.fd-list--multi-input[class*=-compact] .fd-list__label:before,.fd-list--multi-input[class*=-condensed] .fd-list__label:before,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label:before,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label:before{-webkit-margin-start:0;margin-inline-start:0;margin-top:0;-webkit-margin-after:0;margin-block-end:0}.fd-list--multi-input[class*=-compact] .fd-list__footer,.fd-list--multi-input[class*=-compact] .fd-list__label,.fd-list--multi-input[class*=-condensed] .fd-list__footer,.fd-list--multi-input[class*=-condensed] .fd-list__label,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__footer,[class*=-compact] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__footer,[class*=-condensed] .fd-list--multi-input:not([class*=-cozy]) .fd-list__label{padding-block:.5rem;padding-inline:.9375rem}.fd-list--dropdown,.fd-list--multi-input{display:block;max-width:40rem;min-width:5rem}.fd-list--dropdown .fd-list__item,.fd-list--multi-input .fd-list__item{border:none;cursor:pointer}.fd-list--dropdown .fd-list__item.is-selected,.fd-list--dropdown .fd-list__item[aria-selected=true],.fd-list--multi-input .fd-list__item.is-selected,.fd-list--multi-input .fd-list__item[aria-selected=true]{border-bottom:var(--sapList_BorderWidth) solid var(--sapList_SelectionBorderColor)}.fd-list--dropdown .fd-list__secondary,.fd-list--dropdown .fd-list__title,.fd-list--multi-input .fd-list__secondary,.fd-list--multi-input .fd-list__title{font-size:var(--sapFontSize);white-space:normal;-webkit-box-flex:1;-ms-flex:auto;flex:auto;width:auto}.fd-list--dropdown .fd-list__secondary--no-wrap,.fd-list--dropdown .fd-list__title--no-wrap,.fd-list--multi-input .fd-list__secondary--no-wrap,.fd-list--multi-input .fd-list__title--no-wrap{white-space:nowrap}.fd-list--dropdown .fd-list__secondary,.fd-list--multi-input .fd-list__secondary{display:block}.fd-list--dropdown .fd-list__title,.fd-list--multi-input .fd-list__title{max-width:24rem}.fd-list--dropdown .fd-list__title:first-child:last-child,.fd-list--multi-input .fd-list__title:first-child:last-child{max-width:40rem}.fd-list--dropdown .fd-list__secondary,.fd-list--multi-input .fd-list__secondary{max-width:16rem}.fd-list--dropdown.fd-list--mobile,.fd-list--multi-input.fd-list--mobile{max-width:100%}.fd-list--dropdown .fd-list__icon,.fd-list--multi-input .fd-list__icon{line-height:1rem}.fd-list--dropdown.fd-list--large-dropdown,.fd-list--multi-input.fd-list--large-dropdown{max-width:62rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__title,.fd-list--multi-input.fd-list--large-dropdown .fd-list__title{max-width:37.2rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__title:first-child:last-child,.fd-list--multi-input.fd-list--large-dropdown .fd-list__title:first-child:last-child{max-width:62rem}.fd-list--dropdown.fd-list--large-dropdown .fd-list__secondary,.fd-list--multi-input.fd-list--large-dropdown .fd-list__secondary{max-width:24.8rem}.fd-list--dropdown.fd-list--large-dropdown.fd-list--mobile,.fd-list--multi-input.fd-list--large-dropdown.fd-list--mobile{max-width:100%}.fd-list--byline .fd-list__item{height:auto;min-height:5rem;padding-block:.9375rem;padding-inline:1rem;width:100%;-webkit-box-align:start;-ms-flex-align:start;align-items:flex-start}.fd-list--byline .fd-list__item.is-focus,.fd-list--byline .fd-list__item:focus{pointer-events:all;z-index:5}.fd-list--byline .fd-list__item .fd-list__item-counter{-ms-flex-align:center;-ms-flex-item-align:center;align-self:center;-webkit-box-pack:end;-ms-flex-pack:end;height:100%;justify-content:flex-end;min-width:2rem}.fd-list--byline .fd-list__item .fd-list__item-counter,.fd-list--byline .fd-list__thumbnail{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;align-items:center}.fd-list--byline .fd-list__thumbnail{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;pointer-events:none;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-ms-flex-align:center;-webkit-margin-end:.75rem;border-radius:.25rem;color:var(--sapContent_NonInteractiveIconColor);font-size:2rem;height:3rem;margin-inline-end:.75rem;max-height:3rem;max-width:3rem;min-height:3rem;min-width:3rem;width:3rem}.fd-list--byline .fd-list__thumbnail:after,.fd-list--byline .fd-list__thumbnail:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__thumbnail [class*=sap-icon],.fd-list--byline .fd-list__thumbnail[class*=sap-icon]{background:inherit;border-radius:inherit;color:inherit;font-size:inherit;line-height:1}.fd-list--byline .fd-list__thumbnail>svg{height:100%}.fd-list--byline .fd-list__notification{color:var(--sapAccentColor6);font-size:.375rem;left:1rem;position:absolute;top:50%;-webkit-transform:translateY(-50%);transform:translateY(-50%)}.fd-list--byline .fd-list__notification[dir=rtl],[dir=rtl] .fd-list--byline .fd-list__notification{left:auto;right:1rem}.fd-list--byline .fd-list__notification+.fd-list__link .fd-list__content .fd-list__title,.fd-list--byline .fd-list__notification~.fd-list__content .fd-list__title{font-weight:700}.fd-list--byline .fd-list__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;pointer-events:none;-ms-flex-line-pack:justify;align-content:space-between;height:100%;min-height:3rem;min-width:3rem;-webkit-box-flex:1;-ms-flex:1 1 auto;flex:1 1 auto;padding-block:.125rem;padding-inline:0}.fd-list--byline .fd-list__content:after,.fd-list--byline .fd-list__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__title{font-size:var(--sapFontLargeSize);min-height:1rem;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list--byline .fd-list__byline{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-list--byline .fd-list__byline:after,.fd-list--byline .fd-list__byline:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline--2-col{display:-webkit-box;display:-ms-flexbox;display:flex;pointer-events:all}.fd-list--byline .fd-list__byline--wrap .fd-list__byline-left,.fd-list--byline .fd-list__byline--wrap .fd-list__byline-right{display:inline;padding-block:0;padding-inline:0;white-space:normal;width:100%}.fd-list--byline .fd-list__byline--wrap .fd-list__byline-right{float:right;width:auto}.fd-list--byline .fd-list__link--more{pointer-events:all;text-transform:capitalize}.fd-list--byline .fd-list__byline--wrap,.fd-list--byline .fd-list__title--wrap{white-space:normal}.fd-list--byline .fd-list__byline-left{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;width:60%;-ms-flex-item-align:end;align-self:flex-end;-webkit-padding-end:.5rem;padding-inline-end:.5rem}.fd-list--byline .fd-list__byline-left:after,.fd-list--byline .fd-list__byline-left:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline-right{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;line-height:1rem;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-align:right;text-overflow:ellipsis;white-space:nowrap;width:40%;-ms-flex-item-align:end;align-self:flex-end;-webkit-padding-start:.5rem;padding-inline-start:.5rem}.fd-list--byline .fd-list__byline-right:after,.fd-list--byline .fd-list__byline-right:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--byline .fd-list__byline-right[dir=rtl],[dir=rtl] .fd-list--byline .fd-list__byline-right{text-align:left}.fd-list--byline .fd-list__byline-right--neutral{color:var(--sapNeutralTextColor)}.fd-list--byline .fd-list__byline-right--positive{color:var(--sapPositiveTextColor)}.fd-list--byline .fd-list__byline-right--critical{color:var(--sapCriticalTextColor)}.fd-list--byline .fd-list__byline-right--negative{color:var(--sapNegativeTextColor)}.fd-list--byline .fd-list__byline-right--informative{color:var(--sapInformativeTextColor)}.fd-list--byline.fd-list--unread-indicator .fd-list__item{padding-inline:2.125rem 1rem}.fd-list--byline[class*=-compact] .fd-list__title,.fd-list--byline[class*=-condensed] .fd-list__title,[class*=-compact] .fd-list--byline:not([class*=-cozy]) .fd-list__title,[class*=-condensed] .fd-list--byline:not([class*=-cozy]) .fd-list__title{font-size:var(--sapFontSize)}.fd-list--byline.fd-list--no-border .fd-list__item{height:100%;max-height:5rem;padding-block:.5rem}.fd-list--byline.fd-list--no-border .fd-list__item:first-child{-webkit-padding-before:.9375rem;padding-block-start:.9375rem}.fd-list--byline.fd-list--no-border .fd-list__item:last-child{-webkit-padding-after:.9375rem;padding-block-end:.9375rem}.fd-list--message-view{--fdListNavigationIndicatorFontSize:.75rem;--fdList_Item_Height:calc(2.75rem + var(--sapList_BorderWidth));--fdList_Message_View_Item_Byline_Height:calc(3.325rem + var(--sapList_BorderWidth));--fdList_Message_View_Title_Size:var(--sapFontHeader5Size)}.fd-list--message-view .fd-list__item{height:auto}.fd-list--message-view .fd-list__item--byline{--fdList_Item_Height:var(--fdList_Message_View_Item_Byline_Height)}.fd-list--message-view .fd-list__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-flex:1;-ms-flex:1 1 auto;flex:1 1 auto;overflow:hidden;pointer-events:none;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__content:after,.fd-list--message-view .fd-list__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-list--message-view .fd-list__title{color:var(--sapGroup_TitleTextColor);font-family:var(--sapFontHeaderFamily);font-size:var(--fdList_Message_View_Title_Size);font-weight:var(--sapFontHeaderWeight,normal);overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__subtitle{-webkit-padding-before:.25rem;color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);overflow:hidden;padding-block-start:.25rem;text-overflow:ellipsis;white-space:nowrap}.fd-list--message-view .fd-list__link{padding-block:.5rem}.fd-list--message-view .fd-list__link.is-active .fd-list__subtitle,.fd-list--message-view .fd-list__link.is-active .fd-list__title,.fd-list--message-view .fd-list__link.is-active .fd-object-status .fd-object-status__icon,.fd-list--message-view .fd-list__link:active .fd-list__subtitle,.fd-list--message-view .fd-list__link:active .fd-list__title,.fd-list--message-view .fd-list__link:active .fd-object-status .fd-object-status__icon{color:var(--sapList_Active_TextColor)}.fd-list--message-view[class*=-compact],.fd-list--message-view[class*=-condensed],[class*=-compact] .fd-list--message-view:not([class*=-cozy]),[class*=-condensed] .fd-list--message-view:not([class*=-cozy]){--fdList_Message_View_Item_Height:calc(2rem + var(--sapList_BorderWidth));--fdList_Message_View_Title_Size:var(--sapFontHeader6Size);--fdList_Message_View_Item_Byline_Height:calc(3.25rem + var(--sapList_BorderWidth))}.fd-list--navigation .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-icon-tab-bar__list .fd-list__link{gap:.25rem}.fd-list--navigation .fd-list__link{padding-inline:var(--fdList_Navigation_Link_Padding_Left,.9375rem) var(--fdList_Navigation_Link_Padding_Right,.9375rem)}.fd-list--navigation.fd-list--unread-indicator{--fdList_Navigation_Link_Padding_Left:2.125rem;--fdList_Navigation_Link_Padding_Right:.9375rem}.fd-list--navigation.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:.9375rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--selection{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:.9375rem}.fd-list--navigation.fd-list--selection .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--selection.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--selection.fd-list--navigation-indication .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline,.fd-list--navigation.fd-list--byline.fd-list--compact{--fdList_Navigation_Link_Padding_Left:1rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--compact .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline .fd-list__link,.fd-list--navigation.fd-list--byline.fd-list--compact .fd-list__link{padding-block:.9375rem}.fd-list--navigation.fd-list--byline.fd-list--compact.fd-list--unread-indicator,.fd-list--navigation.fd-list--byline.fd-list--unread-indicator{--fdList_Navigation_Link_Padding_Left:2.125rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:.9375rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--byline.fd-list--selection{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-compact],.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-condensed],[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]),[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]){--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-compact] .fd-list__item--link,.fd-list--navigation.fd-list--byline.fd-list--selection[class*=-condensed] .fd-list__item--link,[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]) .fd-list__item--link,[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection:not([class*=-cozy]) .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication{--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication[class*=-compact],.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication[class*=-condensed],[class*=-compact] .fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication:not([class*=-cozy]),[class*=-condensed] .fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication:not([class*=-cozy]){--fdList_Navigation_Link_Padding_Left:2.75rem;--fdList_Navigation_Link_Padding_Right:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link .fd-list__link{padding-block:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child{-webkit-padding-before:0;padding-block-start:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child .fd-list__link{-webkit-padding-before:1rem;padding-block-start:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:first-child .fd-list__link--navigation-indicator:after{-webkit-margin-after:.5rem;margin-block-end:.5rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child{-webkit-padding-after:0;padding-block-end:0}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child .fd-list__link{-webkit-padding-after:1rem;padding-block-end:1rem}.fd-list--navigation.fd-list--byline.fd-list--selection.fd-list--navigation-indication.fd-list--no-border .fd-list__item--link:last-child .fd-list__link--navigation-indicator:after{margin-top:.25rem}.fd-list--navigation.fd-list--navigation-object{--fdList_Navigation_Link_Padding_Left:1rem;--fdList_Navigation_Link_Padding_Right:1rem}.fd-list--navigation.fd-list--navigation-object .fd-list__item--link,.fd-list--navigation.fd-list--navigation-object[dir=rtl] .fd-list__item--link,[dir=rtl] .fd-list--navigation.fd-list--navigation-object .fd-list__item--link{padding-block:0;padding-inline:0}.fd-list--navigation.fd-list--navigation-object .fd-list__link{padding-block:1rem}.fd-list--navigation-indication .fd-list:after{content:\"\";min-width:1.5rem}.fd-list--navigation-indication fd-list__item.fd-list__item--link{-webkit-padding-end:0;padding-inline-end:0}.fd-list--navigation-indication fd-list__item.fd-list__item--link:after{content:none}.fd-list--navigation-indication .fd-list__link:after{content:\"\";min-width:2.5rem}.fd-list--navigation-indication .fd-list__link--navigation-indicator:after{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:var(--sapContent_NonInteractiveIconColor);content:\"\\e1ed\";font-family:SAP-icons;font-size:var(--fdListNavigationIndicatorFontSize,var(--sapFontLargeSize));height:100%;text-decoration:none;text-transform:none}.fd-list--navigation-indication .fd-list__link--navigation-indicator[dir=rtl]:after,[dir=rtl] .fd-list--navigation-indication .fd-list__link--navigation-indicator:after{content:\"\\e1ee\"}.fd-list--navigation-indication .fd-list__icon:last-child,.fd-list--navigation-indication .fd-list__icon[dir=rtl]:last-child,[dir=rtl] .fd-list--navigation-indication .fd-list__icon:last-child{margin-block:0;margin-inline:0}.fd-list--navigation-indication .is-navigated{-webkit-box-shadow:inset -.1875rem 0 0 0 var(--sapList_SelectionBorderColor);box-shadow:inset -.1875rem 0 0 0 var(--sapList_SelectionBorderColor)}.fd-list--navigation-indication .is-navigated[dir=rtl],[dir=rtl] .fd-list--navigation-indication .is-navigated{-webkit-box-shadow:inset .1875rem 0 0 0 var(--sapList_SelectionBorderColor);box-shadow:inset .1875rem 0 0 0 var(--sapList_SelectionBorderColor)}.fd-list--selection .fd-list__item{cursor:pointer;padding-inline:2.75rem .9375rem}.fd-list--selection .fd-list__item.is-hover,.fd-list--selection .fd-list__item:hover{--fdList_Item_Background_Color:var(--sapList_Hover_Background)}.fd-list--selection .fd-list__item.is-selected,.fd-list--selection .fd-list__item[aria-selected=true]{--fdList_Item_Background_Color:var(--sapList_SelectionBackgroundColor);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_SelectionBorderColor)}.fd-list--selection .fd-list__item.is-selected .fd-list__link,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link{background:inherit}.fd-list--selection .fd-list__item.is-selected .fd-list__link.is-active,.fd-list--selection .fd-list__item.is-selected .fd-list__link:active,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link.is-active,.fd-list--selection .fd-list__item[aria-selected=true] .fd-list__link:active{--fdList_Item_Background_Color:var(--sapList_Active_Background)}.fd-list--selection .fd-list__item.is-selected.is-hover,.fd-list--selection .fd-list__item.is-selected:hover,.fd-list--selection .fd-list__item[aria-selected=true].is-hover,.fd-list--selection .fd-list__item[aria-selected=true]:hover{--fdList_Item_Background_Color:var(--sapList_Hover_SelectionBackground)}.fd-list--selection .fd-list__form-item{left:0;position:absolute;top:0;z-index:5}.fd-list--selection .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection .fd-list__form-item{left:auto;right:0}.fd-list--selection[class*=-compact] .fd-list__form-item,.fd-list--selection[class*=-condensed] .fd-list__form-item,[class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item,[class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item{left:.375rem}.fd-list--selection[class*=-compact] .fd-list__form-item[dir=rtl],.fd-list--selection[class*=-condensed] .fd-list__form-item[dir=rtl],[class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection[class*=-compact] .fd-list__form-item,[dir=rtl] .fd-list--selection[class*=-condensed] .fd-list__form-item,[dir=rtl] [class*=-compact] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item,[dir=rtl] [class*=-condensed] .fd-list--selection:not([class*=-cozy]) .fd-list__form-item{left:auto;right:.375rem}.fd-list--selection.fd-list--byline .fd-list__item{padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline .fd-list__form-item{top:.3125rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__item,.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__item,[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__item,[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__item{padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item,.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item,[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item,[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item{left:.375rem;top:.5rem}.fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item[dir=rtl],.fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item[dir=rtl],[class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item[dir=rtl],[dir=rtl] .fd-list--selection.fd-list--byline[class*=-compact] .fd-list__form-item,[dir=rtl] .fd-list--selection.fd-list--byline[class*=-condensed] .fd-list__form-item,[dir=rtl] [class*=-compact] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item,[dir=rtl] [class*=-condensed] .fd-list--selection.fd-list--byline:not([class*=-cozy]) .fd-list__form-item{left:auto;right:.375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item{padding-block:.5rem;padding-inline:2.75rem 1rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:first-child{-webkit-padding-before:.9375rem;padding-block-start:.9375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:last-child{-webkit-padding-after:.9375rem;padding-block-end:.9375rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item{top:0}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item label,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item label{-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item label:after,.fd-list--selection.fd-list--byline.fd-list--no-border .fd-list__item:not(:first-child) .fd-list__form-item.fd-form-item label:after{top:.375rem}.fd-list--selection.fd-list--selection-row .fd-list__item{-webkit-padding-start:1rem;padding-inline-start:1rem}:root{--fdList_Item_Background_Color:var(--sapList_Background);--fdList_Item_Text_Color:var(--sapList_TextColor);--fdList_Item_Border_Color:var(--sapList_BorderColor);--fdList_Item_Text_Font_Size:var(--sapFontLargeSize);--fdList_Item_Icon_Font_Size:1.125rem;--fdList_Item_Height:var(--sapElement_LineHeight);--fdList_Status_Text_Color:var(--sapNeutralTextColor);--fdList_Message_Background_Color:var(--sapNeutralBackground)}.fd-list__item-counter{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-margin-start:1rem;color:var(--sapContent_MarkerTextColor);margin-inline-start:1rem}.fd-list__item-counter:after,.fd-list__item-counter:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list .fd-object-list__item{padding-block:1rem;--fdList_Item_Height:100%}.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-avatar,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-identifier__title,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-list__intro,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-list__object-attribute,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-marker__icon,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-marker__text,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-number__text,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-number__unit,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-status__icon,.fd-object-list .fd-object-list__item .fd-list__link.is-active .fd-object-status__text,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-avatar,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-identifier__title,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-list__intro,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-list__object-attribute,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-marker__icon,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-marker__text,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-number__text,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-number__unit,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-status__icon,.fd-object-list .fd-object-list__item .fd-list__link:active .fd-object-status__text{color:var(--sapList_Active_TextColor);text-shadow:none}.fd-object-list__intro{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;max-width:100%;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;width:100%;-webkit-padding-after:.75rem;color:var(--sapContent_LabelColor);padding-block-end:.75rem}.fd-object-list__intro:after,.fd-object-list__intro:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__container{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;height:100%;width:100%}.fd-object-list__container:after,.fd-object-list__container:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__header{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.75rem}.fd-object-list__header:after,.fd-object-list__header:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__header-left{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-align:left;width:60%}.fd-object-list__header-left:after,.fd-object-list__header-left:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__header-left[dir=rtl],[dir=rtl] .fd-object-list__header-left{text-align:right}.fd-object-list__header-right{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;text-align:right;width:40%;-webkit-margin-start:.25rem;margin-inline-start:.25rem}.fd-object-list__header-right:after,.fd-object-list__header-right:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__header-right[dir=rtl],[dir=rtl] .fd-object-list__header-right{text-align:left}.fd-object-list__row{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;padding-block:0;padding-inline:0;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;gap:.5rem;-webkit-padding-before:.5rem;padding-block-start:.5rem}.fd-object-list__row:after,.fd-object-list__row:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__row-left,.fd-object-list__row-right{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);display:-webkit-box;display:-ms-flexbox;display:flex;font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap;-webkit-box-align:center;-ms-flex-align:center;align-items:center;line-height:1;width:50%}.fd-object-list__row-left:after,.fd-object-list__row-left:before,.fd-object-list__row-right:after,.fd-object-list__row-right:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__row-left:only-child,.fd-object-list__row-right:only-child{width:100%}.fd-object-list__row-right{-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end}.fd-object-list__row-right .fd-object-status__text{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.fd-object-list__content{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;margin-top:.25rem;padding-block:0;padding-inline:0}.fd-object-list__content:after,.fd-object-list__content:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__object-number .fd-object-number__text{display:block;font-size:var(--fdObject_List_Number_Font_Size)}.fd-object-list__object-number .fd-object-number__text:after{content:none}.fd-object-list__object-identifier .fd-object-identifier__title{display:-webkit-box;-webkit-line-clamp:2;-webkit-box-orient:vertical;color:var(--sapGroup_TitleTextColor);font-size:var(--fdObject_List_Title_Font_Size);font-weight:var(--fdObject_List_Title_Font_Weight);line-height:1.5;overflow:hidden;text-overflow:ellipsis;white-space:normal}.fd-object-list__object-attribute{border:0;-webkit-box-sizing:border-box;box-sizing:border-box;color:var(--sapTextColor);color:var(--sapContent_LabelColor);font-family:var(--sapFontFamily);font-size:var(--sapFontSize);font-weight:400;forced-color-adjust:none;line-height:normal;margin-block:0;margin-inline:0;overflow:hidden;padding-block:0;padding-inline:0;text-overflow:ellipsis;white-space:nowrap}.fd-object-list__object-attribute:after,.fd-object-list__object-attribute:before{-webkit-box-sizing:inherit;box-sizing:inherit;font-size:inherit}.fd-object-list__row{align-items:normal}\n/*! Bundled license information:\n\nfundamental-styles/dist/object-list.css:\n  (*!\n   * Fundamental Library Styles v0.38.0\n   * Copyright (c) 2024 SAP SE or an SAP affiliate company.\n   * Licensed under Apache License 2.0 (https://github.com/SAP/fundamental-styles/blob/main/LICENSE)\n   *)\n*/\n"] }]
        }], propDecorators: { introductionText: [{
                type: Input
            }], amount: [{
                type: Input
            }], currency: [{
                type: Input
            }], decimal: [{
                type: Input
            }], numberStatus: [{
                type: Input
            }], label: [{
                type: Input
            }], glyph: [{
                type: Input
            }], circle: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], tile: [{
                type: Input
            }], colorAccent: [{
                type: Input
            }], image: [{
                type: Input
            }], transparent: [{
                type: Input
            }], children: [{
                type: ContentChildren,
                args: [ObjectListItemRowComponent]
            }] } });

class ObjectListItemModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ObjectListItemModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.0.7", ngImport: i0, type: ObjectListItemModule, imports: [ObjectListItemComponent, ObjectListItemRowComponent, ContentDensityModule], exports: [ObjectListItemComponent, ObjectListItemRowComponent, ContentDensityModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ObjectListItemModule, imports: [ObjectListItemComponent, ObjectListItemRowComponent, ContentDensityModule, ContentDensityModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: ObjectListItemModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [ObjectListItemComponent, ObjectListItemRowComponent, ContentDensityModule],
                    exports: [ObjectListItemComponent, ObjectListItemRowComponent, ContentDensityModule]
                }]
        }] });

class StandardListItemComponent extends BaseListItem {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: StandardListItemComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.0.7", type: StandardListItemComponent, isStandalone: true, selector: "fdp-standard-list-item", host: { attributes: { "role": "none" } }, providers: [{ provide: BaseListItem, useExisting: forwardRef(() => StandardListItemComponent) }], usesInheritance: true, ngImport: i0, template: "<!--  list item navigation with Arrow-->\n@if (navigationIndicator || (navigated && !(noDataText !== null && noDataText !== undefined))) {\n    <div\n        #listItem\n        [unread]=\"unRead\"\n        fd-list-item\n        [id]=\"id\"\n        [selected]=\"_selected\"\n        [tabindex]=\"-1\"\n        (keydown)=\"_onKeyDown($event)\"\n        (keyup)=\"_onKeyUp($event)\"\n        class=\"fd-list__item--link\"\n        [class.fd-list__item--inactive]=\"listType === 'inactive'\"\n        [attr.aria-label]=\"ariaLabel\"\n        [attr.aria-describedby]=\"ariaDescribedBy\"\n        [attr.aria-level]=\"ariaLevel\"\n        [attr.aria-posinset]=\"ariaPosinset\"\n        [ariaRole]=\"_listItemRole\"\n        [attr.aria-selected]=\"_selectedAttr\"\n        [attr.aria-setsize]=\"ariaSetSize | async\"\n    >\n        <ng-template [ngTemplateOutlet]=\"selectionTemplate\"> </ng-template>\n        <a\n            #linkElement\n            fd-list-link\n            [routerLink]=\"link\"\n            [navigationIndicator]=\"navigationIndicator\"\n            [navigated]=\"navigated\"\n        >\n            <ng-template [ngTemplateOutlet]=\"_hasByLine ? byLineTemplate : commonTemplate\"></ng-template>\n        </a>\n    </div>\n}\n<!--  list item without navigation and used for simple list display-->\n@if (!navigationIndicator && !navigated && !(noDataText !== null && noDataText !== undefined)) {\n    <div\n        #listItem\n        [unread]=\"unRead\"\n        fd-list-item\n        [id]=\"id\"\n        [selected]=\"_selected\"\n        (keydown)=\"_onKeyDown($event)\"\n        [tabindex]=\"-1\"\n        (keyup)=\"_onKeyUp($event)\"\n        [attr.aria-label]=\"ariaLabel\"\n        [attr.aria-describedby]=\"ariaDescribedBy\"\n        [attr.aria-level]=\"ariaLevel\"\n        [attr.aria-posinset]=\"ariaPosinset\"\n        [class.fd-list__item--inactive]=\"listType === 'inactive'\"\n        [ariaRole]=\"_listItemRole\"\n        [attr.aria-selected]=\"_selectedAttr\"\n        [attr.aria-setsize]=\"ariaSetSize | async\"\n    >\n        <ng-template [ngTemplateOutlet]=\"selectionTemplate\"></ng-template>\n        <ng-template [ngTemplateOutlet]=\"_hasByLine ? byLineTemplate : commonTemplate\"></ng-template>\n    </div>\n}\n@if (noDataText !== null && noDataText !== undefined) {\n    <div\n        #listItem\n        fd-list-item\n        [id]=\"id\"\n        [tabindex]=\"0\"\n        [attr.aria-label]=\"ariaLabel\"\n        [attr.aria-level]=\"ariaLevel\"\n        [attr.aria-posinset]=\"ariaPosinset\"\n        [attr.aria-setsize]=\"ariaSetSize | async\"\n    >\n        <span fd-list-title [attr.aria-label]=\"noDataText\" [attr.title]=\"noDataText\">{{ noDataText }}</span>\n    </div>\n}\n<ng-template #commonTemplate>\n    @if (icon.glyph) {\n        <fd-icon\n            class=\"fd-list__icon\"\n            [glyph]=\"icon.glyph\"\n            [font]=\"icon.font\"\n            [ariaLabel]=\"icon.ariaLabel\"\n            [attr.alt]=\"icon.ariaLabel\"\n            role=\"img\"\n        >\n        </fd-icon>\n    }\n    @if (avatar.label || avatar.image || avatar.glyph || avatar.zoomGlyph) {\n        <fd-avatar\n            [size]=\"avatar.size\"\n            [glyph]=\"avatar.glyph\"\n            [zoomGlyph]=\"avatar.zoomGlyph\"\n            [label]=\"avatar.label\"\n            [circle]=\"avatar.circle\"\n            [placeholder]=\"avatar.placeholder\"\n            [tile]=\"avatar.tile\"\n            [colorAccent]=\"avatar.colorAccent\"\n            [image]=\"avatar.image\"\n            [transparent]=\"avatar.transparent\"\n            [random]=\"avatar.random\"\n            [class]=\"'fd-list__icon ' + avatar.class\"\n            [ariaLabel]=\"avatar.ariaLabel\"\n            [ariaLabelledby]=\"avatar.ariaLabelledby\"\n            [contain]=\"avatar.contain\"\n            [border]=\"avatar.border\"\n            [alterIcon]=\"avatar.alterIcon\"\n            [backupImage]=\"avatar.backupImage\"\n            [clickable]=\"avatar.clickable\"\n            [attr.alt]=\"avatar.ariaLabel\"\n            role=\"img\"\n        ></fd-avatar>\n    }\n    @if (title) {\n        <span fd-list-title [attr.aria-label]=\"ariaLabel\" [attr.nowrap]=\"titleWrap\" [attr.title]=\"title\">\n            {{ title }}\n        </span>\n    }\n    @if (secondary !== null && secondary !== undefined) {\n        <span fd-list-secondary [attr.aria-label]=\"secondary\" [attr.title]=\"secondary\" [attr.nowrap]=\"secondaryWrap\">\n            {{ secondary }}\n        </span>\n    }\n    @if (counter !== null && counter !== undefined) {\n        <span fd-list-secondary class=\"fd-list__item-counter\" [attr.aria-label]=\"counter\" [attr.title]=\"counter\">\n            {{ counter }}\n        </span>\n    }\n    <ng-template [ngTemplateOutlet]=\"actionsTemplate\"></ng-template>\n</ng-template>\n<ng-template #byLineTemplate>\n    <div fdListThumbnail>\n        @if (icon.glyph) {\n            <fd-icon\n                class=\"fd-list__icon\"\n                [glyph]=\"icon.glyph\"\n                [font]=\"icon.font\"\n                [ariaLabel]=\"icon.ariaLabel\"\n                [attr.alt]=\"icon.ariaLabel\"\n                role=\"img\"\n            >\n            </fd-icon>\n        }\n        @if (avatar.label || avatar.image || avatar.glyph || avatar.zoomGlyph) {\n            <fd-avatar\n                [size]=\"avatar.size\"\n                [glyph]=\"avatar.glyph\"\n                [zoomGlyph]=\"avatar.zoomGlyph\"\n                [label]=\"avatar.label\"\n                [circle]=\"avatar.circle\"\n                [placeholder]=\"avatar.placeholder\"\n                [tile]=\"avatar.tile\"\n                [colorAccent]=\"avatar.colorAccent\"\n                [image]=\"avatar.image\"\n                [transparent]=\"avatar.transparent\"\n                [random]=\"avatar.random\"\n                [class]=\"avatar.class\"\n                [ariaLabel]=\"avatar.ariaLabel\"\n                [ariaLabelledby]=\"avatar.ariaLabelledby\"\n                [contain]=\"avatar.contain\"\n                [border]=\"avatar.border\"\n                [alterIcon]=\"avatar.alterIcon\"\n                [backupImage]=\"avatar.backupImage\"\n                [clickable]=\"avatar.clickable\"\n                [attr.alt]=\"avatar.ariaLabel\"\n                role=\"img\"\n            ></fd-avatar>\n        }\n    </div>\n    <div class=\"fd-list__content\">\n        @if (title) {\n            <div fd-list-title [attr.aria-label]=\"title\" [attr.nowrap]=\"titleWrap\" [attr.title]=\"title\">\n                {{ title }}\n            </div>\n        }\n        <div class=\"fd-list__byline fd-list__byline--2-col\">\n            @if (description) {\n                <ng-template\n                    [ngTemplateOutlet]=\"_isAdvancedText(description) ? advancedDescription : simpleDescription\"\n                    [ngTemplateOutletContext]=\"{ $implicit: description }\"\n                ></ng-template>\n            }\n            @if (secondary) {\n                <ng-template\n                    [ngTemplateOutlet]=\"_isAdvancedText(secondary) ? advancedSecondary : simpleSecondary\"\n                    [ngTemplateOutletContext]=\"{ $implicit: secondary }\"\n                ></ng-template>\n            }\n        </div>\n    </div>\n    <ng-template [ngTemplateOutlet]=\"actionsTemplate\"></ng-template>\n</ng-template>\n<ng-template #selectionTemplate>\n    @if ((selectionMode === 'multi' || selectionMode === 'single') && !rowSelection) {\n        <div fd-form-item class=\"fd-list__form-item\">\n            @if (selectionMode === 'multi') {\n                <fd-checkbox\n                    (click)=\"$event.stopPropagation()\"\n                    [(ngModel)]=\"_selected\"\n                    [ariaLabel]=\"ariaLabel\"\n                    tabIndexValue=\"-1\"\n                    (ngModelChange)=\"_onCheckboxModelChange()\"\n                    [attr.aria-selected]=\"_selected\"\n                >\n                </fd-checkbox>\n            }\n            @if (selectionMode === 'single') {\n                <fd-radio-button\n                    [value]=\"value\"\n                    [name]=\"name\"\n                    role=\"radio\"\n                    [(ngModel)]=\"selectionValue\"\n                    [attr.aria-selected]=\"_selected\"\n                >\n                </fd-radio-button>\n            }\n        </div>\n    }\n</ng-template>\n<ng-template #actionsTemplate>\n    <ng-content select=\"#secondaryAction\"></ng-content>\n    @if (listType === 'detail') {\n        <button\n            fd-button\n            #edit\n            [attr.id]=\"'detail-' + id\"\n            role=\"button\"\n            fdType=\"transparent\"\n            glyph=\"edit\"\n            (click)=\"_onActionButtonClick('edit')\"\n            [attr.aria-label]=\"'platformStandardListItem.detailsActionAriaLabel' | fdTranslate\"\n            [attr.title]=\"'platformStandardListItem.detailsActionAriaLabel' | fdTranslate\"\n            (keydown)=\"_onKeyButtonClick($event, 'edit')\"\n        ></button>\n    }\n    @if (selectionMode === 'delete') {\n        <button\n            fd-button\n            #delete\n            [attr.id]=\"'delete-' + id\"\n            role=\"button\"\n            [attr.aria-label]=\"'platformStandardListItem.deleteActionAriaLabel' | fdTranslate\"\n            [attr.title]=\"'platformStandardListItem.deleteActionAriaLabel' | fdTranslate\"\n            fdType=\"transparent\"\n            glyph=\"decline\"\n            (click)=\"_onActionButtonClick('delete')\"\n            (keydown)=\"_onKeyButtonClick($event, 'delete')\"\n        ></button>\n    }\n</ng-template>\n<ng-template #simpleDescription let-description>\n    <span\n        class=\"fd-list__byline-left\"\n        [attr.aria-label]=\"description\"\n        [attr.title]=\"description\"\n        [attr.nowrap]=\"titleWrap\"\n    >\n        {{ description }}\n    </span>\n</ng-template>\n<ng-template #advancedDescription let-description>\n    <span\n        class=\"fd-list__byline-left\"\n        [attr.aria-label]=\"description.ariaLabel ?? description.text\"\n        [attr.title]=\"description.title ?? description.text\"\n        [attr.nowrap]=\"titleWrap\"\n    >\n        {{ description.text }}\n    </span>\n</ng-template>\n<ng-template #simpleSecondary let-secondary>\n    @if (!inverted) {\n        <span\n            [attr.aria-label]=\"secondary\"\n            class=\"fd-list__byline-right\"\n            [class]=\"statusType ? 'fd-list__byline-right--' + statusType : ''\"\n            [attr.title]=\"secondary\"\n            [attr.nowrap]=\"secondaryWrap\"\n        >\n            {{ secondary }}\n        </span>\n    } @else {\n        <span\n            class=\"fd-list__byline-right\"\n            [attr.aria-label]=\"secondary\"\n            [attr.title]=\"secondary\"\n            [attr.nowrap]=\"secondaryWrap\"\n        >\n            <fdp-object-status [status]=\"statusType\" [inverted]=\"inverted\" [label]=\"secondary\"></fdp-object-status>\n        </span>\n    }\n</ng-template>\n<ng-template #advancedSecondary let-secondary>\n    @if (!inverted) {\n        <span\n            [attr.aria-label]=\"secondary.ariaLabel ?? secondary.text\"\n            class=\"fd-list__byline-right\"\n            [class]=\"statusType ? 'fd-list__byline-right--' + statusType : ''\"\n            [attr.title]=\"secondary.title ?? secondary.text\"\n            [attr.nowrap]=\"secondaryWrap\"\n        >\n            {{ secondary.text }}\n        </span>\n    } @else {\n        <span\n            class=\"fd-list__byline-right\"\n            [attr.aria-label]=\"secondary.ariaLabel ?? secondary.text\"\n            [attr.title]=\"secondary.title ?? secondary.text\"\n            [attr.nowrap]=\"secondaryWrap\"\n        >\n            <fdp-object-status [status]=\"statusType\" [inverted]=\"inverted\" [label]=\"secondary.text\"></fdp-object-status>\n        </span>\n    }\n</ng-template>\n", dependencies: [{ kind: "component", type: ListItemComponent, selector: "[fdListItem] ,[fd-list-item]", inputs: ["selected", "noData", "action", "interactive", "growing", "counter", "unread", "byline", "ariaRole", "id", "preventClick"], outputs: ["keyDown"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: ListLinkDirective, selector: "[fd-list-link], [fdListLink]", inputs: ["navigationIndicator", "navigated", "focusable"] }, { kind: "directive", type: RouterLink, selector: "[routerLink]", inputs: ["target", "queryParams", "fragment", "queryParamsHandling", "state", "info", "relativeTo", "preserveFragment", "skipLocationChange", "replaceUrl", "routerLink"] }, { kind: "directive", type: ListTitleDirective, selector: "[fd-list-title], [fdListTitle]", inputs: ["wrap"] }, { kind: "component", type: IconComponent, selector: "fd-icon", inputs: ["glyph", "font", "color", "background", "class", "ariaLabel", "ariaHidden"] }, { kind: "component", type: AvatarComponent, selector: "fd-avatar", inputs: ["class", "id", "ariaLabel", "ariaLabelledby", "label", "size", "font", "glyph", "zoomGlyph", "circle", "transparent", "contain", "placeholder", "tile", "border", "colorAccent", "colorIndication", "random", "clickable", "valueState", "image", "alterIcon", "backupImage"], outputs: ["avatarClicked", "zoomGlyphClicked"] }, { kind: "directive", type: ListSecondaryDirective, selector: "[fd-list-secondary], [fdListSecondary]", inputs: ["type"] }, { kind: "directive", type: ListThumbnailDirective, selector: "[fdListThumbnail], [fd-list-thumbnail]" }, { kind: "component", type: FormItemComponent, selector: "[fd-form-item]", inputs: ["isInline", "horizontal"] }, { kind: "component", type: CheckboxComponent, selector: "fd-checkbox", inputs: ["wrapLabel", "valignLabel", "ariaLabel", "role", "value", "ariaLabelledBy", "ariaDescribedBy", "title", "inputId", "state", "name", "label", "disabled", "readonly", "tristate", "tristateSelectable", "labelClass", "required", "displayOnly", "values", "standalone"], outputs: ["focusChange"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: RadioButtonComponent, selector: "fd-radio-button", inputs: ["ariaLabel", "ariaLabelledBy", "ariaDescribedBy", "title", "tabIndex", "state", "disabled", "readOnly", "selectedValue", "name", "id", "value", "required", "standalone", "wrapLabel", "valignLabel"] }, { kind: "component", type: ButtonComponent, selector: "button[fd-button], a[fd-button], span[fd-button]", inputs: ["class"], exportAs: ["fd-button"] }, { kind: "component", type: ObjectStatusComponent, selector: "fdp-object-status", inputs: ["status", "glyph", "glyphFont", "indicationColor", "secondaryIndication", "clickable", "inverted", "large", "label", "ariaLabel", "title"], outputs: ["objectStatusClick"] }, { kind: "pipe", type: FdTranslatePipe, name: "fdTranslate" }, { kind: "pipe", type: AsyncPipe, name: "async" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: StandardListItemComponent, decorators: [{
            type: Component,
            args: [{ selector: 'fdp-standard-list-item', providers: [{ provide: BaseListItem, useExisting: forwardRef(() => StandardListItemComponent) }], changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, host: {
                        role: 'none'
                    }, imports: [
                        ListItemComponent,
                        NgTemplateOutlet,
                        ListLinkDirective,
                        RouterLink,
                        ListTitleDirective,
                        IconComponent,
                        AvatarComponent,
                        NgClass,
                        ListSecondaryDirective,
                        ListThumbnailDirective,
                        FormItemComponent,
                        CheckboxComponent,
                        FormsModule,
                        RadioButtonComponent,
                        ButtonComponent,
                        ObjectStatusComponent,
                        FdTranslatePipe,
                        AsyncPipe
                    ], template: "<!--  list item navigation with Arrow-->\n@if (navigationIndicator || (navigated && !(noDataText !== null && noDataText !== undefined))) {\n    <div\n        #listItem\n        [unread]=\"unRead\"\n        fd-list-item\n        [id]=\"id\"\n        [selected]=\"_selected\"\n        [tabindex]=\"-1\"\n        (keydown)=\"_onKeyDown($event)\"\n        (keyup)=\"_onKeyUp($event)\"\n        class=\"fd-list__item--link\"\n        [class.fd-list__item--inactive]=\"listType === 'inactive'\"\n        [attr.aria-label]=\"ariaLabel\"\n        [attr.aria-describedby]=\"ariaDescribedBy\"\n        [attr.aria-level]=\"ariaLevel\"\n        [attr.aria-posinset]=\"ariaPosinset\"\n        [ariaRole]=\"_listItemRole\"\n        [attr.aria-selected]=\"_selectedAttr\"\n        [attr.aria-setsize]=\"ariaSetSize | async\"\n    >\n        <ng-template [ngTemplateOutlet]=\"selectionTemplate\"> </ng-template>\n        <a\n            #linkElement\n            fd-list-link\n            [routerLink]=\"link\"\n            [navigationIndicator]=\"navigationIndicator\"\n            [navigated]=\"navigated\"\n        >\n            <ng-template [ngTemplateOutlet]=\"_hasByLine ? byLineTemplate : commonTemplate\"></ng-template>\n        </a>\n    </div>\n}\n<!--  list item without navigation and used for simple list display-->\n@if (!navigationIndicator && !navigated && !(noDataText !== null && noDataText !== undefined)) {\n    <div\n        #listItem\n        [unread]=\"unRead\"\n        fd-list-item\n        [id]=\"id\"\n        [selected]=\"_selected\"\n        (keydown)=\"_onKeyDown($event)\"\n        [tabindex]=\"-1\"\n        (keyup)=\"_onKeyUp($event)\"\n        [attr.aria-label]=\"ariaLabel\"\n        [attr.aria-describedby]=\"ariaDescribedBy\"\n        [attr.aria-level]=\"ariaLevel\"\n        [attr.aria-posinset]=\"ariaPosinset\"\n        [class.fd-list__item--inactive]=\"listType === 'inactive'\"\n        [ariaRole]=\"_listItemRole\"\n        [attr.aria-selected]=\"_selectedAttr\"\n        [attr.aria-setsize]=\"ariaSetSize | async\"\n    >\n        <ng-template [ngTemplateOutlet]=\"selectionTemplate\"></ng-template>\n        <ng-template [ngTemplateOutlet]=\"_hasByLine ? byLineTemplate : commonTemplate\"></ng-template>\n    </div>\n}\n@if (noDataText !== null && noDataText !== undefined) {\n    <div\n        #listItem\n        fd-list-item\n        [id]=\"id\"\n        [tabindex]=\"0\"\n        [attr.aria-label]=\"ariaLabel\"\n        [attr.aria-level]=\"ariaLevel\"\n        [attr.aria-posinset]=\"ariaPosinset\"\n        [attr.aria-setsize]=\"ariaSetSize | async\"\n    >\n        <span fd-list-title [attr.aria-label]=\"noDataText\" [attr.title]=\"noDataText\">{{ noDataText }}</span>\n    </div>\n}\n<ng-template #commonTemplate>\n    @if (icon.glyph) {\n        <fd-icon\n            class=\"fd-list__icon\"\n            [glyph]=\"icon.glyph\"\n            [font]=\"icon.font\"\n            [ariaLabel]=\"icon.ariaLabel\"\n            [attr.alt]=\"icon.ariaLabel\"\n            role=\"img\"\n        >\n        </fd-icon>\n    }\n    @if (avatar.label || avatar.image || avatar.glyph || avatar.zoomGlyph) {\n        <fd-avatar\n            [size]=\"avatar.size\"\n            [glyph]=\"avatar.glyph\"\n            [zoomGlyph]=\"avatar.zoomGlyph\"\n            [label]=\"avatar.label\"\n            [circle]=\"avatar.circle\"\n            [placeholder]=\"avatar.placeholder\"\n            [tile]=\"avatar.tile\"\n            [colorAccent]=\"avatar.colorAccent\"\n            [image]=\"avatar.image\"\n            [transparent]=\"avatar.transparent\"\n            [random]=\"avatar.random\"\n            [class]=\"'fd-list__icon ' + avatar.class\"\n            [ariaLabel]=\"avatar.ariaLabel\"\n            [ariaLabelledby]=\"avatar.ariaLabelledby\"\n            [contain]=\"avatar.contain\"\n            [border]=\"avatar.border\"\n            [alterIcon]=\"avatar.alterIcon\"\n            [backupImage]=\"avatar.backupImage\"\n            [clickable]=\"avatar.clickable\"\n            [attr.alt]=\"avatar.ariaLabel\"\n            role=\"img\"\n        ></fd-avatar>\n    }\n    @if (title) {\n        <span fd-list-title [attr.aria-label]=\"ariaLabel\" [attr.nowrap]=\"titleWrap\" [attr.title]=\"title\">\n            {{ title }}\n        </span>\n    }\n    @if (secondary !== null && secondary !== undefined) {\n        <span fd-list-secondary [attr.aria-label]=\"secondary\" [attr.title]=\"secondary\" [attr.nowrap]=\"secondaryWrap\">\n            {{ secondary }}\n        </span>\n    }\n    @if (counter !== null && counter !== undefined) {\n        <span fd-list-secondary class=\"fd-list__item-counter\" [attr.aria-label]=\"counter\" [attr.title]=\"counter\">\n            {{ counter }}\n        </span>\n    }\n    <ng-template [ngTemplateOutlet]=\"actionsTemplate\"></ng-template>\n</ng-template>\n<ng-template #byLineTemplate>\n    <div fdListThumbnail>\n        @if (icon.glyph) {\n            <fd-icon\n                class=\"fd-list__icon\"\n                [glyph]=\"icon.glyph\"\n                [font]=\"icon.font\"\n                [ariaLabel]=\"icon.ariaLabel\"\n                [attr.alt]=\"icon.ariaLabel\"\n                role=\"img\"\n            >\n            </fd-icon>\n        }\n        @if (avatar.label || avatar.image || avatar.glyph || avatar.zoomGlyph) {\n            <fd-avatar\n                [size]=\"avatar.size\"\n                [glyph]=\"avatar.glyph\"\n                [zoomGlyph]=\"avatar.zoomGlyph\"\n                [label]=\"avatar.label\"\n                [circle]=\"avatar.circle\"\n                [placeholder]=\"avatar.placeholder\"\n                [tile]=\"avatar.tile\"\n                [colorAccent]=\"avatar.colorAccent\"\n                [image]=\"avatar.image\"\n                [transparent]=\"avatar.transparent\"\n                [random]=\"avatar.random\"\n                [class]=\"avatar.class\"\n                [ariaLabel]=\"avatar.ariaLabel\"\n                [ariaLabelledby]=\"avatar.ariaLabelledby\"\n                [contain]=\"avatar.contain\"\n                [border]=\"avatar.border\"\n                [alterIcon]=\"avatar.alterIcon\"\n                [backupImage]=\"avatar.backupImage\"\n                [clickable]=\"avatar.clickable\"\n                [attr.alt]=\"avatar.ariaLabel\"\n                role=\"img\"\n            ></fd-avatar>\n        }\n    </div>\n    <div class=\"fd-list__content\">\n        @if (title) {\n            <div fd-list-title [attr.aria-label]=\"title\" [attr.nowrap]=\"titleWrap\" [attr.title]=\"title\">\n                {{ title }}\n            </div>\n        }\n        <div class=\"fd-list__byline fd-list__byline--2-col\">\n            @if (description) {\n                <ng-template\n                    [ngTemplateOutlet]=\"_isAdvancedText(description) ? advancedDescription : simpleDescription\"\n                    [ngTemplateOutletContext]=\"{ $implicit: description }\"\n                ></ng-template>\n            }\n            @if (secondary) {\n                <ng-template\n                    [ngTemplateOutlet]=\"_isAdvancedText(secondary) ? advancedSecondary : simpleSecondary\"\n                    [ngTemplateOutletContext]=\"{ $implicit: secondary }\"\n                ></ng-template>\n            }\n        </div>\n    </div>\n    <ng-template [ngTemplateOutlet]=\"actionsTemplate\"></ng-template>\n</ng-template>\n<ng-template #selectionTemplate>\n    @if ((selectionMode === 'multi' || selectionMode === 'single') && !rowSelection) {\n        <div fd-form-item class=\"fd-list__form-item\">\n            @if (selectionMode === 'multi') {\n                <fd-checkbox\n                    (click)=\"$event.stopPropagation()\"\n                    [(ngModel)]=\"_selected\"\n                    [ariaLabel]=\"ariaLabel\"\n                    tabIndexValue=\"-1\"\n                    (ngModelChange)=\"_onCheckboxModelChange()\"\n                    [attr.aria-selected]=\"_selected\"\n                >\n                </fd-checkbox>\n            }\n            @if (selectionMode === 'single') {\n                <fd-radio-button\n                    [value]=\"value\"\n                    [name]=\"name\"\n                    role=\"radio\"\n                    [(ngModel)]=\"selectionValue\"\n                    [attr.aria-selected]=\"_selected\"\n                >\n                </fd-radio-button>\n            }\n        </div>\n    }\n</ng-template>\n<ng-template #actionsTemplate>\n    <ng-content select=\"#secondaryAction\"></ng-content>\n    @if (listType === 'detail') {\n        <button\n            fd-button\n            #edit\n            [attr.id]=\"'detail-' + id\"\n            role=\"button\"\n            fdType=\"transparent\"\n            glyph=\"edit\"\n            (click)=\"_onActionButtonClick('edit')\"\n            [attr.aria-label]=\"'platformStandardListItem.detailsActionAriaLabel' | fdTranslate\"\n            [attr.title]=\"'platformStandardListItem.detailsActionAriaLabel' | fdTranslate\"\n            (keydown)=\"_onKeyButtonClick($event, 'edit')\"\n        ></button>\n    }\n    @if (selectionMode === 'delete') {\n        <button\n            fd-button\n            #delete\n            [attr.id]=\"'delete-' + id\"\n            role=\"button\"\n            [attr.aria-label]=\"'platformStandardListItem.deleteActionAriaLabel' | fdTranslate\"\n            [attr.title]=\"'platformStandardListItem.deleteActionAriaLabel' | fdTranslate\"\n            fdType=\"transparent\"\n            glyph=\"decline\"\n            (click)=\"_onActionButtonClick('delete')\"\n            (keydown)=\"_onKeyButtonClick($event, 'delete')\"\n        ></button>\n    }\n</ng-template>\n<ng-template #simpleDescription let-description>\n    <span\n        class=\"fd-list__byline-left\"\n        [attr.aria-label]=\"description\"\n        [attr.title]=\"description\"\n        [attr.nowrap]=\"titleWrap\"\n    >\n        {{ description }}\n    </span>\n</ng-template>\n<ng-template #advancedDescription let-description>\n    <span\n        class=\"fd-list__byline-left\"\n        [attr.aria-label]=\"description.ariaLabel ?? description.text\"\n        [attr.title]=\"description.title ?? description.text\"\n        [attr.nowrap]=\"titleWrap\"\n    >\n        {{ description.text }}\n    </span>\n</ng-template>\n<ng-template #simpleSecondary let-secondary>\n    @if (!inverted) {\n        <span\n            [attr.aria-label]=\"secondary\"\n            class=\"fd-list__byline-right\"\n            [class]=\"statusType ? 'fd-list__byline-right--' + statusType : ''\"\n            [attr.title]=\"secondary\"\n            [attr.nowrap]=\"secondaryWrap\"\n        >\n            {{ secondary }}\n        </span>\n    } @else {\n        <span\n            class=\"fd-list__byline-right\"\n            [attr.aria-label]=\"secondary\"\n            [attr.title]=\"secondary\"\n            [attr.nowrap]=\"secondaryWrap\"\n        >\n            <fdp-object-status [status]=\"statusType\" [inverted]=\"inverted\" [label]=\"secondary\"></fdp-object-status>\n        </span>\n    }\n</ng-template>\n<ng-template #advancedSecondary let-secondary>\n    @if (!inverted) {\n        <span\n            [attr.aria-label]=\"secondary.ariaLabel ?? secondary.text\"\n            class=\"fd-list__byline-right\"\n            [class]=\"statusType ? 'fd-list__byline-right--' + statusType : ''\"\n            [attr.title]=\"secondary.title ?? secondary.text\"\n            [attr.nowrap]=\"secondaryWrap\"\n        >\n            {{ secondary.text }}\n        </span>\n    } @else {\n        <span\n            class=\"fd-list__byline-right\"\n            [attr.aria-label]=\"secondary.ariaLabel ?? secondary.text\"\n            [attr.title]=\"secondary.title ?? secondary.text\"\n            [attr.nowrap]=\"secondaryWrap\"\n        >\n            <fdp-object-status [status]=\"statusType\" [inverted]=\"inverted\" [label]=\"secondary.text\"></fdp-object-status>\n        </span>\n    }\n</ng-template>\n" }]
        }] });

class StandardListItemModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: StandardListItemModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.0.7", ngImport: i0, type: StandardListItemModule, imports: [StandardListItemComponent, ContentDensityModule], exports: [StandardListItemComponent, ContentDensityModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: StandardListItemModule, imports: [StandardListItemComponent, ContentDensityModule, ContentDensityModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: StandardListItemModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [StandardListItemComponent, ContentDensityModule],
                    exports: [StandardListItemComponent, ContentDensityModule]
                }]
        }] });

const components = [
    ListComponent,
    ListFooterComponent,
    ListGroupHeaderComponent,
    ListItemDef,
    ContentDensityModule,
    StandardListItemModule,
    ObjectListItemModule,
    DisplayListItemModule,
    ActionListItemModule,
    FreeContentListItemComponent,
    LoadMoreContentDirective
];
class PlatformListModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: PlatformListModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.0.7", ngImport: i0, type: PlatformListModule, imports: [ListComponent,
            ListFooterComponent,
            ListGroupHeaderComponent,
            ListItemDef,
            ContentDensityModule,
            StandardListItemModule,
            ObjectListItemModule,
            DisplayListItemModule,
            ActionListItemModule,
            FreeContentListItemComponent,
            LoadMoreContentDirective], exports: [ListComponent,
            ListFooterComponent,
            ListGroupHeaderComponent,
            ListItemDef,
            ContentDensityModule,
            StandardListItemModule,
            ObjectListItemModule,
            DisplayListItemModule,
            ActionListItemModule,
            FreeContentListItemComponent,
            LoadMoreContentDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: PlatformListModule, imports: [ListComponent,
            ContentDensityModule,
            StandardListItemModule,
            ObjectListItemModule,
            DisplayListItemModule,
            ActionListItemModule,
            FreeContentListItemComponent,
            ContentDensityModule,
            StandardListItemModule,
            ObjectListItemModule,
            DisplayListItemModule,
            ActionListItemModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.7", ngImport: i0, type: PlatformListModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [...components],
                    exports: [...components]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ActionChangeEvent, ActionListItemComponent, ActionListItemModule, BaseListItem, DisplayListItemComponent, DisplayListItemModule, FdpListComponent, FreeContentListItemComponent, IS_ACTIVE_CLASS, LIST_ITEM_TYPE, ListAvatarConfig, ListComponent, ListConfig, ListFooterComponent, ListGroupHeaderComponent, ListIconConfig, ListItemDef, LoadMoreContentDirective, ModifyItemEvent, ObjectListItemComponent, ObjectListItemModule, ObjectListItemRowComponent, PlatformListModule, SelectionChangeEvent, StandardListItemComponent, StandardListItemModule };
//# sourceMappingURL=fundamental-ngx-platform-list.mjs.map
